import { Never } from "@responsible-ai/core-ui";
export interface IDatasetSummary {
    featureNames?: string[];
    classNames?: string[];
    categoricalMap?: {
        [key: number]: string[];
    };
}
export declare enum PredictionTypes {
    binaryClassification = "binaryClassification",
    regression = "regression",
    probability = "probability"
}
export declare type PredictionType = PredictionTypes.binaryClassification | PredictionTypes.probability | PredictionTypes.regression;
export interface IMetricResponse {
    global: number;
    bins: number[];
}
export interface IMetricRequest {
    metricKey: string;
    binVector: number[];
    modelIndex: number;
}
export interface IFeatureBinMeta {
    binVector: number[];
    binLabels: string[];
    featureBinName?: string;
}
export interface ICustomMetric {
    name?: string;
    description?: string;
    id: string;
}
export interface IFairnessBaseData {
    dataSummary?: IDatasetSummary;
    predictedY: number[][];
    modelNames?: string[];
    trueY: number[];
    testData?: any[][];
}
export interface IPreComputedData {
    precomputedMetrics: Array<Array<{
        [key: string]: IMetricResponse;
    }>>;
    precomputedFeatureBins: IFeatureBinMeta[];
    predictionType: PredictionTypes;
    customMetrics?: ICustomMetric[];
}
export declare type IRunTimeData = Never<IPreComputedData> & {
    testData: any[][];
};
export declare type IPreComputedFairnessData = IFairnessBaseData & IPreComputedData;
export declare type IRunTimeFairnessData = IFairnessBaseData & IRunTimeData;
export declare type IFairnessData = IPreComputedFairnessData | IRunTimeFairnessData;
export declare type IFairnessProps = IFairnessData & {
    startingTabIndex?: number;
    theme?: any;
    locale?: string;
    stringParams?: any;
    supportedBinaryClassificationAccuracyKeys: string[];
    supportedRegressionAccuracyKeys: string[];
    supportedProbabilityAccuracyKeys: string[];
    shouldInitializeIcons?: boolean;
    iconUrl?: string;
    requestMetrics?: (request: IMetricRequest, abortSignal?: AbortSignal) => Promise<IMetricResponse>;
};
