import _ from 'lodash';
import { getLocalization, RangeTypes, ModelMetadata, PlotlyMode, ChartBuilder, AccessibleChart } from '@responsible-ai/mlchartlib';
import { initializeIcons, mergeStyleSets as mergeStyleSets$1, FontSizes as FontSizes$1, FontWeights as FontWeights$1, getTheme as getTheme$1, Text as Text$1, Checkbox, SpinButton, PrimaryButton as PrimaryButton$1, DefaultButton as DefaultButton$1, ActionButton as ActionButton$1, Selection, Stack as Stack$1, Modal, DetailsList, SelectionMode, Icon as Icon$1, FocusZone as FocusZone$1, Spinner as Spinner$1, SpinnerSize as SpinnerSize$1, ChoiceGroup, StackItem as StackItem$1, Separator, createTheme as createTheme$1, loadTheme, Pivot, PivotItem, IconButton as IconButton$1, Dropdown } from 'office-ui-fabric-react';
import * as React from 'react';
import React__default, { Component, Children, createContext, createElement, useContext, useEffect, useState, memo, forwardRef, useRef, createRef, Fragment, isValidElement, cloneElement } from 'react';
import { findDOMNode, createPortal } from 'react-dom';

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
  try {
    var info = gen[key](arg);
    var value = info.value;
  } catch (error) {
    reject(error);
    return;
  }

  if (info.done) {
    resolve(value);
  } else {
    Promise.resolve(value).then(_next, _throw);
  }
}

function _asyncToGenerator(fn) {
  return function () {
    var self = this,
        args = arguments;
    return new Promise(function (resolve, reject) {
      var gen = fn.apply(self, args);

      function _next(value) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
      }

      function _throw(err) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
      }

      _next(undefined);
    });
  };
}

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

function _inherits(subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function");
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      writable: true,
      configurable: true
    }
  });
  if (superClass) _setPrototypeOf(subClass, superClass);
}

function _getPrototypeOf(o) {
  _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
    return o.__proto__ || Object.getPrototypeOf(o);
  };
  return _getPrototypeOf(o);
}

function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };

  return _setPrototypeOf(o, p);
}

function _isNativeReflectConstruct() {
  if (typeof Reflect === "undefined" || !Reflect.construct) return false;
  if (Reflect.construct.sham) return false;
  if (typeof Proxy === "function") return true;

  try {
    Date.prototype.toString.call(Reflect.construct(Date, [], function () {}));
    return true;
  } catch (e) {
    return false;
  }
}

function _assertThisInitialized(self) {
  if (self === void 0) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return self;
}

function _possibleConstructorReturn(self, call) {
  if (call && (typeof call === "object" || typeof call === "function")) {
    return call;
  }

  return _assertThisInitialized(self);
}

function _createSuper(Derived) {
  var hasNativeReflectConstruct = _isNativeReflectConstruct();

  return function _createSuperInternal() {
    var Super = _getPrototypeOf(Derived),
        result;

    if (hasNativeReflectConstruct) {
      var NewTarget = _getPrototypeOf(this).constructor;

      result = Reflect.construct(Super, arguments, NewTarget);
    } else {
      result = Super.apply(this, arguments);
    }

    return _possibleConstructorReturn(this, result);
  };
}

function _toConsumableArray(arr) {
  return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread();
}

function _arrayWithoutHoles(arr) {
  if (Array.isArray(arr)) return _arrayLikeToArray(arr);
}

function _iterableToArray(iter) {
  if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter);
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _nonIterableSpread() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

var PredictionTypes;

(function (PredictionTypes) {
  PredictionTypes["binaryClassification"] = "binaryClassification";
  PredictionTypes["regression"] = "regression";
  PredictionTypes["probability"] = "probability";
})(PredictionTypes || (PredictionTypes = {}));

var loremIpsum = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.";
var defaultClassNames = "Třída {0}";
var defaultFeatureNames = "Citlivý příznak {0}";
var defaultSingleFeatureName = "Citlivý příznak";
var defaultCustomMetricName = "Vlastní metrika {0}";
var accuracyTab = "Nestrannost ve výkonu";
var opportunityTab = "Nestrannost v příležitosti";
var modelComparisonTab = "Porovnání modelů";
var tableTab = "Zobrazení podrobností";
var dataSpecifications = "Statistiky dat";
var attributes = "Atributy";
var singleAttributeCount = "1 citlivý příznak";
var attributesCount = "Počet citlivých příznaků: {0}";
var instanceCount = "Počet instancí: {0}";
var close = "Zavřít";
var calculating = "Probíhá výpočet...";
var accuracyMetricLegacy = "Metrika výkonu";
var errorOnInputs = "Chyba ve vstupu. Citlivé příznaky musí být v tuto chvíli kategorické hodnoty. Namapujte prosím hodnoty na intervalové kategorie a zkuste to znovu.";
var Accuracy = {
	header: "Jak chcete měřit výkon?",
	modelMakes: "Značky modelů",
	modelsMake: "Značka modelů",
	body: "Vaše data obsahují několik popisků (celkem {0}) a predikce {2} {1}. Na základě této informace doporučujeme následující metriky. Vyberte prosím ze seznamu jednu metriku.",
	binaryClassifier: "binární klasifikátor",
	probabalisticRegressor: "Regresor probit",
	regressor: "regresor",
	binary: "binární",
	continuous: "průběžné"
};
var Parity = {
	header: "Nestrannost měřená ve smyslu nekonzistence",
	body: "Metriky nekonzistence vyjadřují proměnlivost chování modelu mezi vybranými příznaky. Existují dva druhy metrik nekonzistence: další připravujeme..."
};
var Header = {
	title: "Fairlearn",
	documentation: "Dokumentace"
};
var Footer = {
	back: "Zpět",
	next: "Další"
};
var Intro = {
	welcome: "Vítá vás",
	fairlearnDashboard: "Řídicí panel Fairlearn",
	introBody: "Řídicí panel Fairlearn umožňuje posoudit kompromisy mezi výkonem a nestranností modelů.",
	explanatoryStep: "Pokud chcete nastavit posouzení, musí se zadat citlivý příznak a metrika výkonu.",
	getStarted: "Začínáme",
	features: "Citlivé příznaky",
	featuresInfo: "Citlivé příznaky se používají k rozdělení dat do skupin. Nestrannost modelu mezi těmito skupinami se měří jako metriky nekonzistence. Metriky nekonzistence vyjadřují, jak moc se chování modelu liší mezi jednotlivými skupinami.",
	accuracy: "Metrika výkonu",
	accuracyInfo: "Metriky výkonu se používají k vyhodnocení celkové kvality modelu i kvality modelu v jednotlivých skupinách. Rozdíl mezi odlehlými hodnotami metriky výkonu ve skupinách se označuje za nekonzistenci ve výkonu."
};
var ModelComparison = {
	title: "Porovnání modelů",
	howToRead: "Jak přečíst tento graf",
	lower: "méně",
	higher: "více",
	howToReadText: "Tento graf reprezentuje každý z modelů {0} jako bod, který se dá vybrat. Osa x představuje {1}, kde {2} je lépe. Osa y představuje nekonzistenci a méně je lépe.",
	insights: "Přehledy",
	insightsText1: "Graf zobrazuje {0} a nekonzistenci modelů {1}.",
	insightsText2: "{0} má rozsah od {1} do {2}. Rozsah nekonzistence je od {3} do {4}.",
	insightsText3: "Nejpřesnější model dosahuje {0} z {1} a má nekonzistenci {2}.",
	insightsText4: "Model s nejmenší nekonzistencí {2} dosahuje {0} z {1}.",
	disparityInOutcomes: "Nekonzistence v predikcích",
	disparityInAccuracy: "Nekonzistence v {0}",
	howToMeasureDisparity: "Jak se má nekonzistence měřit?"
};
var Report = {
	modelName: "Model {0}",
	title: "Nekonzistence ve výkonu",
	globalAccuracyText: "Je celkové {0}",
	accuracyDisparityText: "Je nekonzistence v {0}",
	editConfiguration: "Upravit konfiguraci",
	backToComparisons: "Vícemodelové zobrazení",
	outcomesTitle: "Nekonzistence v predikcích",
	minTag: "Minimum",
	maxTag: "Maximum",
	groupLabel: "Podskupina",
	underestimationError: "Podhodnocení",
	underpredictionExplanation: "(predikováno = 0, skutečnost = 1)",
	overpredictionExplanation: "(predikováno = 1, skutečnost = 0)",
	overestimationError: "Nadhodnocení",
	classificationOutcomesHowToRead: "Pruhový graf zobrazuje míru výběru v jednotlivých skupinách, tedy podíl bodů klasifikovaných jako 1.",
	regressionOutcomesHowToRead: "Krabicové diagramy zobrazují distribuci chyb v jednotlivých skupinách. Jednotlivé datové body se zobrazují v popředí.",
	classificationAccuracyHowToRead1: "Pruhový graf zobrazuje distribuci chyb v jednotlivých skupinách.",
	classificationAccuracyHowToRead2: "Chyby jsou rozdělené na chyby nadhodnocení (predikuje se 1, když skutečný popisek je 0) a chyby podhodnocení (predikuje se 0, když skutečný popisek je 1).",
	classificationAccuracyHowToRead3: "Uvedené míry se získají vydělením počtu chyb celkovou velikostí skupiny.",
	probabilityAccuracyHowToRead1: "Pruhový graf zobrazuje střední absolutní chybu v jednotlivých skupinách rozdělenou na nadhodnocení a podhodnocení.",
	probabilityAccuracyHowToRead2: "Pro každou ukázku změříme rozdíl mezi predikcí a popiskem. Pokud je kladný, nazveme ho nadhodnocením, a pokud je záporný, je to podhodnocení.",
	probabilityAccuracyHowToRead3: "Uvedeme součet chyb nadhodnocení a součet chyb podhodnocení vydělené celkovou velikostí skupiny.",
	regressionAccuracyHowToRead: "Chyba je rozdíl mezi predikcí a popiskem. Krabicové diagramy zobrazují distribuci chyb v jednotlivých skupinách. Jednotlivé datové body se zobrazují v popředí.",
	distributionOfPredictions: "Distribuce predikcí",
	distributionOfErrors: "Distribuce chyb",
	tooltipPrediction: "Predikce: {0}",
	tooltipError: "Chyba: {0}"
};
var Feature = {
	header: "Se kterým příznakem byste chtěli vyhodnotit nestrannost modelu?",
	body: "Nestrannost se vyhodnocuje ve smyslu nekonzistence chování modelů. Vaše data rozdělíme podle hodnot každého vybraného příznaku a vyhodnotíme, jak se mezi jednotlivými částmi liší metrika výkonu a predikce modelu.",
	learnMore: "Další informace",
	summaryCategoricalCount: "Tento příznak má následující počet jedinečných hodnot: {0}",
	summaryNumericCount: "Tento číselný příznak má rozsah od {0} do {1} a je seskupený do {2} intervalů.",
	showCategories: "Zobrazit vše",
	hideCategories: "Sbalit",
	categoriesOverflow: "   a tento počet dalších kategorií: {0}",
	editBinning: "Upravit skupiny",
	subgroups: "Podskupiny"
};
var Metrics = {
	accuracyScore: "Úspěšnost",
	precisionScore: "Přesnost",
	recallScore: "Úplnost",
	zeroOneLoss: "Funkce zero-one loss",
	specificityScore: "Skóre specifičnosti",
	missRate: "Míra nesprávných predikcí",
	falloutRate: "Míra vypuštění",
	maxError: "Maximální chyba",
	meanAbsoluteError: "Střední absolutní chyba",
	meanSquaredError: " MSE (střední kvadratická chyba)",
	meanSquaredLogError: "Střední kvadratická logaritmická chyba",
	medianAbsoluteError: "Mediánová absolutní chyba",
	average: "Průměrná predikce",
	selectionRate: "Míra výběru",
	overprediction: "Nadhodnocení",
	underprediction: "Podhodnocení",
	r2_score: "Skóre spolehlivosti R",
	rms_error: "RMSE (odmocněná střední kvadratická chyba)",
	auc: "Oblast pod křivkou ROC",
	balancedRootMeanSquaredError: "Vyrovnané RMSE",
	balancedAccuracy: "Vyrovnaná přesnost",
	f1Score: "F1-Score",
	logLoss: "Log Loss",
	accuracyDescription: "Část správně klasifikovaných datových bodů",
	precisionDescription: "Část správně klasifikovaných datových bodů mezi body klasifikovanými jako 1",
	recallDescription: "Část správně klasifikovaných datových bodů mezi body, jejichž skutečný popisek je 1. Alternativní názvy: míra pravdivě pozitivních predikcí, citlivost",
	rmseDescription: "Druhá odmocnina průměru kvadratických chyb",
	mseDescription: "Průměr kvadratických chyb",
	meanAbsoluteErrorDescription: "Průměr absolutních hodnot chyb. Je robustnější vůči odlehlým hodnotám než MSE.",
	r2Description: "Část odchylky v popiscích vysvětlené modelem",
	aucDescription: "Kvalita predikcí při oddělování pozitivních příkladů od těch negativních, zobrazovaná jako skóre",
	balancedRMSEDescription: "Váhy pozitivních a negativních příkladů se nastaví znovu, aby příklady měly stejnou celkovou váhu. Vhodné v situacích, kdy jsou základní data ve výrazné nerovnováze.",
	balancedAccuracyDescription: "Váhy pozitivních a negativních příkladů se nastaví znovu, aby příklady měly stejnou celkovou váhu. Vhodné v situacích, kdy jsou základní data ve výrazné nerovnováze.",
	f1ScoreDescription: "F1-Score is the harmonic mean of precision and recall."
};
var BinDialog = {
	header: "Nakonfigurovat intervaly",
	makeCategorical: "Považovat za kategorické",
	save: "Uložit",
	cancel: "Zrušit",
	numberOfBins: "Počet intervalů:",
	categoryHeader: "Hodnoty intervalů:"
};
var cs = {
	loremIpsum: loremIpsum,
	defaultClassNames: defaultClassNames,
	defaultFeatureNames: defaultFeatureNames,
	defaultSingleFeatureName: defaultSingleFeatureName,
	defaultCustomMetricName: defaultCustomMetricName,
	accuracyTab: accuracyTab,
	opportunityTab: opportunityTab,
	modelComparisonTab: modelComparisonTab,
	tableTab: tableTab,
	dataSpecifications: dataSpecifications,
	attributes: attributes,
	singleAttributeCount: singleAttributeCount,
	attributesCount: attributesCount,
	instanceCount: instanceCount,
	close: close,
	calculating: calculating,
	accuracyMetricLegacy: accuracyMetricLegacy,
	errorOnInputs: errorOnInputs,
	Accuracy: Accuracy,
	Parity: Parity,
	Header: Header,
	Footer: Footer,
	Intro: Intro,
	ModelComparison: ModelComparison,
	Report: Report,
	Feature: Feature,
	Metrics: Metrics,
	BinDialog: BinDialog
};

var loremIpsum$1 = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.";
var defaultClassNames$1 = "Klasse \"{0}\"";
var defaultFeatureNames$1 = "Sensibles Feature {0}";
var defaultSingleFeatureName$1 = "Sensibles Feature";
var defaultCustomMetricName$1 = "Benutzerdefinierte Metrik {0}";
var accuracyTab$1 = "Fairness bei der Leistung";
var opportunityTab$1 = "Fairness bei Chancen";
var modelComparisonTab$1 = "Modellvergleich";
var tableTab$1 = "Detailansicht";
var dataSpecifications$1 = "Datenstatistik";
var attributes$1 = "Attribute";
var singleAttributeCount$1 = "1 sensibles Feature";
var attributesCount$1 = "{0} sensible Features";
var instanceCount$1 = "{0} Instanzen";
var close$1 = "Schließen";
var calculating$1 = "Wird berechnet...";
var accuracyMetricLegacy$1 = "Leistungsmetrik";
var errorOnInputs$1 = "Fehler bei der Eingabe. Sensible Features müssen zurzeit kategorische Werte sein. Ordnen Sie den Datengruppenkategorien Werte zu, und versuchen Sie es noch mal.";
var Accuracy$1 = {
	header: "Wie möchten Sie die Leistung messen?",
	modelMakes: "Ihrem Modell",
	modelsMake: "Ihren Modellen",
	body: "Ihre Daten enthalten {0} Beschriftungen, und Vorhersagen werden von {1} zur {2} erstellt. Basierend auf diesen Informationen empfehlen wir die folgenden Metriken. Wählen Sie eine Metrik aus der Liste aus.",
	binaryClassifier: "binären Klassifizierung",
	probabalisticRegressor: "Probit-Regression",
	regressor: "Regression",
	binary: "binäre",
	continuous: "fortlaufende"
};
var Parity$1 = {
	header: "Fairness gemessen in Bezug auf die Abweichung",
	body: "Abweichungsmetriken quantifizieren die Variation des Modellverhaltens für die ausgewählten Features. Es gibt zwei Arten von Abweichungsmetriken: Weitere Informationen folgen..."
};
var Header$1 = {
	title: "Fairlearn",
	documentation: "Dokumentation"
};
var Footer$1 = {
	back: "Zurück",
	next: "Weiter"
};
var Intro$1 = {
	welcome: "Willkommen beim",
	fairlearnDashboard: "Fairlearn-Dashboard",
	introBody: "Mit dem Fairlearn-Dashboard können Sie Kompromisse zwischen Leistung und Fairness Ihrer Modelle bewerten.",
	explanatoryStep: "Um die Bewertung einzurichten, müssen Sie ein sensibles Feature und eine Leistungsmetrik angeben.",
	getStarted: "Erste Schritte",
	features: "Sensible Features",
	featuresInfo: "Anhand sensibler Features werden Ihre Daten in Gruppen unterteilt. Die Fairness Ihres Modells in diesen Gruppen wird mithilfe von Abweichungsmetriken gemessen. Diese drücken in Zahlen aus, inwieweit das Verhalten Ihres Modells in diesen Gruppen variiert.",
	accuracy: "Leistungsmetrik",
	accuracyInfo: "Leistungsmetriken werden verwendet, um die Gesamtqualität Ihres Modells sowie die Qualität Ihres Modells in den einzelnen Gruppen auszuwerten. Der Unterschied zwischen den Extremwerten der Leistungsmetrik in den Gruppen wird als Leistungsabweichung gemeldet."
};
var ModelComparison$1 = {
	title: "Modellvergleich",
	howToRead: "Lesen dieses Diagramms",
	lower: "ein geringerer Wert",
	higher: "ein höherer Wert",
	howToReadText: "Dieses Diagramm stellt jedes der {0} Modelle als auswählbaren Punkt dar. Die x-Achse stellt \"{1}\" dar, wobei {2} besser ist. Die y-Achse stellt die Abweichung dar, wobei ein geringerer Wert besser ist.",
	insights: "Erkenntnisse",
	insightsText1: "Das Diagramm zeigt \"{0}\" und die Abweichung bei {1} Modellen.",
	insightsText2: "\"{0}\" liegt im Bereich zwischen {1} und {2}. Die Abweichung reicht von {3} bis {4}.",
	insightsText3: "Das genaueste Modell erzielt für \"{0}\" einen Wert von {1} und eine Abweichung von {2}.",
	insightsText4: "Das Modell mit der niedrigsten Abweichung erzielt für \"{0}\" einen Wert von {1} und eine Abweichung von {2}.",
	disparityInOutcomes: "Abweichung in Vorhersagen",
	disparityInAccuracy: "Abweichung in {0}",
	howToMeasureDisparity: "Wie soll die Abweichung gemessen werden?"
};
var Report$1 = {
	modelName: "Modell {0}",
	title: "Leistungsabweichung",
	globalAccuracyText: "Ist der Gesamtwert von \"{0}\"",
	accuracyDisparityText: "Ist die Abweichung in \"{0}\"",
	editConfiguration: "Konfiguration bearbeiten",
	backToComparisons: "Ansicht mit mehreren Modellen",
	outcomesTitle: "Abweichung in Vorhersagen",
	minTag: "Min.",
	maxTag: "Max.",
	groupLabel: "Untergruppe",
	underestimationError: "Falsch negative Vorhersage",
	underpredictionExplanation: "(vorhergesagt = 0, richtig = 1)",
	overpredictionExplanation: "(vorhergesagt = 1, richtig = 0)",
	overestimationError: "Falsch positive Vorhersage",
	classificationOutcomesHowToRead: "Das Balkendiagramm zeigt die Auswahlrate der einzelnen Gruppen, d. h. den Anteil der als 1 klassifizierten Punkte.",
	regressionOutcomesHowToRead: "Boxplots zeigen die Verteilung der Vorhersagen in den einzelnen Gruppen. Einzelne Datenpunkte werden darübergelegt.",
	classificationAccuracyHowToRead1: "Das Balkendiagramm zeigt die Verteilung von Fehlern in den einzelnen Gruppen.",
	classificationAccuracyHowToRead2: "Fehler werden in falsch positive Vorhersagen (Vorhersage von 1 bei einer Beschriftung von 0) und falsch negative Vorhersagen (Vorhersage von 0 bei einer Beschriftung von 1) unterteilt.",
	classificationAccuracyHowToRead3: "Die gemeldeten Raten werden durch Teilen der Fehleranzahl durch die Gesamtgröße der Gruppe ermittelt.",
	probabilityAccuracyHowToRead1: "Das Balkendiagramm zeigt die mittleren absoluten Fehler in den einzelnen Gruppen, aufgeteilt in falsch positive und falsch negative Vorhersagen.",
	probabilityAccuracyHowToRead2: "In jedem Beispiel wird die Differenz zwischen der Vorhersage und der Beschriftung gemessen. Wenn diese positiv ist, wird dies als falsch positive Vorhersage bezeichnet. Ist sie negativ, handelt es sich um eine falsch negative Vorhersage.",
	probabilityAccuracyHowToRead3: "Wir melden die Summe der Fehler durch falsch positive Vorhersagen und die Summe der Fehler durch falsch negative Vorhersagen, geteilt durch die Gesamtgröße der Gruppe.",
	regressionAccuracyHowToRead: "Ein Fehler ist der Unterschied zwischen der Vorhersage und der Beschriftung. Boxplots zeigen die Verteilung von Fehlern in den einzelnen Gruppen. Einzelne Datenpunkte werden darübergelegt.",
	distributionOfPredictions: "Verteilung der Vorhersagen",
	distributionOfErrors: "Fehlerverteilung",
	tooltipPrediction: "Vorhersage: {0}",
	tooltipError: "Fehler: {0}"
};
var Feature$1 = {
	header: "Anhand welcher Features möchten Sie die Fairness Ihres Modells auswerten?",
	body: "Fairness wird hinsichtlich der Abweichungen im Verhalten Ihres Modells ausgewertet. Wir teilen Ihre Daten entsprechend den Werten der einzelnen ausgewählten Features auf und bewerten, wie sich die Leistungsmetrik und die Vorhersagen Ihres Modells in den einzelnen Teilen unterscheiden.",
	learnMore: "Weitere Informationen",
	summaryCategoricalCount: "Dieses Feature weist {0} eindeutige Werte auf.",
	summaryNumericCount: "Der Bereich dieses numerischen Features liegt zwischen {0} und {1} und ist in {2} Datengruppen unterteilt.",
	showCategories: "Alle anzeigen",
	hideCategories: "Reduzieren",
	categoriesOverflow: "   und {0} weitere Kategorien",
	editBinning: "Gruppen bearbeiten",
	subgroups: "Untergruppen"
};
var Metrics$1 = {
	accuracyScore: "Genauigkeit",
	precisionScore: "Genauigkeit",
	recallScore: "Wiedererkennung",
	zeroOneLoss: "Null-Eins-Verlust",
	specificityScore: "Spezifitätsscore",
	missRate: "Fehlerrate",
	falloutRate: "Ausfallrate",
	maxError: "Maximaler Fehler",
	meanAbsoluteError: "Mittlerer absoluter Fehler",
	meanSquaredError: " MSE (mittlerer quadratischer Fehler)",
	meanSquaredLogError: "Mittlerer quadratischer logarithmischer Fehler",
	medianAbsoluteError: "Mittlere absolute Abweichung vom Median",
	average: "Durchschnittliche Vorhersage",
	selectionRate: "Auswahlrate",
	overprediction: "Falsch positive Vorhersage",
	underprediction: "Falsch negative Vorhersage",
	r2_score: "R-quadratischer Score",
	rms_error: "RMSE (Wurzel des mittleren quadratischen Fehlers)",
	auc: "Fläche unter der ROC-Kurve",
	balancedRootMeanSquaredError: "Ausgewogener RMSE",
	balancedAccuracy: "Ausgewogene Genauigkeit",
	f1Score: "F1-Score",
	logLoss: "Log Loss",
	accuracyDescription: "Der Anteil der Datenpunkte, die korrekt klassifiziert werden.",
	precisionDescription: "Der Anteil der Datenpunkte, die unter den als 1 klassifizierten Datenpunkten korrekt klassifiziert werden.",
	recallDescription: "Der Anteil der Datenpunkte, die unter denjenigen korrekt klassifiziert werden, deren echte Beschriftung 1 lautet. Alternative Namen: True Positive-Rate, Sensitivität.",
	rmseDescription: "Quadratwurzel des Durchschnitts von quadratischen Fehlern.",
	mseDescription: "Der Durchschnitt aus quadratischen Fehlern.",
	meanAbsoluteErrorDescription: "Der Durchschnitt der absoluten Fehlerwerte. Stabiler bei Ausreißern als MSE.",
	r2Description: "Der Anteil der Varianz in den Beschriftungen, die vom Modell erklärt werden.",
	aucDescription: "Die Qualität der Vorhersagen, dargestellt als Scores, beim Trennen positiver Beispiele von negativen Beispielen.",
	balancedRMSEDescription: "Positive und negative Beispiele werden neu gewichtet, sodass sie insgesamt die gleiche Gewichtung aufweisen. Diese Option ist geeignet, wenn die zugrunde liegenden Daten hochgradig unausgewogen sind.",
	balancedAccuracyDescription: "Positive und negative Beispiele werden neu gewichtet, sodass sie insgesamt die gleiche Gewichtung aufweisen. Diese Option ist geeignet, wenn die zugrunde liegenden Daten hochgradig unausgewogen sind.",
	f1ScoreDescription: "F1-Score is the harmonic mean of precision and recall."
};
var BinDialog$1 = {
	header: "Datengruppen konfigurieren",
	makeCategorical: "Als kategorisch behandeln",
	save: "Speichern",
	cancel: "Abbrechen",
	numberOfBins: "Datengruppenanzahl:",
	categoryHeader: "Datengruppenwerte:"
};
var de = {
	loremIpsum: loremIpsum$1,
	defaultClassNames: defaultClassNames$1,
	defaultFeatureNames: defaultFeatureNames$1,
	defaultSingleFeatureName: defaultSingleFeatureName$1,
	defaultCustomMetricName: defaultCustomMetricName$1,
	accuracyTab: accuracyTab$1,
	opportunityTab: opportunityTab$1,
	modelComparisonTab: modelComparisonTab$1,
	tableTab: tableTab$1,
	dataSpecifications: dataSpecifications$1,
	attributes: attributes$1,
	singleAttributeCount: singleAttributeCount$1,
	attributesCount: attributesCount$1,
	instanceCount: instanceCount$1,
	close: close$1,
	calculating: calculating$1,
	accuracyMetricLegacy: accuracyMetricLegacy$1,
	errorOnInputs: errorOnInputs$1,
	Accuracy: Accuracy$1,
	Parity: Parity$1,
	Header: Header$1,
	Footer: Footer$1,
	Intro: Intro$1,
	ModelComparison: ModelComparison$1,
	Report: Report$1,
	Feature: Feature$1,
	Metrics: Metrics$1,
	BinDialog: BinDialog$1
};

var loremIpsum$2 = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.";
var defaultClassNames$2 = "Class {0}";
var defaultFeatureNames$2 = "Sensitive feature {0}";
var defaultSingleFeatureName$2 = "Sensitive feature";
var defaultCustomMetricName$2 = "Custom metric {0}";
var accuracyTab$2 = "Fairness in Performance";
var opportunityTab$2 = "Fairness in Opportunity";
var modelComparisonTab$2 = "Model comparison";
var tableTab$2 = "Detail View";
var dataSpecifications$2 = "Data statistics";
var attributes$2 = "Attributes";
var singleAttributeCount$2 = "1 sensitive feature";
var attributesCount$2 = "{0} sensitive features";
var instanceCount$2 = "{0} instances";
var close$2 = "Close";
var done = "Done";
var calculating$2 = "Calculating...";
var accuracyMetricLegacy$2 = "Performance metric";
var sensitiveFeatures = "01 Sensitive features";
var accuracyMetric = "02 Performance metrics";
var disparityMetric = "03 Disparity metrics";
var errorOnInputs$2 = "Error with input. Sensitive features must be categorical values at this time. Please map values to binned categories and retry.";
var Accuracy$2 = {
	header: "How do you want to measure performance?",
	modelMakes: "model makes",
	modelsMake: "models make",
	body: "Your data contains {0} labels and your {2} {1} predictions. Based on that information, we recommend the following metrics. Please select one metric from the list.",
	"_body.comment": "States whether labels are binary or continuous (0) and whether predictions are binary or continuous (1). (2) simply allows 'model(s) make' to be either singular or plural",
	binaryClassifier: "binary classifier",
	probabalisticRegressor: "probit regressor",
	regressor: "regressor",
	binary: "binary",
	continuous: "continuous"
};
var Parity$2 = {
	header: "Fairness measured in terms of disparity",
	bodyLegacy: "Disparity metrics quantify variation of your model's behavior across selected features. There are two kinds of disparity metrics: more to come....",
	body: "Disparity metrics quantify variation of your model's behavior across selected features. There are four kinds of disparity metrics: more to come...."
};
var Header$2 = {
	title: "Fairlearn",
	documentation: "Documentation"
};
var Footer$2 = {
	back: "Back",
	next: "Next"
};
var Intro$2 = {
	welcome: "Welcome to the",
	fairlearnDashboard: "Fairlearn dashboard",
	introBody: "The Fairlearn dashboard enables you to assess tradeoffs between performance and fairness of your models",
	explanatoryStep: "To set up the assessment, you need to specify a sensitive feature and a performance metric.",
	getStarted: "Get started",
	features: "Sensitive features",
	featuresInfo: "Sensitive features are used to split your data into groups. Fairness of your model across these groups is measured by disparity metrics. Disparity metrics quantify how much your model's behavior varies across these groups.",
	accuracy: "Performance metric",
	accuracyInfo: "Performance metrics are used to evaluate the overall quality of your model as well as the quality of your model in each group. The difference between the extreme values of the performance metric across the groups is reported as the disparity in performance.",
	parity: "Disparity metrics",
	parityInfo: "Parity metrics are used to evaluate the overall quality of your model as well as the quality of your model in each group. The difference between the extreme values of accuracy is reported as the disparity in accuracy."
};
var ModelComparison$2 = {
	title: "Model comparison",
	howToRead: "How to read this chart",
	lower: "lower",
	higher: "higher",
	howToReadText: "This chart represents each of the {0} models as a selectable point. The x-axis represents {1}, with {2} being better. The y-axis represents disparity, with lower being better.",
	"_howToReadText.comment": "Instructions for reading a chart. The number of models in the chart (0), the metric shown of the x-axix (1), and orientation for interpreting the x-axis",
	insightsLegacy: "Insights",
	insights: "Key Insights",
	downloadReport: "Download report",
	disparity: " The disparity ",
	rangesFrom: " ranges from ",
	to: " to ",
	period: ". ",
	introModalText: "Each model is a selectable point. Click or tap on model for it's full fairness assessment.",
	helpModalText1: "The x-axis represents accuracy, with higher being better.",
	helpModalText2: "The y-axis represents disparity,  with lower being better.",
	insightsText1: "The chart shows {0} and disparity of {1} models.",
	"_insightsText1.comment": "??? NOT FOUND IN SRC",
	insightsText2: "{0} ranges from {1} to {2}. The disparity ranges from {3} to {4}.",
	"_insightsText2.comment": "The range (low to high) of the metric, and range (low to high) of the associated disparity for that metric",
	insightsText3: "The most accurate model achieves {0} of {1} and a disparity of {2}.",
	"_insightsText3.comment": "For the most accurate model: The name of the accuracy measure (0), the formatted numerical value of the accuracy (1), and the formatted numerical value of the disparity (2)",
	insightsText4: "The lowest-disparity model achieves {0} of {1} and a disparity of {2}.",
	"_insightsText4.comment": "For the lowest-disparity model: The name of the accuracy measure (0), the formatted numerical value of the accuracy (1), and the formatted numerical value of the disparity (2)",
	disparityInOutcomes: "Disparity in predictions",
	disparityInAccuracy: "Disparity in {0}",
	"_disparityInAccuracy.comment": "The name of the metric for which disparity is assessed",
	howToMeasureDisparity: "How should disparity be measured?"
};
var Report$2 = {
	modelName: "Model {0}",
	"_modelName.comment": "The name of the model",
	title: "Disparity in performance",
	globalAccuracyText: "Is the overall {0}",
	"_globalAccuracyText.comment": "The title of the metric for which accuracy is being assessed",
	accuracyDisparityText: "Is the disparity in {0}",
	"_accuracyDisparityText.comment": "The title of the metric for which accuracy is being assessed",
	editConfiguration: "Edit configuration",
	backToComparisonsLegacy: "Multimodel view",
	backToComparisons: "Back to all models",
	assessmentResults: "Assessment results for",
	equalizedOddsDisparity: "Equalized odds disparity",
	outcomesTitle: "Disparity in predictions",
	expandSensitiveAttributes: "Expand sensitive attributes",
	collapseSensitiveAttributes: "Collapse sensitive attributes",
	minTag: "Min",
	maxTag: "Max",
	groupLabel: "Subgroup",
	overallLabel: "Overall",
	underestimationError: "Underprediction",
	underpredictionExplanation: "(predicted = 0, true = 1)",
	overpredictionExplanation: "(predicted = 1, true = 0)",
	overestimationError: "Overprediction",
	classificationOutcomesHowToRead: "The bar chart shows the selection rate in each group, meaning the fraction of points classified as 1.",
	regressionOutcomesHowToRead: "Box plots show the distribution of predictions in each group. Individual data points are overlaid on top.",
	classificationAccuracyHowToRead1: "The bar chart shows the distribution of errors in each group.",
	classificationAccuracyHowToRead2: "Errors are split into overprediction errors (predicting 1 when the true label is 0), and underprediction errors (predicting 0 when the true label is 1).",
	classificationAccuracyHowToRead3: "The reported rates are obtained by dividing the number of errors by the overall group size.",
	probabilityAccuracyHowToRead1: "The bar chart shows mean absolute error in each group, split into overprediction and underprediction.",
	probabilityAccuracyHowToRead2: "On each example, we measure the difference between the prediction and the label. If it is positive, we call it overprediction and if it is negative, we call it underprediction.",
	probabilityAccuracyHowToRead3: "We report the sum of overprediction errors and the sum of underprediction errors divided by the overall group size.",
	regressionAccuracyHowToRead: "Error is the difference between the prediction and the label. Box plots show the distribution of errors in each group. Individual data points are overlaid on top.",
	distributionOfPredictions: "Distribution of predictions",
	distributionOfErrors: "Distribution of errors",
	tooltipPrediction: "Prediction: {0}",
	"_tooltipPrediction.comment": "Displays tooltip with the formatted numerical value of the prediction",
	tooltipError: "Error: {0}",
	"_tooltipError.comment": "Displays tooltip with the formatted numerical value of the error"
};
var Feature$2 = {
	header: "Along which features would you like to evaluate your model's fairness?",
	body: "Fairness is evaluated in terms of disparities in your model's behavior. We will split your data according to values of each selected feature, and evaluate how your model's performance metric and predictions differ across these splits.",
	learnMore: "Learn more",
	summaryCategoricalCount: "This feature has {0} unique values",
	"_summaryCategoricalCount.comment": "Number of unique values of the feature",
	summaryNumericCount: "This numeric feature ranges from {0} to {1}, and is grouped into {2} bins.",
	"_summaryNumericalCount.comment": "The numerical range (low and high values) of the feature, and number of bin groups within that range",
	showCategories: "Show all",
	hideCategories: "Collapse",
	categoriesOverflow: "   and {0} additional categories",
	"_categoriesOverflow.comment": "??? NOT IN SRC - number of remaining additional categories",
	editBinning: "Edit groups",
	subgroups: "Subgroups"
};
var Metrics$2 = {
	accuracyScore: "Accuracy",
	precisionScore: "Precision",
	recallScore: "Recall",
	zeroOneLoss: "Zero-one loss",
	specificityScore: "Specificity score",
	missRate: "Miss rate",
	falloutRate: "Fallout rate",
	maxError: "Max error",
	meanAbsoluteError: "Mean absolute error",
	meanSquaredError: " MSE (mean squared error)",
	meanSquaredLogError: "Mean squared log error",
	medianAbsoluteError: "Median absolute error",
	average: "Average prediction",
	selectionRate: "Selection rate",
	overprediction: "Overprediction",
	underprediction: "Underprediction",
	r2_score: "R-squared score",
	rms_error: "RMSE (root mean squared error)",
	auc: "Area under ROC curve",
	balancedRootMeanSquaredError: "Balanced RMSE",
	balancedAccuracy: "Balanced accuracy",
	f1Score: "F1-Score",
	"_f1Score.comment": "Data science terminology: https://en.wikipedia.org/wiki/F1_score",
	logLoss: "Log Loss",
	"_logLoss.comment": "Data science terminology",
	accuracyDescription: "The fraction of data points classified correctly.",
	precisionDescription: "The fraction of data points classified correctly among those classified as 1.",
	recallDescription: "The fraction of data points classified correctly among those whose true label is 1. Alternative names: true positive rate, sensitivity.",
	rmseDescription: "Square root of the average of squared errors.",
	mseDescription: "The average of squared errors.",
	meanAbsoluteErrorDescription: "The average of absolute values of errors. More robust to outliers than MSE.",
	r2Description: "The fraction of variance in the labels explained by the model.",
	aucDescription: "The quality of the predictions, viewed as scores, in separating positive examples from negative examples.",
	balancedRMSEDescription: "Positive and negative examples are reweighted to have equal total weight. Suitable if the underlying data is highly imbalanced.",
	balancedAccuracyDescription: "Positive and negative examples are reweighted to have equal total weight. Suitable if the underlying data is highly imbalanced.",
	parityDifference: "Parity difference",
	parityDifferenceDescription: "Parity difference",
	parityRatio: "Parity ratio",
	parityRatioDescription: "Parity ratio",
	errorRateDifference: "Error rate difference",
	errorRateDifferenceDescription: "Error rate difference",
	equalOpportunityDifference: "Equal opportunity difference",
	equalOpportunityDifferenceDescription: "Equal opportunity difference",
	f1ScoreDescription: "F1-Score is the harmonic mean of precision and recall."
};
var BinDialog$2 = {
	header: "Configure bins",
	makeCategorical: "Treat as categorical",
	save: "Save",
	cancel: "Cancel",
	numberOfBins: "Number of bins:",
	categoryHeader: "Bin values:"
};
var en = {
	loremIpsum: loremIpsum$2,
	"_loremIpsum.comment": "DO NOT TRANSLATE. This is placeholder text the user will NOT see",
	defaultClassNames: defaultClassNames$2,
	"_defaultClassNames.comment": "models that output classes have this as the default class names when name are not given by the user",
	defaultFeatureNames: defaultFeatureNames$2,
	"_defaultFeatureNames.comment": "models that output classes have this as the default class names when name are not given by the user",
	defaultSingleFeatureName: defaultSingleFeatureName$2,
	defaultCustomMetricName: defaultCustomMetricName$2,
	"_defaultCustomMetricName.comment": "prepend in front of the numerical index of the custom metric from the list of custom metrics",
	accuracyTab: accuracyTab$2,
	opportunityTab: opportunityTab$2,
	modelComparisonTab: modelComparisonTab$2,
	tableTab: tableTab$2,
	dataSpecifications: dataSpecifications$2,
	attributes: attributes$2,
	singleAttributeCount: singleAttributeCount$2,
	attributesCount: attributesCount$2,
	"_attributesCount.comment": "formatted string of the number of attributes",
	instanceCount: instanceCount$2,
	"_instanceCount.comment": "formatted string of the number of instances",
	close: close$2,
	done: done,
	calculating: calculating$2,
	accuracyMetricLegacy: accuracyMetricLegacy$2,
	sensitiveFeatures: sensitiveFeatures,
	accuracyMetric: accuracyMetric,
	disparityMetric: disparityMetric,
	errorOnInputs: errorOnInputs$2,
	Accuracy: Accuracy$2,
	Parity: Parity$2,
	Header: Header$2,
	Footer: Footer$2,
	Intro: Intro$2,
	ModelComparison: ModelComparison$2,
	Report: Report$2,
	Feature: Feature$2,
	Metrics: Metrics$2,
	BinDialog: BinDialog$2
};

var loremIpsum$3 = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.";
var defaultClassNames$3 = "Clase {0}";
var defaultFeatureNames$3 = "Característica confidencial {0}";
var defaultSingleFeatureName$3 = "Característica confidencial";
var defaultCustomMetricName$3 = "Métrica personalizada {0}";
var accuracyTab$3 = "Equidad en rendimiento";
var opportunityTab$3 = "Equidad en oportunidades";
var modelComparisonTab$3 = "Comparación de modelos";
var tableTab$3 = "Vista detallada";
var dataSpecifications$3 = "Estadísticas de datos";
var attributes$3 = "Atributos";
var singleAttributeCount$3 = "1 característica confidencial";
var attributesCount$3 = "{0} características confidenciales";
var instanceCount$3 = "{0} instancias";
var close$3 = "Cerrar";
var calculating$3 = "Cálculo en curso...";
var accuracyMetricLegacy$3 = "Métrica de rendimiento";
var errorOnInputs$3 = "Error con la entrada. Las características confidenciales deben ser valores de categorías en este momento. Asigne valores a las categorías con rangos y vuelva a intentarlo.";
var Accuracy$3 = {
	header: "¿Cómo quiere medir el rendimiento?",
	modelMakes: "modelo hace",
	modelsMake: "modelos hacen",
	body: "Los datos contienen etiquetas ({0}) y sus predicciones ({2} {1}). En función de esta información, se recomiendan las métricas siguientes. Seleccione una de la lista.",
	binaryClassifier: "clasificador de elementos binarios",
	probabalisticRegressor: "regresor probit",
	regressor: "regresor",
	binary: "binario",
	continuous: "continuo"
};
var Parity$3 = {
	header: "Equidad medida en términos de disparidad",
	body: "Las métricas de disparidad cuantifican la variación del comportamiento del modelo en las características seleccionadas. Hay dos tipos de métricas de disparidad, pero está previsto que haya más disponibles."
};
var Header$3 = {
	title: "Fairlearn",
	documentation: "Documentación"
};
var Footer$3 = {
	back: "Atrás",
	next: "Siguiente"
};
var Intro$3 = {
	welcome: "Le damos la bienvenida a",
	fairlearnDashboard: "Panel de Fairlearn",
	introBody: "El panel de Fairlearn le permite evaluar las contrapartidas entre el rendimiento y la equidad de los modelos.",
	explanatoryStep: "Para configurar la evaluación, debe especificar una característica confidencial y una métrica de rendimiento.",
	getStarted: "Introducción",
	features: "Características confidenciales",
	featuresInfo: "Las características confidenciales se usan para dividir los datos en grupos. Las métricas de disparidad miden la equidad del modelo en estos grupos y cuantifican la variación del comportamiento del modelo en estos grupos.",
	accuracy: "Métrica de rendimiento",
	accuracyInfo: "Las métricas de rendimiento se usan para evaluar la calidad general del modelo, así como la calidad del modelo en cada grupo. La diferencia entre los valores extremos de la métrica de rendimiento en los distintos grupos se notifica como una disparidad de rendimiento."
};
var ModelComparison$3 = {
	title: "Comparación de modelos",
	howToRead: "Cómo leer este gráfico",
	lower: "menor",
	higher: "mayor",
	howToReadText: "Este gráfico representa cada uno de los {0} modelos como un punto seleccionable. El eje X representa {1}, donde un valor {2} es mejor; el eje Y representa la disparidad, donde un valor menor es mejor.",
	insights: "Conclusiones",
	insightsText1: "El gráfico muestra {0} y disparidad de los modelos de {1}.",
	insightsText2: "{0} puede tener un valor de {1} a {2}. La disparidad puede tener un valor de {3} a {4}.",
	insightsText3: "El modelo más preciso logra {0} de {1} y una disparidad de {2}.",
	insightsText4: "El modelo de menor disparidad logra {0} de {1} y una disparidad de {2}.",
	disparityInOutcomes: "Disparidad en predicciones",
	disparityInAccuracy: "Disparidad en {0}",
	howToMeasureDisparity: "¿Cómo se deben medir las disparidades?"
};
var Report$3 = {
	modelName: "Modelo {0}",
	title: "Disparidad en rendimiento",
	globalAccuracyText: "Es el valor total de {0}",
	accuracyDisparityText: "Es la disparidad en {0}",
	editConfiguration: "Editar configuración",
	backToComparisons: "Vista multimodelo",
	outcomesTitle: "Disparidad en predicciones",
	minTag: "Mín.",
	maxTag: "Máx.",
	groupLabel: "Subgrupo",
	underestimationError: "Infrapredicción",
	underpredictionExplanation: "(predicción: 0, verdadero: 1)",
	overpredictionExplanation: "(predicción: 1, verdadero: 0)",
	overestimationError: "Sobrepredicción",
	classificationOutcomesHowToRead: "El gráfico de barras muestra la probabilidad de selecciones de cada grupo, es decir, la fracción de puntos que se clasifica como 1.",
	regressionOutcomesHowToRead: "Los diagramas de caja muestran la distribución de predicciones en cada grupo, mientras que los puntos de datos individuales están superpuestos.",
	classificationAccuracyHowToRead1: "El gráfico de barras muestra la distribución de los errores en cada grupo.",
	classificationAccuracyHowToRead2: "Los errores se dividen en errores de sobrepredicción (se predice 1 cuando la etiqueta verdadera es 0) y los errores de infrapredicción (se predice 0 cuando la etiqueta verdadera es 1).",
	classificationAccuracyHowToRead3: "Las probabilidades indicadas se obtienen dividiendo el número de errores entre el tamaño total del grupo.",
	probabilityAccuracyHowToRead1: "El gráfico de barras muestra un error absoluto medio en cada grupo, dividido en sobrepredicción e infrapredicción.",
	probabilityAccuracyHowToRead2: "En cada ejemplo se mide la diferencia entre la predicción y la etiqueta. Si es positiva, se será una sobrepredicción y, si es negativa, será una infrapredicción.",
	probabilityAccuracyHowToRead3: "Se informa de la suma de errores de sobrepredicción y de infrapredicción divididos entre el tamaño total del grupo.",
	regressionAccuracyHowToRead: "El error es la diferencia entre la predicción y la etiqueta. Los diagramas de caja muestran la distribución de errores en cada grupo, mientras que los puntos de datos individuales están superpuestos.",
	distributionOfPredictions: "Distribución de predicciones",
	distributionOfErrors: "Distribución de errores",
	tooltipPrediction: "Predicción: {0}",
	tooltipError: "Error: {0}"
};
var Feature$3 = {
	header: "¿Con respecto a qué características quiere evaluar la equidad de su modelo?",
	body: "La equidad se evalúa en términos de disparidades en el comportamiento del modelo. Se dividirán los datos en función de los valores de las características seleccionadas y se evaluarán las diferencias entre las predicciones y las métricas de rendimiento del modelo de acuerdo con estas divisiones.",
	learnMore: "Más información",
	summaryCategoricalCount: "Esta característica tiene {0} valores únicos.",
	summaryNumericCount: "Esta característica numérica abarca de {0} a {1} y se agrupa en {2} rangos.",
	showCategories: "Mostrar todo",
	hideCategories: "Contraer",
	categoriesOverflow: "   y {0} categorías adicionales",
	editBinning: "Editar grupos",
	subgroups: "Subgrupos"
};
var Metrics$3 = {
	accuracyScore: "Exactitud",
	precisionScore: "Precisión",
	recallScore: "Coincidencia",
	zeroOneLoss: "Pérdida cero-uno",
	specificityScore: "Puntuación de especificidad",
	missRate: "Probabilidad de errores",
	falloutRate: "Probabilidad de efectos colaterales",
	maxError: "Error de máximo",
	meanAbsoluteError: "Error absoluto de media",
	meanSquaredError: " ECM (error cuadrático medio)",
	meanSquaredLogError: "Error logarítmico de cuadrático medio",
	medianAbsoluteError: "Error absoluto de mediana",
	average: "Predicción promedio",
	selectionRate: "Probabilidad de selecciones",
	overprediction: "Sobrepredicción",
	underprediction: "Infrapredicción",
	r2_score: "Puntuación de R cuadrado",
	rms_error: "RECM (raíz del error cuadrático medio)",
	auc: "Área bajo la curva ROC",
	balancedRootMeanSquaredError: "RECM equilibrado",
	balancedAccuracy: "Exactitud equilibrada",
	f1Score: "F1-Score",
	logLoss: "Log Loss",
	accuracyDescription: "Fracción de puntos de datos clasificada correctamente.",
	precisionDescription: "Fracción de puntos de datos clasificada correctamente entre los clasificados como 1.",
	recallDescription: "Fracción de puntos de datos clasificada correctamente entre aquellos cuya etiqueta verdadera es 1. Nombres alternativos: índice de verdaderos positivos, confidencialidad.",
	rmseDescription: "Raíz cuadrada del promedio de errores cuadráticos.",
	mseDescription: "Promedio de errores cuadráticos.",
	meanAbsoluteErrorDescription: "Promedio de valores absolutos de errores; más robusto a valores atípicos que ECM.",
	r2Description: "Fracción de varianza de las etiquetas explicadas por el modelo.",
	aucDescription: "Calidad de las predicciones, vistas como puntuaciones, en la separación de ejemplos positivos de ejemplos negativos.",
	balancedRMSEDescription: "Los ejemplos positivos y negativos se vuelven a ponderar para que tengan la misma ponderación total. Esto es adecuado si los datos subyacentes están muy desequilibrados.",
	balancedAccuracyDescription: "Los ejemplos positivos y negativos se vuelven a ponderar para que tengan la misma ponderación total. Esto es adecuado si los datos subyacentes están muy desequilibrados.",
	f1ScoreDescription: "F1-Score is the harmonic mean of precision and recall."
};
var BinDialog$3 = {
	header: "Configuración de rangos",
	makeCategorical: "Tratar como valor categórico",
	save: "Guardar",
	cancel: "Cancelar",
	numberOfBins: "Número de rangos:",
	categoryHeader: "Valores de rangos:"
};
var es = {
	loremIpsum: loremIpsum$3,
	defaultClassNames: defaultClassNames$3,
	defaultFeatureNames: defaultFeatureNames$3,
	defaultSingleFeatureName: defaultSingleFeatureName$3,
	defaultCustomMetricName: defaultCustomMetricName$3,
	accuracyTab: accuracyTab$3,
	opportunityTab: opportunityTab$3,
	modelComparisonTab: modelComparisonTab$3,
	tableTab: tableTab$3,
	dataSpecifications: dataSpecifications$3,
	attributes: attributes$3,
	singleAttributeCount: singleAttributeCount$3,
	attributesCount: attributesCount$3,
	instanceCount: instanceCount$3,
	close: close$3,
	calculating: calculating$3,
	accuracyMetricLegacy: accuracyMetricLegacy$3,
	errorOnInputs: errorOnInputs$3,
	Accuracy: Accuracy$3,
	Parity: Parity$3,
	Header: Header$3,
	Footer: Footer$3,
	Intro: Intro$3,
	ModelComparison: ModelComparison$3,
	Report: Report$3,
	Feature: Feature$3,
	Metrics: Metrics$3,
	BinDialog: BinDialog$3
};

var loremIpsum$4 = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.";
var defaultClassNames$4 = "Classe {0}";
var defaultFeatureNames$4 = "Caractéristique sensible {0}";
var defaultSingleFeatureName$4 = "Caractéristique sensible";
var defaultCustomMetricName$4 = "Métrique personnalisée {0}";
var accuracyTab$4 = "Équité dans les performances";
var opportunityTab$4 = "Équité dans l'opportunité";
var modelComparisonTab$4 = "Comparaison de modèles";
var tableTab$4 = "Vue Détails";
var dataSpecifications$4 = "Statistiques des données";
var attributes$4 = "Attributs";
var singleAttributeCount$4 = "1 caractéristique sensible";
var attributesCount$4 = "{0} caractéristiques sensibles";
var instanceCount$4 = "{0} instances";
var close$4 = "Fermer";
var calculating$4 = "Calcul...";
var accuracyMetricLegacy$4 = "Métrique de performances";
var errorOnInputs$4 = "Erreur d'entrée. Les caractéristiques sensibles doivent être des valeurs catégoriques pour l'instant. Mappez les valeurs à des catégories classées et réessayez.";
var Accuracy$4 = {
	header: "Comment voulez-vous mesurer les performances ?",
	modelMakes: "votre modèle fait",
	modelsMake: "vos modèles font",
	body: "Vos données contiennent des étiquettes de type « {0} » et {2} {1} prédictions. D'après ces informations, nous vous recommandons d'utiliser les métriques suivantes. Sélectionnez une métrique dans la liste.",
	binaryClassifier: "classifieur binaire",
	probabalisticRegressor: "régresseur probit",
	regressor: "régresseur",
	binary: "binaire",
	continuous: "continu"
};
var Parity$4 = {
	header: "Équité mesurée en termes de disparité",
	body: "Les métriques de disparité quantifient la variation du comportement de votre modèle sur les caractéristiques sélectionnées. Il existe deux types de métriques de disparité : d'autres sont à venir..."
};
var Header$4 = {
	title: "Fairlearn",
	documentation: "Documentation"
};
var Footer$4 = {
	back: "Précédent",
	next: "Suivant"
};
var Intro$4 = {
	welcome: "Bienvenue dans :",
	fairlearnDashboard: "Tableau de bord Fairlearn",
	introBody: "Le tableau de bord Fairlearn vous permet d'évaluer les compromis entre les performances et l'équité de vos modèles",
	explanatoryStep: "Pour configurer l'évaluation, vous devez spécifier une caractéristique sensible et une métrique de performances.",
	getStarted: "Démarrer",
	features: "Caractéristiques sensibles",
	featuresInfo: "Les caractéristiques sensibles permettent de diviser vos données en groupes. L'équité de votre modèle dans ces groupes est évaluée par des métriques de disparité qui quantifient la variation du comportement de votre modèle dans ces groupes.",
	accuracy: "Métrique de performances",
	accuracyInfo: "Les métriques de performances permettent d'évaluer la qualité globale de votre modèle ainsi que la qualité de votre modèle dans chaque groupe. La disparité des performances signalée est la différence entre les valeurs extrêmes de la métrique de performances dans les groupes."
};
var ModelComparison$4 = {
	title: "Comparaison de modèles",
	howToRead: "Comment lire ce graphique",
	lower: "inférieure",
	higher: "supérieure",
	howToReadText: "Ce graphique représente chacun des modèles {0} sous la forme d'un point sélectionnable. L'axe X représente {1} (une valeur {2} étant meilleure). L'axe Y représente la disparité (une valeur inférieure étant meilleure).",
	insights: "Insights",
	insightsText1: "Le graphique montre {0} et la disparité de {1} modèles.",
	insightsText2: "{0} est compris entre {1} et {2}. Les plages de disparité vont de {3} à {4}.",
	insightsText3: "Le modèle le plus juste obtient {0} sur {1} et une disparité de {2}.",
	insightsText4: "Le modèle de disparité le plus faible obtient {0} sur {1} et une disparité de {2}.",
	disparityInOutcomes: "Disparité dans les prédictions",
	disparityInAccuracy: "Disparité dans {0}",
	howToMeasureDisparity: "Comment la disparité doit-elle être mesurée ?"
};
var Report$4 = {
	modelName: "Modèle {0}",
	title: "Disparité des performances",
	globalAccuracyText: "Est le {0} d'ensemble",
	accuracyDisparityText: "Est la disparité dans {0}",
	editConfiguration: "Modifier la configuration",
	backToComparisons: "Vue multimodèle",
	outcomesTitle: "Disparité dans les prédictions",
	minTag: "Min",
	maxTag: "Max",
	groupLabel: "Sous-groupe",
	underestimationError: "Sous-prédiction",
	underpredictionExplanation: "(prédit = 0, true = 1)",
	overpredictionExplanation: "(prédit = 1, true = 0)",
	overestimationError: "Surprédiction",
	classificationOutcomesHowToRead: "Le graphique à barres montre le taux de sélection dans chaque groupe, c'est-à-dire la fraction des points classifiés comme ayant la valeur 1.",
	regressionOutcomesHowToRead: "Les diagrammes à surfaces montrent la répartition des prédictions dans chaque groupe. Les points de données individuels sont superposés.",
	classificationAccuracyHowToRead1: "Le graphique à barres montre la répartition des erreurs dans chaque groupe.",
	classificationAccuracyHowToRead2: "Les erreurs sont divisées en erreurs de surprédiction (prédire 1 quand l'étiquette true est 0) et en erreurs de sous-prédiction (prédire 0 quand l'étiquette true est 1).",
	classificationAccuracyHowToRead3: "Les taux signalés sont obtenus en divisant le nombre d'erreurs par la taille totale du groupe.",
	probabilityAccuracyHowToRead1: "Le graphique à barres montre l'erreur absolue moyenne dans chaque groupe, divisée en surprédiction et en sous-prédiction.",
	probabilityAccuracyHowToRead2: "Dans chaque exemple, nous mesurons la différence entre la prédiction et l'étiquette. Si elle est positive, nous parlons de surprédiction ; si elle est négative, nous parlons de sous-prédiction.",
	probabilityAccuracyHowToRead3: "Nous signalons la somme des erreurs de surprédiction et la somme des erreurs de sous-prédiction divisée par la taille totale du groupe.",
	regressionAccuracyHowToRead: "L'erreur est la différence entre la prédiction et l'étiquette. Les diagrammes à surfaces montrent la répartition des erreurs dans chaque groupe. Les points de données individuels sont superposés.",
	distributionOfPredictions: "Répartition des prédictions",
	distributionOfErrors: "Distribution des erreurs",
	tooltipPrediction: "Prédiction : {0}",
	tooltipError: "Erreur : {0}"
};
var Feature$4 = {
	header: "Selon quelles caractéristiques souhaitez-vous évaluer l'équité de votre modèle ?",
	body: "L'équité est évaluée en termes de disparités dans le comportement de votre modèle. Nous allons diviser vos données en fonction des valeurs de chaque caractéristique sélectionnée, puis évaluer la manière dont la métrique et les prédictions de performance de votre modèle diffèrent dans ces divisions.",
	learnMore: "En savoir plus",
	summaryCategoricalCount: "Cette caractéristique a {0} valeurs uniques",
	summaryNumericCount: "Cette caractéristique numérique, comprise entre {0} et {1}, est regroupée en {2} classes.",
	showCategories: "Tout afficher",
	hideCategories: "Réduire",
	categoriesOverflow: "   et {0} catégories supplémentaires",
	editBinning: "Modifier les groupes",
	subgroups: "Sous-groupes"
};
var Metrics$4 = {
	accuracyScore: "Justesse",
	precisionScore: "Précision",
	recallScore: "Rappeler",
	zeroOneLoss: "Perte zéro-un",
	specificityScore: "Score de spécificité",
	missRate: "Taux d'échec",
	falloutRate: "Taux de faux positifs",
	maxError: "Erreur max.",
	meanAbsoluteError: "Erreur absolue moyenne",
	meanSquaredError: " MSE (erreur quadratique moyenne)",
	meanSquaredLogError: "Erreur logarithmique quadratique moyenne",
	medianAbsoluteError: "Erreur absolue médiane",
	average: "Prédiction moyenne",
	selectionRate: "Taux de sélection",
	overprediction: "Surprédiction",
	underprediction: "Sous-prédiction",
	r2_score: "Score du coefficient de détermination",
	rms_error: "RMSE (racine de l'erreur quadratique moyenne)",
	auc: "Zone sous la courbe ROC",
	balancedRootMeanSquaredError: "RMSE équilibrée",
	balancedAccuracy: "Justesse équilibrée",
	f1Score: "F1-Score",
	logLoss: "Log Loss",
	accuracyDescription: "Fraction des points de données correctement classifiés.",
	precisionDescription: "Fraction de points de données correctement classifiés parmi ceux classifiés comme ayant la valeur 1.",
	recallDescription: "Fraction des points de données correctement classifiés parmi ceux dont l'étiquette true est 1. Autres noms : taux de vrais positifs, sensibilité.",
	rmseDescription: "Racine carrée de la moyenne des erreurs quadratiques.",
	mseDescription: "Moyenne des erreurs quadratiques.",
	meanAbsoluteErrorDescription: "Moyenne des valeurs absolues des erreurs. Résiste mieux aux valeurs hors norme que MSE.",
	r2Description: "Fraction de variance dans les étiquettes expliquée par le modèle.",
	aucDescription: "Qualité des prédictions, présentées sous forme de scores, pour séparer les exemples positifs des exemples négatifs.",
	balancedRMSEDescription: "Les exemples positifs et négatifs sont repondérés pour avoir un poids total égal. Convient si les données sous-jacentes sont fortement déséquilibrées.",
	balancedAccuracyDescription: "Les exemples positifs et négatifs sont repondérés pour avoir un poids total égal. Convient si les données sous-jacentes sont fortement déséquilibrées.",
	f1ScoreDescription: "F1-Score is the harmonic mean of precision and recall."
};
var BinDialog$4 = {
	header: "Configurer les classes",
	makeCategorical: "Considérer comme catégorique",
	save: "Enregistrer",
	cancel: "Annuler",
	numberOfBins: "Nombre de classes :",
	categoryHeader: "Valeurs de classe :"
};
var fr = {
	loremIpsum: loremIpsum$4,
	defaultClassNames: defaultClassNames$4,
	defaultFeatureNames: defaultFeatureNames$4,
	defaultSingleFeatureName: defaultSingleFeatureName$4,
	defaultCustomMetricName: defaultCustomMetricName$4,
	accuracyTab: accuracyTab$4,
	opportunityTab: opportunityTab$4,
	modelComparisonTab: modelComparisonTab$4,
	tableTab: tableTab$4,
	dataSpecifications: dataSpecifications$4,
	attributes: attributes$4,
	singleAttributeCount: singleAttributeCount$4,
	attributesCount: attributesCount$4,
	instanceCount: instanceCount$4,
	close: close$4,
	calculating: calculating$4,
	accuracyMetricLegacy: accuracyMetricLegacy$4,
	errorOnInputs: errorOnInputs$4,
	Accuracy: Accuracy$4,
	Parity: Parity$4,
	Header: Header$4,
	Footer: Footer$4,
	Intro: Intro$4,
	ModelComparison: ModelComparison$4,
	Report: Report$4,
	Feature: Feature$4,
	Metrics: Metrics$4,
	BinDialog: BinDialog$4
};

var loremIpsum$5 = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.";
var defaultClassNames$5 = "{0} osztály";
var defaultFeatureNames$5 = "Érzékeny jellemző: {0}";
var defaultSingleFeatureName$5 = "Érzékeny jellemző";
var defaultCustomMetricName$5 = "Egyéni metrika: {0}";
var accuracyTab$5 = "Teljesítmény méltányossága";
var opportunityTab$5 = "Lehetőség méltányossága";
var modelComparisonTab$5 = "Modell-összehasonlítás";
var tableTab$5 = "Részletes nézet";
var dataSpecifications$5 = "Adatok statisztikái";
var attributes$5 = "Attribútumok";
var singleAttributeCount$5 = "1 érzékeny jellemző";
var attributesCount$5 = "{0} érzékeny jellemző";
var instanceCount$5 = "{0} példány";
var close$5 = "Bezárás";
var calculating$5 = "Számítás...";
var accuracyMetricLegacy$5 = "Teljesítménymutató";
var errorOnInputs$5 = "Hiba történt a bemenettel. Az érzékeny jellemzőknek jelenleg kategorikus értékeknek kell lenniük. Rendelje hozzá az értékeket dobozolt kategóriákhoz, majd próbálja újra.";
var Accuracy$5 = {
	header: "Hogyan szeretné mérni a teljesítményt?",
	modelMakes: "modell végrehajt",
	modelsMake: "modellek végrehajtanak",
	body: "Az adatok {0} címkét és {2} {1} előrejelzést tartalmaznak. Ezen információ alapján a következő metrikákat javasoljuk. Válasszon ki egy metrikát a listából.",
	binaryClassifier: "bináris osztályozó",
	probabalisticRegressor: "probit magyarázó változója",
	regressor: "magyarázó változó",
	binary: "bináris",
	continuous: "folyamatos"
};
var Parity$5 = {
	header: "Egyenlőtlenség alapján mért méltányosság",
	body: "Az egyenlőtlenségi metrikák számszerűsítik a modell viselkedésének variációját a kiválasztott jellemzők tekintetében. Kétféle egyenlőtlenségi metrika létezik: hamarosan...."
};
var Header$5 = {
	title: "Fairlearn",
	documentation: "Dokumentáció"
};
var Footer$5 = {
	back: "Vissza",
	next: "Tovább"
};
var Intro$5 = {
	welcome: "Üdvözöli a",
	fairlearnDashboard: "Fairlearn irányítópult",
	introBody: "A Fairlearn-irányítópult lehetővé teszi a modellek teljesítménye és a méltányossága közötti kompromisszumok értékelését",
	explanatoryStep: "Az értékelés beállításához meg kell adnia egy érzékeny jellemzőt és egy teljesítménymutatót.",
	getStarted: "Első lépések",
	features: "Érzékeny jellemzők",
	featuresInfo: "Az érzékeny jellemzők csoportokra osztják az adatokat. A modell csoportonkénti méltányossága az egyenlőtlenségi metrikák alapján van mérve. Az egyenlőtlenségi metrikák számszerűsítik, hogy a modell csoportonkénti viselkedése mennyire változatos.",
	accuracy: "Teljesítménymutató",
	accuracyInfo: "A teljesítménymutató a modell összesített és csoportonkénti teljesítményének kiértékelésére szolgálnak. A teljesítménymutató szélsőséges értékei közötti csoportonkénti különbséget a rendszer teljesítménybeli egyenlőtlenségként fogja lejelenteni."
};
var ModelComparison$5 = {
	title: "Modell-összehasonlítás",
	howToRead: "A diagram értelmezése",
	lower: "alacsonyabb",
	higher: "magasabb",
	howToReadText: "Ez a diagram a(z) {0} modellek mindegyikét kijelölhető pontként ábrázolja. Az x tengelyen {1} látható, ahol {2} jobb. Az Y tengely az egyenlőtlenséget mutatja, ahol az alacsonyabb érték jobb.",
	insights: "Elemzések",
	insightsText1: "A diagramon látható a(z) {0} és a(z) {1} modellek egyenlőtlensége.",
	insightsText2: "A(z) {0} terjedelme: {1}–{2}. Az egyenlőtlenség terjedelme: {3}–{4}.",
	insightsText3: "A legpontosabb modell {1}/{0} értéket és {2} egyenlőtlenséget ér el.",
	insightsText4: "A legkisebb egyenlőtlenséges modell {1}/{0} értéket és {2} egyenlőtlenséget ér el.",
	disparityInOutcomes: "Egyenlőtlenség az előrejelzések között",
	disparityInAccuracy: "Egyenlőtlenség itt: {0}",
	howToMeasureDisparity: "Hogyan szeretné mérni az egyenlőtlenséget?"
};
var Report$5 = {
	modelName: "{0} modell",
	title: "Teljesítménybeli egyenlőtlenség",
	globalAccuracyText: "A teljes {0}",
	accuracyDisparityText: "A(z) {0} egyenlőtlenségét jelenti",
	editConfiguration: "Konfiguráció szerkesztése",
	backToComparisons: "Többmodelles nézet",
	outcomesTitle: "Egyenlőtlenség az előrejelzések között",
	minTag: "Minimum",
	maxTag: "Maximum",
	groupLabel: "Alcsoport",
	underestimationError: "Alábecslés",
	underpredictionExplanation: "(előrejelzett = 0, igaz = 1)",
	overpredictionExplanation: "(előrejelzett = 1, igaz = 0)",
	overestimationError: "Túlbecslés",
	classificationOutcomesHowToRead: "A sávdiagram az egyes csoportok kiválasztási arányát, vagyis az 1-es osztályozású ponthányadokat jeleníti meg.",
	regressionOutcomesHowToRead: "A dobozdiagramok a csoportonként eloszló előrejelzéseket mutatják. Az egyéni adatpontok felül, átfedésben jelennek meg.",
	classificationAccuracyHowToRead1: "A sávdiagram az eltérések eloszlását mutatja az egyes csoportokban.",
	classificationAccuracyHowToRead2: "Az eltéréseket a rendszer túlbecslési eltérésekre (az előrejelzés 1, miközben a valós címke 0) és alábecslési eltérésekre (az előrejelzés 0, miközben a valós címke 1) bontja.",
	classificationAccuracyHowToRead3: "A jelentett arányokat az eltérések számának a csoport teljes méretével való elosztása eredményezi.",
	probabilityAccuracyHowToRead1: "A sávdiagram az egyes csoportokátlagos abszolút eltérését mutatja, túlbecslésre és alábecslésre osztva.",
	probabilityAccuracyHowToRead2: "Minden példa esetében az előrejelzés és a címke közti különbséget mérjük. Ha a különbség pozitív, azt túlbecslésnek, ha negatív, azt alábecslésnek nevezzük.",
	probabilityAccuracyHowToRead3: "A jelentésben a túlbecslések és az alábecslések eltérései összegének és a csoport teljes méretének hányadosa szerepel.",
	regressionAccuracyHowToRead: "Az eltérés az előrejelzés és a címke közötti különbséget jelöli. A dobozdiagramok a csoportonkénti hibaeloszlást mutatják. Az egyéni adatpontok felül, átfedésben jelennek meg.",
	distributionOfPredictions: "Előrejelzések eloszlása",
	distributionOfErrors: "Eltérések eloszlása",
	tooltipPrediction: "Előrejelzés: {0}",
	tooltipError: "Eltérés: {0}"
};
var Feature$5 = {
	header: "Mely jellemzők mellett szeretné kiértékelni a modell méltányosságát?",
	body: "A méltányosságot a rendszer a modell viselkedésében mutatkozó egyenlőtlenségek alapján értékeli ki. Az adatokat az egyes kiválasztott jellemzők értékei szerint osztjuk fel, és kiértékeljük, hogy a modell teljesítménymutatója és előrejelzései felosztásonként hogyan változik.",
	learnMore: "További információ",
	summaryCategoricalCount: "Ez a jellemző {0} egyedi értékeket tartalmaz",
	summaryNumericCount: "Ez a numerikus jellemző {0} és {1} között mozog, és {2} dobozba van csoportosítva.",
	showCategories: "Összes megjelenítése",
	hideCategories: "Összecsukás",
	categoriesOverflow: "   és további {0} kategória",
	editBinning: "Csoportok szerkesztése",
	subgroups: "Alcsoportok"
};
var Metrics$5 = {
	accuracyScore: "Pontosság",
	precisionScore: "Pontosság",
	recallScore: "Felidézés",
	zeroOneLoss: "Nulla–egy veszteség",
	specificityScore: "Specifikussági pontszám",
	missRate: "Kihagyási arány",
	falloutRate: "Kiesési valószínűség",
	maxError: "Maximális eltérés",
	meanAbsoluteError: "Átlagos abszolút eltérés",
	meanSquaredError: " MSE (átlagos négyzetes eltérés)",
	meanSquaredLogError: "Átlagos négyzetes naplóeltérés",
	medianAbsoluteError: "Medián abszolút eltérés",
	average: "Átlagos előrejelzés",
	selectionRate: "Kiválasztási arány",
	overprediction: "Túlbecslés",
	underprediction: "Alábecslés",
	r2_score: "Négyzetgyök pontszám",
	rms_error: "RMSE (gyökér-átlagos négyzetes eltérés)",
	auc: "ROC-görbe alatti terület",
	balancedRootMeanSquaredError: "Kiegyensúlyozott RMSE",
	balancedAccuracy: "Kiegyensúlyozott pontosság",
	f1Score: "F1-Score",
	logLoss: "Log Loss",
	accuracyDescription: "A megfelelően osztályozott adatpontok hányada.",
	precisionDescription: "Az 1-es osztályozású adatpontok hányada, amelyek helyesen vannak osztályozva.",
	recallDescription: "Az 1-es valós címkével rendelkező adatpontok hányada, amelyek helyesen vannak osztályozva. Alternatív megnevezés: valós pozitív arány, érzékenység.",
	rmseDescription: "A négyzetes eltérések átlagának négyzetgyöke.",
	mseDescription: "A négyzetes eltérések átlaga.",
	meanAbsoluteErrorDescription: "Az eltérések abszolút értékeinek átlaga. Ellenállóbbak a kiugró értékekkel szemben, mint az MSE.",
	r2Description: "A címkék modell által kifejtett varianciahányada.",
	aucDescription: "Az előrejelzések pontszámként ábrázolt minősége a pozitív és a negatív példák elkülönítése terén.",
	balancedRMSEDescription: "A rendszer újrasúlyozza a pozitív és negatív példákat, hogy a teljes súly egyenlő legyen. Akkor ajánlott, ha a mögöttes adatok nagy mértékben kiegyensúlyozatlanok.",
	balancedAccuracyDescription: "A rendszer újrasúlyozza a pozitív és negatív példákat, hogy a teljes súly egyenlő legyen. Akkor ajánlott, ha a mögöttes adatok nagy mértékben kiegyensúlyozatlanok.",
	f1ScoreDescription: "F1-Score is the harmonic mean of precision and recall."
};
var BinDialog$5 = {
	header: "Dobozok konfigurálása",
	makeCategorical: "Kezelés kategorikusként",
	save: "Mentés",
	cancel: "Mégse",
	numberOfBins: "Dobozok száma:",
	categoryHeader: "Dobozértékek:"
};
var hu = {
	loremIpsum: loremIpsum$5,
	defaultClassNames: defaultClassNames$5,
	defaultFeatureNames: defaultFeatureNames$5,
	defaultSingleFeatureName: defaultSingleFeatureName$5,
	defaultCustomMetricName: defaultCustomMetricName$5,
	accuracyTab: accuracyTab$5,
	opportunityTab: opportunityTab$5,
	modelComparisonTab: modelComparisonTab$5,
	tableTab: tableTab$5,
	dataSpecifications: dataSpecifications$5,
	attributes: attributes$5,
	singleAttributeCount: singleAttributeCount$5,
	attributesCount: attributesCount$5,
	instanceCount: instanceCount$5,
	close: close$5,
	calculating: calculating$5,
	accuracyMetricLegacy: accuracyMetricLegacy$5,
	errorOnInputs: errorOnInputs$5,
	Accuracy: Accuracy$5,
	Parity: Parity$5,
	Header: Header$5,
	Footer: Footer$5,
	Intro: Intro$5,
	ModelComparison: ModelComparison$5,
	Report: Report$5,
	Feature: Feature$5,
	Metrics: Metrics$5,
	BinDialog: BinDialog$5
};

var loremIpsum$6 = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.";
var defaultClassNames$6 = "Classe {0}";
var defaultFeatureNames$6 = "Caratteristica sensibile {0}";
var defaultSingleFeatureName$6 = "Caratteristica sensibile";
var defaultCustomMetricName$6 = "Metrica personalizzata {0}";
var accuracyTab$6 = "Equità nelle prestazioni";
var opportunityTab$6 = "Equità nelle opportunità";
var modelComparisonTab$6 = "Confronto tra modelli";
var tableTab$6 = "Visualizzazione dettagli";
var dataSpecifications$6 = "Statistiche dati";
var attributes$6 = "Attributi";
var singleAttributeCount$6 = "1 caratteristica sensibile";
var attributesCount$6 = "{0} caratteristiche sensibili";
var instanceCount$6 = "{0} istanze";
var close$6 = "Chiudi";
var calculating$6 = "Calcolo...";
var accuracyMetricLegacy$6 = "Metrica delle prestazioni";
var errorOnInputs$6 = "Errore con input. Le caratteristiche sensibili devono essere al momento valori categorici. Eseguire il mapping dei valori alle categorie di cui è stato effettuato il binning e riprovare.";
var Accuracy$6 = {
	header: "Come si vogliono misurare le prestazioni?",
	modelMakes: "il modello crea",
	modelsMake: "i modelli creano",
	body: "I dati contengono etichette di tipo {0} e {2} stime con {1}. In base a queste informazioni, è consigliabile usare le metriche seguenti. Selezionare una metrica dall'elenco.",
	binaryClassifier: "classificatore binario",
	probabalisticRegressor: "regressore probit",
	regressor: "regressore",
	binary: "binario",
	continuous: "continuo"
};
var Parity$6 = {
	header: "Equità misurata in termini di disparità",
	body: "Le metriche di disparità quantificano la variazione del comportamento del modello in tutte le funzionalità selezionate. Esistono due tipi di metriche di disparità: altro da aggiungere...."
};
var Header$6 = {
	title: "Fairlearn",
	documentation: "Documentazione"
};
var Footer$6 = {
	back: "Indietro",
	next: "Avanti"
};
var Intro$6 = {
	welcome: "Benvenuti in",
	fairlearnDashboard: "Dashboard Fairlearn",
	introBody: "Il dashboard Fairlearn consente di valutare i compromessi tra prestazioni ed equità dei modelli",
	explanatoryStep: "Per configurare la valutazione, è necessario specificare una caratteristica sensibile e una metrica delle prestazioni.",
	getStarted: "Attività iniziali",
	features: "Caratteristiche sensibili",
	featuresInfo: "Le caratteristiche sensibili vengono usate per suddividere i dati in gruppi. L'equità del modello in questi gruppi viene misurata con le metriche di disparità. Le metriche di disparità quantificano quanto varia il comportamento del modello in questi gruppi.",
	accuracy: "Metrica delle prestazioni",
	accuracyInfo: "Le metriche delle prestazioni vengono usate per valutare la qualità complessiva del modello e la qualità del modello in ogni gruppo. La differenza tra i valori estremi della metrica delle prestazioni nei gruppi viene indicata come disparità nelle prestazioni."
};
var ModelComparison$6 = {
	title: "Confronto tra modelli",
	howToRead: "Come leggere questo grafico",
	lower: "più basso",
	higher: "più alto",
	howToReadText: "Questo grafico rappresenta ciascuno dei {0} modelli come punto selezionabile. L'asse x rappresenta {1}, con un valore {2} come valore migliore. L'asse y rappresenta la disparità, con un valore più basso come valore migliore.",
	insights: "Informazioni dettagliate",
	insightsText1: "Il grafico mostra {0} e la disparità di {1} modelli.",
	insightsText2: "{0} varia da {1} a {2}. La disparità varia da {3} a {4}.",
	insightsText3: "Il modello più accurato raggiunge {0} di {1} e una disparità di {2}.",
	insightsText4: "Il modello con disparità più bassa raggiunge {0} di {1} e una disparità di {2}.",
	disparityInOutcomes: "Disparità nelle previsioni",
	disparityInAccuracy: "Disparità in {0}",
	howToMeasureDisparity: "Come misurare la disparità?"
};
var Report$6 = {
	modelName: "Modello {0}",
	title: "Disparità nelle prestazioni",
	globalAccuracyText: "{0} in generale",
	accuracyDisparityText: "Disparità in {0}",
	editConfiguration: "Modifica configurazione",
	backToComparisons: "Vista multimodello",
	outcomesTitle: "Disparità nelle previsioni",
	minTag: "Min",
	maxTag: "Max",
	groupLabel: "Sottogruppo",
	underestimationError: "Sottostima",
	underpredictionExplanation: "(previsto = 0, vero = 1)",
	overpredictionExplanation: "(previsto = 1, vero = 0)",
	overestimationError: "Sovrastima",
	classificationOutcomesHowToRead: "Il grafico a barre mostra il tasso di selezione in ogni gruppo, ovvero la frazione dei punti classificati come 1.",
	regressionOutcomesHowToRead: "I box plot mostrano la distribuzione delle previsioni in ogni gruppo. I singoli punti dati sono sovrapposti in alto.",
	classificationAccuracyHowToRead1: "Il grafico a barre mostra la distribuzione degli errori in ogni gruppo.",
	classificationAccuracyHowToRead2: "Gli errori vengono suddivisi in errori di sovrastima (previsione di 1 quando l'etichetta vero è 0) ed errori di sottostima (previsione di 0 quando l'etichetta vero è 1).",
	classificationAccuracyHowToRead3: "Le percentuali indicate si ottengono dividendo il numero di errori per le dimensioni complessive del gruppo.",
	probabilityAccuracyHowToRead1: "Il grafico a barre mostra l'errore assoluto medio in ogni gruppo, suddiviso in sovrastima e sottostima.",
	probabilityAccuracyHowToRead2: "In ogni esempio, viene misurata la differenza tra la previsione e l'etichetta. Se è positiva, viene definita sovrastima e se è negativa, viene definita sottostima.",
	probabilityAccuracyHowToRead3: "Viene riportata la somma degli errori di sovrastima e la somma degli errori di sottostima divisi per le dimensioni complessive del gruppo.",
	regressionAccuracyHowToRead: "Errore indica la differenza tra la previsione e l'etichetta. I box plot mostrano la distribuzione degli errori in ogni gruppo. I singoli punti dati sono sovrapposti in alto.",
	distributionOfPredictions: "Distribuzione delle previsioni",
	distributionOfErrors: "Distribuzione degli errori",
	tooltipPrediction: "Previsione: {0}",
	tooltipError: "Errore: {0}"
};
var Feature$6 = {
	header: "Con quali funzionalità si vuole valutare l'equità del modello?",
	body: "L'equità viene valutata in termini di disparità nel comportamento del modello. I dati verranno suddivisi in base ai valori di ogni funzionalità selezionata e verrà valutato il modo in cui le previsioni e la metrica delle prestazioni del modello differiscono tra queste suddivisioni.",
	learnMore: "Altre informazioni",
	summaryCategoricalCount: "Questa funzionalità ha {0} valori univoci",
	summaryNumericCount: "Questa funzionalità numerica varia da {0} a {1} ed è raggruppata in {2} bin.",
	showCategories: "Mostra tutto",
	hideCategories: "Comprimi",
	categoriesOverflow: "   e {0} categorie aggiuntive",
	editBinning: "Modifica gruppi",
	subgroups: "Sottogruppi"
};
var Metrics$6 = {
	accuracyScore: "Accuratezza",
	precisionScore: "Precisione",
	recallScore: "Richiama",
	zeroOneLoss: "Perdita zero-uno",
	specificityScore: "Punteggio di specificità",
	missRate: "Frequenza di fallimento",
	falloutRate: "Tasso di ricaduta",
	maxError: "Errore massimo",
	meanAbsoluteError: "Errore assoluto medio",
	meanSquaredError: " MSE (errore quadratico medio)",
	meanSquaredLogError: "Errore logaritmico quadratico medio",
	medianAbsoluteError: "Errore assoluto mediano",
	average: "Previsione media",
	selectionRate: "Tasso di selezione",
	overprediction: "Sovrastima",
	underprediction: "Sottostima",
	r2_score: "Punteggio R quadrato",
	rms_error: "RMSE (radice dell'errore quadratico medio)",
	auc: "Area sotto la curva ROC",
	balancedRootMeanSquaredError: "RMSE bilanciato",
	balancedAccuracy: "Accuratezza bilanciata",
	f1Score: "F1-Score",
	logLoss: "Log Loss",
	accuracyDescription: "Frazione dei punti dati classificati correttamente.",
	precisionDescription: "Frazione dei punti dati classificati correttamente tra quelli classificati come 1.",
	recallDescription: "Frazione dei punti dati classificati correttamente tra quelli la cui etichetta vero è 1. Nomi alternativi: percentuale di veri positivi, sensibilità.",
	rmseDescription: "Radice quadrata della media degli errori quadratici.",
	mseDescription: "Media degli errori quadratici.",
	meanAbsoluteErrorDescription: "Media dei valori assoluti degli errori. Più affidabile per gli outlier rispetto a MSE.",
	r2Description: "Frazione della varianza nelle etichette spiegata dal modello.",
	aucDescription: "Qualità delle previsioni, visualizzate come punteggi, nel separare esempi positivi da esempi negativi.",
	balancedRMSEDescription: "Gli esempi positivi e negativi vengono riponderati in modo da avere un peso totale uguale. Adatto se i dati sottostanti sono altamente sbilanciati.",
	balancedAccuracyDescription: "Gli esempi positivi e negativi vengono riponderati in modo da avere un peso totale uguale. Adatto se i dati sottostanti sono altamente sbilanciati.",
	f1ScoreDescription: "F1-Score is the harmonic mean of precision and recall."
};
var BinDialog$6 = {
	header: "Configura bin",
	makeCategorical: "Gestisci come categorie",
	save: "Salva",
	cancel: "Annulla",
	numberOfBins: "Numero di bin:",
	categoryHeader: "Valori bin:"
};
var it = {
	loremIpsum: loremIpsum$6,
	defaultClassNames: defaultClassNames$6,
	defaultFeatureNames: defaultFeatureNames$6,
	defaultSingleFeatureName: defaultSingleFeatureName$6,
	defaultCustomMetricName: defaultCustomMetricName$6,
	accuracyTab: accuracyTab$6,
	opportunityTab: opportunityTab$6,
	modelComparisonTab: modelComparisonTab$6,
	tableTab: tableTab$6,
	dataSpecifications: dataSpecifications$6,
	attributes: attributes$6,
	singleAttributeCount: singleAttributeCount$6,
	attributesCount: attributesCount$6,
	instanceCount: instanceCount$6,
	close: close$6,
	calculating: calculating$6,
	accuracyMetricLegacy: accuracyMetricLegacy$6,
	errorOnInputs: errorOnInputs$6,
	Accuracy: Accuracy$6,
	Parity: Parity$6,
	Header: Header$6,
	Footer: Footer$6,
	Intro: Intro$6,
	ModelComparison: ModelComparison$6,
	Report: Report$6,
	Feature: Feature$6,
	Metrics: Metrics$6,
	BinDialog: BinDialog$6
};

var loremIpsum$7 = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.";
var defaultClassNames$7 = "クラス {0}";
var defaultFeatureNames$7 = "重要な特徴量 {0}";
var defaultSingleFeatureName$7 = "重要な特徴量";
var defaultCustomMetricName$7 = "カスタム メトリック {0}";
var accuracyTab$7 = "パフォーマンスの公平性";
var opportunityTab$7 = "機会の公平性";
var modelComparisonTab$7 = "モデルの比較";
var tableTab$7 = "詳細ビュー";
var dataSpecifications$7 = "データの統計情報";
var attributes$7 = "属性";
var singleAttributeCount$7 = "1 個の重要な特徴量";
var attributesCount$7 = "{0} 個の重要な特徴量";
var instanceCount$7 = "{0} 個のインスタンス";
var close$7 = "閉じる";
var calculating$7 = "計算しています...";
var accuracyMetricLegacy$7 = "パフォーマンス メトリック";
var errorOnInputs$7 = "入力でエラーが発生しました。現在、重要な特徴量はカテゴリ値である必要があります。値をビン分割されたカテゴリにマップしてから、もう一度お試しください。";
var Accuracy$7 = {
	header: "パフォーマンスの測定方法",
	modelMakes: "モデルの結果",
	modelsMake: "モデルの結果",
	body: "お客様のデータには、{0} ラベルと {2} {1} 予測が含まれています。この情報に基づいて、次のメトリックをお勧めします。リストからメトリックをいずれか 1 つ選択してください。",
	binaryClassifier: "2 項分類子",
	probabalisticRegressor: "プロビット リグレッサー",
	regressor: "リグレッサー",
	binary: "2 項",
	continuous: "継続的"
};
var Parity$7 = {
	header: "公平性を不均衡の観点から測定",
	body: "不均衡メトリックは、選択した特徴量間のモデルの動作のバリエーションを定量化します。次の 2 種類の不均衡メトリックがあり、さらに増える予定です。"
};
var Header$7 = {
	title: "Fairlearn",
	documentation: "ドキュメント"
};
var Footer$7 = {
	back: "戻る",
	next: "次へ"
};
var Intro$7 = {
	welcome: "ようこそ:",
	fairlearnDashboard: "Fairlearn ダッシュボード",
	introBody: "Fairlearn ダッシュボードを使用すると、モデルのパフォーマンスと公平性との間のトレードオフを評価できます",
	explanatoryStep: "評価を設定するには、重要な特徴量とパフォーマンス メトリックを指定する必要があります。",
	getStarted: "はじめに",
	features: "重要な特徴量",
	featuresInfo: "重要な特徴量は、データをグループに分割するために使用されます。これらのグループ間のモデルの公平性は、不均衡メトリックによって測定されます。不均衡メトリックは、これらのグループ間でモデルの動作がどれだけ変わるかを定量化します。",
	accuracy: "パフォーマンス メトリック",
	accuracyInfo: "パフォーマンス メトリックは、モデルの全体的な品質と、各グループのモデルの品質を評価するために使用されます。グループ間のパフォーマンス メトリックの極値の差は、パフォーマンスの不均衡として報告されます。"
};
var ModelComparison$7 = {
	title: "モデルの比較",
	howToRead: "このグラフの読み取り方法",
	lower: "値が小さい",
	higher: "値が大きい",
	howToReadText: "このグラフでは、各 {0} モデルを選択可能なポイントとして表します。X 軸は {1} を表し、{2} ほど優れています。Y 軸は、不均衡を表し、値が小さいほど優れています。",
	insights: "分析情報",
	insightsText1: "このグラフには、{1} モデルの {0} と不均衡が示されています。",
	insightsText2: "{0} の範囲は {1} から {2} までです。不均衡の範囲は {3} から {4} までです。",
	insightsText3: "最も正確なモデルは {1} の {0} と {2} の不均衡を実現します。",
	insightsText4: "最小の不均衡モデルは、{1} の {0} と {2} の不均衡を実現します。",
	disparityInOutcomes: "予測の不均衡",
	disparityInAccuracy: "{0} の不均衡",
	howToMeasureDisparity: "不均衡の測定方法"
};
var Report$7 = {
	modelName: "モデル {0}",
	title: "パフォーマンスの不均衡",
	globalAccuracyText: "全体的な {0}",
	accuracyDisparityText: "{0} の不均衡",
	editConfiguration: "構成の編集",
	backToComparisons: "マルチモデル ビュー",
	outcomesTitle: "予測の不均衡",
	minTag: "最小値",
	maxTag: "最大値",
	groupLabel: "サブグループ",
	underestimationError: "過小予測",
	underpredictionExplanation: "(予測 = 0、true = 1)",
	overpredictionExplanation: "(予測 = 1、true = 0)",
	overestimationError: "過剰予測",
	classificationOutcomesHowToRead: "横棒グラフは、各グループの選択率を示しており、ポイントの割合が 1 として分類されます。",
	regressionOutcomesHowToRead: "ボックス プロットは、各グループの予測の分布を示します。個々のデータ ポイントは上に重ねて表示されています。",
	classificationAccuracyHowToRead1: "横棒グラフは、各グループの誤差の分布を示します。",
	classificationAccuracyHowToRead2: "誤差は過剰予測による誤差 (true ラベルが 0 の場合に 1 を予測) と過少予測による誤差 (true ラベルが 1 の場合に 0 を予測) に分割されます。",
	classificationAccuracyHowToRead3: "報告率は、誤差の数をグループ全体のサイズで除算して取得します。",
	probabilityAccuracyHowToRead1: "横棒グラフは、各グループの平均絶対誤差を示しており、過剰予測と過少予測に分割されます。",
	probabilityAccuracyHowToRead2: "それぞれの例では、予測とラベルの差を測定します。正の場合は過剰予測と呼び、負の場合は過少予測と呼びます。",
	probabilityAccuracyHowToRead3: "過剰予測の誤差の合計と過小予測の誤差の合計をグループ全体のサイズで除算したものが報告されます。",
	regressionAccuracyHowToRead: "誤差は、予測とラベルの差です。ボックス プロットは、各グループの誤差の分布を示します。個々のデータ ポイントが上に重ねて表示されています。",
	distributionOfPredictions: "予測の分布",
	distributionOfErrors: "誤差の分布",
	tooltipPrediction: "予測: {0}",
	tooltipError: "誤差: {0}"
};
var Feature$7 = {
	header: "モデルの公平性を評価する特徴量",
	body: "公平性は、モデルの動作における不均衡の観点から評価されます。選択された各特徴量の値に従ってデータが分割され、モデルのパフォーマンス メトリックと予測がこれらの分割間でどのように異なるかが評価されます。",
	learnMore: "詳細情報",
	summaryCategoricalCount: "この特徴量には {0} 個の一意の値があります",
	summaryNumericCount: "この数値の特徴量は {0} から {1} までの範囲に及び、{2} 個のビンにグループ化されています。",
	showCategories: "すべて表示",
	hideCategories: "折りたたむ",
	categoriesOverflow: "と {0} 個の追加カテゴリ",
	editBinning: "グループの編集",
	subgroups: "サブグループ"
};
var Metrics$7 = {
	accuracyScore: "精度",
	precisionScore: "精度",
	recallScore: "再現率",
	zeroOneLoss: "0-1 損失",
	specificityScore: "特異度スコア",
	missRate: "見逃し率",
	falloutRate: "フォールアウト率",
	maxError: "誤差の最大値",
	meanAbsoluteError: "平均絶対誤差",
	meanSquaredError: " MSE (平均二乗誤差)",
	meanSquaredLogError: "平均二乗対数誤差",
	medianAbsoluteError: "中央絶対誤差",
	average: "平均予測",
	selectionRate: "選択率",
	overprediction: "過剰予測",
	underprediction: "過小予測",
	r2_score: "決定係数スコア",
	rms_error: "RMSE (平均平方二乗誤差)",
	auc: "ROC 曲線下の面積",
	balancedRootMeanSquaredError: "バランスの取れた RMSE",
	balancedAccuracy: "バランス精度",
	f1Score: "F1-Score",
	logLoss: "Log Loss",
	accuracyDescription: "正しく分類されたデータ ポイントの割合。",
	precisionDescription: "1 に分類されたデータ ポイントの中で正しく分類されたデータ ポイントの割合。",
	recallDescription: "true ラベルが 1 のデータ ポイントの中で正しく分類されたデータ ポイントの割合。代替名: 真陽性率、感度。",
	rmseDescription: "平均二乗誤差の平方根。",
	mseDescription: "二乗誤差の平均値。",
	meanAbsoluteErrorDescription: "誤差の絶対値の平均値。MSE よりも外れ値に対して頑健です。",
	r2Description: "モデルによって説明されているラベルの差異の割合。",
	aucDescription: "負の例から正の例を分ける際の予測の品質をスコアとして見たものです。",
	balancedRMSEDescription: "正および負の例は、総重量が等しくなるようにもう一度加重されます。基になるデータが極めて不均衡である場合に適しています。",
	balancedAccuracyDescription: "正および負の例は、総重量が等しくなるようにもう一度加重されます。基になるデータが極めて不均衡である場合に適しています。",
	f1ScoreDescription: "F1-Score is the harmonic mean of precision and recall."
};
var BinDialog$7 = {
	header: "ビンの構成",
	makeCategorical: "カテゴリ別として扱う",
	save: "保存",
	cancel: "キャンセル",
	numberOfBins: "ビンの数:",
	categoryHeader: "ビンの値:"
};
var ja = {
	loremIpsum: loremIpsum$7,
	defaultClassNames: defaultClassNames$7,
	defaultFeatureNames: defaultFeatureNames$7,
	defaultSingleFeatureName: defaultSingleFeatureName$7,
	defaultCustomMetricName: defaultCustomMetricName$7,
	accuracyTab: accuracyTab$7,
	opportunityTab: opportunityTab$7,
	modelComparisonTab: modelComparisonTab$7,
	tableTab: tableTab$7,
	dataSpecifications: dataSpecifications$7,
	attributes: attributes$7,
	singleAttributeCount: singleAttributeCount$7,
	attributesCount: attributesCount$7,
	instanceCount: instanceCount$7,
	close: close$7,
	calculating: calculating$7,
	accuracyMetricLegacy: accuracyMetricLegacy$7,
	errorOnInputs: errorOnInputs$7,
	Accuracy: Accuracy$7,
	Parity: Parity$7,
	Header: Header$7,
	Footer: Footer$7,
	Intro: Intro$7,
	ModelComparison: ModelComparison$7,
	Report: Report$7,
	Feature: Feature$7,
	Metrics: Metrics$7,
	BinDialog: BinDialog$7
};

var loremIpsum$8 = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.";
var defaultClassNames$8 = "클래스 {0}";
var defaultFeatureNames$8 = "중요한 기능 {0}";
var defaultSingleFeatureName$8 = "중요한 기능";
var defaultCustomMetricName$8 = "사용자 지정 메트릭 {0}";
var accuracyTab$8 = "성능의 공정성";
var opportunityTab$8 = "기회의 공정성";
var modelComparisonTab$8 = "모델 비교";
var tableTab$8 = "자세히 보기";
var dataSpecifications$8 = "데이터 통계";
var attributes$8 = "특성";
var singleAttributeCount$8 = "중요한 기능 1개";
var attributesCount$8 = "중요한 기능 {0}개";
var instanceCount$8 = "인스턴스 {0}개";
var close$8 = "닫기";
var calculating$8 = "계산하는 중...";
var accuracyMetricLegacy$8 = "성능 메트릭";
var errorOnInputs$8 = "입력에 오류가 있습니다. 지금은 중요한 기능이 범주 값이어야 합니다. 값을 계급 구간으로 나뉜 범주에 매핑한 후 다시 시도하세요.";
var Accuracy$8 = {
	header: "성능을 어떻게 측정하시겠습니까?",
	modelMakes: "모델 생성",
	modelsMake: "모델 생성",
	body: "데이터에 {0} 레이블과 {2} {1} 예측이 포함되어 있습니다. 해당 정보를 기반으로, 다음과 같은 메트릭이 권장됩니다. 목록에서 메트릭 하나를 선택하세요.",
	binaryClassifier: "이진 분류자",
	probabalisticRegressor: "프로빗 회귀 변수",
	regressor: "회귀 변수",
	binary: "이진",
	continuous: "연속"
};
var Parity$8 = {
	header: "차이 측면에서 측정된 공정성",
	body: "차이 메트릭은 선택한 기능에서 모델 동작의 변형을 정량화합니다. 차이 메트릭에는 두 가지 종류가 있으며 더 많은 종류가 제공될 예정입니다."
};
var Header$8 = {
	title: "Fairlearn",
	documentation: "설명서"
};
var Footer$8 = {
	back: "뒤로",
	next: "다음"
};
var Intro$8 = {
	welcome: "환영",
	fairlearnDashboard: "Fairlearn 대시보드",
	introBody: "Fairlearn 대시보드에서 모델의 성능과 공정성 간의 상쇄 관계를 평가할 수 있습니다.",
	explanatoryStep: "평가를 설정하려면 중요한 기능과 성능 메트릭을 지정해야 합니다.",
	getStarted: "시작",
	features: "중요한 기능",
	featuresInfo: "중요한 기능은 데이터를 그룹으로 분할하는 데 사용됩니다. 해당 그룹에서 모델의 공정성은 차이 메트릭으로 측정됩니다. 차이 메트릭은 모델의 동작이 해당 그룹에서 얼마나 다른지를 정량화합니다.",
	accuracy: "성능 메트릭",
	accuracyInfo: "성능 메트릭은 모델의 전체 품질과 각 그룹의 모델 품질을 평가하는 데 사용됩니다. 그룹에서 성능 메트릭의 극단적인 값 간 차이는 성능의 차이로 보고됩니다."
};
var ModelComparison$8 = {
	title: "모델 비교",
	howToRead: "이 차트를 읽는 방법",
	lower: "더 낮은",
	higher: "더 높은",
	howToReadText: "이 차트에서는 {0}개 모델을 각각 선택 가능한 요소로 나타냅니다. x축은 {1}을(를) 나타내고 {2} 경우가 더 좋습니다. y축은 차이를 나타내고 더 낮은 경우가 더 좋습니다.",
	insights: "인사이트",
	insightsText1: "차트에는 {1}개 모델의 {0} 및 차이가 표시됩니다.",
	insightsText2: "{0}의 범위는 {1}~{2}입니다. 차이 범위는 {3}~{4}입니다.",
	insightsText3: "가장 정확한 모델은 {1}의 {0} 및 {2}의 차이를 실현합니다.",
	insightsText4: "차이가 최저인 모델은 {1}의 {0} 및 {2}의 차이를 실현합니다.",
	disparityInOutcomes: "예측의 차이",
	disparityInAccuracy: "{0}의 차이",
	howToMeasureDisparity: "차이를 측정하는 방법은 무엇입니까?"
};
var Report$8 = {
	modelName: "모델 {0}",
	title: "성능의 차이",
	globalAccuracyText: "전체 {0}인지 여부",
	accuracyDisparityText: "{0}의 차이인지 여부",
	editConfiguration: "구성 편집",
	backToComparisons: "다중 모델 보기",
	outcomesTitle: "예측의 차이",
	minTag: "최솟값",
	maxTag: "최댓값",
	groupLabel: "하위 그룹",
	underestimationError: "과소 예측",
	underpredictionExplanation: "(예측 = 0, 실제 = 1)",
	overpredictionExplanation: "(예측 = 1, 실제 = 0)",
	overestimationError: "과대 예측",
	classificationOutcomesHowToRead: "가로 막대형 차트는 각 그룹의 선택 비율을 보여 주며, 1로 분류된 요소의 비율을 의미합니다.",
	regressionOutcomesHowToRead: "상자 그림은 각 그룹의 예측 분포를 보여 줍니다. 개별 데이터 요소가 위에 오버레이되어 있습니다.",
	classificationAccuracyHowToRead1: "가로 막대형 차트는 각 그룹의 오차 분포를 보여 줍니다.",
	classificationAccuracyHowToRead2: "오차는 과대 예측 오차(실제 레이블이 0인 경우 1을 예측)와 과소 예측 오차(실제 레이블이 1인 경우 0을 예측)로 나뉩니다.",
	classificationAccuracyHowToRead3: "보고된 비율은 오차 수를 전체 그룹 크기로 나눠 얻을 수 있습니다.",
	probabilityAccuracyHowToRead1: "가로 막대형 차트는 각 그룹의 절대 평균 오차를 의미하며, 과대 예측과 과소 예측으로 나누어져 있습니다.",
	probabilityAccuracyHowToRead2: "각 예제에서는 예측과 레이블 간의 차이를 측정합니다. 양수이면 과대 예측이라고 하고, 음수이면 과소 예측이라고 합니다.",
	probabilityAccuracyHowToRead3: "과대 예측 오차의 합계와 과소 예측 오차의 합계를 전체 그룹 크기로 나눈 값을 보고합니다.",
	regressionAccuracyHowToRead: "오차는 예측과 레이블 간의 차이입니다. 상자 그림은 각 그룹의 오차 분포를 보여 줍니다. 개별 데이터 요소가 위에 오버레이되어 있습니다.",
	distributionOfPredictions: "예측 분포",
	distributionOfErrors: "오차 분포",
	tooltipPrediction: "예측: {0}",
	tooltipError: "오차: {0}"
};
var Feature$8 = {
	header: "어떤 기능에 따라 모델의 공정성을 평가하시겠습니까?",
	body: "공정성은 모델 동작의 차이 측면에서 평가됩니다. 선택한 각 기능의 값에 따라 데이터를 분할하고 해당 분할에서 모델의 성능 메트릭 및 예측이 어떻게 다른지를 평가합니다.",
	learnMore: "자세한 정보",
	summaryCategoricalCount: "이 기능에는 고유 값이 {0}개 있습니다.",
	summaryNumericCount: "이 숫자 기능은 범위가 {0}~{1}이며, {2}개 bin으로 그룹화되었습니다.",
	showCategories: "모두 표시",
	hideCategories: "축소",
	categoriesOverflow: "   및 {0}개 추가 범주",
	editBinning: "그룹 편집",
	subgroups: "하위 그룹"
};
var Metrics$8 = {
	accuracyScore: "정확도",
	precisionScore: "정밀도",
	recallScore: "회수",
	zeroOneLoss: "제로-원 손실",
	specificityScore: "특정성 점수",
	missRate: "실패율",
	falloutRate: "좋지 못한 결과 비율",
	maxError: "최대 오차",
	meanAbsoluteError: "절대 평균 오차",
	meanSquaredError: " MSE(평균 제곱 오차)",
	meanSquaredLogError: "평균 제곱 로그 오차",
	medianAbsoluteError: "중앙값 절대 오차",
	average: "평균 예측",
	selectionRate: "선택 비율",
	overprediction: "과대 예측",
	underprediction: "과소 예측",
	r2_score: "R-제곱 점수",
	rms_error: "RMSE(제곱 평균 오차)",
	auc: "ROC 곡선 아래의 영역",
	balancedRootMeanSquaredError: "균형 잡힌 RMSE",
	balancedAccuracy: "균형 정확도",
	f1Score: "F1-Score",
	logLoss: "Log Loss",
	accuracyDescription: "제대로 분류된 데이터 요소의 비율입니다.",
	precisionDescription: "1로 분류된 데이터 요소 중에서 제대로 분류된 데이터 요소의 비율입니다.",
	recallDescription: "실제 레이블이 1인 데이터 요소 중 제대로 분류된 데이터 요소의 비율입니다. 대체 이름: 진양성 비율, 민감도.",
	rmseDescription: "제곱 오차의 평균에 대한 제곱근입니다.",
	mseDescription: "제곱 오차의 평균입니다.",
	meanAbsoluteErrorDescription: "오차의 절대값에 대한 평균입니다. MSE보다 이상값에 영향을 덜 받습니다.",
	r2Description: "모델에서 설명하는 레이블의 분산 비율입니다.",
	aucDescription: "올바른 예제와 잘못된 예제를 구분하여 점수로 표시한 예측의 품질입니다.",
	balancedRMSEDescription: "올바른 예제와 잘못된 예제는 같은 총 가중치를 갖도록 가중치가 다시 지정됩니다. 기본 데이터가 매우 불균형한 경우 적합합니다.",
	balancedAccuracyDescription: "올바른 예제와 잘못된 예제는 같은 총 가중치를 갖도록 가중치가 다시 지정됩니다. 기본 데이터가 매우 불균형한 경우 적합합니다.",
	f1ScoreDescription: "F1-Score is the harmonic mean of precision and recall."
};
var BinDialog$8 = {
	header: "bin 구성",
	makeCategorical: "범주로 처리",
	save: "저장",
	cancel: "취소",
	numberOfBins: "bin 수:",
	categoryHeader: "bin 값:"
};
var ko = {
	loremIpsum: loremIpsum$8,
	defaultClassNames: defaultClassNames$8,
	defaultFeatureNames: defaultFeatureNames$8,
	defaultSingleFeatureName: defaultSingleFeatureName$8,
	defaultCustomMetricName: defaultCustomMetricName$8,
	accuracyTab: accuracyTab$8,
	opportunityTab: opportunityTab$8,
	modelComparisonTab: modelComparisonTab$8,
	tableTab: tableTab$8,
	dataSpecifications: dataSpecifications$8,
	attributes: attributes$8,
	singleAttributeCount: singleAttributeCount$8,
	attributesCount: attributesCount$8,
	instanceCount: instanceCount$8,
	close: close$8,
	calculating: calculating$8,
	accuracyMetricLegacy: accuracyMetricLegacy$8,
	errorOnInputs: errorOnInputs$8,
	Accuracy: Accuracy$8,
	Parity: Parity$8,
	Header: Header$8,
	Footer: Footer$8,
	Intro: Intro$8,
	ModelComparison: ModelComparison$8,
	Report: Report$8,
	Feature: Feature$8,
	Metrics: Metrics$8,
	BinDialog: BinDialog$8
};

var loremIpsum$9 = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.";
var defaultClassNames$9 = "Klasse {0}";
var defaultFeatureNames$9 = "Gevoelige functie {0}";
var defaultSingleFeatureName$9 = "Gevoelige functie";
var defaultCustomMetricName$9 = "Aangepaste metrische gegevens {0}";
var accuracyTab$9 = "Verdeling in prestaties";
var opportunityTab$9 = "Verdeling in verkoopkans";
var modelComparisonTab$9 = "Modelvergelijking";
var tableTab$9 = "Detailweergave";
var dataSpecifications$9 = "Gegevensstatistieken";
var attributes$9 = "Kenmerken";
var singleAttributeCount$9 = "1 gevoelige functie";
var attributesCount$9 = "{0} gevoelige functies";
var instanceCount$9 = "{0} exemplaren";
var close$9 = "Sluiten";
var calculating$9 = "Berekenen...";
var accuracyMetricLegacy$9 = "Metrische prestatiegegevens";
var errorOnInputs$9 = "Fout bij invoer. Gevoelige functies moeten op dit moment categorisch zijn. Wijs waarden toe aan categorieën in bins en probeer het opnieuw.";
var Accuracy$9 = {
	header: "Hoe wilt u de prestaties meten?",
	modelMakes: "model maakt",
	modelsMake: "modellen maken",
	body: "Uw gegevens bevatten {0} labels en uw {2} {1} voorspellingen. Op basis van deze informatie raden we de volgende metrische gegevens aan. Selecteer één waarde in de lijst.",
	binaryClassifier: "binaire classificatie",
	probabalisticRegressor: "probit regressor",
	regressor: "regressor",
	binary: "binair",
	continuous: "doorlopend"
};
var Parity$9 = {
	header: "Verdeling gemeten in termen van verschil",
	body: "Met de verschilwaarden wordt de variatie van het gedrag van uw model op geselecteerde functies gekwantificeerd. Er zijn twee soorten verschilwaarden: wordt vervolgd...."
};
var Header$9 = {
	title: "Fairlearn",
	documentation: "Documentatie"
};
var Footer$9 = {
	back: "Vorige",
	next: "Volgende"
};
var Intro$9 = {
	welcome: "Welkom bij",
	fairlearnDashboard: "Fairlearn-dashboard",
	introBody: "Met het Fairlearn-dashboard kunt u de compromissen tussen prestaties en verdeling van uw modellen evalueren",
	explanatoryStep: "Als u de evaluatie wilt instellen, moet u een gevoelige functie en metrische prestatiegegevens opgeven.",
	getStarted: "Aan de slag",
	features: "Gevoelige functies",
	featuresInfo: "Gevoelige functies worden gebruikt om uw gegevens te splitsen in groepen. De verdeling van uw model over deze groepen wordt gemeten door de verschilwaarden te meten. Met de verschilwaarden wordt bepaald hoeveel het gedrag van uw model tussen deze groepen kan variëren.",
	accuracy: "Metrische prestatiegegevens",
	accuracyInfo: "Metrische prestatiegegevens worden gebruikt om de algehele kwaliteit van uw model en de kwaliteit van uw model in elke groep te evalueren. Het verschil tussen de uitersten van de metrische prestatiegegevens in de groepen wordt gerapporteerd als de prestatieverhouding."
};
var ModelComparison$9 = {
	title: "Modelvergelijking",
	howToRead: "Hoe u deze grafiek moet lezen",
	lower: "lager",
	higher: "hoger",
	howToReadText: "Deze grafiek toont elk van de {0} modellen als een selecteerbaar punt. De x-as toont {1}, waarbij {2} beter is. De y-as toont het verschil, waarbij lager beter is.",
	insights: "Inzichten",
	insightsText1: "De grafiek toont {0} en het verschil tussen {1} modellen.",
	insightsText2: "{0} loopt van {1} tot {2}. Het verschil loopt van {3} tot {4}.",
	insightsText3: "Het meest nauwkeurige model bereikt {0} van {1} en een verschil van {2}.",
	insightsText4: "Het model met het kleinste verschil bereikt {0} van {1} en een verschil van {2}.",
	disparityInOutcomes: "Verschil in voorspellingen",
	disparityInAccuracy: "Verschil in {0}",
	howToMeasureDisparity: "Hoe moet het verschil worden gemeten?"
};
var Report$9 = {
	modelName: "Model {0}",
	title: "Verschil in prestaties",
	globalAccuracyText: "Is de algemene {0}",
	accuracyDisparityText: "Is het verschil in {0}",
	editConfiguration: "Configuratie bewerken",
	backToComparisons: "Weergave met meerdere modellen",
	outcomesTitle: "Verschil in voorspellingen",
	minTag: "Minimum",
	maxTag: "Maximum",
	groupLabel: "Subgroep",
	underestimationError: "Ondervoorspelling",
	underpredictionExplanation: "(voorspeld = 0, werkelijk = 1)",
	overpredictionExplanation: "(voorspeld = 1, werkelijk = 0)",
	overestimationError: "Overvoorspelling",
	classificationOutcomesHowToRead: "Het staafdiagram toont het selectiepercentage in elke groep, dat wil zeggen het aantal punten dat wordt geclassificeerd als 1.",
	regressionOutcomesHowToRead: "In boxplots wordt de distributie van voorspellingen in elke groep weergegeven. Afzonderlijke gegevenspunten worden hier overheen gelegd.",
	classificationAccuracyHowToRead1: "In het staafdiagram wordt de distributie van fouten in elke groep weergegeven.",
	classificationAccuracyHowToRead2: "Fouten zijn opgesplitst in fouten met overvoorspelling (voorspelling 1 wanneer het werkelijke label 0 is) en fouten met ondervoorspelling (voorspelling 0 wanneer het werkelijke label 1 is).",
	classificationAccuracyHowToRead3: "De gerapporteerde aantallen worden verkregen door het aantal fouten te delen door de totale groepsgrootte.",
	probabilityAccuracyHowToRead1: "Het staafdiagram laat de gemiddelde absolute fout in elke groep zien, gesplitst naar overvoorspelling en ondervoorspellinig.",
	probabilityAccuracyHowToRead2: "In elk voorbeeld wordt het verschil gemeten tussen de voorspelling en het label. Als het positief is, wordt het overvoorspelling genoemd en als het negatief is, wordt het ondervoorspelling genoemd.",
	probabilityAccuracyHowToRead3: "We rapporteren de som van de fouten met overvoorspelling en de som van de fouten met ondervoorspelling, gedeeld door de totale groepsgrootte.",
	regressionAccuracyHowToRead: "De fout is het verschil tussen de voorspelling en het label. In boxplots wordt de distributie van fouten in elke groep weergegeven. Afzonderlijke gegevenspunten worden hier overheen gelegd.",
	distributionOfPredictions: "Distributie van voorspellingen",
	distributionOfErrors: "Distributie van fouten",
	tooltipPrediction: "Voorspelling: {0}",
	tooltipError: "Fout: {0}"
};
var Feature$9 = {
	header: "Voor welke functies wilt u de verdeling van uw model evalueren?",
	body: "Verdeling wordt geëvalueerd in termen van verschillen in het gedrag van uw model. Uw gegevens worden gesplitst op basis van de waarden van elke geselecteerde functie en er wordt geëvalueerd hoe deze splitsingen verschillen in de prestatiegegevens en voorspellingen van uw model.",
	learnMore: "Meer informatie",
	summaryCategoricalCount: "Deze functie heeft {0} unieke waarden",
	summaryNumericCount: "Deze numerieke functie heeft een bereik van {0} tot {1} en is gegroepeerd in {2} bins.",
	showCategories: "Alles weergeven",
	hideCategories: "Samenvouwen",
	categoriesOverflow: "   en {0} aanvullende categorieën",
	editBinning: "Groepen bewerken",
	subgroups: "Subgroepen"
};
var Metrics$9 = {
	accuracyScore: "Nauwkeurigheid",
	precisionScore: "Precisie",
	recallScore: "Terughalen",
	zeroOneLoss: "Nul-één verlies",
	specificityScore: "Score voor specificiteit",
	missRate: "Aantal missers",
	falloutRate: "Uitvalpercentage",
	maxError: "Maximumfout",
	meanAbsoluteError: "Gemiddelde absolute fout",
	meanSquaredError: " MSE (gemiddelde fout in het kwadraat)",
	meanSquaredLogError: "Gemiddelde logboekfout in kwadraat",
	medianAbsoluteError: "Mediaan absolute fout",
	average: "Gemiddelde voorspelling",
	selectionRate: "Selectiesnelheid",
	overprediction: "Overvoorspelling",
	underprediction: "Ondervoorspelling",
	r2_score: "R-kwadraatscore",
	rms_error: "RMSE (wortel gemiddelde kwadratische fout)",
	auc: "Gebied onder ROC-curve",
	balancedRootMeanSquaredError: "Verdeelde RMSE",
	balancedAccuracy: "Verdeelde nauwkeurigheid",
	f1Score: "F1-Score",
	logLoss: "Log Loss",
	accuracyDescription: "Het deel van de gegevenspunten dat op de juiste wijze is ingedeeld.",
	precisionDescription: "Het deel van de gegevenspunten dat correct is geclassificeerd van alle gegevenspunten die als 1 zijn geclassificeerd.",
	recallDescription: "Het deel van de gegevenspunten dat correct is geclassificeerd van alle gegevenspunten waarvan het werkelijke label 1 is. Alternatieve benamingen: frequentie terecht-positieven, gevoeligheid.",
	rmseDescription: "Vierkantswortel van het gemiddelde van de kwadratische fouten.",
	mseDescription: "Het gemiddelde van de kwadratische fouten.",
	meanAbsoluteErrorDescription: "Het gemiddelde van de absolute waarden van fouten. Robuuster voor uitschieters dan MSE.",
	r2Description: "Het deel afwijking in de labels die worden uitgelegd door het model.",
	aucDescription: "De kwaliteit van de voorspellingen, die worden weergegeven als scores, in het scheiden van positieve voorbeelden van negatieve voorbeelden.",
	balancedRMSEDescription: "Positieve en negatieve voorbeelden worden opnieuw gewogen zodat ze even zwaar wegen. Geschikt als de onderliggende gegevens zeer ongelijk zijn verdeeld.",
	balancedAccuracyDescription: "Positieve en negatieve voorbeelden worden opnieuw gewogen zodat ze even zwaar wegen. Geschikt als de onderliggende gegevens zeer ongelijk zijn verdeeld.",
	f1ScoreDescription: "F1-Score is the harmonic mean of precision and recall."
};
var BinDialog$9 = {
	header: "Bins configureren",
	makeCategorical: "Beschouwen als categorisch",
	save: "Opslaan",
	cancel: "Annuleren",
	numberOfBins: "Aantal bins:",
	categoryHeader: "Binwaarden:"
};
var nl = {
	loremIpsum: loremIpsum$9,
	defaultClassNames: defaultClassNames$9,
	defaultFeatureNames: defaultFeatureNames$9,
	defaultSingleFeatureName: defaultSingleFeatureName$9,
	defaultCustomMetricName: defaultCustomMetricName$9,
	accuracyTab: accuracyTab$9,
	opportunityTab: opportunityTab$9,
	modelComparisonTab: modelComparisonTab$9,
	tableTab: tableTab$9,
	dataSpecifications: dataSpecifications$9,
	attributes: attributes$9,
	singleAttributeCount: singleAttributeCount$9,
	attributesCount: attributesCount$9,
	instanceCount: instanceCount$9,
	close: close$9,
	calculating: calculating$9,
	accuracyMetricLegacy: accuracyMetricLegacy$9,
	errorOnInputs: errorOnInputs$9,
	Accuracy: Accuracy$9,
	Parity: Parity$9,
	Header: Header$9,
	Footer: Footer$9,
	Intro: Intro$9,
	ModelComparison: ModelComparison$9,
	Report: Report$9,
	Feature: Feature$9,
	Metrics: Metrics$9,
	BinDialog: BinDialog$9
};

var loremIpsum$a = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum.";
var defaultClassNames$a = "Klasa {0}";
var defaultFeatureNames$a = "Cecha wrażliwa {0}";
var defaultSingleFeatureName$a = "Cecha wrażliwa";
var defaultCustomMetricName$a = "Metryka niestandardowa {0}";
var accuracyTab$a = "Atrakcyjność wydajności";
var opportunityTab$a = "Atrakcyjność okazji";
var modelComparisonTab$a = "Porównanie modeli";
var tableTab$a = "Widok szczegółów";
var dataSpecifications$a = "Statystyki danych";
var attributes$a = "Atrybuty";
var singleAttributeCount$a = "1 cecha wrażliwa";
var attributesCount$a = "Cechy wrażliwe w liczbie {0}";
var instanceCount$a = "Wystąpienia: {0}";
var close$a = "Zamknij";
var calculating$a = "Trwa obliczanie...";
var accuracyMetricLegacy$a = "Metryka wydajności";
var errorOnInputs$a = "Błąd danych wejściowych. Cechy wrażliwe muszą być teraz wartościami kategorialnymi. Zamapuj wartości do kategorii w przedziałach i ponów próbę.";
var Accuracy$a = {
	header: "Jak chcesz mierzyć wydajność?",
	modelMakes: "model tworzy",
	modelsMake: "modele tworzą",
	body: "Dane zawierają etykiety w liczbie {0} oraz przewidywania ({2} {1}). Na podstawie tych informacji zalecamy następujące metryki. Wybierz jedną metrykę z listy.",
	binaryClassifier: "klasyfikator binarny",
	probabalisticRegressor: "regresor probitów",
	regressor: "regresor",
	binary: "binarny",
	continuous: "ciągły"
};
var Parity$a = {
	header: "Atrakcyjność mierzona za pomocą rozbieżności",
	body: "Metryki rozbieżności określają wartość odchylenia dla zachowania modelu w ramach wybranych cech. Istnieją dwa rodzaje metryk rozbieżności: informacje zostaną uzupełnione...."
};
var Header$a = {
	title: "Fairlearn",
	documentation: "Dokumentacja"
};
var Footer$a = {
	back: "Wstecz",
	next: "Dalej"
};
var Intro$a = {
	welcome: "Witamy w",
	fairlearnDashboard: "Pulpit nawigacyjny Fairlearn",
	introBody: "Pulpit nawigacyjny Fairlearn umożliwia ocenę kompromisów między wydajnością i atrakcyjnością modeli",
	explanatoryStep: "Aby skonfigurować ocenę, należy określić cechę wrażliwą i metrykę wydajności.",
	getStarted: "Rozpocznij",
	features: "Cechy wrażliwe",
	featuresInfo: "Cechy wrażliwe służą do dzielenia danych na grupy. Atrakcyjność modelu w ramach tych grup jest mierzona za pomocą metryk rozbieżności. Metryki rozbieżności określają wielkość różnic w zachowaniu modelu względem grup.",
	accuracy: "Metryka wydajności",
	accuracyInfo: "Metryki wydajności służą do oceny ogólnej jakości modelu oraz jakości modelu w każdej grupie. Różnica między skrajnymi wartościami metryki wydajności w grupach jest zgłaszana jako rozbieżność wydajności."
};
var ModelComparison$a = {
	title: "Porównanie modeli",
	howToRead: "Jak czytać ten wykres",
	lower: "mniejsza",
	higher: "większa",
	howToReadText: "Ten wykres reprezentuje każdy z {0} modeli jako punkt, który można wybrać. Oś X reprezentuje {1}, przy czym wartość {2} jest lepsza. Oś Y reprezentuje rozbieżność, przy czym wartość mniejsza jest lepsza.",
	insights: "Analizy",
	insightsText1: "Wykres pokazuje {0} i rozbieżność {1} modeli.",
	insightsText2: "Zakresy w liczbie {0} od {1} do {2}. Zakresy rozbieżności od {3} do {4}.",
	insightsText3: "Najbardziej dokładny model osiąga {0} z {1} i rozbieżność {2}.",
	insightsText4: "Model najniższej rozbieżności osiąga {0} z {1} i rozbieżność {2}.",
	disparityInOutcomes: "Rozbieżność w przewidywaniach",
	disparityInAccuracy: "Rozbieżność w {0}",
	howToMeasureDisparity: "Jak należy mierzyć rozbieżności?"
};
var Report$a = {
	modelName: "Model {0}",
	title: "Rozbieżność wydajności",
	globalAccuracyText: "To ogólnie {0}",
	accuracyDisparityText: "To rozbieżność w {0}",
	editConfiguration: "Edytuj konfigurację",
	backToComparisons: "Widok wielu modeli",
	outcomesTitle: "Rozbieżność w przewidywaniach",
	minTag: "Min.",
	maxTag: "Maks.",
	groupLabel: "Podgrupa",
	underestimationError: "Niedoszacowanie",
	underpredictionExplanation: "(przewidywane = 0, rzeczywiste = 1)",
	overpredictionExplanation: "(przewidywane = 1, rzeczywiste = 0)",
	overestimationError: "Przeszacowanie",
	classificationOutcomesHowToRead: "Wykres słupkowy pokazuje współczynnik wyboru w każdej grupie, co oznacza ułamek punktów sklasyfikowanych jako 1.",
	regressionOutcomesHowToRead: "Wykresy skrzynkowe pokazują rozkład przewidywań w każdej grupie. Poszczególne punkty danych są nałożone na górze.",
	classificationAccuracyHowToRead1: "Wykres słupkowy pokazuje rozkład błędów w każdej grupie.",
	classificationAccuracyHowToRead2: "Błędy są podzielone na błędy przeszacowania (przewidywanie 1, gdy rzeczywista etykieta to 0) i niedoszacowania (przewidywanie 0, gdy rzeczywista etykieta to 1).",
	classificationAccuracyHowToRead3: "Zgłoszone współczynniki uzyskuje się przez podzielenie liczby błędów przez łączny rozmiar grupy.",
	probabilityAccuracyHowToRead1: "Wykres słupkowy pokazuje średni błąd bezwzględny w każdej grupie podzielony na przeszacowania i niedoszacowania.",
	probabilityAccuracyHowToRead2: "Dla każdej próbki mierzymy różnicę między przewidywaniem i etykietą. Jeśli jest dodatnia, oznacza to przeszacowanie, a jeśli ujemna — niedoszacowanie.",
	probabilityAccuracyHowToRead3: "Zgłaszamy sumę błędów przeszacowania oraz sumę błędów niedoszacowania podzieloną przez łączny rozmiar grupy.",
	regressionAccuracyHowToRead: "Błąd to różnica między przewidywaniem i etykietą. Wykresy skrzynkowe pokazują rozkład błędów w każdej grupie. Poszczególne punkty danych są nałożone na górze.",
	distributionOfPredictions: "Rozkład przewidywań",
	distributionOfErrors: "Rozkład błędów",
	tooltipPrediction: "Przewidywanie: {0}",
	tooltipError: "Błąd: {0}"
};
var Feature$a = {
	header: "Względem jakich cech chcesz ocenić atrakcyjność modelu?",
	body: "Atrakcyjność jest oceniana pod względem rozbieżności w zachowaniu modelu. Dane zostaną podzielone według wartości każdej wybranej cechy, a następnie zostaną ocenione różnice między metryką wydajności i przewidywaniami modelu w ramach tych podziałów.",
	learnMore: "Dowiedz się więcej",
	summaryCategoricalCount: "Liczba unikatowych wartości tej cechy to {0}",
	summaryNumericCount: "Zakres tej cechy liczbowej to od {0} do {1} w {2} przedziałach.",
	showCategories: "Pokaż wszystko",
	hideCategories: "Zwiń",
	categoriesOverflow: "   i dodatkowe kategorie w liczbie {0}",
	editBinning: "Edytuj grupy",
	subgroups: "Podgrupy"
};
var Metrics$a = {
	accuracyScore: "Dokładność",
	precisionScore: "Dokładność",
	recallScore: "Unieważnij",
	zeroOneLoss: "Utrata zerojedynkowa",
	specificityScore: "Wynik swoistości",
	missRate: "Współczynnik chybień",
	falloutRate: "Współczynnik odpadów",
	maxError: "Maksymalny błąd",
	meanAbsoluteError: "Średni błąd bezwzględny",
	meanSquaredError: " MSE (średni błąd kwadratowy)",
	meanSquaredLogError: "Błąd dziennika średniego kwadratowego",
	medianAbsoluteError: "Mediana błędu bezwzględnego",
	average: "Średnie przewidywanie",
	selectionRate: "Współczynnik wyboru",
	overprediction: "Przeszacowanie",
	underprediction: "Niedoszacowanie",
	r2_score: "Wynik współczynnika R do kwadratu",
	rms_error: "RMSE (średni błąd kwadratowy)",
	auc: "Obszar pod krzywą ROC",
	balancedRootMeanSquaredError: "Zrównoważone RMSE",
	balancedAccuracy: "Zrównoważona dokładność",
	f1Score: "F1-Score",
	logLoss: "Log Loss",
	accuracyDescription: "Ułamek punktów danych sklasyfikowanych poprawnie.",
	precisionDescription: "Ułamek punktów danych sklasyfikowanych poprawnie wśród tych, które sklasyfikowano jako 1.",
	recallDescription: "Ułamek punktów danych sklasyfikowanych poprawnie wśród tych, których rzeczywista etykieta to 1. Alternatywne nazwy: rzeczywisty współczynnik poprawności, wrażliwość.",
	rmseDescription: "Pierwiastek kwadratowy ze średniej błędów do kwadratu.",
	mseDescription: "Średnia kwadratów błędów.",
	meanAbsoluteErrorDescription: "Średnia wartości bezwzględnych błędów. Bardziej niezawodna dla wartości odstających niż wartość MSE.",
	r2Description: "Ułamek odchylenia w etykietach objaśnionych przez model.",
	aucDescription: "Jakość przewidywań dla oddzielania próbek pozytywnych od negatywnych wyświetlana w postaci wyników.",
	balancedRMSEDescription: "Próbki pozytywne i negatywne są ważone ponownie, tak aby miały równą wagę łączną. Odpowiednie, jeśli dane podstawowe są bardzo niezrównoważone.",
	balancedAccuracyDescription: "Próbki pozytywne i negatywne są ważone ponownie, tak aby miały równą wagę łączną. Odpowiednie, jeśli dane podstawowe są bardzo niezrównoważone.",
	f1ScoreDescription: "F1-Score is the harmonic mean of precision and recall."
};
var BinDialog$a = {
	header: "Konfiguruj przedziały",
	makeCategorical: "Traktuj jako kategorialne",
	save: "Zapisz",
	cancel: "Anuluj",
	numberOfBins: "Liczba przedziałów:",
	categoryHeader: "Wartości przedziału:"
};
var pl = {
	loremIpsum: loremIpsum$a,
	defaultClassNames: defaultClassNames$a,
	defaultFeatureNames: defaultFeatureNames$a,
	defaultSingleFeatureName: defaultSingleFeatureName$a,
	defaultCustomMetricName: defaultCustomMetricName$a,
	accuracyTab: accuracyTab$a,
	opportunityTab: opportunityTab$a,
	modelComparisonTab: modelComparisonTab$a,
	tableTab: tableTab$a,
	dataSpecifications: dataSpecifications$a,
	attributes: attributes$a,
	singleAttributeCount: singleAttributeCount$a,
	attributesCount: attributesCount$a,
	instanceCount: instanceCount$a,
	close: close$a,
	calculating: calculating$a,
	accuracyMetricLegacy: accuracyMetricLegacy$a,
	errorOnInputs: errorOnInputs$a,
	Accuracy: Accuracy$a,
	Parity: Parity$a,
	Header: Header$a,
	Footer: Footer$a,
	Intro: Intro$a,
	ModelComparison: ModelComparison$a,
	Report: Report$a,
	Feature: Feature$a,
	Metrics: Metrics$a,
	BinDialog: BinDialog$a
};

var loremIpsum$b = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.";
var defaultClassNames$b = "Classe {0}";
var defaultFeatureNames$b = "Recurso confidencial {0}";
var defaultSingleFeatureName$b = "Recurso confidencial";
var defaultCustomMetricName$b = "Métrica personalizada {0}";
var accuracyTab$b = "Equidade no Desempenho";
var opportunityTab$b = "Equidade na Oportunidade";
var modelComparisonTab$b = "Comparação de modelo";
var tableTab$b = "Exibição de Detalhes";
var dataSpecifications$b = "Estatísticas de dados";
var attributes$b = "Atributos";
var singleAttributeCount$b = "1 recurso confidencial";
var attributesCount$b = "{0} recursos confidenciais";
var instanceCount$b = "{0} instâncias";
var close$b = "Fechar";
var calculating$b = "Calculando...";
var accuracyMetricLegacy$b = "Métrica de desempenho";
var errorOnInputs$b = "Erro com a entrada. Recursos confidenciais precisam ser valores categóricos neste momento. Mapeie valores para as categorias compartimentalizadas e tente novamente.";
var Accuracy$b = {
	header: "Como deseja medir o desempenho?",
	modelMakes: "realizado por modelo",
	modelsMake: "realizado por modelos",
	body: "Os seus dados contêm {0} rótulos e as suas previsões de {2} {1}. Com base nessas informações, recomendamos as métricas a seguir. Selecione uma métrica na lista.",
	binaryClassifier: "classificador binário",
	probabalisticRegressor: "regressor de probit",
	regressor: "regressor",
	binary: "binário",
	continuous: "contínuo"
};
var Parity$b = {
	header: "Equidade medida em termos de disparidade",
	body: "As métricas de disparidade quantificam a variação do comportamento do seu modelo nos recursos selecionados. Há dois tipos de métricas de disparidade: mais em breve...."
};
var Header$b = {
	title: "Fairlearn",
	documentation: "Documentação"
};
var Footer$b = {
	back: "Voltar",
	next: "Avançar"
};
var Intro$b = {
	welcome: "Bem-vindo(a) a",
	fairlearnDashboard: "Painel do Fairlearn",
	introBody: "O painel do Fairlearn permite que você avalie as compensações entre o desempenho e a equidade dos seus modelos",
	explanatoryStep: "Para configurar a avaliação, é necessário especificar um recurso confidencial e uma métrica de desempenho.",
	getStarted: "Introdução",
	features: "Recursos confidenciais",
	featuresInfo: "Recursos confidenciais são usados para dividir os seus dados em grupos. A equidade do seu modelo nesses grupos é medida por métricas de disparidade. As métricas de disparidade quantificam o quanto o comportamento do modelo varia nesses grupos.",
	accuracy: "Métrica de desempenho",
	accuracyInfo: "As métricas de desempenho são usadas para avaliar a qualidade geral do seu modelo, bem como a qualidade do seu modelo em cada grupo. A diferença entre os valores extremos da métrica de desempenho nos grupos é relatada como a disparidade no desempenho."
};
var ModelComparison$b = {
	title: "Comparação de modelo",
	howToRead: "Como ler este gráfico",
	lower: "menor",
	higher: "maior",
	howToReadText: "Este gráfico representa cada um dos modelos de {0} como um ponto selecionável. O eixo x representa {1}, no qual {2} é melhor. O eixo y representa a disparidade, na qual um valor menor é melhor.",
	insights: "Insights",
	insightsText1: "O gráfico mostra {0} e a disparidade de modelos de {1}.",
	insightsText2: "{0} tem um intervalo de {1} a {2}. A disparidade tem um intervalo de {3} a {4}.",
	insightsText3: "O modelo mais preciso atinge {0} de {1} e uma disparidade de {2}.",
	insightsText4: "O modelo com menor disparidade atinge {0} de {1} e uma disparidade de {2}.",
	disparityInOutcomes: "Disparidade nas previsões",
	disparityInAccuracy: "A disparidade no {0}",
	howToMeasureDisparity: "Como deve ser medida a disparidade?"
};
var Report$b = {
	modelName: "Modelo {0}",
	title: "Disparidade no desempenho",
	globalAccuracyText: "É o {0} geral",
	accuracyDisparityText: "É a disparidade em {0}",
	editConfiguration: "Editar a configuração",
	backToComparisons: "Exibição multimodelo",
	outcomesTitle: "Disparidade nas previsões",
	minTag: "Mín.",
	maxTag: "Máx.",
	groupLabel: "Subgrupo",
	underestimationError: "Subprevisão",
	underpredictionExplanation: "(previsto = 0, verdadeiro = 1)",
	overpredictionExplanation: "(previsto = 1, verdadeiro = 0)",
	overestimationError: "Sobreprevisão",
	classificationOutcomesHowToRead: "O gráfico de barras mostra a taxa de seleção em cada grupo, o que significa a fração de pontos classificados como 1.",
	regressionOutcomesHowToRead: "Os gráficos de caixa mostram a distribuição de previsões em cada grupo. Os pontos de dados individuais estão sobrepostos na parte superior.",
	classificationAccuracyHowToRead1: "O gráfico de barras mostra a distribuição de erros em cada grupo.",
	classificationAccuracyHowToRead2: "Os erros são divididos em erros de sobreprevisão (prever 1 quando o rótulo verdadeiro é 0) e erros de subprevisão (prever 0 quando o rótulo verdadeiro é 1).",
	classificationAccuracyHowToRead3: "As taxas relatadas são obtidas ao dividir o número de erros pelo tamanho geral do grupo.",
	probabilityAccuracyHowToRead1: "O gráfico de barras mostra um erro absoluto médio em cada grupo, dividido em sobreprevisão e subprevisão.",
	probabilityAccuracyHowToRead2: "Em cada exemplo, medimos a diferença entre a previsão e o rótulo. Se for positiva, nós a chamaremos de sobreprevisão, e se for negativa, nós a chamaremos de subprevisão.",
	probabilityAccuracyHowToRead3: "Relatamos a soma de erros de sobreprevisão e a soma de erros de subprevisão divididas pelo tamanho do grupo geral.",
	regressionAccuracyHowToRead: "O erro é a diferença entre a previsão e o rótulo. Os gráficos de caixa mostram a distribuição de erros em cada grupo. Os pontos de dados individuais estão sobrepostos na parte superior.",
	distributionOfPredictions: "Distribuição de previsões",
	distributionOfErrors: "Distribuição de erros",
	tooltipPrediction: "Previsão: {0}",
	tooltipError: "Erro: {0}"
};
var Feature$b = {
	header: "Junto com quais recursos você deseja avaliar a equidade do seu modelo?",
	body: "A equidade é avaliada em termos de disparidades no comportamento do modelo. Vamos dividir os seus dados de acordo com os valores de cada recurso selecionado e avaliar como a métrica de desempenho e as previsões do modelo diferem nessas divisões.",
	learnMore: "Saiba mais",
	summaryCategoricalCount: "Este recurso tem {0} valores exclusivos",
	summaryNumericCount: "Este recurso numérico varia de {0} a {1} e é agrupado em {2} compartimentos.",
	showCategories: "Mostrar tudo",
	hideCategories: "Recolher",
	categoriesOverflow: "   e {0} categorias adicionais",
	editBinning: "Editar grupos",
	subgroups: "Subgrupos"
};
var Metrics$b = {
	accuracyScore: "Precisão",
	precisionScore: "Precisão",
	recallScore: "Recall",
	zeroOneLoss: "Perda zero-um",
	specificityScore: "Pontuação de especificidade",
	missRate: "Taxa de erros",
	falloutRate: "Taxa de fallout",
	maxError: "Máximo de erros",
	meanAbsoluteError: "Erro absoluto médio",
	meanSquaredError: " MSE (erro quadrático médio)",
	meanSquaredLogError: "Erro logarítmico quadrático médio",
	medianAbsoluteError: "Erro absoluto mediano",
	average: "Previsão média",
	selectionRate: "Taxa de seleção",
	overprediction: "Sobreprevisão",
	underprediction: "Subprevisão",
	r2_score: "Pontuação de R-quadrado",
	rms_error: "RMSE (raiz do erro quadrático médio)",
	auc: "Área abaixo da curva do ROC",
	balancedRootMeanSquaredError: "RMSE equilibrado",
	balancedAccuracy: "Precisão balanceada",
	f1Score: "F1-Score",
	logLoss: "Log Loss",
	accuracyDescription: "A fração de pontos de dados classificados corretamente.",
	precisionDescription: "A fração de pontos de dados classificados corretamente entre aqueles classificados como 1.",
	recallDescription: "A fração de pontos de dados classificados corretamente entre aqueles cujo rótulo verdadeiro é 1. Nomes alternativos: taxa de verdadeiro positivo, confidencialidade.",
	rmseDescription: "Raiz quadrada da média de erros quadráticos.",
	mseDescription: "A média de erros quadráticos.",
	meanAbsoluteErrorDescription: "A média de valores absolutos de erros. Mais robusto para exceções do que para MSE.",
	r2Description: "A fração de variância nos rótulos explicada pelo modelo.",
	aucDescription: "A qualidade das previsões, exibidas como pontuações, ao separar exemplos positivos de exemplos negativos.",
	balancedRMSEDescription: "Exemplos positivos e negativos são ponderados novamente para que tenham o peso total igual. Adequado se os dados subjacentes forem altamente desequilibrados.",
	balancedAccuracyDescription: "Exemplos positivos e negativos são ponderados novamente para que tenham o peso total igual. Adequado se os dados subjacentes forem altamente desequilibrados.",
	f1ScoreDescription: "F1-Score is the harmonic mean of precision and recall."
};
var BinDialog$b = {
	header: "Configurar compartimentos",
	makeCategorical: "Tratar como categórico",
	save: "Salvar",
	cancel: "Cancelar",
	numberOfBins: "Número de compartimentos:",
	categoryHeader: "Valores de compartimento:"
};
var ptbr = {
	loremIpsum: loremIpsum$b,
	defaultClassNames: defaultClassNames$b,
	defaultFeatureNames: defaultFeatureNames$b,
	defaultSingleFeatureName: defaultSingleFeatureName$b,
	defaultCustomMetricName: defaultCustomMetricName$b,
	accuracyTab: accuracyTab$b,
	opportunityTab: opportunityTab$b,
	modelComparisonTab: modelComparisonTab$b,
	tableTab: tableTab$b,
	dataSpecifications: dataSpecifications$b,
	attributes: attributes$b,
	singleAttributeCount: singleAttributeCount$b,
	attributesCount: attributesCount$b,
	instanceCount: instanceCount$b,
	close: close$b,
	calculating: calculating$b,
	accuracyMetricLegacy: accuracyMetricLegacy$b,
	errorOnInputs: errorOnInputs$b,
	Accuracy: Accuracy$b,
	Parity: Parity$b,
	Header: Header$b,
	Footer: Footer$b,
	Intro: Intro$b,
	ModelComparison: ModelComparison$b,
	Report: Report$b,
	Feature: Feature$b,
	Metrics: Metrics$b,
	BinDialog: BinDialog$b
};

var loremIpsum$c = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.";
var defaultClassNames$c = "Classe {0}";
var defaultFeatureNames$c = "Funcionalidade sensível {0}";
var defaultSingleFeatureName$c = "Funcionalidade sensível";
var defaultCustomMetricName$c = "Métrica personalizada {0}";
var accuracyTab$c = "Equidade no Desempenho";
var opportunityTab$c = "Equidade na Oportunidade";
var modelComparisonTab$c = "Comparação de modelos";
var tableTab$c = "Vista de Detalhes";
var dataSpecifications$c = "Estatísticas de dados";
var attributes$c = "Atributos";
var singleAttributeCount$c = "1 funcionalidade sensível";
var attributesCount$c = "{0} funcionalidades sensíveis";
var instanceCount$c = "{0} instâncias";
var close$c = "Fechar";
var calculating$c = "A calcular...";
var accuracyMetricLegacy$c = "Métrica de desempenho";
var errorOnInputs$c = "Erro na entrada. As funcionalidades sensíveis têm de ser valores categóricos neste momento. Mapeie os valores para as categorias discretizadas e tente novamente.";
var Accuracy$c = {
	header: "Como quer medir o desempenho?",
	modelMakes: "o modelo faz",
	modelsMake: "os modelos fazem",
	body: "Os dados contêm {0} etiquetas e {2} {1} predições. Com base nessa informação, recomendamos as seguintes métricas. Selecione uma métrica da lista.",
	binaryClassifier: "classificador binário",
	probabalisticRegressor: "regressor probit",
	regressor: "regressor",
	binary: "binário",
	continuous: "contínuo"
};
var Parity$c = {
	header: "Equidade medida em termos de disparidade",
	body: "As métricas de disparidade quantificam a variação do comportamento do seu modelo nas funcionalidades selecionadas. Há dois tipos de métricas de disparidade: mais novidades em breve...."
};
var Header$c = {
	title: "Fairlearn",
	documentation: "Documentação"
};
var Footer$c = {
	back: "Anterior",
	next: "Seguinte"
};
var Intro$c = {
	welcome: "Bem-vindo ao",
	fairlearnDashboard: "Dashboard do Fairlearn",
	introBody: "O dashboard do Fairlearn permite avaliar compromissos entre desempenho e equidade dos seus modelos",
	explanatoryStep: "Para configurar a avaliação, é necessário especificar uma funcionalidade sensível e uma métrica de desempenho.",
	getStarted: "Introdução",
	features: "Funcionalidades sensíveis",
	featuresInfo: "As funcionalidades sensíveis servem para dividir os seus dados em grupos. A equidade do seu modelo entre estes grupos é medida por métricas de disparidade. As métricas de disparidade quantificam a variação do comportamento do seu modelo entre estes grupos.",
	accuracy: "Métrica de desempenho",
	accuracyInfo: "As métricas de desempenho servem para avaliar a qualidade global do seu modelo, bem como a qualidade do seu modelo em cada grupo. A diferença entre os valores extremos da métrica de desempenho entre os grupos é reportada como a disparidade no desempenho."
};
var ModelComparison$c = {
	title: "Comparação de modelos",
	howToRead: "Como ler este gráfico",
	lower: "mais baixa",
	higher: "mais alta",
	howToReadText: "Este gráfico representa cada um dos {0} modelos como um ponto selecionável. O eixo x representa {1}, sendo que {2} é melhor. O eixo y representa a disparidade, sendo que mais baixa é melhor.",
	insights: "Informações",
	insightsText1: "O gráfico mostra {0} e disparidade de {1} modelos.",
	insightsText2: "{0} varia de {1} a {2}. A disparidade varia de {3} a {4}.",
	insightsText3: "O modelo mais preciso consegue {0} de {1} e uma disparidade de {2}.",
	insightsText4: "O modelo com menor disparidade consegue {0} de {1} e uma disparidade de {2}.",
	disparityInOutcomes: "Disparidade nas predições",
	disparityInAccuracy: "Disparidade em {0}",
	howToMeasureDisparity: "Como se deve medir a disparidade?"
};
var Report$c = {
	modelName: "Modelo {0}",
	title: "Disparidade no desempenho",
	globalAccuracyText: "É o {0} global",
	accuracyDisparityText: "É a disparidade em {0}",
	editConfiguration: "Editar configuração",
	backToComparisons: "Vista de vários modelos",
	outcomesTitle: "Disparidade nas predições",
	minTag: "Mín.",
	maxTag: "Máx.",
	groupLabel: "Subgrupo",
	underestimationError: "Subpredição",
	underpredictionExplanation: "(previsto = 0, verdadeiro = 1)",
	overpredictionExplanation: "(previsto = 1, verdadeiro = 0)",
	overestimationError: "Sobrepredição",
	classificationOutcomesHowToRead: "O gráfico de barras mostra a taxa de seleção em cada grupo, o que significa a fração de pontos classificados como 1.",
	regressionOutcomesHowToRead: "Os gráficos de caixas mostram a distribuição das predições em cada grupo. Os pontos de dados individuais estão sobrepostos em cima.",
	classificationAccuracyHowToRead1: "O gráfico de barras mostra a distribuição de erros em cada grupo.",
	classificationAccuracyHowToRead2: "Os erros dividem-se em erros de sobrepredição (prever 1 quando a etiqueta verdadeira é 0) e erros de subpredição (prever 0 quando a etiqueta verdadeira é 1).",
	classificationAccuracyHowToRead3: "As taxas reportadas são obtidas dividindo o número de erros pelo tamanho do grupo global.",
	probabilityAccuracyHowToRead1: "O gráfico de barras mostra o erro absoluto médio em cada grupo, dividido em sobrepredição e subpredição.",
	probabilityAccuracyHowToRead2: "Em cada exemplo, medimos a diferença entre a predição e a etiqueta. Se for positivo, chamamos sobrepredição e, se for negativo, chamamos subpredição.",
	probabilityAccuracyHowToRead3: "Reportamos a soma dos erros de sobrepredição e a soma dos erros de subpredição divididos pelo tamanho do grupo global.",
	regressionAccuracyHowToRead: "Erro é a diferença entre a predição e a etiqueta. Os gráficos de caixas mostram a distribuição de erros em cada grupo. Os pontos de dados individuais estão sobrepostos em cima.",
	distributionOfPredictions: "Distribuição de predições",
	distributionOfErrors: "Distribuição de erros",
	tooltipPrediction: "Predição: {0}",
	tooltipError: "Erro: {0}"
};
var Feature$c = {
	header: "Em que funcionalidades gostaria de avaliar a equidade do seu modelo?",
	body: "A equidade é avaliada em termos de disparidades no comportamento do seu modelo. Dividiremos os seus dados de acordo com os valores de cada funcionalidade selecionada e avaliaremos de que forma a métrica de desempenho do seu modelo e as predições diferem entre estas divisões.",
	learnMore: "Saiba mais",
	summaryCategoricalCount: "Esta funcionalidade tem {0} valores exclusivos",
	summaryNumericCount: "Esta funcionalidade numérica varia de {0} a {1}, e está agrupada em {2} discretizações.",
	showCategories: "Mostrar tudo",
	hideCategories: "Fechar",
	categoriesOverflow: "   e {0} categorias adicionais",
	editBinning: "Editar grupos",
	subgroups: "Subgrupos"
};
var Metrics$c = {
	accuracyScore: "Precisão",
	precisionScore: "Precisão",
	recallScore: "Revocação",
	zeroOneLoss: "Perda zero-um",
	specificityScore: "Classificação de especificidade",
	missRate: "Taxa de erros",
	falloutRate: "Taxa de dispersão",
	maxError: "Erro máximo",
	meanAbsoluteError: "Erro absoluto médio",
	meanSquaredError: " MSE (erro quadrático médio)",
	meanSquaredLogError: "Erro de registo quadrático médio",
	medianAbsoluteError: "Erro mediano absoluto",
	average: "Predição média",
	selectionRate: "Taxa de seleção",
	overprediction: "Sobrepredição",
	underprediction: "Subpredição",
	r2_score: "Classificação de R ao quadrado",
	rms_error: "RMSE (raiz do erro quadrático médio)",
	auc: "Área sob a curva ROC",
	balancedRootMeanSquaredError: "RMSE equilibrado",
	balancedAccuracy: "Precisão equilibrada",
	f1Score: "F1-Score",
	logLoss: "Log Loss",
	accuracyDescription: "A fração de pontos de dados classificados corretamente.",
	precisionDescription: "A fração de pontos de dados classificados corretamente entre os classificados como 1.",
	recallDescription: "A fração de pontos de dados classificados corretamente entre aqueles cuja etiqueta verdadeira é 1. Nomes alternativos: taxa de verdadeiros positivos, sensibilidade.",
	rmseDescription: "A raiz quadrada da média de erros quadráticos.",
	mseDescription: "A média de erros quadráticos.",
	meanAbsoluteErrorDescription: "A média dos valores absolutos dos erros. Mais robusto para valores atípicos do que o MSE.",
	r2Description: "A fração de desvio nas etiquetas explicadas pelo modelo.",
	aucDescription: "A qualidade das predições, visualizada como classificações, na separação de exemplos positivos de exemplos negativos.",
	balancedRMSEDescription: "Os exemplos positivos e negativos são reponderados para terem uma ponderação total igual. Adequado se existir um grande desequilíbrio nos dados subjacentes.",
	balancedAccuracyDescription: "Os exemplos positivos e negativos são reponderados para terem uma ponderação total igual. Adequado se existir um grande desequilíbrio nos dados subjacentes.",
	f1ScoreDescription: "F1-Score is the harmonic mean of precision and recall."
};
var BinDialog$c = {
	header: "Configurar discretizações",
	makeCategorical: "Tratar como categórico",
	save: "Guardar",
	cancel: "Cancelar",
	numberOfBins: "Número de discretizações:",
	categoryHeader: "Valores de discretização:"
};
var pt = {
	loremIpsum: loremIpsum$c,
	defaultClassNames: defaultClassNames$c,
	defaultFeatureNames: defaultFeatureNames$c,
	defaultSingleFeatureName: defaultSingleFeatureName$c,
	defaultCustomMetricName: defaultCustomMetricName$c,
	accuracyTab: accuracyTab$c,
	opportunityTab: opportunityTab$c,
	modelComparisonTab: modelComparisonTab$c,
	tableTab: tableTab$c,
	dataSpecifications: dataSpecifications$c,
	attributes: attributes$c,
	singleAttributeCount: singleAttributeCount$c,
	attributesCount: attributesCount$c,
	instanceCount: instanceCount$c,
	close: close$c,
	calculating: calculating$c,
	accuracyMetricLegacy: accuracyMetricLegacy$c,
	errorOnInputs: errorOnInputs$c,
	Accuracy: Accuracy$c,
	Parity: Parity$c,
	Header: Header$c,
	Footer: Footer$c,
	Intro: Intro$c,
	ModelComparison: ModelComparison$c,
	Report: Report$c,
	Feature: Feature$c,
	Metrics: Metrics$c,
	BinDialog: BinDialog$c
};

var loremIpsum$d = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.";
var defaultClassNames$d = "Класс {0}";
var defaultFeatureNames$d = "Чувствительный признак {0}";
var defaultSingleFeatureName$d = "Чувствительный признак";
var defaultCustomMetricName$d = "Настраиваемая метрика {0}";
var accuracyTab$d = "Достоверность по производительности";
var opportunityTab$d = "Достоверность по возможностям";
var modelComparisonTab$d = "Сравнение моделей";
var tableTab$d = "Подробное представление";
var dataSpecifications$d = "Статистика данных";
var attributes$d = "Атрибуты";
var singleAttributeCount$d = "1 чувствительный признак";
var attributesCount$d = "Чувствительные признаки: {0}";
var instanceCount$d = "Экземпляров: {0}";
var close$d = "Закрыть";
var calculating$d = "Вычисление…";
var accuracyMetricLegacy$d = "Метрика производительности";
var errorOnInputs$d = "Ошибка ввода. Чувствительные признаки сейчас должны быть категориальными значениями. Назначьте значения категориям интервалов и повторите попытку.";
var Accuracy$d = {
	header: "Как вы хотите измерять производительность?",
	modelMakes: "модель делает",
	modelsMake: "модели делают",
	body: "Ваши данные содержат {0} метки, а {1} прогнозы ({2}). На основе этих сведений мы рекомендуем использовать следующие метрики. Выберите одну метрику из списка.",
	binaryClassifier: "двоичный классификатор",
	probabalisticRegressor: "пробит-регрессор",
	regressor: "регрессор",
	binary: "двоичные",
	continuous: "непрерывные"
};
var Parity$d = {
	header: "Измерение достоверности через несоответствие",
	body: "Метрики несоответствия количественно характеризуют отличия в поведении модели по выбранным признакам. Доступны два вида метрик, но будут добавлены и другие…"
};
var Header$d = {
	title: "Fairlearn",
	documentation: "Документация"
};
var Footer$d = {
	back: "Назад",
	next: "Далее"
};
var Intro$d = {
	welcome: "Вас приветствует",
	fairlearnDashboard: "Панель мониторинга Fairlearn",
	introBody: "Панель мониторинга Fairlearn позволяет оценивать компромисс между производительностью и достоверностью моделей.",
	explanatoryStep: "Чтобы настроить оценку, необходимо указать чувствительный признак и метрику производительности.",
	getStarted: "Начало работы",
	features: "Чувствительные признаки",
	featuresInfo: "Чувствительные признаки используются для разделения данных на группы. Достоверность вашей модели в этих группах измеряется с помощью метрик несоответствия, которые количественно показывают различия в ее поведении в разных группах.",
	accuracy: "Метрика производительности",
	accuracyInfo: "Метрики производительности используются для оценки общего качества модели, а также качества модели в каждой группе. Различие между крайними значениями метрики в группах представляется как несоответствие в работе."
};
var ModelComparison$d = {
	title: "Сравнение моделей",
	howToRead: "Как читать эту диаграмму",
	lower: "ниже",
	higher: "выше",
	howToReadText: "На этой диаграмме каждая из моделей ({0}) представляет собой точку для выбора. Ось X представляет функцию \"{1}\" (чем {2}, тем лучше), а ось Y характеризует несоответствие (чем ниже, тем лучше).",
	insights: "Аналитика",
	insightsText1: "Диаграмма показывает функцию \"{0}\" и несоответствие моделей ({1}).",
	insightsText2: "Функция \"{0}\" имеет диапазон от {1} до {2}, а несоответствие — от {3} до {4}.",
	insightsText3: "Самая правильная модель обеспечивает для функции \"{0}\" значение {1} и имеет несоответствие {2}.",
	insightsText4: "Модель с наименьшим несоответствием обеспечивает для функции \"{0}\" значение {1} и имеет несоответствие {2}.",
	disparityInOutcomes: "Несоответствие прогнозов",
	disparityInAccuracy: "Несоответствие в {0}",
	howToMeasureDisparity: "Как измерять несоответствие?"
};
var Report$d = {
	modelName: "Модель {0}",
	title: "Несоответствие производительности",
	globalAccuracyText: "Общее значение для \"{0}\"",
	accuracyDisparityText: "Является несоответствием в функции \"{0}\"",
	editConfiguration: "Изменить конфигурацию",
	backToComparisons: "Многомодельное представление",
	outcomesTitle: "Несоответствие прогнозов",
	minTag: "Мин.",
	maxTag: "Макс.",
	groupLabel: "Подгруппа",
	underestimationError: "Преуменьшение прогноза",
	underpredictionExplanation: "(прогноз = 0, истина = 1)",
	overpredictionExplanation: "(прогноз = 1, истина = 0)",
	overestimationError: "Преувеличение прогноза",
	classificationOutcomesHowToRead: "Линейчатая диаграмма показывает степень отбора в каждой группе, то есть долю точек с классификацией 1.",
	regressionOutcomesHowToRead: "Блочные диаграммы показывают распределение прогнозов в каждой группе. Сверху наложены отдельные точки данных.",
	classificationAccuracyHowToRead1: "Линейчатая диаграмма показывает распределение ошибок в каждой группе.",
	classificationAccuracyHowToRead2: "Ошибки разделяются на ошибки преувеличения прогноза (прогнозирование значения 1, когда истинная метка — 0) и преуменьшения прогноза (прогнозирование 0, когда истинная метка — 1).",
	classificationAccuracyHowToRead3: "Выдаваемые показатели получаются делением числа ошибок на общий размер группы.",
	probabilityAccuracyHowToRead1: "Линейчатая диаграмма показывает среднюю абсолютную ошибку в каждой группе с подразделением на преуменьшение и преуменьшение прогноза.",
	probabilityAccuracyHowToRead2: "В каждом примере мы измеряем разницу между прогнозом и меткой. Если разница положительная, это называется преувеличением прогноза, а если отрицательная — преуменьшением.",
	probabilityAccuracyHowToRead3: "Мы сообщаем сумму ошибок преувеличения прогноза и сумму ошибок преуменьшения, деленные на общий размер группы.",
	regressionAccuracyHowToRead: "Ошибка представляет собой разницу между прогнозом и меткой. Блочные диаграммы показывают распределение ошибок в каждой группе. Сверху наложены отдельные точки данных.",
	distributionOfPredictions: "Распределение прогнозов",
	distributionOfErrors: "Распределение ошибок",
	tooltipPrediction: "Прогноз: {0}",
	tooltipError: "Ошибка: {0}"
};
var Feature$d = {
	header: "Для каких признаков вы хотите оценить достоверность модели?",
	body: "Достоверность оценивается с точки зрения несоответствий в поведении модели. Мы разделим ваши данные по значениям каждого выбранного признака и оценим, насколько метрики производительности и прогнозы вашей модели различаются в этих группах.",
	learnMore: "Дополнительные сведения",
	summaryCategoricalCount: "Уникальных значений признака: {0}",
	summaryNumericCount: "Этот числовой признак имеет диапазон от {0} до {1} и группируется в следующее число интервалов: {2}.",
	showCategories: "Показать все",
	hideCategories: "Свернуть",
	categoriesOverflow: " и другие категории ({0})",
	editBinning: "Изменить группы",
	subgroups: "Подгруппы"
};
var Metrics$d = {
	accuracyScore: "Правильность",
	precisionScore: "Точность",
	recallScore: "Полнота",
	zeroOneLoss: "Двоичная функция потерь",
	specificityScore: "Оценка специфичности",
	missRate: "Доля промахов",
	falloutRate: "Доля ложных заключений",
	maxError: "Максимальная ошибка",
	meanAbsoluteError: "Средняя абсолютная ошибка",
	meanSquaredError: " Среднеквадратичная ошибка",
	meanSquaredLogError: "Среднеквадратичная ошибка журнала",
	medianAbsoluteError: "Медианная абсолютная ошибка",
	average: "Средний прогноз",
	selectionRate: "Степень отбора",
	overprediction: "Преувеличение прогноза",
	underprediction: "Преуменьшение прогноза",
	r2_score: "Оценка \"R-квадрат\"",
	rms_error: "Среднеквадратичная ошибка (корень)",
	auc: "Площадь под ROC-кривой",
	balancedRootMeanSquaredError: "Сбалансированная среднеквадратичная ошибка",
	balancedAccuracy: "Сбалансированная правильность",
	f1Score: "F1-Score",
	logLoss: "Log Loss",
	accuracyDescription: "Доля точек данных с корректной классификацией.",
	precisionDescription: "Доля точек данных с корректной классификацией среди тех, что классифицированы как 1.",
	recallDescription: "Доля точек данных с корректной классификацией среди тех, чья истинная метка — 1. Другие названия: доля истинноположительных результатов, чувствительность.",
	rmseDescription: "Квадратный корень среднего значения из квадратов ошибки.",
	mseDescription: "Среднее значение из квадратов ошибки.",
	meanAbsoluteErrorDescription: "Среднее число абсолютных величин ошибки. Больше подходит для крайних значений, чем для среднеквадратичной ошибки.",
	r2Description: "Доля изменчивости в метках, объясняемая моделью.",
	aucDescription: "Качество (числовые оценки) прогнозов на основе отделения положительных примеров от отрицательных.",
	balancedRMSEDescription: "Переназначение весов для положительных и отрицательных примеров так, чтобы общий вес совпадал. Рекомендуется для сильно несбалансированных данных.",
	balancedAccuracyDescription: "Переназначение весов для положительных и отрицательных примеров так, чтобы общий вес совпадал. Рекомендуется для сильно несбалансированных данных.",
	f1ScoreDescription: "F1-Score is the harmonic mean of precision and recall."
};
var BinDialog$d = {
	header: "Настройка интервалов",
	makeCategorical: "Рассматривать как категориальные",
	save: "Сохранить",
	cancel: "Отмена",
	numberOfBins: "Число интервалов:",
	categoryHeader: "Значения интервалов:"
};
var ru = {
	loremIpsum: loremIpsum$d,
	defaultClassNames: defaultClassNames$d,
	defaultFeatureNames: defaultFeatureNames$d,
	defaultSingleFeatureName: defaultSingleFeatureName$d,
	defaultCustomMetricName: defaultCustomMetricName$d,
	accuracyTab: accuracyTab$d,
	opportunityTab: opportunityTab$d,
	modelComparisonTab: modelComparisonTab$d,
	tableTab: tableTab$d,
	dataSpecifications: dataSpecifications$d,
	attributes: attributes$d,
	singleAttributeCount: singleAttributeCount$d,
	attributesCount: attributesCount$d,
	instanceCount: instanceCount$d,
	close: close$d,
	calculating: calculating$d,
	accuracyMetricLegacy: accuracyMetricLegacy$d,
	errorOnInputs: errorOnInputs$d,
	Accuracy: Accuracy$d,
	Parity: Parity$d,
	Header: Header$d,
	Footer: Footer$d,
	Intro: Intro$d,
	ModelComparison: ModelComparison$d,
	Report: Report$d,
	Feature: Feature$d,
	Metrics: Metrics$d,
	BinDialog: BinDialog$d
};

var loremIpsum$e = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.";
var defaultClassNames$e = "Klass {0}";
var defaultFeatureNames$e = "Känslig funktion {0}";
var defaultSingleFeatureName$e = "Känslig funktion";
var defaultCustomMetricName$e = "Anpassat mått {0}";
var accuracyTab$e = "Rättvisa i prestanda";
var opportunityTab$e = "Rättvisa i affärsmöjlighet";
var modelComparisonTab$e = "Modelljämförelse";
var tableTab$e = "Detaljvy";
var dataSpecifications$e = "Datastatistik";
var attributes$e = "Attribut";
var singleAttributeCount$e = "1 känslig funktion";
var attributesCount$e = "{0} känsliga funktioner";
var instanceCount$e = "{0} instanser";
var close$e = "Stäng";
var calculating$e = "Beräknar...";
var accuracyMetricLegacy$e = "Prestandamått";
var errorOnInputs$e = "Fel med indata. De känsliga funktionerna måste vara kategoriska värden just nu. Mappa värden till diskretiserade kategorier och försök igen.";
var Accuracy$e = {
	header: "Hur vill du mäta prestanda?",
	modelMakes: "modellen gör",
	modelsMake: "modellerna gör",
	body: "Dina data innehåller {0} etiketter och {2} {1} förutsägelser. Baserat på den informationen rekommenderar vi följande mått. Välj ett mått från listan.",
	binaryClassifier: "binär klassificerare",
	probabalisticRegressor: "probitregressor",
	regressor: "regressor",
	binary: "binär",
	continuous: "kontinuerlig"
};
var Parity$e = {
	header: "Rättvisa mätt avseende diskrepans",
	body: "Diskrepansmått kvantifierar variationer i dina modellers beteende för valda funktioner. Det finns två olika typer av diskrepansmått: mer kommer..."
};
var Header$e = {
	title: "Fairlearn",
	documentation: "Dokumentation"
};
var Footer$e = {
	back: "Tillbaka",
	next: "Nästa"
};
var Intro$e = {
	welcome: "Välkommen till",
	fairlearnDashboard: "Fairlearn-instrumentpanel",
	introBody: "Med Fairlearn-instrumentpanelen kan du utvärdera kompromisser mellan prestanda och rättvisa för dina modeller",
	explanatoryStep: "Om du vill konfigurera utvärderingen måste du ange en känslig funktion och ett prestandamått.",
	getStarted: "Kom igång",
	features: "Känsliga funktioner",
	featuresInfo: "Känsliga funktioner används för att dela upp dina data i grupper. Din modells rättvisa för dessa grupper mäts av diskrepansmått. Diskrepansmått anger hur mycket av modellens beteende som varierar för de här grupperna.",
	accuracy: "Prestandamått",
	accuracyInfo: "Prestandamått används för att utvärdera den totala kvaliteten på din modell och kvaliteten på din modell i varje grupp. Skillnaden mellan de extrema värdena på prestandamåttet i grupperna rapporteras som en prestandadiskrepans."
};
var ModelComparison$e = {
	title: "Modelljämförelse",
	howToRead: "Så här läser du det här diagrammet",
	lower: "lägre",
	higher: "högre",
	howToReadText: "Det här diagrammet representerar var och en av {0}-modellerna som en valbar punkt. X-axeln representerar {1}, där {2} är bättre. Y-axeln representerar diskrepans, där lägre är bättre.",
	insights: "Insikter",
	insightsText1: "Diagrammet visar {0} och diskrepanser för {1} modeller.",
	insightsText2: "{0} intervall från {1} till {2}. Diskrepansen är från {3} till {4}.",
	insightsText3: "Den mest exakta modellen uppnår {0} av {1} och en diskrepans på {2}.",
	insightsText4: "Modellen med lägsta diskrepans uppnår {0} av {1} och en diskrepans på {2}.",
	disparityInOutcomes: "Diskrepans i förutsägelser",
	disparityInAccuracy: "Diskrepans i {0}",
	howToMeasureDisparity: "Hur ska diskrepanser mätas?"
};
var Report$e = {
	modelName: "Modell {0}",
	title: "Prestandadiskrepans",
	globalAccuracyText: "Är den totala {0}",
	accuracyDisparityText: "Är diskrepansen i {0}",
	editConfiguration: "Redigera konfigurationen",
	backToComparisons: "Multimodellvy",
	outcomesTitle: "Diskrepans i förutsägelser",
	minTag: "Min",
	maxTag: "Max",
	groupLabel: "Undergrupp",
	underestimationError: "Underförutsägelse",
	underpredictionExplanation: "(uppskattat = 0, sant = 1)",
	overpredictionExplanation: "(uppskattat = 1, sant = 0)",
	overestimationError: "Överförutsägelse",
	classificationOutcomesHowToRead: "I stapeldiagrammet visas markeringshastigheten i varje grupp, vilket innebär fraktionen punkter som klassificeras som 1.",
	regressionOutcomesHowToRead: "I låddiagram visas fördelningen av förutsägelser i varje grupp. Enskilda datapunkter läggs ovanpå.",
	classificationAccuracyHowToRead1: "Stapeldiagrammet visar distributionen av fel i varje grupp.",
	classificationAccuracyHowToRead2: "Fel delas upp i överförutsägelsefel (förutsäger 1 när den sanna etiketten är 0) och underförutsägelsefel (förutsäger 0 när den sanna etiketten är 1).",
	classificationAccuracyHowToRead3: "De rapporterade frekvenserna erhålls genom att dela antalet fel med den totala gruppstorleken.",
	probabilityAccuracyHowToRead1: "Stapeldiagrammet visar ett absolut fel i varje grupp, uppdelat på överförutsägelse och underförutsägelse.",
	probabilityAccuracyHowToRead2: "I varje exempel mäter vi skillnaden mellan förutsägelse och etikett. Om det är positivt, så kallar vi det överförutsägelse och om det är negativt så kallar vi det underförutsägelse.",
	probabilityAccuracyHowToRead3: "Vi rapporterar summan av antalet överförutsägelser och summan av antalet underförutsägelser dividerat med den totala gruppstorleken.",
	regressionAccuracyHowToRead: "Fel är skillnaden mellan förutsägelsen och etiketten. I låddiagram visas fördelningen av fel i varje grupp. Enskilda datapunkter läggs ovanpå.",
	distributionOfPredictions: "Distribution av förutsägelser",
	distributionOfErrors: "Distribution av fel",
	tooltipPrediction: "Förutsägelse: {0}",
	tooltipError: "Fel: {0}"
};
var Feature$e = {
	header: "Efter vilka funktioner vill du utvärdera din modells rättvisa?",
	body: "Rättvisa utvärderas i förhållande till diskrepanser i modellens beteende. Vi delar upp dina data enligt värdena för varje vald funktion och utvärderar hur modellens prestandamått och förutsägelser skiljer sig åt i dessa delningar.",
	learnMore: "Läs mer",
	summaryCategoricalCount: "Den här funktionen har {0} unika värden",
	summaryNumericCount: "Den här numeriska funktionen sträcker sig från {0} till {1} och grupperas i {2} diskretiseringar.",
	showCategories: "Visa alla",
	hideCategories: "Minimera",
	categoriesOverflow: "   och {0} ytterligare kategorier",
	editBinning: "Redigera grupper",
	subgroups: "Undergrupper"
};
var Metrics$e = {
	accuracyScore: "Noggrannhet",
	precisionScore: "Precision",
	recallScore: "Träffsäkerhet",
	zeroOneLoss: "Zero-one-förlust",
	specificityScore: "Specificitetspoäng",
	missRate: "Missfrekvens",
	falloutRate: "Utfallshastighet",
	maxError: "Max fel",
	meanAbsoluteError: "Medelvärde för absoluta fel",
	meanSquaredError: " MSE (medelkvadratfel)",
	meanSquaredLogError: "Medelkvadratvärde för loggfel",
	medianAbsoluteError: "Medianvärde av absoluta fel",
	average: "Genomsnittlig förutsägelse",
	selectionRate: "Markeringshastighet",
	overprediction: "Överförutsägelse",
	underprediction: "Underförutsägelse",
	r2_score: "R-kvadratvärde",
	rms_error: "RMSE (rot-medelkvadratfel)",
	auc: "Område under ROC-kurvan",
	balancedRootMeanSquaredError: "Balanserad RMSE",
	balancedAccuracy: "Balanserad noggrannhet",
	f1Score: "F1-Score",
	logLoss: "Log Loss",
	accuracyDescription: "Datapunktsfraktionen klassificeras korrekt.",
	precisionDescription: "Fraktionen av datapunkter som klassificeras korrekt bland de som klassificerats som 1.",
	recallDescription: "Fraktionen av datapunkter som klassificeras korrekt bland de vars sanna etikett är 1. Alternativa namn: sant positiv hastighet, känslighet.",
	rmseDescription: "Kvadratroten för genomsnittet av kvadratfel.",
	mseDescription: "Medelvärdet för kvadratfel.",
	meanAbsoluteErrorDescription: "Medelvärdet av absoluta värden för fel. Mer robust för extremvärden än MSE.",
	r2Description: "Fraktionen av varians i etiketterna som beskrivs av modellen.",
	aucDescription: "Kvaliteten på förutsägelserna, visade som poäng, vid separering av positiva exempel från negativa exempel.",
	balancedRMSEDescription: "Positiva och negativa exempel viktas om för att ha samma total viktning. Lämpligt om underliggande data är högt obalanserade.",
	balancedAccuracyDescription: "Positiva och negativa exempel viktas om för att ha samma total viktning. Lämpligt om underliggande data är högt obalanserade.",
	f1ScoreDescription: "F1-Score is the harmonic mean of precision and recall."
};
var BinDialog$e = {
	header: "Konfigurera diskretiseringar",
	makeCategorical: "Hantera som kategoriskt",
	save: "Spara",
	cancel: "Avbryt",
	numberOfBins: "Antal diskretiseringar:",
	categoryHeader: "Diskretiserade värden:"
};
var sv = {
	loremIpsum: loremIpsum$e,
	defaultClassNames: defaultClassNames$e,
	defaultFeatureNames: defaultFeatureNames$e,
	defaultSingleFeatureName: defaultSingleFeatureName$e,
	defaultCustomMetricName: defaultCustomMetricName$e,
	accuracyTab: accuracyTab$e,
	opportunityTab: opportunityTab$e,
	modelComparisonTab: modelComparisonTab$e,
	tableTab: tableTab$e,
	dataSpecifications: dataSpecifications$e,
	attributes: attributes$e,
	singleAttributeCount: singleAttributeCount$e,
	attributesCount: attributesCount$e,
	instanceCount: instanceCount$e,
	close: close$e,
	calculating: calculating$e,
	accuracyMetricLegacy: accuracyMetricLegacy$e,
	errorOnInputs: errorOnInputs$e,
	Accuracy: Accuracy$e,
	Parity: Parity$e,
	Header: Header$e,
	Footer: Footer$e,
	Intro: Intro$e,
	ModelComparison: ModelComparison$e,
	Report: Report$e,
	Feature: Feature$e,
	Metrics: Metrics$e,
	BinDialog: BinDialog$e
};

var loremIpsum$f = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.";
var defaultClassNames$f = "{0} sınıfı";
var defaultFeatureNames$f = "{0} hassas özelliği";
var defaultSingleFeatureName$f = "Hassas özellik";
var defaultCustomMetricName$f = "Özel {0} ölçümü";
var accuracyTab$f = "Performans Eşitliği";
var opportunityTab$f = "Fırsat Eşitliği";
var modelComparisonTab$f = "Model karşılaştırması";
var tableTab$f = "Ayrıntı Görünümü";
var dataSpecifications$f = "Veri istatistikleri";
var attributes$f = "Öznitelikler";
var singleAttributeCount$f = "1 hassas özellik";
var attributesCount$f = "{0} hassas özellik";
var instanceCount$f = "{0} örnek";
var close$f = "Kapat";
var calculating$f = "Hesaplanıyor...";
var accuracyMetricLegacy$f = "Performans ölçümü";
var errorOnInputs$f = "Giriş hatası. Hassas özellikler şu anda kategorik değerler olmalıdır. Lütfen değerleri bölmelenmiş kategorilere eşleyip yeniden deneyin.";
var Accuracy$f = {
	header: "Performansı nasıl ölçmek istiyorsunuz?",
	modelMakes: "model şunları yapar:",
	modelsMake: "modeller şunları yapar:",
	body: "Verileriniz {0} etiket ve {2} {1} tahmininizi içeriyor. Bu bilgilere dayanarak, aşağıdaki ölçümleri kullanmanızı öneririz. Lütfen listeden bir ölçüm seçin.",
	binaryClassifier: "ikili sınıflandırıcı",
	probabalisticRegressor: "probit regresörü",
	regressor: "regresör",
	binary: "ikili",
	continuous: "sürekli"
};
var Parity$f = {
	header: "Eşitlik, farklar temel alınarak ölçülür",
	body: "Fark ölçümleri, modelinizin seçilen özelliklerde gösterdiği davranışın varyasyon miktarını ölçer. İki tür fark ölçümü vardır. Daha fazla ölçüm kullanıma sunulacak..."
};
var Header$f = {
	title: "Fairlearn",
	documentation: "Belgeler"
};
var Footer$f = {
	back: "Geri",
	next: "Sonraki"
};
var Intro$f = {
	welcome: "Hoş geldiniz",
	fairlearnDashboard: "Fairlearn panosu",
	introBody: "Fairlearn panosu, modellerinizin performansı ve eşitliği arasındaki karşılaştırmaları değerlendirmenizi sağlar",
	explanatoryStep: "Değerlendirmeyi ayarlamak için hassas bir özellik ve performans ölçümü belirtmeniz gerekir.",
	getStarted: "Kullanmaya başlayın",
	features: "Hassas özellikler",
	featuresInfo: "Hassas özellikler, verilerinizi gruplara bölmek için kullanılır. Modelinizin bu gruplar arasındaki eşitliği, fark ölçümleriyle ölçülür. Fark ölçümleri, modelinizin bu gruplar arasında ne kadar farklı davrandığını ölçer.",
	accuracy: "Performans ölçümü",
	accuracyInfo: "Performans ölçümleri, modelinizin genel ve her gruptaki kalitesini değerlendirmek için kullanılır. Gruplar arasındaki performans ölçümünün uç değerleri arasındaki fark, performans farkı olarak bildirilir."
};
var ModelComparison$f = {
	title: "Model karşılaştırması",
	howToRead: "Bu grafiği okuma",
	lower: "daha düşük",
	higher: "daha yüksek",
	howToReadText: "Bu grafik, {0} modelin her birini seçilebilir bir nokta olarak temsil eder. X ekseni {1} temsil eder, {2} değerler daha iyidir. Y ekseni farkı temsil eder, düşük değerler daha iyidir.",
	insights: "İçgörüler",
	insightsText1: "Grafik, {1} modelin {0} ve farkını gösterir.",
	insightsText2: "{0}, {1} ile {2} aralığındayken, fark {3} ile {4} aralığındadır.",
	insightsText3: "En doğru model, {0}/{1} ve {2} farkını alır.",
	insightsText4: "En düşük farka sahip model {0}/{1} ve {2} farkını alır.",
	disparityInOutcomes: "Tahmin farkı",
	disparityInAccuracy: "{0} farkı",
	howToMeasureDisparity: "Fark nasıl ölçülür?"
};
var Report$f = {
	modelName: "{0} modeli",
	title: "Performans farkı",
	globalAccuracyText: "Genel {0}",
	accuracyDisparityText: "{0} farkıdır",
	editConfiguration: "Yapılandırmayı düzenle",
	backToComparisons: "Çoklu model görünümü",
	outcomesTitle: "Tahmin farkı",
	minTag: "Minimum",
	maxTag: "Maksimum",
	groupLabel: "Alt grup",
	underestimationError: "Düşük tahmin",
	underpredictionExplanation: "(tahmini = 0, true = 1)",
	overpredictionExplanation: "(tahmini = 1, true = 0)",
	overestimationError: "Yüksek tahmin",
	classificationOutcomesHowToRead: "Çubuk grafik, her gruptaki seçim oranını gösterir. Bu, 1 olarak sınıflandırılan noktaların kesir değerini ifade eder.",
	regressionOutcomesHowToRead: "Kutu grafikleri her gruptaki tahminlerin dağılımını gösterir. Veri noktaları ayrı ayrı olacak şekilde en üstte yer alır.",
	classificationAccuracyHowToRead1: "Çubuk grafik, her gruptaki hataların dağılımını gösterir.",
	classificationAccuracyHowToRead2: "Hatalar, yüksek tahmin hataları (1 tahmin edilirken gerçek etiketin 0 olması) ve düşük tahmin hataları (0 tahmin edilirken gerçek etiketin 1 olması) olarak ayrılır.",
	classificationAccuracyHowToRead3: "Bildirilen oranlar, hata sayısı genel grup boyutuna bölünerek bulunur.",
	probabilityAccuracyHowToRead1: "Çubuk grafik, her gruptaki ortalama mutlak hataları yüksek tahmin ve düşük tahmin olarak ayrılmış şekilde gösterir.",
	probabilityAccuracyHowToRead2: "Her örnekte, tahmin ile etiket arasındaki farkı ölçeriz. Fark pozitifse yüksek tahmin, negatifse düşük tahmin olarak adlandırırız.",
	probabilityAccuracyHowToRead3: "Yüksek tahmin hataları ile düşük tahmin hatalarının toplamını toplam grup boyutuna bölerek bildiririz.",
	regressionAccuracyHowToRead: "Hata, tahmin ile etiket arasındaki farktır. Kutu grafikleri, her gruptaki hataların dağılımını gösterir. Veri noktaları ayrı ayrı olacak şekilde en üste yer alır.",
	distributionOfPredictions: "Tahmin dağılımı",
	distributionOfErrors: "Hata dağılımı",
	tooltipPrediction: "Tahmin: {0}",
	tooltipError: "Hata: {0}"
};
var Feature$f = {
	header: "Modelinizin eşitliğini hangi özelliklerle birlikte değerlendirmek istiyorsunuz?",
	body: "Eşitlik, modelinizin davranışındaki farklara yönelik olarak değerlendirilir. Verilerinizi seçilen her bir özelliğin değerlerine göre böleriz ve modelinizin performans ölçümü ile tahminlerinin bu bölmeler arasında nasıl farklılık gösterdiğini değerlendiririz.",
	learnMore: "Daha fazla bilgi",
	summaryCategoricalCount: "Bu özellik, {0} benzersiz değer içeriyor",
	summaryNumericCount: "Bu sayısal özellik {0} ile {1} aralığındadır ve {2} bölmeye gruplandırılmıştır.",
	showCategories: "Tümünü göster",
	hideCategories: "Daralt",
	categoriesOverflow: "   ve {0} ek kategori",
	editBinning: "Grupları düzenle",
	subgroups: "Alt gruplar"
};
var Metrics$f = {
	accuracyScore: "Doğruluk",
	precisionScore: "Duyarlık",
	recallScore: "Geri çağırma",
	zeroOneLoss: "0-1 kayıp",
	specificityScore: "Belirginlik puanı",
	missRate: "İsabetsizlik oranı",
	falloutRate: "Hata oranı",
	maxError: "Maksimum hata sayısı",
	meanAbsoluteError: "Ortalama mutlak hata sayısı",
	meanSquaredError: " MSE (ortalama hata karesi)",
	meanSquaredLogError: "Ortalama günlük hatası karesi",
	medianAbsoluteError: "Ortanca mutlak hata",
	average: "Ortalama tahmin",
	selectionRate: "Seçim oranı",
	overprediction: "Yüksek tahmin",
	underprediction: "Düşük tahmin",
	r2_score: "R kare puanı",
	rms_error: "RMSE (kök ortalama hata karesi)",
	auc: "ROC eğrisinin altındaki alan",
	balancedRootMeanSquaredError: "Dengeli RMSE",
	balancedAccuracy: "Dengeli doğruluk",
	f1Score: "F1-Score",
	logLoss: "Log Loss",
	accuracyDescription: "Doğru olarak sınıflandırılmış veri noktalarının kesir değeri.",
	precisionDescription: "1 olarak sınıflandırılanların arasında doğru şekilde sınıflandırılmış veri noktalarının kesir değeri.",
	recallDescription: "Gerçek etiketi 1 olanların arasında doğru bir şekilde sınıflandırılmış veri noktalarının kesir değeri. Alternatif adlar: gerçek pozitif oran, hassasiyet.",
	rmseDescription: "Hata karelerinin ortalamasının karekökü.",
	mseDescription: "Hata karelerinin ortalaması.",
	meanAbsoluteErrorDescription: "Hata mutlak değerlerinin ortalaması. Aykırı değerlere karşı MSE'den daha dayanıklıdır.",
	r2Description: "Model tarafından açıklanan etiketlerdeki varyansın kesir değeri.",
	aucDescription: "Olumlu örnekleri olumsuz örneklerden ayırırken puan olarak görüntülenen tahminlerin kalitesi.",
	balancedRMSEDescription: "Pozitif ve negatif örnekler eşit toplam ağırlığa sahip olacak şekilde yeniden ağırlıklandırılır. Bu, temel alınan verilerin fazla dengesiz olması durumunda uygundur.",
	balancedAccuracyDescription: "Pozitif ve negatif örnekler eşit toplam ağırlığa sahip olacak şekilde yeniden ağırlıklandırılır. Bu, temel alınan verilerin fazla dengesiz olması durumunda uygundur.",
	f1ScoreDescription: "F1-Score is the harmonic mean of precision and recall."
};
var BinDialog$f = {
	header: "Bölmeleri yapılandır",
	makeCategorical: "Kategorik olarak değerlendir",
	save: "Kaydet",
	cancel: "İptal",
	numberOfBins: "Bölme sayısı:",
	categoryHeader: "Bölme değerleri:"
};
var tr = {
	loremIpsum: loremIpsum$f,
	defaultClassNames: defaultClassNames$f,
	defaultFeatureNames: defaultFeatureNames$f,
	defaultSingleFeatureName: defaultSingleFeatureName$f,
	defaultCustomMetricName: defaultCustomMetricName$f,
	accuracyTab: accuracyTab$f,
	opportunityTab: opportunityTab$f,
	modelComparisonTab: modelComparisonTab$f,
	tableTab: tableTab$f,
	dataSpecifications: dataSpecifications$f,
	attributes: attributes$f,
	singleAttributeCount: singleAttributeCount$f,
	attributesCount: attributesCount$f,
	instanceCount: instanceCount$f,
	close: close$f,
	calculating: calculating$f,
	accuracyMetricLegacy: accuracyMetricLegacy$f,
	errorOnInputs: errorOnInputs$f,
	Accuracy: Accuracy$f,
	Parity: Parity$f,
	Header: Header$f,
	Footer: Footer$f,
	Intro: Intro$f,
	ModelComparison: ModelComparison$f,
	Report: Report$f,
	Feature: Feature$f,
	Metrics: Metrics$f,
	BinDialog: BinDialog$f
};

var loremIpsum$g = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.";
var defaultClassNames$g = "类 {0}";
var defaultFeatureNames$g = "敏感特征 {0}";
var defaultSingleFeatureName$g = "敏感特征";
var defaultCustomMetricName$g = "自定义指标 {0}";
var accuracyTab$g = "性能的公平性";
var opportunityTab$g = "机会的公平性";
var modelComparisonTab$g = "模型比较";
var tableTab$g = "详细信息视图";
var dataSpecifications$g = "数据统计信息";
var attributes$g = "特性";
var singleAttributeCount$g = "1 个敏感特征";
var attributesCount$g = "{0} 个敏感特征";
var instanceCount$g = "{0} 个实例";
var close$g = "关闭";
var calculating$g = "正在计算...";
var accuracyMetricLegacy$g = "性能指标";
var errorOnInputs$g = "输入出错。目前敏感特征必须是分类值。请将值映射到已装箱的类别，然后重试。";
var Accuracy$g = {
	header: "你想如何衡量性能?",
	modelMakes: "模型",
	modelsMake: "模型",
	body: "你的数据包含 {0} 个标签和 {2} {1} 预测。根据此信息，我们推荐以下指标。请从列表中选择一个指标。",
	binaryClassifier: "二元分类器",
	probabalisticRegressor: "Probit 回归量",
	regressor: "回归量",
	binary: "二进制",
	continuous: "连续"
};
var Parity$g = {
	header: "根据差异衡量公平性",
	body: "差异指标量化了模型在所选特征之间的行为变化。有两种类型的差异指标: 即将推出更多..."
};
var Header$g = {
	title: "Fairlearn",
	documentation: "文档"
};
var Footer$g = {
	back: "上一步",
	next: "下一步"
};
var Intro$g = {
	welcome: "欢迎使用",
	fairlearnDashboard: "Fairlearn 仪表板",
	introBody: "借助 Fairlearn 仪表板，可以评估模型的性能和公平性之间的权衡",
	explanatoryStep: "若要设置评估，需要指定一个敏感特征和一个性能指标。",
	getStarted: "开始使用",
	features: "敏感特征",
	featuresInfo: "使用敏感特征可以将数据拆分为组。通过差异指标衡量模型在这些组之间的公平性。差异指标将量化模型在这些组之间的行为变化。",
	accuracy: "性能指标",
	accuracyInfo: "性能指标用于评估模型的总体质量以及在每个组中的模型质量。各组的性能指标极值之间的差异称为性能差异。"
};
var ModelComparison$g = {
	title: "模型比较",
	howToRead: "如何阅读此图表",
	lower: "偏低",
	higher: "偏高",
	howToReadText: "此图表将每个 {0} 模型表示为一个可选择的点。X 轴表示 {1}，越 {2} 越好。Y 轴表示差异，越低越好。",
	insights: "见解",
	insightsText1: "此图表显示 {0} 和 {1} 个模型的差异。",
	insightsText2: "{0} 的范围是从 {1} 到 {2}。差异的范围是从 {3} 到 {4}。",
	insightsText3: "最准确的模型可达到 {1} 的 {0} 和 {2} 的差异。",
	insightsText4: "最低差异模型可达到 {1} 的 {0} 和 {2} 的差异。",
	disparityInOutcomes: "预测差异",
	disparityInAccuracy: "{0} 差异",
	howToMeasureDisparity: "如何衡量差异?"
};
var Report$g = {
	modelName: "模型 {0}",
	title: "性能差异",
	globalAccuracyText: "是总体 {0}",
	accuracyDisparityText: "是 {0} 的差异",
	editConfiguration: "编辑配置",
	backToComparisons: "多模型视图",
	outcomesTitle: "预测差异",
	minTag: "最小值",
	maxTag: "最大值",
	groupLabel: "子组",
	underestimationError: "过低预测",
	underpredictionExplanation: "(预测值 = 0，true = 1)",
	overpredictionExplanation: "(预测值 = 1，true = 0)",
	overestimationError: "过高预测",
	classificationOutcomesHowToRead: "条形图显示每组的选择率，表示分类为 1 的点的分数。",
	regressionOutcomesHowToRead: "箱形图显示每个组的预测值分布。各个数据点在顶部重叠。",
	classificationAccuracyHowToRead1: "条形图显示每个组的误差分布。",
	classificationAccuracyHowToRead2: "误差分为“过高预测”误差(true 标签为 0 时预测值为 1)和“过低预测”误差(true 标签为 1 时预测值为 0)。",
	classificationAccuracyHowToRead3: "通过将误差数除以组总大小得到报告率。",
	probabilityAccuracyHowToRead1: "条形图显示各组的平均绝对误差，分为“过高预测”和“过低预测”。",
	probabilityAccuracyHowToRead2: "我们对每个样本测量预测值和标签值之间的差异。如果是正值，则视为过高预测，如果是负值，则视为过低预测。",
	probabilityAccuracyHowToRead3: "我们报告“过高预测”误差总数与“过低预测”误差总数除以组总大小后的值。",
	regressionAccuracyHowToRead: "误差是预测值和标签值之间的差异。箱形图显示每个组的误差分布。各个数据点在顶部重叠。",
	distributionOfPredictions: "预测分布",
	distributionOfErrors: "误差分布",
	tooltipPrediction: "预测: {0}",
	tooltipError: "误差: {0}"
};
var Feature$g = {
	header: "你想要通过哪些特征评估模型的公平性?",
	body: "根据模型行为差异评估公平性。我们将根据每个所选特征的值来拆分数据，并评估这些拆分数据的模型性能指标和预测之间的差异。",
	learnMore: "了解更多",
	summaryCategoricalCount: "此特征具有 {0} 个唯一值",
	summaryNumericCount: "此数值特征的范围从 {0} 到 {1}，并被划分到 {2} 个箱中。",
	showCategories: "全部显示",
	hideCategories: "折叠",
	categoriesOverflow: "和 {0} 个附加类别",
	editBinning: "编辑组",
	subgroups: "子组"
};
var Metrics$g = {
	accuracyScore: "准确度",
	precisionScore: "精准率",
	recallScore: "召回",
	zeroOneLoss: "0-1 损失",
	specificityScore: "特异性分数",
	missRate: "漏检率",
	falloutRate: "错检率",
	maxError: "最大误差",
	meanAbsoluteError: "平均绝对误差",
	meanSquaredError: "MSE (均方误差)",
	meanSquaredLogError: "均方对数误差",
	medianAbsoluteError: "中值绝对误差",
	average: "平均预测",
	selectionRate: "选择率",
	overprediction: "过高预测",
	underprediction: "过低预测",
	r2_score: "R 平方分数",
	rms_error: "RMSE (均方根误差)",
	auc: "ROC 曲线下的面积",
	balancedRootMeanSquaredError: "平衡 RMSE",
	balancedAccuracy: "平衡准确度",
	f1Score: "F1-Score",
	logLoss: "Log Loss",
	accuracyDescription: "正确分类的数据点的分数。",
	precisionDescription: "分类为 1 的数据中正确分类的数据点的分数。",
	recallDescription: "真实标签为 1 的数据中正确分类的数据点的分数。其他名称: 真正率、敏感度。",
	rmseDescription: "方差平均值的平方根。",
	mseDescription: "平方误差的平均值。",
	meanAbsoluteErrorDescription: "误差绝对值的平均值。与 MSE 相比，对离群值更具健壮性。",
	r2Description: "模型解释的标签差异的分数。",
	aucDescription: "将正负样本分隔开的预测质量(以分数形式表示)。",
	balancedRMSEDescription: "对正样本和负样本重新进行加权以具有同等的总权重。适用于基础数据高度不均衡的情况。",
	balancedAccuracyDescription: "对正样本和负样本重新进行加权以具有同等的总权重。适用于基础数据高度不均衡的情况。",
	f1ScoreDescription: "F1-Score is the harmonic mean of precision and recall."
};
var BinDialog$g = {
	header: "配置箱",
	makeCategorical: "视为类别",
	save: "保存",
	cancel: "取消",
	numberOfBins: "箱数:",
	categoryHeader: "箱值:"
};
var zhcn = {
	loremIpsum: loremIpsum$g,
	defaultClassNames: defaultClassNames$g,
	defaultFeatureNames: defaultFeatureNames$g,
	defaultSingleFeatureName: defaultSingleFeatureName$g,
	defaultCustomMetricName: defaultCustomMetricName$g,
	accuracyTab: accuracyTab$g,
	opportunityTab: opportunityTab$g,
	modelComparisonTab: modelComparisonTab$g,
	tableTab: tableTab$g,
	dataSpecifications: dataSpecifications$g,
	attributes: attributes$g,
	singleAttributeCount: singleAttributeCount$g,
	attributesCount: attributesCount$g,
	instanceCount: instanceCount$g,
	close: close$g,
	calculating: calculating$g,
	accuracyMetricLegacy: accuracyMetricLegacy$g,
	errorOnInputs: errorOnInputs$g,
	Accuracy: Accuracy$g,
	Parity: Parity$g,
	Header: Header$g,
	Footer: Footer$g,
	Intro: Intro$g,
	ModelComparison: ModelComparison$g,
	Report: Report$g,
	Feature: Feature$g,
	Metrics: Metrics$g,
	BinDialog: BinDialog$g
};

var loremIpsum$h = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.";
var defaultClassNames$h = "類別 {0}";
var defaultFeatureNames$h = "敏感性特徵 {0}";
var defaultSingleFeatureName$h = "敏感性特徵";
var defaultCustomMetricName$h = "自訂指標 {0}";
var accuracyTab$h = "成效公平性";
var opportunityTab$h = "商機公平性";
var modelComparisonTab$h = "模型比較";
var tableTab$h = "詳細資料檢視";
var dataSpecifications$h = "資料統計資料";
var attributes$h = "屬性";
var singleAttributeCount$h = "1 個敏感性特徵";
var attributesCount$h = "{0} 個敏感性特徵";
var instanceCount$h = "{0} 個執行個體";
var close$h = "關閉";
var calculating$h = "正在計算...";
var accuracyMetricLegacy$h = "成效指標";
var errorOnInputs$h = "輸入發生錯誤。敏感性特徵目前必須是類別目錄值。請將值對應至組界類別，然後重試。";
var Accuracy$h = {
	header: "要如何測量成效?",
	modelMakes: "模型會建立",
	modelsMake: "模型會建立",
	body: "您的資料包含 {0} 個標籤和 {2} 個 {1} 預測。根據這些資訊，建議您使用下列指標。請從清單中選取一個指標。",
	binaryClassifier: "二元分類器",
	probabalisticRegressor: "概率迴歸輸入變數",
	regressor: "迴歸輸入變數",
	binary: "二元",
	continuous: "連續"
};
var Parity$h = {
	header: "依據差距進行測量的公平性",
	body: "差距指標會在所選功能間量化模型行為的變化。有兩種差距指標: 即將推出更多...."
};
var Header$h = {
	title: "Fairlearn",
	documentation: "文件"
};
var Footer$h = {
	back: "上一步",
	next: "下一步"
};
var Intro$h = {
	welcome: "歡迎使用",
	fairlearnDashboard: "Fairlearn 儀表板",
	introBody: "Fairlearn 儀表板可讓您評定模型成效與公平性之間的權衡",
	explanatoryStep: "若要設定評定，您必須指定敏感性特徵和成效指標。",
	getStarted: "立即開始",
	features: "敏感性特徵",
	featuresInfo: "敏感性特徵會用於將資料分割成群組。這些群組的模型公平性會以差距指標測量。差距指標會量化模型行為在各群組之間的差異。",
	accuracy: "成效指標",
	accuracyInfo: "成效指標可用於評估模型的整體品質，以及每個群組中的模型品質。各群組成效指標極端值之間的差異，會在成效中回報為差距。"
};
var ModelComparison$h = {
	title: "模型比較",
	howToRead: "如何閱讀此圖表",
	lower: "低於",
	higher: "高於",
	howToReadText: "此圖表會將每個 {0} 模型表示為可選取的點。X 軸代表 {1}，越{2}越好。Y 軸代表差距，越低越好。",
	insights: "見解",
	insightsText1: "此圖表顯示 {0} 與 {1} 模型的差距。",
	insightsText2: "{0} 的範圍為 {1} 到 {2}。差距的範圍為 {3} 到 {4}。",
	insightsText3: "最準確的模型達到 {1} 的 {0} 和 {2} 的差距。",
	insightsText4: "最低差距模型達到 {1} 的 {0} 和 {2} 的差距。",
	disparityInOutcomes: "預測中的差距",
	disparityInAccuracy: "{0} 中的差距",
	howToMeasureDisparity: "應如何測量差距?"
};
var Report$h = {
	modelName: "模型 {0}",
	title: "成效差距",
	globalAccuracyText: "為整體 {0}",
	accuracyDisparityText: "為 {0} 中的差距",
	editConfiguration: "編輯組態",
	backToComparisons: "多重模型檢視",
	outcomesTitle: "預測中的差距",
	minTag: "最小值",
	maxTag: "最大值",
	groupLabel: "子群組",
	underestimationError: "低於預測",
	underpredictionExplanation: "(已預測 = 0，True = 1)",
	overpredictionExplanation: "(已預測 = 1，True = 0)",
	overestimationError: "高於預測",
	classificationOutcomesHowToRead: "橫條圖會顯示各群組中的選擇率，表示分類為 1 的資料點。",
	regressionOutcomesHowToRead: "盒狀圖會顯示各群組中的預測分佈。個別資料點會重疊在上方。",
	classificationAccuracyHowToRead1: "橫條圖會顯示各群組中的誤差分佈。",
	classificationAccuracyHowToRead2: "錯誤會分割成高於預測錯誤 (當 True 標籤為 0 時，預測 1) 及低於預測錯誤 (當 True 標籤為 1 時，預測 0)。",
	classificationAccuracyHowToRead3: "以整體群組大小除以錯誤數目來取得回報比率。",
	probabilityAccuracyHowToRead1: "橫條圖會顯示各群組的平均絕對誤差，分割成高於預測及低於預測。",
	probabilityAccuracyHowToRead2: "在每個範例中，我們都會測量預測與標籤之間的差異。若是正數，我們稱為高於預測; 若是負數，我們稱為低於預測。",
	probabilityAccuracyHowToRead3: "我們回報了高於預測誤差總和及低於預測誤差總和除以整體群組大小。",
	regressionAccuracyHowToRead: "誤差是預測與標籤之間的差異。盒狀圖會顯示各群組中的誤差分佈。個別資料點會重疊在上方。",
	distributionOfPredictions: "預測分佈",
	distributionOfErrors: "誤差分佈",
	tooltipPrediction: "預測: {0}",
	tooltipError: "誤差: {0}"
};
var Feature$h = {
	header: "要依循哪些特徵評估模型公平性?",
	body: "公平性會根據模型行為中的差距部分進行評估。我們會依據各個所選特徵的值來分割資料，並評估在這些分割中，模型的成效指標與預測有何差異。",
	learnMore: "深入了解",
	summaryCategoricalCount: "此特徵有 {0} 個唯一的值",
	summaryNumericCount: "此數值特徵的範圍為 {0} 到 {1}，並分成 {2} 個組界。",
	showCategories: "全部顯示",
	hideCategories: "摺疊",
	categoriesOverflow: "   和其他 {0} 個類別",
	editBinning: "編輯群組",
	subgroups: "子群組"
};
var Metrics$h = {
	accuracyScore: "正確性",
	precisionScore: "精確度",
	recallScore: "召回率",
	zeroOneLoss: "0-1 損失",
	specificityScore: "具體程度分數",
	missRate: "失誤率",
	falloutRate: "散落率",
	maxError: "最大誤差",
	meanAbsoluteError: "平均絕對誤差",
	meanSquaredError: " MSE (均方誤差)",
	meanSquaredLogError: "平均平方對數誤差",
	medianAbsoluteError: "絕對誤差中位數",
	average: "平均預測",
	selectionRate: "選擇率",
	overprediction: "高於預測",
	underprediction: "低於預測",
	r2_score: "R 平方分數",
	rms_error: "RMSE (平均平方根誤差)",
	auc: "ROC 曲線下的區域",
	balancedRootMeanSquaredError: "平衡的 RMSE",
	balancedAccuracy: "平衡的正確性",
	f1Score: "F1-Score",
	logLoss: "Log Loss",
	accuracyDescription: "正確分類的資料點。",
	precisionDescription: "在分類為 1 的資料點當中，正確分類的資料點。",
	recallDescription: "在 True 標籤為 1 的資料點當中，正確分類的資料點。替代名稱: 確判為真率、敏感度。",
	rmseDescription: "平方誤差平均的平方根。",
	mseDescription: "平方誤差的平均。",
	meanAbsoluteErrorDescription: "誤差絕對值的平均。比 MSE 更不易受極端值影響。",
	r2Description: "模型所解釋的標籤變異數。",
	aucDescription: "從負值範例分隔出正值範例的預測品質，以分數檢視。",
	balancedRMSEDescription: "正值與負值範例會重新加權，使總權重相等。適用於高度不平衡的基礎資料。",
	balancedAccuracyDescription: "正值與負值範例會重新加權，使總權重相等。適用於高度不平衡的基礎資料。",
	f1ScoreDescription: "F1-Score is the harmonic mean of precision and recall."
};
var BinDialog$h = {
	header: "設定組界",
	makeCategorical: "視為類別",
	save: "儲存",
	cancel: "取消",
	numberOfBins: "組界數目:",
	categoryHeader: "組界值:"
};
var zhtw = {
	loremIpsum: loremIpsum$h,
	defaultClassNames: defaultClassNames$h,
	defaultFeatureNames: defaultFeatureNames$h,
	defaultSingleFeatureName: defaultSingleFeatureName$h,
	defaultCustomMetricName: defaultCustomMetricName$h,
	accuracyTab: accuracyTab$h,
	opportunityTab: opportunityTab$h,
	modelComparisonTab: modelComparisonTab$h,
	tableTab: tableTab$h,
	dataSpecifications: dataSpecifications$h,
	attributes: attributes$h,
	singleAttributeCount: singleAttributeCount$h,
	attributesCount: attributesCount$h,
	instanceCount: instanceCount$h,
	close: close$h,
	calculating: calculating$h,
	accuracyMetricLegacy: accuracyMetricLegacy$h,
	errorOnInputs: errorOnInputs$h,
	Accuracy: Accuracy$h,
	Parity: Parity$h,
	Header: Header$h,
	Footer: Footer$h,
	Intro: Intro$h,
	ModelComparison: ModelComparison$h,
	Report: Report$h,
	Feature: Feature$h,
	Metrics: Metrics$h,
	BinDialog: BinDialog$h
};

var localization = getLocalization({
  en: en,
  cs: cs,
  de: de,
  es: es,
  fr: fr,
  hu: hu,
  it: it,
  ja: ja,
  ko: ko,
  nl: nl,
  pl: pl,
  "pt-BR": ptbr,
  "pt-PT": pt,
  ru: ru,
  sv: sv,
  tr: tr,
  "zh-CN": zhcn,
  "zh-TW": zhtw
});

var AccuracyOptions = {
  accuracy_score: {
    key: "accuracy_score",
    title: localization.Metrics.accuracyScore,
    description: localization.Metrics.accuracyDescription,
    isMinimization: false,
    isPercentage: true,
    userVisible: true
  },
  precision_score: {
    key: "precision_score",
    title: localization.Metrics.precisionScore,
    description: localization.Metrics.precisionDescription,
    isMinimization: false,
    isPercentage: true,
    userVisible: true
  },
  recall_score: {
    key: "recall_score",
    title: localization.Metrics.recallScore,
    description: localization.Metrics.recallDescription,
    isMinimization: false,
    isPercentage: true,
    userVisible: true
  },
  zero_one_loss: {
    key: "zero_one_loss",
    title: localization.Metrics.zeroOneLoss,
    description: localization.loremIpsum,
    isMinimization: true,
    isPercentage: true
  },
  specificity_score: {
    key: "specificity_score",
    title: localization.Metrics.specificityScore,
    description: localization.loremIpsum,
    isMinimization: false,
    isPercentage: true
  },
  miss_rate: {
    key: "miss_rate",
    title: localization.Metrics.missRate,
    description: localization.loremIpsum,
    isMinimization: true,
    isPercentage: true
  },
  fallout_rate: {
    key: "fallout_rate",
    title: localization.Metrics.falloutRate,
    description: localization.loremIpsum,
    isMinimization: true,
    isPercentage: true
  },
  false_positive_over_total: {
    key: "false_positive_over_total",
    title: localization.Metrics.falloutRate,
    description: localization.loremIpsum,
    isMinimization: true,
    isPercentage: true
  },
  false_negative_over_total: {
    key: "false_negative_over_total",
    title: localization.Metrics.falloutRate,
    description: localization.loremIpsum,
    isMinimization: true,
    isPercentage: true
  },
  max_error: {
    key: "max_error",
    title: localization.Metrics.maxError,
    description: localization.loremIpsum,
    isMinimization: true,
    isPercentage: false
  },
  mean_absolute_error: {
    key: "mean_absolute_error",
    title: localization.Metrics.meanAbsoluteError,
    description: localization.Metrics.meanAbsoluteErrorDescription,
    isMinimization: true,
    isPercentage: false,
    userVisible: true
  },
  mean_squared_error: {
    key: "mean_squared_error",
    title: localization.Metrics.meanSquaredError,
    description: localization.Metrics.mseDescription,
    isMinimization: true,
    isPercentage: false,
    userVisible: true
  },
  mean_squared_log_error: {
    key: "mean_squared_log_error",
    title: localization.Metrics.meanSquaredLogError,
    description: localization.loremIpsum,
    isMinimization: true,
    isPercentage: false
  },
  median_absolute_error: {
    key: "median_absolute_error",
    title: localization.Metrics.medianAbsoluteError,
    description: localization.loremIpsum,
    isMinimization: true,
    isPercentage: false
  },
  balanced_root_mean_squared_error: {
    key: "balanced_root_mean_squared_error",
    title: localization.Metrics.balancedRootMeanSquaredError,
    description: localization.Metrics.balancedRMSEDescription,
    isMinimization: true,
    isPercentage: false,
    userVisible: true
  },
  average: {
    key: "average",
    title: localization.Metrics.average,
    description: localization.loremIpsum,
    isMinimization: false,
    isPercentage: false
  },
  selection_rate: {
    key: "selection_rate",
    title: localization.Metrics.selectionRate,
    description: localization.loremIpsum,
    isMinimization: false,
    isPercentage: true
  },
  overprediction: {
    key: "overprediction",
    title: localization.Metrics.overprediction,
    description: localization.loremIpsum,
    isMinimization: true,
    isPercentage: false
  },
  underprediction: {
    key: "underprediction",
    title: localization.Metrics.underprediction,
    description: localization.loremIpsum,
    isMinimization: true,
    isPercentage: false
  },
  r2_score: {
    key: "r2_score",
    title: localization.Metrics.r2_score,
    description: localization.Metrics.r2Description,
    isMinimization: false,
    isPercentage: false,
    userVisible: true,
    alwaysUpperCase: true
  },
  root_mean_squared_error: {
    key: "root_mean_squared_error",
    title: localization.Metrics.rms_error,
    description: localization.Metrics.rmseDescription,
    isMinimization: true,
    isPercentage: false,
    userVisible: true,
    alwaysUpperCase: true
  },
  auc: {
    key: "auc",
    title: localization.Metrics.auc,
    description: localization.Metrics.aucDescription,
    isMinimization: false,
    isPercentage: false,
    userVisible: true
  },
  balanced_accuracy_score: {
    key: "balanced_accuracy_score",
    title: localization.Metrics.balancedAccuracy,
    description: localization.Metrics.balancedAccuracyDescription,
    isMinimization: false,
    isPercentage: true,
    userVisible: true
  },
  f1_score: {
    key: "f1_score",
    title: localization.Metrics.f1Score,
    description: localization.Metrics.f1ScoreDescription,
    isMinimization: false,
    isPercentage: false,
    userVisible: true,
    alwaysUpperCase: true
  },
  log_loss: {
    key: "log_loss",
    title: localization.Metrics.logLoss,
    description: localization.loremIpsum,
    isMinimization: true,
    isPercentage: false
  }
};

var ParityModes;

(function (ParityModes) {
  ParityModes[ParityModes["difference"] = 0] = "difference";
  ParityModes[ParityModes["ratio"] = 1] = "ratio";
})(ParityModes || (ParityModes = {}));

var ParityOptions = {
  selection_rate: {
    key: "selection_rate",
    title: localization.Metrics.parityDifference,
    description: localization.Metrics.parityDifferenceDescription,
    parityMetric: "selection_rate",
    parityMode: ParityModes.difference
  },
  selection_rate_ratio: {
    key: "selection_rate_ratio",
    title: localization.Metrics.parityRatio,
    description: localization.Metrics.parityRatioDescription,
    parityMetric: "selection_rate",
    parityMode: ParityModes.ratio
  },
  zero_one_loss: {
    key: "zero_one_loss",
    title: localization.Metrics.errorRateDifference,
    description: localization.Metrics.errorRateDifferenceDescription,
    parityMetric: "zero_one_loss",
    parityMode: ParityModes.difference
  },
  recall_score: {
    key: "recall_score",
    title: localization.Metrics.equalOpportunityDifference,
    description: localization.Metrics.equalOpportunityDifferenceDescription,
    parityMetric: "recall_score",
    parityMode: ParityModes.difference
  }
};

var BinnedResponseBuilder = /*#__PURE__*/function () {
  function BinnedResponseBuilder() {
    _classCallCheck(this, BinnedResponseBuilder);
  }

  _createClass(BinnedResponseBuilder, null, [{
    key: "buildCategorical",
    value: function buildCategorical(featureRange, index, sensitiveFeatures) {
      if (featureRange.rangeType === RangeTypes.categorical) {
        return {
          hasError: false,
          array: featureRange.uniqueValues,
          featureIndex: index,
          rangeType: RangeTypes.categorical,
          labelArray: featureRange.uniqueValues
        };
      }

      var uniqueValues = BinnedResponseBuilder.getIntegerUniqueValues(sensitiveFeatures, index);
      return {
        hasError: false,
        array: uniqueValues,
        featureIndex: index,
        rangeType: RangeTypes.categorical,
        labelArray: uniqueValues.map(function (num) {
          return num.toString();
        })
      };
    }
  }, {
    key: "buildNumeric",
    value: function buildNumeric(featureRange, index, sensitiveFeatures, binCountIn) {
      var binCount;

      if (binCountIn === undefined) {
        if (featureRange.rangeType === RangeTypes.integer) {
          var uniqueValues = BinnedResponseBuilder.getIntegerUniqueValues(sensitiveFeatures, index);
          binCount = Math.min(5, uniqueValues.length);
        } else {
          binCount = 5;
        }
      } else {
        binCount = binCountIn;
      }

      var delta = featureRange.max - featureRange.min;

      if (delta === 0 || binCount === 0) {
        return {
          hasError: false,
          array: [featureRange.max],
          featureIndex: index,
          rangeType: RangeTypes.categorical,
          labelArray: [featureRange.max.toString()]
        };
      } // make uniform bins in these cases


      if (featureRange.rangeType === RangeTypes.numeric || delta < binCount - 1) {
        var binDelta = delta / binCount;

        var _array = new Array(binCount).fill(0).map(function (_, index) {
          return index !== binCount - 1 ? featureRange.min + binDelta * (1 + index) : featureRange.max;
        });

        var prevMax = featureRange.min;

        var _labelArray = _array.map(function (num) {
          var label = "".concat(prevMax.toLocaleString(undefined, {
            maximumSignificantDigits: 3
          }), " - ").concat(num.toLocaleString(undefined, {
            maximumSignificantDigits: 3
          }));
          prevMax = num;
          return label;
        });

        return {
          hasError: false,
          array: _array,
          featureIndex: index,
          rangeType: RangeTypes.numeric,
          labelArray: _labelArray
        };
      } // handle integer case, increment delta since we include the ends as discrete values


      var intDelta = delta / binCount;
      var array = new Array(binCount).fill(0).map(function (_, index) {
        if (index === binCount - 1) {
          return featureRange.max;
        }

        return Math.ceil(featureRange.min - 1 + intDelta * (index + 1));
      });
      var previousVal = featureRange.min;
      var labelArray = array.map(function (num) {
        var label = previousVal === num ? previousVal.toLocaleString(undefined, {
          maximumSignificantDigits: 3
        }) : "".concat(previousVal.toLocaleString(undefined, {
          maximumSignificantDigits: 3
        }), " - ").concat(num.toLocaleString(undefined, {
          maximumSignificantDigits: 3
        }));
        previousVal = num + 1;
        return label;
      });
      return {
        hasError: false,
        array: array,
        featureIndex: index,
        rangeType: RangeTypes.integer,
        labelArray: labelArray
      };
    }
  }, {
    key: "buildDefaultBin",
    value: function buildDefaultBin(featureRange, index, sensitiveFeatures) {
      if (featureRange.rangeType === RangeTypes.categorical) {
        return BinnedResponseBuilder.buildCategorical(featureRange, index, sensitiveFeatures);
      }

      if (featureRange.rangeType === RangeTypes.integer) {
        var uniqueValues = BinnedResponseBuilder.getIntegerUniqueValues(sensitiveFeatures, index);

        if (uniqueValues.length <= BinnedResponseBuilder.UpperBoundUniqueIntegers) {
          return BinnedResponseBuilder.buildCategorical(featureRange, index, sensitiveFeatures);
        }
      }

      return BinnedResponseBuilder.buildNumeric(featureRange, index, sensitiveFeatures);
    }
  }, {
    key: "getIntegerUniqueValues",
    value: function getIntegerUniqueValues(sensitiveFeatures, index) {
      var column = sensitiveFeatures.map(function (row) {
        return row[index];
      });
      return _.uniq(column).sort(function (a, b) {
        return a - b;
      });
    }
  }]);

  return BinnedResponseBuilder;
}();
BinnedResponseBuilder.UpperBoundUniqueIntegers = 10;

var WizardBuilder = /*#__PURE__*/function () {
  function WizardBuilder() {
    _classCallCheck(this, WizardBuilder);
  }

  _createClass(WizardBuilder, null, [{
    key: "initializeIcons",
    value: function initializeIcons$1(props) {
      if (WizardBuilder.iconsInitialized === false && props.shouldInitializeIcons !== false) {
        initializeIcons(props.iconUrl);

        WizardBuilder.iconsInitialized = true;
      }
    }
  }, {
    key: "buildModelNames",
    value: function buildModelNames(props) {
      return !!props.modelNames && props.modelNames.length === props.predictedY.length ? props.modelNames : props.predictedY.map(function (_, modelIndex) {
        return "Model ".concat(modelIndex);
      });
    }
  }, {
    key: "buildInitialFairnessContext",
    value: function buildInitialFairnessContext(props) {
      return {
        dataset: props.testData,
        trueY: props.trueY,
        predictions: props.predictedY,
        binVector: [],
        groupNames: [],
        modelMetadata: this.buildModelMetadata(props),
        modelNames: this.buildModelNames(props)
      };
    }
  }, {
    key: "buildPrecomputedFairnessContext",
    value: function buildPrecomputedFairnessContext(props) {
      return {
        dataset: undefined,
        trueY: props.trueY,
        predictions: props.predictedY,
        binVector: props.precomputedFeatureBins[0].binVector,
        groupNames: props.precomputedFeatureBins[0].binLabels,
        modelMetadata: this.buildPrecomputedModelMetadata(props),
        modelNames: this.buildModelNames(props)
      };
    }
  }, {
    key: "getClassLength",
    value: function getClassLength(props) {
      return _.uniq(props.trueY).length;
    }
  }, {
    key: "buildPrecomputedModelMetadata",
    value: function buildPrecomputedModelMetadata(props) {
      var _props$dataSummary, _props$dataSummary2;

      var featureNames = (_props$dataSummary = props.dataSummary) === null || _props$dataSummary === void 0 ? void 0 : _props$dataSummary.featureNames;

      if (!featureNames) {
        featureNames = props.precomputedFeatureBins.map(function (binObject, index) {
          return binObject.featureBinName || localization.formatString(localization.defaultFeatureNames, index);
        });
      }

      var classNames = ((_props$dataSummary2 = props.dataSummary) === null || _props$dataSummary2 === void 0 ? void 0 : _props$dataSummary2.classNames) || this.buildIndexedNames(this.getClassLength(props), localization.defaultClassNames);
      var featureRanges = props.precomputedFeatureBins.map(function (binMeta) {
        return {
          uniqueValues: binMeta.binLabels,
          rangeType: RangeTypes.categorical
        };
      });
      return {
        featureNames: featureNames,
        featureNamesAbridged: featureNames,
        classNames: classNames,
        featureIsCategorical: props.precomputedFeatureBins.map(function () {
          return true;
        }),
        featureRanges: featureRanges,
        PredictionType: props.predictionType
      };
    }
  }, {
    key: "buildModelMetadata",
    value: function buildModelMetadata(props) {
      var _props$dataSummary3, _props$dataSummary4, _props$dataSummary5, _props$dataSummary6;

      var featureNames = (_props$dataSummary3 = props.dataSummary) === null || _props$dataSummary3 === void 0 ? void 0 : _props$dataSummary3.featureNames;

      if (!featureNames) {
        var featureLength = 0;

        if (props.testData && props.testData[0] !== undefined) {
          featureLength = props.testData[0].length;
        }

        featureNames = featureLength === 1 ? [localization.defaultSingleFeatureName] : this.buildIndexedNames(featureLength, localization.defaultFeatureNames);
      }

      var classNames = ((_props$dataSummary4 = props.dataSummary) === null || _props$dataSummary4 === void 0 ? void 0 : _props$dataSummary4.classNames) || this.buildIndexedNames(this.getClassLength(props), localization.defaultClassNames);
      var featureIsCategorical = ModelMetadata.buildIsCategorical(featureNames.length, props.testData, (_props$dataSummary5 = props.dataSummary) === null || _props$dataSummary5 === void 0 ? void 0 : _props$dataSummary5.categoricalMap);
      var featureRanges = ModelMetadata.buildFeatureRanges(props.testData, featureIsCategorical, (_props$dataSummary6 = props.dataSummary) === null || _props$dataSummary6 === void 0 ? void 0 : _props$dataSummary6.categoricalMap);
      var PredictionType = this.determinePredictionType(props.trueY, props.predictedY, props.predictionType);
      return {
        featureNames: featureNames,
        featureNamesAbridged: featureNames,
        classNames: classNames,
        featureIsCategorical: featureIsCategorical,
        featureRanges: featureRanges,
        PredictionType: PredictionType
      };
    }
  }, {
    key: "buildIndexedNames",
    value: function buildIndexedNames(length, baseString) {
      return _toConsumableArray(new Array(length).keys()).map(function (i) {
        return localization.formatString(baseString, i.toString());
      });
    }
  }, {
    key: "determinePredictionType",
    value: function determinePredictionType(trueY, predictedY, specifiedType) {
      if (specifiedType === PredictionTypes.binaryClassification || specifiedType === PredictionTypes.probability || specifiedType === PredictionTypes.regression) {
        return specifiedType;
      }

      var predictedIsPossibleProba = predictedY.every(function (predictionVector) {
        return predictionVector.every(function (x) {
          return x >= 0 && x <= 1;
        });
      });
      var trueIsBinary = _.uniq(trueY).length < 3;

      if (!trueIsBinary) {
        return PredictionTypes.regression;
      }

      if (_.uniq(_.flatten(predictedY)).length < 3) {
        return PredictionTypes.binaryClassification;
      }

      if (predictedIsPossibleProba) {
        return PredictionTypes.probability;
      }

      return PredictionTypes.regression;
    }
  }, {
    key: "buildAccuracyListForPrecomputedMetrics",
    value: function buildAccuracyListForPrecomputedMetrics(props) {
      var customMetrics = [];
      var providedMetrics = [];
      Object.keys(props.precomputedMetrics[0][0]).forEach(function (key) {
        var metric = AccuracyOptions[key];

        if (metric !== undefined) {
          if (metric.userVisible) {
            providedMetrics.push(metric);
          }
        } else {
          var _props$customMetrics;

          var customMetric = (_props$customMetrics = props.customMetrics) === null || _props$customMetrics === void 0 ? void 0 : _props$customMetrics.find(function (metric) {
            return metric.id === key;
          });
          customMetrics.push({
            key: key,
            title: (customMetric === null || customMetric === void 0 ? void 0 : customMetric.name) || localization.formatString(localization.defaultCustomMetricName, customMetrics.length),
            isMinimization: true,
            isPercentage: true,
            description: customMetric === null || customMetric === void 0 ? void 0 : customMetric.description
          });
        }
      });
      return customMetrics.concat(providedMetrics);
    }
  }, {
    key: "buildParityListForPrecomputedMetrics",
    value: function buildParityListForPrecomputedMetrics(props) {
      var customMetrics = [];
      var providedMetrics = [];
      Object.keys(props.precomputedMetrics[0][0]).forEach(function (key) {
        var metric = ParityOptions[key];

        if (metric !== undefined) {
          providedMetrics.push(metric);
        }
      });
      return customMetrics.concat(providedMetrics);
    }
  }, {
    key: "buildFeatureBins",
    value: function buildFeatureBins(fairnessContext) {
      return fairnessContext.modelMetadata.featureNames.map(function (_, index) {
        return BinnedResponseBuilder.buildDefaultBin(fairnessContext.modelMetadata.featureRanges[index], index, fairnessContext.dataset);
      });
    }
  }, {
    key: "generateBinVectorForBin",
    value: function generateBinVectorForBin(value, dataset) {
      if (!dataset) {
        return [];
      }

      return dataset.map(function (row) {
        var featureValue = row[value.featureIndex];

        if (value.rangeType === RangeTypes.categorical) {
          // this handles categorical, as well as integers when user requests to treat as categorical
          return value.array.indexOf(featureValue);
        }

        return value.array.findIndex(function (upperLimit) {
          return upperLimit >= featureValue;
        });
      });
    }
  }]);

  return WizardBuilder;
}();
WizardBuilder.iconsInitialized = false;

var MetricsCache = /*#__PURE__*/function () {
  function MetricsCache(featureCount, numberOfModels, fetchMethod, precomputedCache) {
    _classCallCheck(this, MetricsCache);

    this.featureCount = featureCount;
    this.numberOfModels = numberOfModels;
    this.fetchMethod = fetchMethod;

    if (precomputedCache) {
      this.cache = precomputedCache;
    } else {
      this.cache = new Array(featureCount).fill(0).map(function () {
        return new Array(numberOfModels).fill(0).map(function () {
          return {};
        });
      });
    }
  }

  _createClass(MetricsCache, [{
    key: "getMetric",
    value: function () {
      var _getMetric = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(binIndexVector, featureIndex, modelIndex, key) {
        var value;
        return regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                value = this.cache[featureIndex][modelIndex][key];

                if (!(value === undefined && this.fetchMethod)) {
                  _context.next = 6;
                  break;
                }

                _context.next = 4;
                return this.fetchMethod({
                  metricKey: key,
                  binVector: binIndexVector,
                  modelIndex: modelIndex
                });

              case 4:
                value = _context.sent;
                this.cache[featureIndex][modelIndex][key] = value;

              case 6:
                return _context.abrupt("return", this.cache[featureIndex][modelIndex][key]);

              case 7:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function getMetric(_x, _x2, _x3, _x4) {
        return _getMetric.apply(this, arguments);
      }

      return getMetric;
    }()
  }, {
    key: "getDisparityMetric",
    value: function () {
      var _getDisparityMetric = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(binIndexVector, featureIndex, modelIndex, key, disparityMethod) {
        var _value;

        var value, bins, min, max;
        return regeneratorRuntime.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                value = this.cache[featureIndex][modelIndex][key];

                if (!(value === undefined && this.fetchMethod)) {
                  _context2.next = 6;
                  break;
                }

                _context2.next = 4;
                return this.fetchMethod({
                  metricKey: key,
                  binVector: binIndexVector,
                  modelIndex: modelIndex
                });

              case 4:
                value = _context2.sent;
                this.cache[featureIndex][modelIndex][key] = value;

              case 6:
                if ((_value = value) === null || _value === void 0 ? void 0 : _value.bins) {
                  _context2.next = 8;
                  break;
                }

                return _context2.abrupt("return", Number.NaN);

              case 8:
                bins = value.bins.slice().filter(function (x) {
                  return x !== undefined && !Number.isNaN(x);
                });
                min = _.min(bins);
                max = _.max(bins);

                if (!(min === undefined || max === undefined || max === 0 && disparityMethod === ParityModes.ratio)) {
                  _context2.next = 13;
                  break;
                }

                return _context2.abrupt("return", Number.NaN);

              case 13:
                return _context2.abrupt("return", disparityMethod === ParityModes.difference ? max - min : min / max);

              case 14:
              case "end":
                return _context2.stop();
            }
          }
        }, _callee2, this);
      }));

      function getDisparityMetric(_x5, _x6, _x7, _x8, _x9) {
        return _getDisparityMetric.apply(this, arguments);
      }

      return getDisparityMetric;
    }()
  }, {
    key: "clearCache",
    value: function clearCache(binIndex) {
      var _this = this;

      if (binIndex !== undefined) {
        this.cache[binIndex] = new Array(this.numberOfModels).fill(0).map(function () {
          return {};
        });
      } else {
        this.cache = new Array(this.featureCount).fill(0).map(function () {
          return new Array(_this.numberOfModels).fill(0).map(function () {
            return {};
          });
        });
      }
    }
  }]);

  return MetricsCache;
}();

var BinDialogStyles = function BinDialogStyles() {
  var theme = getTheme$1();
  return mergeStyleSets$1({
    frame: {
      height: "400px",
      width: "500px",
      display: "flex",
      flexDirection: "column",
      backgroundColor: theme.semanticColors.bodyBackground
    },
    header: {
      padding: "12px",
      textAlign: "center",
      backgroundColor: theme.semanticColors.bodyFrameBackground,
      color: theme.semanticColors.bodyText
    },
    buttons: {
      display: "inline-flex",
      flexDirection: "row-reverse",
      padding: "10px"
    },
    saveButton: {
      height: "44px",
      padding: "12px",
      marginLeft: "10px"
    },
    cancelButton: {
      height: "44px",
      padding: "12px"
    },
    binCounter: {
      selectors: {
        "& label": {
          color: theme.semanticColors.bodyText,
          fontSize: FontSizes$1.mediumPlus,
          fontWeight: FontWeights$1.regular
        }
      }
    },
    main: {
      flexGrow: 1,
      padding: "20px 40px",
      overflow: "hidden",
      display: "flex",
      flexDirection: "column"
    },
    controls: {
      display: "inline-flex",
      width: "100%",
      justifyContent: "space-between",
      height: "30px",
      alignItems: "center",
      paddingBottom: "10px",
      borderBottom: "1px solid",
      borderBottomColor: theme.semanticColors.bodyDivider,
      marginBottom: "10px"
    },
    scrollArea: {
      overflowY: "auto",
      overflowX: "hidden",
      flexGrow: "2"
    },
    groupLabel: {
      color: theme.semanticColors.bodyText,
      height: "25px",
      borderBottom: "1px solid",
      borderBottomColor: theme.semanticColors.bodyDivider,
      paddingLeft: "12px"
    }
  });
};

var BinDialog$i = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(BinDialog, _React$PureComponent);

  var _super = _createSuper(BinDialog);

  function BinDialog(props) {
    var _this;

    _classCallCheck(this, BinDialog);

    _this = _super.call(this, props);

    _this.onSave = function () {
      _this.props.onSave(_this.state);
    };

    _this.toggleCategorical = function (_ev, checked) {
      if (checked) {
        _this.setState(BinnedResponseBuilder.buildCategorical(_this.props.range, _this.props.index, _this.props.dataset));
      } else if (_this.props.bins.rangeType === RangeTypes.integer) {
        _this.setState(_this.props.bins);
      } else {
        _this.setState(BinnedResponseBuilder.buildNumeric(_this.props.range, _this.props.index, _this.props.dataset));
      }
    };

    _this.setBinCount = function (delta, stringVal) {
      if (delta === 0) {
        var number = +stringVal;

        if (!Number.isInteger(number) || number > BinDialog.maxBins || number < BinDialog.minBins) {
          return _this.state.array.length.toString();
        }

        _this.setState(BinnedResponseBuilder.buildNumeric(_this.props.range, _this.props.index, _this.props.dataset, number));
      } else {
        var prevVal = _this.state.array.length;
        var binCount = prevVal + delta;

        if (binCount > BinDialog.maxBins || binCount < BinDialog.minBins) {
          return prevVal.toString();
        }

        _this.setState(BinnedResponseBuilder.buildNumeric(_this.props.range, _this.props.index, _this.props.dataset, prevVal + delta));
      }
    };

    _this.state = _.cloneDeep(props.bins);
    return _this;
  }

  _createClass(BinDialog, [{
    key: "render",
    value: function render() {
      var styles = BinDialogStyles();
      return React__default.createElement("div", {
        className: styles.frame
      }, React__default.createElement(Text$1, {
        variant: "xLargePlus",
        className: styles.header
      }, localization.BinDialog.header), React__default.createElement("div", {
        className: styles.main
      }, React__default.createElement("div", {
        className: styles.controls
      }, this.props.range.rangeType === RangeTypes.integer && React__default.createElement(Checkbox, {
        label: localization.BinDialog.makeCategorical,
        checked: this.state.rangeType === RangeTypes.categorical,
        onChange: this.toggleCategorical
      }), this.state.rangeType !== RangeTypes.categorical && React__default.createElement("div", {
        className: styles.binCounter
      }, React__default.createElement(SpinButton, {
        styles: {
          spinButtonWrapper: {
            maxWidth: "98px"
          },
          labelWrapper: {
            alignSelf: "center"
          },
          root: {
            display: "inline-flex",
            "float": "right",
            selectors: {
              "> div": {
                maxWidth: "108px"
              }
            }
          }
        },
        label: localization.BinDialog.numberOfBins,
        min: BinDialog.minBins,
        max: BinDialog.maxBins,
        value: this.state.array.length.toString(),
        onIncrement: this.setBinCount.bind(this, 1),
        onDecrement: this.setBinCount.bind(this, -1),
        onValidate: this.setBinCount.bind(this, 0)
      }))), React__default.createElement(Text$1, null, localization.BinDialog.categoryHeader), React__default.createElement("div", {
        className: styles.scrollArea
      }, this.state.labelArray.map(function (val, i) {
        return React__default.createElement("div", {
          className: styles.groupLabel,
          key: i
        }, val);
      }))), React__default.createElement("div", {
        className: styles.buttons
      }, React__default.createElement(PrimaryButton$1, {
        className: styles.saveButton,
        text: localization.BinDialog.save,
        onClick: this.onSave
      }), React__default.createElement(DefaultButton$1, {
        className: styles.cancelButton,
        text: localization.BinDialog.cancel,
        onClick: this.props.onCancel
      })));
    }
  }]);

  return BinDialog;
}(React__default.PureComponent);
BinDialog$i.minBins = 1;
BinDialog$i.maxBins = 30;

var DataSpecificationBladeStyles = function DataSpecificationBladeStyles() {
  var theme = getTheme$1();
  return mergeStyleSets$1({
    title: {
      color: theme.semanticColors.bodyText,
      height: "20px",
      paddingBottom: "10px"
    },
    frame: {
      paddingTop: "35px",
      paddingLeft: "60px",
      width: "120px",
      boxSizing: "content-box"
    },
    text: {
      color: theme.semanticColors.bodyText
    }
  });
};

var DataSpecificationBlade = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(DataSpecificationBlade, _React$PureComponent);

  var _super = _createSuper(DataSpecificationBlade);

  function DataSpecificationBlade() {
    _classCallCheck(this, DataSpecificationBlade);

    return _super.apply(this, arguments);
  }

  _createClass(DataSpecificationBlade, [{
    key: "render",
    value: function render() {
      var styles = DataSpecificationBladeStyles();
      return React__default.createElement("div", {
        className: styles.frame
      }, React__default.createElement(Text$1, {
        variant: "small",
        className: styles.title,
        block: true
      }, localization.dataSpecifications), React__default.createElement(Text$1, {
        variant: "small",
        className: styles.text,
        block: true
      }, this.props.featureNames.length === 1 ? localization.singleAttributeCount : localization.formatString(localization.attributesCount, this.props.featureNames.length)), React__default.createElement(Text$1, {
        variant: "small",
        className: styles.text,
        block: true
      }, localization.formatString(localization.instanceCount, this.props.numberRows)));
    }
  }]);

  return DataSpecificationBlade;
}(React__default.PureComponent);

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise */

var extendStatics = function(d, b) {
    extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
    return extendStatics(d, b);
};

function __extends(d, b) {
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

function __decorate(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}

function __spreadArrays() {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
}

// A packages cache that makes sure that we don't inject the same packageName twice in the same bundle -
// this cache is local to the module closure inside this bundle
var packagesCache = {};
// Cache access to window to avoid IE11 memory leak.
var _win = undefined;
try {
    _win = window;
}
catch (e) {
    /* no-op */
}
function setVersion(packageName, packageVersion) {
    if (typeof _win !== 'undefined') {
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        var packages = (_win.__packages__ = _win.__packages__ || {});
        // We allow either the global packages or local packages caches to invalidate so testing can
        // just clear the global to set this state
        if (!packages[packageName] || !packagesCache[packageName]) {
            packagesCache[packageName] = packageVersion;
            var versions = (packages[packageName] = packages[packageName] || []);
            versions.push(packageVersion);
        }
    }
}

setVersion('@uifabric/set-version', '6.0.0');

var _window = undefined;
// Note: Accessing "window" in IE11 is somewhat expensive, and calling "typeof window"
// hits a memory leak, whereas aliasing it and calling "typeof _window" does not.
// Caching the window value at the file scope lets us minimize the impact.
try {
    _window = window;
}
catch (e) {
    /* no-op */
}
/**
 * Helper to get the window object. The helper will make sure to use a cached variable
 * of "window", to avoid overhead and memory leaks in IE11. Note that in popup scenarios the
 * window object won't match the "global" window object, and for these scenarios, you should
 * pass in an element hosted within the popup.
 *
 * @public
 */
function getWindow(rootElement) {
    if ( typeof _window === 'undefined') {
        return undefined;
    }
    else {
        var el = rootElement;
        return el && el.ownerDocument && el.ownerDocument.defaultView ? el.ownerDocument.defaultView : _window;
    }
}

/**
 * Bugs often appear in async code when stuff gets disposed, but async operations don't get canceled.
 * This Async helper class solves these issues by tying async code to the lifetime of a disposable object.
 *
 * Usage: Anything class extending from BaseModel can access this helper via this.async. Otherwise create a
 * new instance of the class and remember to call dispose() during your code's dispose handler.
 *
 * @public
 */
var Async = /** @class */ (function () {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    function Async(parent, onError) {
        this._timeoutIds = null;
        this._immediateIds = null;
        this._intervalIds = null;
        this._animationFrameIds = null;
        this._isDisposed = false;
        this._parent = parent || null;
        this._onErrorHandler = onError;
        this._noop = function () {
            /* do nothing */
        };
    }
    /**
     * Dispose function, clears all async operations.
     */
    Async.prototype.dispose = function () {
        var id;
        this._isDisposed = true;
        this._parent = null;
        // Clear timeouts.
        if (this._timeoutIds) {
            for (id in this._timeoutIds) {
                if (this._timeoutIds.hasOwnProperty(id)) {
                    this.clearTimeout(parseInt(id, 10));
                }
            }
            this._timeoutIds = null;
        }
        // Clear immediates.
        if (this._immediateIds) {
            for (id in this._immediateIds) {
                if (this._immediateIds.hasOwnProperty(id)) {
                    this.clearImmediate(parseInt(id, 10));
                }
            }
            this._immediateIds = null;
        }
        // Clear intervals.
        if (this._intervalIds) {
            for (id in this._intervalIds) {
                if (this._intervalIds.hasOwnProperty(id)) {
                    this.clearInterval(parseInt(id, 10));
                }
            }
            this._intervalIds = null;
        }
        // Clear animation frames.
        if (this._animationFrameIds) {
            for (id in this._animationFrameIds) {
                if (this._animationFrameIds.hasOwnProperty(id)) {
                    this.cancelAnimationFrame(parseInt(id, 10));
                }
            }
            this._animationFrameIds = null;
        }
    };
    /**
     * SetTimeout override, which will auto cancel the timeout during dispose.
     * @param callback - Callback to execute.
     * @param duration - Duration in milliseconds.
     * @returns The setTimeout id.
     */
    Async.prototype.setTimeout = function (callback, duration) {
        var _this = this;
        var timeoutId = 0;
        if (!this._isDisposed) {
            if (!this._timeoutIds) {
                this._timeoutIds = {};
            }
            timeoutId = setTimeout(function () {
                // Time to execute the timeout, enqueue it as a foreground task to be executed.
                try {
                    // Now delete the record and call the callback.
                    if (_this._timeoutIds) {
                        delete _this._timeoutIds[timeoutId];
                    }
                    callback.apply(_this._parent);
                }
                catch (e) {
                    if (_this._onErrorHandler) {
                        _this._onErrorHandler(e);
                    }
                }
            }, duration);
            this._timeoutIds[timeoutId] = true;
        }
        return timeoutId;
    };
    /**
     * Clears the timeout.
     * @param id - Id to cancel.
     */
    Async.prototype.clearTimeout = function (id) {
        if (this._timeoutIds && this._timeoutIds[id]) {
            clearTimeout(id);
            delete this._timeoutIds[id];
        }
    };
    /**
     * SetImmediate override, which will auto cancel the immediate during dispose.
     * @param callback - Callback to execute.
     * @param targetElement - Optional target element to use for identifying the correct window.
     * @returns The setTimeout id.
     */
    Async.prototype.setImmediate = function (callback, targetElement) {
        var _this = this;
        var immediateId = 0;
        var win = getWindow(targetElement);
        if (!this._isDisposed) {
            if (!this._immediateIds) {
                this._immediateIds = {};
            }
            var setImmediateCallback = function () {
                // Time to execute the timeout, enqueue it as a foreground task to be executed.
                try {
                    // Now delete the record and call the callback.
                    if (_this._immediateIds) {
                        delete _this._immediateIds[immediateId];
                    }
                    callback.apply(_this._parent);
                }
                catch (e) {
                    _this._logError(e);
                }
            };
            immediateId = win.setTimeout(setImmediateCallback, 0);
            this._immediateIds[immediateId] = true;
        }
        return immediateId;
    };
    /**
     * Clears the immediate.
     * @param id - Id to cancel.
     * @param targetElement - Optional target element to use for identifying the correct window.
     */
    Async.prototype.clearImmediate = function (id, targetElement) {
        var win = getWindow(targetElement);
        if (this._immediateIds && this._immediateIds[id]) {
            win.clearTimeout(id);
            delete this._immediateIds[id];
        }
    };
    /**
     * SetInterval override, which will auto cancel the timeout during dispose.
     * @param callback - Callback to execute.
     * @param duration - Duration in milliseconds.
     * @returns The setTimeout id.
     */
    Async.prototype.setInterval = function (callback, duration) {
        var _this = this;
        var intervalId = 0;
        if (!this._isDisposed) {
            if (!this._intervalIds) {
                this._intervalIds = {};
            }
            intervalId = setInterval(function () {
                // Time to execute the interval callback, enqueue it as a foreground task to be executed.
                try {
                    callback.apply(_this._parent);
                }
                catch (e) {
                    _this._logError(e);
                }
            }, duration);
            this._intervalIds[intervalId] = true;
        }
        return intervalId;
    };
    /**
     * Clears the interval.
     * @param id - Id to cancel.
     */
    Async.prototype.clearInterval = function (id) {
        if (this._intervalIds && this._intervalIds[id]) {
            clearInterval(id);
            delete this._intervalIds[id];
        }
    };
    /**
     * Creates a function that, when executed, will only call the func function at most once per
     * every wait milliseconds. Provide an options object to indicate that func should be invoked
     * on the leading and/or trailing edge of the wait timeout. Subsequent calls to the throttled
     * function will return the result of the last func call.
     *
     * Note: If leading and trailing options are true func will be called on the trailing edge of
     * the timeout only if the throttled function is invoked more than once during the wait timeout.
     *
     * @param func - The function to throttle.
     * @param wait - The number of milliseconds to throttle executions to. Defaults to 0.
     * @param options - The options object.
     * @returns The new throttled function.
     */
    Async.prototype.throttle = function (func, wait, options) {
        var _this = this;
        if (this._isDisposed) {
            return this._noop;
        }
        var waitMS = wait || 0;
        var leading = true;
        var trailing = true;
        var lastExecuteTime = 0;
        var lastResult;
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        var lastArgs;
        var timeoutId = null;
        if (options && typeof options.leading === 'boolean') {
            leading = options.leading;
        }
        if (options && typeof options.trailing === 'boolean') {
            trailing = options.trailing;
        }
        var callback = function (userCall) {
            var now = new Date().getTime();
            var delta = now - lastExecuteTime;
            var waitLength = leading ? waitMS - delta : waitMS;
            if (delta >= waitMS && (!userCall || leading)) {
                lastExecuteTime = now;
                if (timeoutId) {
                    _this.clearTimeout(timeoutId);
                    timeoutId = null;
                }
                lastResult = func.apply(_this._parent, lastArgs);
            }
            else if (timeoutId === null && trailing) {
                timeoutId = _this.setTimeout(callback, waitLength);
            }
            return lastResult;
        };
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        var resultFunction = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            lastArgs = args;
            return callback(true);
        };
        return resultFunction;
    };
    /**
     * Creates a function that will delay the execution of func until after wait milliseconds have
     * elapsed since the last time it was invoked. Provide an options object to indicate that func
     * should be invoked on the leading and/or trailing edge of the wait timeout. Subsequent calls
     * to the debounced function will return the result of the last func call.
     *
     * Note: If leading and trailing options are true func will be called on the trailing edge of
     * the timeout only if the debounced function is invoked more than once during the wait
     * timeout.
     *
     * @param func - The function to debounce.
     * @param wait - The number of milliseconds to delay.
     * @param options - The options object.
     * @returns The new debounced function.
     */
    Async.prototype.debounce = function (func, wait, options) {
        var _this = this;
        if (this._isDisposed) {
            var noOpFunction = (function () {
                /** Do nothing */
            });
            noOpFunction.cancel = function () {
                return;
            };
            /* eslint-disable @typescript-eslint/no-explicit-any */
            noOpFunction.flush = (function () { return null; });
            /* eslint-enable @typescript-eslint/no-explicit-any */
            noOpFunction.pending = function () { return false; };
            return noOpFunction;
        }
        var waitMS = wait || 0;
        var leading = false;
        var trailing = true;
        var maxWait = null;
        var lastCallTime = 0;
        var lastExecuteTime = new Date().getTime();
        var lastResult;
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        var lastArgs;
        var timeoutId = null;
        if (options && typeof options.leading === 'boolean') {
            leading = options.leading;
        }
        if (options && typeof options.trailing === 'boolean') {
            trailing = options.trailing;
        }
        if (options && typeof options.maxWait === 'number' && !isNaN(options.maxWait)) {
            maxWait = options.maxWait;
        }
        var markExecuted = function (time) {
            if (timeoutId) {
                _this.clearTimeout(timeoutId);
                timeoutId = null;
            }
            lastExecuteTime = time;
        };
        var invokeFunction = function (time) {
            markExecuted(time);
            lastResult = func.apply(_this._parent, lastArgs);
        };
        var callback = function (userCall) {
            var now = new Date().getTime();
            var executeImmediately = false;
            if (userCall) {
                if (leading && now - lastCallTime >= waitMS) {
                    executeImmediately = true;
                }
                lastCallTime = now;
            }
            var delta = now - lastCallTime;
            var waitLength = waitMS - delta;
            var maxWaitDelta = now - lastExecuteTime;
            var maxWaitExpired = false;
            if (maxWait !== null) {
                // maxWait only matters when there is a pending callback
                if (maxWaitDelta >= maxWait && timeoutId) {
                    maxWaitExpired = true;
                }
                else {
                    waitLength = Math.min(waitLength, maxWait - maxWaitDelta);
                }
            }
            if (delta >= waitMS || maxWaitExpired || executeImmediately) {
                invokeFunction(now);
            }
            else if ((timeoutId === null || !userCall) && trailing) {
                timeoutId = _this.setTimeout(callback, waitLength);
            }
            return lastResult;
        };
        var pending = function () {
            return !!timeoutId;
        };
        var cancel = function () {
            if (pending()) {
                // Mark the debounced function as having executed
                markExecuted(new Date().getTime());
            }
        };
        var flush = function () {
            if (pending()) {
                invokeFunction(new Date().getTime());
            }
            return lastResult;
        };
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        var resultFunction = (function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            lastArgs = args;
            return callback(true);
        });
        resultFunction.cancel = cancel;
        resultFunction.flush = flush;
        resultFunction.pending = pending;
        return resultFunction;
    };
    Async.prototype.requestAnimationFrame = function (callback, targetElement) {
        var _this = this;
        var animationFrameId = 0;
        var win = getWindow(targetElement);
        if (!this._isDisposed) {
            if (!this._animationFrameIds) {
                this._animationFrameIds = {};
            }
            var animationFrameCallback = function () {
                try {
                    // Now delete the record and call the callback.
                    if (_this._animationFrameIds) {
                        delete _this._animationFrameIds[animationFrameId];
                    }
                    callback.apply(_this._parent);
                }
                catch (e) {
                    _this._logError(e);
                }
            };
            animationFrameId = win.requestAnimationFrame
                ? win.requestAnimationFrame(animationFrameCallback)
                : win.setTimeout(animationFrameCallback, 0);
            this._animationFrameIds[animationFrameId] = true;
        }
        return animationFrameId;
    };
    Async.prototype.cancelAnimationFrame = function (id, targetElement) {
        var win = getWindow(targetElement);
        if (this._animationFrameIds && this._animationFrameIds[id]) {
            win.cancelAnimationFrame ? win.cancelAnimationFrame(id) : win.clearTimeout(id);
            delete this._animationFrameIds[id];
        }
    };
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    Async.prototype._logError = function (e) {
        if (this._onErrorHandler) {
            this._onErrorHandler(e);
        }
    };
    return Async;
}());

/**
 * Compares a to b and b to a.
 *
 * @public
 */
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function shallowCompare(a, b) {
    for (var propName in a) {
        if (a.hasOwnProperty(propName)) {
            if (!b.hasOwnProperty(propName) || b[propName] !== a[propName]) {
                return false;
            }
        }
    }
    for (var propName in b) {
        if (b.hasOwnProperty(propName)) {
            if (!a.hasOwnProperty(propName)) {
                return false;
            }
        }
    }
    return true;
}
/**
 * Makes a resulting merge of a bunch of objects. Pass in the target object followed by 1 or more
 * objects as arguments and they will be merged sequentially into the target. Note that this will
 * shallow merge; it will not create new cloned values for target members.
 *
 * @public
 * @param target - Target object to merge following object arguments into.
 * @param args - One or more objects that will be mixed into the target in the order they are provided.
 * @returns Resulting merged target.
 */
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function assign(target) {
    var args = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        args[_i - 1] = arguments[_i];
    }
    return filteredAssign.apply(this, [null, target].concat(args));
}
/**
 * Makes a resulting merge of a bunch of objects, but allows a filter function to be passed in to filter
 * the resulting merges. This allows for scenarios where you want to merge "everything except that one thing"
 * or "properties that start with data-". Note that this will shallow merge; it will not create new cloned
 * values for target members.
 *
 * @public
 * @param isAllowed - Callback to determine if the given propName is allowed in the result.
 * @param target - Target object to merge following object arguments into.
 * @param args - One or more objects that will be mixed into the target in the order they are provided.
 * @returns Resulting merged target.
 */
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function filteredAssign(isAllowed, target) {
    var args = [];
    for (var _i = 2; _i < arguments.length; _i++) {
        args[_i - 2] = arguments[_i];
    }
    target = target || {};
    for (var _a = 0, args_1 = args; _a < args_1.length; _a++) {
        var sourceObject = args_1[_a];
        if (sourceObject) {
            for (var propName in sourceObject) {
                if (sourceObject.hasOwnProperty(propName) && (!isAllowed || isAllowed(propName))) {
                    target[propName] = sourceObject[propName];
                }
            }
        }
    }
    return target;
}

/** An instance of EventGroup allows anything with a handle to it to trigger events on it.
 *  If the target is an HTMLElement, the event will be attached to the element and can be
 *  triggered as usual (like clicking for onClick).
 *  The event can be triggered by calling EventGroup.raise() here. If the target is an
 *  HTMLElement, the event gets raised and is handled by the browser. Otherwise, it gets
 *  handled here in EventGroup, and the handler is called in the context of the parent
 *  (which is passed in in the constructor).
 *
 * @public
 * {@docCategory EventGroup}
 */
var EventGroup = /** @class */ (function () {
    /** parent: the context in which events attached to non-HTMLElements are called */
    function EventGroup(parent) {
        this._id = EventGroup._uniqueId++;
        this._parent = parent;
        this._eventRecords = [];
    }
    /** For IE8, bubbleEvent is ignored here and must be dealt with by the handler.
     *  Events raised here by default have bubbling set to false and cancelable set to true.
     *  This applies also to built-in events being raised manually here on HTMLElements,
     *  which may lead to unexpected behavior if it differs from the defaults.
     *
     */
    EventGroup.raise = function (target, eventName, eventArgs, bubbleEvent) {
        var retVal;
        if (EventGroup._isElement(target)) {
            if (typeof document !== 'undefined' && document.createEvent) {
                var ev = document.createEvent('HTMLEvents');
                ev.initEvent(eventName, bubbleEvent || false, true);
                assign(ev, eventArgs);
                retVal = target.dispatchEvent(ev);
            }
            else if (typeof document !== 'undefined' && document.createEventObject) {
                // IE8
                var evObj = document.createEventObject(eventArgs);
                // cannot set cancelBubble on evObj, fireEvent will overwrite it
                target.fireEvent('on' + eventName, evObj);
            }
        }
        else {
            while (target && retVal !== false) {
                var events = target.__events__;
                var eventRecords = events ? events[eventName] : null;
                if (eventRecords) {
                    for (var id in eventRecords) {
                        if (eventRecords.hasOwnProperty(id)) {
                            var eventRecordList = eventRecords[id];
                            for (var listIndex = 0; retVal !== false && listIndex < eventRecordList.length; listIndex++) {
                                var record = eventRecordList[listIndex];
                                if (record.objectCallback) {
                                    retVal = record.objectCallback.call(record.parent, eventArgs);
                                }
                            }
                        }
                    }
                }
                // If the target has a parent, bubble the event up.
                target = bubbleEvent ? target.parent : null;
            }
        }
        return retVal;
    };
    EventGroup.isObserved = function (target, eventName) {
        var events = target && target.__events__;
        return !!events && !!events[eventName];
    };
    /** Check to see if the target has declared support of the given event. */
    EventGroup.isDeclared = function (target, eventName) {
        var declaredEvents = target && target.__declaredEvents;
        return !!declaredEvents && !!declaredEvents[eventName];
    };
    EventGroup.stopPropagation = function (event) {
        if (event.stopPropagation) {
            event.stopPropagation();
        }
        else {
            // IE8
            event.cancelBubble = true;
        }
    };
    EventGroup._isElement = function (target) {
        return (!!target && (!!target.addEventListener || (typeof HTMLElement !== 'undefined' && target instanceof HTMLElement)));
    };
    EventGroup.prototype.dispose = function () {
        if (!this._isDisposed) {
            this._isDisposed = true;
            this.off();
            this._parent = null;
        }
    };
    /** On the target, attach a set of events, where the events object is a name to function mapping. */
    EventGroup.prototype.onAll = function (target, events, useCapture) {
        for (var eventName in events) {
            if (events.hasOwnProperty(eventName)) {
                this.on(target, eventName, events[eventName], useCapture);
            }
        }
    };
    /**
     * On the target, attach an event whose handler will be called in the context of the parent
     * of this instance of EventGroup.
     */
    EventGroup.prototype.on = function (target, eventName, callback, options) {
        var _this = this;
        if (eventName.indexOf(',') > -1) {
            var events = eventName.split(/[ ,]+/);
            for (var i = 0; i < events.length; i++) {
                this.on(target, events[i], callback, options);
            }
        }
        else {
            var parent_1 = this._parent;
            var eventRecord = {
                target: target,
                eventName: eventName,
                parent: parent_1,
                callback: callback,
                options: options,
            };
            // Initialize and wire up the record on the target, so that it can call the callback if the event fires.
            var events = (target.__events__ = target.__events__ || {});
            events[eventName] =
                events[eventName] ||
                    {
                        count: 0,
                    };
            events[eventName][this._id] = events[eventName][this._id] || [];
            events[eventName][this._id].push(eventRecord);
            events[eventName].count++;
            if (EventGroup._isElement(target)) {
                var processElementEvent = function () {
                    var args = [];
                    for (var _i = 0; _i < arguments.length; _i++) {
                        args[_i] = arguments[_i];
                    }
                    if (_this._isDisposed) {
                        return;
                    }
                    var result;
                    try {
                        result = callback.apply(parent_1, args);
                        if (result === false && args[0]) {
                            var e = args[0];
                            if (e.preventDefault) {
                                e.preventDefault();
                            }
                            if (e.stopPropagation) {
                                e.stopPropagation();
                            }
                            e.cancelBubble = true;
                        }
                    }
                    catch (e) {
                        // ignore
                    }
                    return result;
                };
                eventRecord.elementCallback = processElementEvent;
                if (target.addEventListener) {
                    target.addEventListener(eventName, processElementEvent, options);
                }
                else if (target.attachEvent) {
                    // IE8
                    target.attachEvent('on' + eventName, processElementEvent);
                }
            }
            else {
                var processObjectEvent = function () {
                    var args = [];
                    for (var _i = 0; _i < arguments.length; _i++) {
                        args[_i] = arguments[_i];
                    }
                    if (_this._isDisposed) {
                        return;
                    }
                    return callback.apply(parent_1, args);
                };
                eventRecord.objectCallback = processObjectEvent;
            }
            // Remember the record locally, so that it can be removed.
            this._eventRecords.push(eventRecord);
        }
    };
    EventGroup.prototype.off = function (target, eventName, callback, options) {
        for (var i = 0; i < this._eventRecords.length; i++) {
            var eventRecord = this._eventRecords[i];
            if ((!target || target === eventRecord.target) &&
                (!eventName || eventName === eventRecord.eventName) &&
                (!callback || callback === eventRecord.callback) &&
                (typeof options !== 'boolean' || options === eventRecord.options)) {
                var events = eventRecord.target.__events__;
                var targetArrayLookup = events[eventRecord.eventName];
                var targetArray = targetArrayLookup ? targetArrayLookup[this._id] : null;
                // We may have already target's entries, so check for null.
                if (targetArray) {
                    if (targetArray.length === 1 || !callback) {
                        targetArrayLookup.count -= targetArray.length;
                        delete events[eventRecord.eventName][this._id];
                    }
                    else {
                        targetArrayLookup.count--;
                        targetArray.splice(targetArray.indexOf(eventRecord), 1);
                    }
                    if (!targetArrayLookup.count) {
                        delete events[eventRecord.eventName];
                    }
                }
                if (eventRecord.elementCallback) {
                    if (eventRecord.target.removeEventListener) {
                        eventRecord.target.removeEventListener(eventRecord.eventName, eventRecord.elementCallback, eventRecord.options);
                    }
                    else if (eventRecord.target.detachEvent) {
                        // IE8
                        eventRecord.target.detachEvent('on' + eventRecord.eventName, eventRecord.elementCallback);
                    }
                }
                this._eventRecords.splice(i--, 1);
            }
        }
    };
    /** Trigger the given event in the context of this instance of EventGroup. */
    EventGroup.prototype.raise = function (eventName, eventArgs, bubbleEvent) {
        return EventGroup.raise(this._parent, eventName, eventArgs, bubbleEvent);
    };
    /** Declare an event as being supported by this instance of EventGroup. */
    EventGroup.prototype.declare = function (event) {
        var declaredEvents = (this._parent.__declaredEvents = this._parent.__declaredEvents || {});
        if (typeof event === 'string') {
            declaredEvents[event] = true;
        }
        else {
            for (var i = 0; i < event.length; i++) {
                declaredEvents[event[i]] = true;
            }
        }
    };
    EventGroup._uniqueId = 0;
    return EventGroup;
}());

/**
 * Helper to get the document object. Note that in popup window cases, document
 * might be the wrong document, which is why we look at ownerDocument for the
 * truth. Also note that the SSR flag is used to test ssr scenarios even if
 * document is defined (from JSDOM for example.)
 *
 * @public
 */
function getDocument(rootElement) {
    if ( typeof document === 'undefined') {
        return undefined;
    }
    else {
        var el = rootElement;
        return el && el.ownerDocument ? el.ownerDocument : document;
    }
}

var InjectionMode = {
    /**
     * Avoids style injection, use getRules() to read the styles.
     */
    none: 0,
    /**
     * Inserts rules using the insertRule api.
     */
    insertNode: 1,
    /**
     * Appends rules using appendChild.
     */
    appendChild: 2,
};
var STYLESHEET_SETTING = '__stylesheet__';
/**
 * MSIE 11 doesn't cascade styles based on DOM ordering, but rather on the order that each style node
 * is created. As such, to maintain consistent priority, IE11 should reuse a single style node.
 */
var REUSE_STYLE_NODE = typeof navigator !== 'undefined' && /rv:11.0/.test(navigator.userAgent);
var _global = {};
// Grab window.
try {
    _global = window;
}
catch (_a) {
    /* leave as blank object */
}
var _stylesheet;
/**
 * Represents the state of styles registered in the page. Abstracts
 * the surface for adding styles to the stylesheet, exposes helpers
 * for reading the styles registered in server rendered scenarios.
 *
 * @public
 */
var Stylesheet = /** @class */ (function () {
    function Stylesheet(config) {
        this._rules = [];
        this._preservedRules = [];
        this._rulesToInsert = [];
        this._counter = 0;
        this._keyToClassName = {};
        this._onResetCallbacks = [];
        this._classNameToArgs = {};
        this._config = __assign({ injectionMode: InjectionMode.insertNode, defaultPrefix: 'css', namespace: undefined, cspSettings: undefined }, config);
        this._keyToClassName = this._config.classNameCache || {};
    }
    /**
     * Gets the singleton instance.
     */
    Stylesheet.getInstance = function () {
        var _a;
        _stylesheet = _global[STYLESHEET_SETTING];
        if (!_stylesheet || (_stylesheet._lastStyleElement && _stylesheet._lastStyleElement.ownerDocument !== document)) {
            var fabricConfig = ((_a = _global) === null || _a === void 0 ? void 0 : _a.FabricConfig) || {};
            _stylesheet = _global[STYLESHEET_SETTING] = new Stylesheet(fabricConfig.mergeStyles);
        }
        return _stylesheet;
    };
    /**
     * Configures the stylesheet.
     */
    Stylesheet.prototype.setConfig = function (config) {
        this._config = __assign(__assign({}, this._config), config);
    };
    /**
     * Configures a reset callback.
     *
     * @param callback - A callback which will be called when the Stylesheet is reset.
     */
    Stylesheet.prototype.onReset = function (callback) {
        this._onResetCallbacks.push(callback);
    };
    /**
     * Generates a unique classname.
     *
     * @param displayName - Optional value to use as a prefix.
     */
    Stylesheet.prototype.getClassName = function (displayName) {
        var namespace = this._config.namespace;
        var prefix = displayName || this._config.defaultPrefix;
        return "" + (namespace ? namespace + '-' : '') + prefix + "-" + this._counter++;
    };
    /**
     * Used internally to cache information about a class which was
     * registered with the stylesheet.
     */
    Stylesheet.prototype.cacheClassName = function (className, key, args, rules) {
        this._keyToClassName[key] = className;
        this._classNameToArgs[className] = {
            args: args,
            rules: rules,
        };
    };
    /**
     * Gets the appropriate classname given a key which was previously
     * registered using cacheClassName.
     */
    Stylesheet.prototype.classNameFromKey = function (key) {
        return this._keyToClassName[key];
    };
    /**
     * Gets all classnames cache with the stylesheet.
     */
    Stylesheet.prototype.getClassNameCache = function () {
        return this._keyToClassName;
    };
    /**
     * Gets the arguments associated with a given classname which was
     * previously registered using cacheClassName.
     */
    Stylesheet.prototype.argsFromClassName = function (className) {
        var entry = this._classNameToArgs[className];
        return entry && entry.args;
    };
    /**
     * Gets the arguments associated with a given classname which was
     * previously registered using cacheClassName.
     */
    Stylesheet.prototype.insertedRulesFromClassName = function (className) {
        var entry = this._classNameToArgs[className];
        return entry && entry.rules;
    };
    /**
     * Inserts a css rule into the stylesheet.
     * @param preserve - Preserves the rule beyond a reset boundary.
     */
    Stylesheet.prototype.insertRule = function (rule, preserve) {
        var injectionMode = this._config.injectionMode;
        var element = injectionMode !== InjectionMode.none ? this._getStyleElement() : undefined;
        if (preserve) {
            this._preservedRules.push(rule);
        }
        if (element) {
            switch (this._config.injectionMode) {
                case InjectionMode.insertNode:
                    var sheet = element.sheet;
                    try {
                        sheet.insertRule(rule, sheet.cssRules.length);
                    }
                    catch (e) {
                        // The browser will throw exceptions on unsupported rules (such as a moz prefix in webkit.)
                        // We need to swallow the exceptions for this scenario, otherwise we'd need to filter
                        // which could be slower and bulkier.
                    }
                    break;
                case InjectionMode.appendChild:
                    element.appendChild(document.createTextNode(rule));
                    break;
            }
        }
        else {
            this._rules.push(rule);
        }
        if (this._config.onInsertRule) {
            this._config.onInsertRule(rule);
        }
    };
    /**
     * Gets all rules registered with the stylesheet; only valid when
     * using InsertionMode.none.
     */
    Stylesheet.prototype.getRules = function (includePreservedRules) {
        return ((includePreservedRules ? this._preservedRules.join('') : '') + this._rules.join('') + this._rulesToInsert.join(''));
    };
    /**
     * Resets the internal state of the stylesheet. Only used in server
     * rendered scenarios where we're using InsertionMode.none.
     */
    Stylesheet.prototype.reset = function () {
        this._rules = [];
        this._rulesToInsert = [];
        this._counter = 0;
        this._classNameToArgs = {};
        this._keyToClassName = {};
        this._onResetCallbacks.forEach(function (callback) { return callback(); });
    };
    // Forces the regeneration of incoming styles without totally resetting the stylesheet.
    Stylesheet.prototype.resetKeys = function () {
        this._keyToClassName = {};
    };
    Stylesheet.prototype._getStyleElement = function () {
        var _this = this;
        if (!this._styleElement && typeof document !== 'undefined') {
            this._styleElement = this._createStyleElement();
            if (!REUSE_STYLE_NODE) {
                // Reset the style element on the next frame.
                window.requestAnimationFrame(function () {
                    _this._styleElement = undefined;
                });
            }
        }
        return this._styleElement;
    };
    Stylesheet.prototype._createStyleElement = function () {
        var head = document.head;
        var styleElement = document.createElement('style');
        styleElement.setAttribute('data-merge-styles', 'true');
        var cspSettings = this._config.cspSettings;
        if (cspSettings) {
            if (cspSettings.nonce) {
                styleElement.setAttribute('nonce', cspSettings.nonce);
            }
        }
        if (this._lastStyleElement) {
            // If the `nextElementSibling` is null, then the insertBefore will act as a regular append.
            // https://developer.mozilla.org/en-US/docs/Web/API/Node/insertBefore#Syntax
            head.insertBefore(styleElement, this._lastStyleElement.nextElementSibling);
        }
        else {
            var placeholderStyleTag = this._findPlaceholderStyleTag();
            if (placeholderStyleTag) {
                head.insertBefore(styleElement, placeholderStyleTag.nextElementSibling);
            }
            else {
                head.insertBefore(styleElement, head.childNodes[0]);
            }
        }
        this._lastStyleElement = styleElement;
        return styleElement;
    };
    Stylesheet.prototype._findPlaceholderStyleTag = function () {
        var head = document.head;
        if (head) {
            return head.querySelector('style[data-merge-styles]');
        }
        return null;
    };
    return Stylesheet;
}());

/**
 * Separates the classes and style objects. Any classes that are pre-registered
 * args are auto expanded into objects.
 */
function extractStyleParts() {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    var classes = [];
    var objects = [];
    var stylesheet = Stylesheet.getInstance();
    function _processArgs(argsList) {
        for (var _i = 0, argsList_1 = argsList; _i < argsList_1.length; _i++) {
            var arg = argsList_1[_i];
            if (arg) {
                if (typeof arg === 'string') {
                    if (arg.indexOf(' ') >= 0) {
                        _processArgs(arg.split(' '));
                    }
                    else {
                        var translatedArgs = stylesheet.argsFromClassName(arg);
                        if (translatedArgs) {
                            _processArgs(translatedArgs);
                        }
                        else {
                            // Avoid adding the same class twice.
                            if (classes.indexOf(arg) === -1) {
                                classes.push(arg);
                            }
                        }
                    }
                }
                else if (Array.isArray(arg)) {
                    _processArgs(arg);
                }
                else if (typeof arg === 'object') {
                    objects.push(arg);
                }
            }
        }
    }
    _processArgs(args);
    return {
        classes: classes,
        objects: objects,
    };
}

/**
 * Sets the current RTL value.
 */
function setRTL(isRTL) {
    if (_rtl !== isRTL) {
        _rtl = isRTL;
    }
}
/**
 * Gets the current RTL value.
 */
function getRTL() {
    if (_rtl === undefined) {
        _rtl =
            typeof document !== 'undefined' &&
                !!document.documentElement &&
                document.documentElement.getAttribute('dir') === 'rtl';
    }
    return _rtl;
}
// This has been split into 2 lines because it was working in Fabric due to the code being transpiled to es5, so this
// was converted to var while not working in Fluent that uses babel to transpile the code to be es6-like. Splitting the
// logic into two lines, however, allows it to work in both scenarios.
var _rtl;
_rtl = getRTL();
function getStyleOptions() {
    return {
        rtl: getRTL(),
    };
}

var rules = {};
function kebabRules(rulePairs, index) {
    var rule = rulePairs[index];
    if (rule.charAt(0) !== '-') {
        rulePairs[index] = rules[rule] = rules[rule] || rule.replace(/([A-Z])/g, '-$1').toLowerCase();
    }
}

var _vendorSettings;
function getVendorSettings() {
    if (!_vendorSettings) {
        var doc = typeof document !== 'undefined' ? document : undefined;
        var nav = typeof navigator !== 'undefined' ? navigator : undefined;
        var userAgent = nav ? nav.userAgent.toLowerCase() : undefined;
        if (!doc) {
            _vendorSettings = {
                isWebkit: true,
                isMoz: true,
                isOpera: true,
                isMs: true,
            };
        }
        else {
            _vendorSettings = {
                isWebkit: !!(doc && 'WebkitAppearance' in doc.documentElement.style),
                isMoz: !!(userAgent && userAgent.indexOf('firefox') > -1),
                isOpera: !!(userAgent && userAgent.indexOf('opera') > -1),
                isMs: !!(nav && (/rv:11.0/i.test(nav.userAgent) || /Edge\/\d./i.test(navigator.userAgent))),
            };
        }
    }
    return _vendorSettings;
}

var autoPrefixNames = {
    'user-select': 1,
};
function prefixRules(rulePairs, index) {
    var vendorSettings = getVendorSettings();
    var name = rulePairs[index];
    if (autoPrefixNames[name]) {
        var value = rulePairs[index + 1];
        if (autoPrefixNames[name]) {
            if (vendorSettings.isWebkit) {
                rulePairs.push('-webkit-' + name, value);
            }
            if (vendorSettings.isMoz) {
                rulePairs.push('-moz-' + name, value);
            }
            if (vendorSettings.isMs) {
                rulePairs.push('-ms-' + name, value);
            }
            if (vendorSettings.isOpera) {
                rulePairs.push('-o-' + name, value);
            }
        }
    }
}

var NON_PIXEL_NUMBER_PROPS = [
    'column-count',
    'font-weight',
    'flex',
    'flex-grow',
    'flex-shrink',
    'fill-opacity',
    'opacity',
    'order',
    'z-index',
    'zoom',
];
function provideUnits(rulePairs, index) {
    var name = rulePairs[index];
    var value = rulePairs[index + 1];
    if (typeof value === 'number') {
        var unit = NON_PIXEL_NUMBER_PROPS.indexOf(name) === -1 ? 'px' : '';
        rulePairs[index + 1] = "" + value + unit;
    }
}

var _a;
var LEFT = 'left';
var RIGHT = 'right';
var NO_FLIP = '@noflip';
var NAME_REPLACEMENTS = (_a = {},
    _a[LEFT] = RIGHT,
    _a[RIGHT] = LEFT,
    _a);
var VALUE_REPLACEMENTS = {
    'w-resize': 'e-resize',
    'sw-resize': 'se-resize',
    'nw-resize': 'ne-resize',
};
/**
 * RTLifies the rulePair in the array at the current index. This mutates the array for performance
 * reasons.
 */
function rtlifyRules(options, rulePairs, index) {
    if (options.rtl) {
        var name_1 = rulePairs[index];
        if (!name_1) {
            return;
        }
        var value = rulePairs[index + 1];
        if (typeof value === 'string' && value.indexOf(NO_FLIP) >= 0) {
            rulePairs[index + 1] = value.replace(/\s*(?:\/\*\s*)?\@noflip\b(?:\s*\*\/)?\s*?/g, '');
        }
        else if (name_1.indexOf(LEFT) >= 0) {
            rulePairs[index] = name_1.replace(LEFT, RIGHT);
        }
        else if (name_1.indexOf(RIGHT) >= 0) {
            rulePairs[index] = name_1.replace(RIGHT, LEFT);
        }
        else if (String(value).indexOf(LEFT) >= 0) {
            rulePairs[index + 1] = value.replace(LEFT, RIGHT);
        }
        else if (String(value).indexOf(RIGHT) >= 0) {
            rulePairs[index + 1] = value.replace(RIGHT, LEFT);
        }
        else if (NAME_REPLACEMENTS[name_1]) {
            rulePairs[index] = NAME_REPLACEMENTS[name_1];
        }
        else if (VALUE_REPLACEMENTS[value]) {
            rulePairs[index + 1] = VALUE_REPLACEMENTS[value];
        }
        else {
            switch (name_1) {
                case 'margin':
                case 'padding':
                    rulePairs[index + 1] = flipQuad(value);
                    break;
                case 'box-shadow':
                    rulePairs[index + 1] = negateNum(value, 0);
                    break;
            }
        }
    }
}
/**
 * Given a string value in a space delimited format (e.g. "1 2 3 4"), negates a particular value.
 */
function negateNum(value, partIndex) {
    var parts = value.split(' ');
    var numberVal = parseInt(parts[partIndex], 10);
    parts[0] = parts[0].replace(String(numberVal), String(numberVal * -1));
    return parts.join(' ');
}
/**
 * Given a string quad, flips the left and right values.
 */
function flipQuad(value) {
    if (typeof value === 'string') {
        var parts = value.split(' ');
        if (parts.length === 4) {
            return parts[0] + " " + parts[3] + " " + parts[2] + " " + parts[1];
        }
    }
    return value;
}

var DISPLAY_NAME = 'displayName';
function getDisplayName(rules) {
    var rootStyle = rules && rules['&'];
    return rootStyle ? rootStyle.displayName : undefined;
}
var globalSelectorRegExp = /\:global\((.+?)\)/g;
/**
 * Finds comma separated selectors in a :global() e.g. ":global(.class1, .class2, .class3)"
 * and wraps them each in their own global ":global(.class1), :global(.class2), :global(.class3)"
 *
 * @param selectorWithGlobals The selector to process
 * @returns The updated selector
 */
function expandCommaSeparatedGlobals(selectorWithGlobals) {
    // We the selector does not have a :global() we can shortcut
    if (!globalSelectorRegExp.test(selectorWithGlobals)) {
        return selectorWithGlobals;
    }
    var replacementInfo = [];
    var findGlobal = /\:global\((.+?)\)/g;
    var match = null;
    // Create a result list for global selectors so we can replace them.
    while ((match = findGlobal.exec(selectorWithGlobals))) {
        // Only if the found selector is a comma separated list we'll process it.
        if (match[1].indexOf(',') > -1) {
            replacementInfo.push([
                match.index,
                match.index + match[0].length,
                // Wrap each of the found selectors in :global()
                match[1]
                    .split(',')
                    .map(function (v) { return ":global(" + v.trim() + ")"; })
                    .join(', '),
            ]);
        }
    }
    // Replace the found selectors with their wrapped variants in reverse order
    return replacementInfo
        .reverse()
        .reduce(function (selector, _a) {
        var matchIndex = _a[0], matchEndIndex = _a[1], replacement = _a[2];
        var prefix = selector.slice(0, matchIndex);
        var suffix = selector.slice(matchEndIndex);
        return prefix + replacement + suffix;
    }, selectorWithGlobals);
}
function expandSelector(newSelector, currentSelector) {
    if (newSelector.indexOf(':global(') >= 0) {
        return newSelector.replace(globalSelectorRegExp, '$1');
    }
    else if (newSelector.indexOf(':') === 0) {
        return currentSelector + newSelector;
    }
    else if (newSelector.indexOf('&') < 0) {
        return currentSelector + ' ' + newSelector;
    }
    return newSelector;
}
function extractRules(args, rules, currentSelector) {
    if (rules === void 0) { rules = { __order: [] }; }
    if (currentSelector === void 0) { currentSelector = '&'; }
    var stylesheet = Stylesheet.getInstance();
    var currentRules = rules[currentSelector];
    if (!currentRules) {
        currentRules = {};
        rules[currentSelector] = currentRules;
        rules.__order.push(currentSelector);
    }
    for (var _i = 0, args_1 = args; _i < args_1.length; _i++) {
        var arg = args_1[_i];
        // If the arg is a string, we need to look up the class map and merge.
        if (typeof arg === 'string') {
            var expandedRules = stylesheet.argsFromClassName(arg);
            if (expandedRules) {
                extractRules(expandedRules, rules, currentSelector);
            }
            // Else if the arg is an array, we need to recurse in.
        }
        else if (Array.isArray(arg)) {
            extractRules(arg, rules, currentSelector);
        }
        else {
            for (var prop in arg) {
                if (prop === 'selectors') {
                    var selectors = arg.selectors;
                    var _loop_1 = function (newSelector) {
                        if (selectors.hasOwnProperty(newSelector)) {
                            var selectorValue_1 = selectors[newSelector];
                            if (newSelector.indexOf('@') === 0) {
                                newSelector = newSelector + '{' + currentSelector;
                                extractRules([selectorValue_1], rules, newSelector);
                            }
                            else if (newSelector.indexOf(',') > -1) {
                                expandCommaSeparatedGlobals(newSelector)
                                    .split(',')
                                    .map(function (s) { return s.trim(); })
                                    .forEach(function (separatedSelector) {
                                    return extractRules([selectorValue_1], rules, expandSelector(separatedSelector, currentSelector));
                                });
                            }
                            else {
                                extractRules([selectorValue_1], rules, expandSelector(newSelector, currentSelector));
                            }
                        }
                    };
                    for (var newSelector in selectors) {
                        _loop_1(newSelector);
                    }
                }
                else {
                    if (arg[prop] !== undefined) {
                        // Else, add the rule to the currentSelector.
                        if (prop === 'margin' || prop === 'padding') {
                            expandQuads(currentRules, prop, arg[prop]);
                        }
                        else {
                            currentRules[prop] = arg[prop];
                        }
                    }
                }
            }
        }
    }
    return rules;
}
function expandQuads(currentRules, name, value) {
    var parts = typeof value === 'string' ? value.split(' ') : [value];
    currentRules[name + 'Top'] = parts[0];
    currentRules[name + 'Right'] = parts[1] || parts[0];
    currentRules[name + 'Bottom'] = parts[2] || parts[0];
    currentRules[name + 'Left'] = parts[3] || parts[1] || parts[0];
}
function getKeyForRules(options, rules) {
    var serialized = [options.rtl ? 'rtl' : 'ltr'];
    var hasProps = false;
    for (var _i = 0, _a = rules.__order; _i < _a.length; _i++) {
        var selector = _a[_i];
        serialized.push(selector);
        var rulesForSelector = rules[selector];
        for (var propName in rulesForSelector) {
            if (rulesForSelector.hasOwnProperty(propName) && rulesForSelector[propName] !== undefined) {
                hasProps = true;
                serialized.push(propName, rulesForSelector[propName]);
            }
        }
    }
    return hasProps ? serialized.join('') : undefined;
}
function repeatString(target, count) {
    if (count <= 0) {
        return '';
    }
    if (count === 1) {
        return target;
    }
    return target + repeatString(target, count - 1);
}
function serializeRuleEntries(options, ruleEntries) {
    if (!ruleEntries) {
        return '';
    }
    var allEntries = [];
    for (var entry in ruleEntries) {
        if (ruleEntries.hasOwnProperty(entry) && entry !== DISPLAY_NAME && ruleEntries[entry] !== undefined) {
            allEntries.push(entry, ruleEntries[entry]);
        }
    }
    // Apply transforms.
    for (var i = 0; i < allEntries.length; i += 2) {
        kebabRules(allEntries, i);
        provideUnits(allEntries, i);
        rtlifyRules(options, allEntries, i);
        prefixRules(allEntries, i);
    }
    // Apply punctuation.
    for (var i = 1; i < allEntries.length; i += 4) {
        allEntries.splice(i, 1, ':', allEntries[i], ';');
    }
    return allEntries.join('');
}
function styleToRegistration(options) {
    var args = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        args[_i - 1] = arguments[_i];
    }
    var rules = extractRules(args);
    var key = getKeyForRules(options, rules);
    if (key) {
        var stylesheet = Stylesheet.getInstance();
        var registration = {
            className: stylesheet.classNameFromKey(key),
            key: key,
            args: args,
        };
        if (!registration.className) {
            registration.className = stylesheet.getClassName(getDisplayName(rules));
            var rulesToInsert = [];
            for (var _a = 0, _b = rules.__order; _a < _b.length; _a++) {
                var selector = _b[_a];
                rulesToInsert.push(selector, serializeRuleEntries(options, rules[selector]));
            }
            registration.rulesToInsert = rulesToInsert;
        }
        return registration;
    }
    return undefined;
}
/**
 * Insert style to stylesheet.
 * @param registration Style registration.
 * @param specificityMultiplier Number of times classname selector is repeated in the css rule.
 * This is to increase css specificity in case it's needed. Default to 1.
 */
function applyRegistration(registration, specificityMultiplier) {
    if (specificityMultiplier === void 0) { specificityMultiplier = 1; }
    var stylesheet = Stylesheet.getInstance();
    var className = registration.className, key = registration.key, args = registration.args, rulesToInsert = registration.rulesToInsert;
    if (rulesToInsert) {
        // rulesToInsert is an ordered array of selector/rule pairs.
        for (var i = 0; i < rulesToInsert.length; i += 2) {
            var rules = rulesToInsert[i + 1];
            if (rules) {
                var selector = rulesToInsert[i];
                selector = selector.replace(/&/g, repeatString("." + registration.className, specificityMultiplier));
                // Insert. Note if a media query, we must close the query with a final bracket.
                var processedRule = selector + "{" + rules + "}" + (selector.indexOf('@') === 0 ? '}' : '');
                stylesheet.insertRule(processedRule);
            }
        }
        stylesheet.cacheClassName(className, key, args, rulesToInsert);
    }
}
function styleToClassName(options) {
    var args = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        args[_i - 1] = arguments[_i];
    }
    var registration = styleToRegistration.apply(void 0, __spreadArrays([options], args));
    if (registration) {
        applyRegistration(registration, options.specificityMultiplier);
        return registration.className;
    }
    return '';
}

/**
 * Concatenation helper, which can merge class names together. Skips over falsey values.
 *
 * @public
 */
function mergeStyles() {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    return mergeCss(args, getStyleOptions());
}
/**
 * Concatenation helper, which can merge class names together. Skips over falsey values.
 * Accepts a set of options that will be used when calculating styles.
 *
 * @public
 */
function mergeCss(args, options) {
    var styleArgs = args instanceof Array ? args : [args];
    var _a = extractStyleParts(styleArgs), classes = _a.classes, objects = _a.objects;
    if (objects.length) {
        classes.push(styleToClassName(options || {}, objects));
    }
    return classes.join(' ');
}

/**
 * Combine a set of styles together (but does not register css classes).
 * @param styleSets - One or more stylesets to be merged (each param can also be falsy).
 */
function concatStyleSets() {
    var styleSets = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        styleSets[_i] = arguments[_i];
    }
    if (styleSets && styleSets.length === 1 && styleSets[0] && !styleSets[0].subComponentStyles) {
        return styleSets[0];
    }
    var mergedSet = {};
    // We process sub component styles in two phases. First we collect them, then we combine them into 1 style function.
    var workingSubcomponentStyles = {};
    for (var _a = 0, styleSets_1 = styleSets; _a < styleSets_1.length; _a++) {
        var currentSet = styleSets_1[_a];
        if (currentSet) {
            for (var prop in currentSet) {
                if (currentSet.hasOwnProperty(prop)) {
                    if (prop === 'subComponentStyles' && currentSet.subComponentStyles !== undefined) {
                        // subcomponent styles - style functions or objects
                        var currentComponentStyles = currentSet.subComponentStyles;
                        for (var subCompProp in currentComponentStyles) {
                            if (currentComponentStyles.hasOwnProperty(subCompProp)) {
                                if (workingSubcomponentStyles.hasOwnProperty(subCompProp)) {
                                    workingSubcomponentStyles[subCompProp].push(currentComponentStyles[subCompProp]);
                                }
                                else {
                                    workingSubcomponentStyles[subCompProp] = [currentComponentStyles[subCompProp]];
                                }
                            }
                        }
                        continue;
                    }
                    // the as any casts below is a workaround for ts 2.8.
                    // todo: remove cast to any in ts 2.9.
                    var mergedValue = mergedSet[prop];
                    var currentValue = currentSet[prop];
                    if (mergedValue === undefined) {
                        mergedSet[prop] = currentValue;
                    }
                    else {
                        mergedSet[prop] = __spreadArrays((Array.isArray(mergedValue) ? mergedValue : [mergedValue]), (Array.isArray(currentValue) ? currentValue : [currentValue]));
                    }
                }
            }
        }
    }
    if (Object.keys(workingSubcomponentStyles).length > 0) {
        mergedSet.subComponentStyles = {};
        var mergedSubStyles = mergedSet.subComponentStyles;
        var _loop_1 = function (subCompProp) {
            if (workingSubcomponentStyles.hasOwnProperty(subCompProp)) {
                var workingSet_1 = workingSubcomponentStyles[subCompProp];
                mergedSubStyles[subCompProp] = function (styleProps) {
                    return concatStyleSets.apply(void 0, workingSet_1.map(function (styleFunctionOrObject) {
                        return typeof styleFunctionOrObject === 'function' ? styleFunctionOrObject(styleProps) : styleFunctionOrObject;
                    }));
                };
            }
        };
        // now we process the subcomponent styles if there are any
        for (var subCompProp in workingSubcomponentStyles) {
            _loop_1(subCompProp);
        }
    }
    return mergedSet;
}

/**
 * Takes in one or more style set objects, each consisting of a set of areas,
 * each which will produce a class name. Using this is analogous to calling
 * `mergeStyles` for each property in the object, but ensures we maintain the
 * set ordering when multiple style sets are merged.
 *
 * @param styleSets - One or more style sets to be merged.
 */
function mergeStyleSets() {
    var styleSets = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        styleSets[_i] = arguments[_i];
    }
    return mergeCssSets(styleSets, getStyleOptions());
}
/**
 * Takes in one or more style set objects, each1consisting of a set of areas,
 * each which will produce a class name. Using this is analogous to calling
 * `mergeCss` for each property in the object, but ensures the
 * set ordering when multiple style sets are merged.
 *
 * @param styleSets - One or more style sets to be merged.
 * @param options - (optional) Options to use when creating rules.
 */
function mergeCssSets(styleSets, options) {
    var _a, _b;
    var classNameSet = { subComponentStyles: {} };
    var styleSet = styleSets[0];
    if (!styleSet && styleSets.length <= 1) {
        return { subComponentStyles: {} };
    }
    var concatenatedStyleSet = concatStyleSets.apply(void 0, styleSets);
    var registrations = [];
    for (var styleSetArea in concatenatedStyleSet) {
        if (concatenatedStyleSet.hasOwnProperty(styleSetArea)) {
            if (styleSetArea === 'subComponentStyles') {
                classNameSet.subComponentStyles = concatenatedStyleSet.subComponentStyles || {};
                continue;
            }
            var styles = concatenatedStyleSet[styleSetArea];
            var _c = extractStyleParts(styles), classes = _c.classes, objects = _c.objects;
            if ((_a = objects) === null || _a === void 0 ? void 0 : _a.length) {
                var registration = styleToRegistration(options || {}, { displayName: styleSetArea }, objects);
                if (registration) {
                    registrations.push(registration);
                    classNameSet[styleSetArea] = classes.concat([registration.className]).join(' ');
                }
            }
            else {
                classNameSet[styleSetArea] = classes.join(' ');
            }
        }
    }
    for (var _i = 0, registrations_1 = registrations; _i < registrations_1.length; _i++) {
        var registration = registrations_1[_i];
        if (registration) {
            applyRegistration(registration, (_b = options) === null || _b === void 0 ? void 0 : _b.specificityMultiplier);
        }
    }
    return classNameSet;
}

/**
 * Concatenates style sets into one, but resolves functional sets using the given props.
 * @param styleProps - Props used to resolve functional sets.
 * @param allStyles - Style sets, which can be functions or objects.
 */
function concatStyleSetsWithProps(styleProps) {
    var allStyles = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        allStyles[_i - 1] = arguments[_i];
    }
    var result = [];
    for (var _a = 0, allStyles_1 = allStyles; _a < allStyles_1.length; _a++) {
        var styles = allStyles_1[_a];
        if (styles) {
            result.push(typeof styles === 'function' ? styles(styleProps) : styles);
        }
    }
    if (result.length === 1) {
        return result[0];
    }
    else if (result.length) {
        // cliffkoh: I cannot figure out how to avoid the cast to any here.
        // It is something to do with the use of Omit in IStyleSet.
        // It might not be necessary once  Omit becomes part of lib.d.ts (when we remove our own Omit and rely on
        // the official version).
        return concatStyleSets.apply(void 0, result);
    }
    return {};
}

/**
 * Registers a font face.
 * @public
 */
function fontFace(font) {
    Stylesheet.getInstance().insertRule("@font-face{" + serializeRuleEntries(getStyleOptions(), font) + "}", true);
}

/**
 * Registers keyframe definitions.
 *
 * @public
 */
function keyframes(timeline) {
    var stylesheet = Stylesheet.getInstance();
    var name = stylesheet.getClassName();
    var rulesArray = [];
    for (var prop in timeline) {
        if (timeline.hasOwnProperty(prop)) {
            rulesArray.push(prop, '{', serializeRuleEntries(getStyleOptions(), timeline[prop]), '}');
        }
    }
    var rules = rulesArray.join('');
    stylesheet.insertRule("@keyframes " + name + "{" + rules + "}", true);
    stylesheet.cacheClassName(name, rules, [], ['keyframes', rules]);
    return name;
}

var _scrollbarWidth;
var DisabledScrollClassName = mergeStyles({
    overflow: 'hidden !important',
});
/**
 * Placing this attribute on scrollable divs optimizes detection to know
 * if the div is scrollable or not (given we can avoid expensive operations
 * like getComputedStyle.)
 *
 * @public
 */
var DATA_IS_SCROLLABLE_ATTRIBUTE = 'data-is-scrollable';
/**
 * Calculates the width of a scrollbar for the browser/os.
 *
 * @public
 */
function getScrollbarWidth() {
    if (_scrollbarWidth === undefined) {
        var scrollDiv = document.createElement('div');
        scrollDiv.style.setProperty('width', '100px');
        scrollDiv.style.setProperty('height', '100px');
        scrollDiv.style.setProperty('overflow', 'scroll');
        scrollDiv.style.setProperty('position', 'absolute');
        scrollDiv.style.setProperty('top', '-9999px');
        document.body.appendChild(scrollDiv);
        // Get the scrollbar width
        _scrollbarWidth = scrollDiv.offsetWidth - scrollDiv.clientWidth;
        // Delete the DIV
        document.body.removeChild(scrollDiv);
    }
    return _scrollbarWidth;
}
/**
 * Traverses up the DOM for the element with the data-is-scrollable=true attribute, or returns
 * document.body.
 *
 * @public
 */
function findScrollableParent(startingElement) {
    var el = startingElement;
    var doc = getDocument(startingElement);
    // First do a quick scan for the scrollable attribute.
    while (el && el !== doc.body) {
        if (el.getAttribute(DATA_IS_SCROLLABLE_ATTRIBUTE) === 'true') {
            return el;
        }
        el = el.parentElement;
    }
    // If we haven't found it, the use the slower method: compute styles to evaluate if overflow is set.
    el = startingElement;
    while (el && el !== doc.body) {
        if (el.getAttribute(DATA_IS_SCROLLABLE_ATTRIBUTE) !== 'false') {
            var computedStyles = getComputedStyle(el);
            var overflowY = computedStyles ? computedStyles.getPropertyValue('overflow-y') : '';
            if (overflowY && (overflowY === 'scroll' || overflowY === 'auto')) {
                return el;
            }
        }
        el = el.parentElement;
    }
    // Fall back to window scroll.
    if (!el || el === doc.body) {
        el = getWindow(startingElement);
    }
    return el;
}

/* eslint-disable no-console */
/**
 * Sends a warning to console, if the api is present.
 *
 * @public
 * @param message - Warning message.
 */
function warn(message) {
    if (console && console.warn) {
        console.warn(message);
    }
}

/**
 * Warns when props are required if a condition is met.
 *
 * @public
 * @param componentName - The name of the component being used.
 * @param props - The props passed into the component.
 * @param requiredProps - The name of the props that are required when the condition is met.
 * @param conditionalPropName - The name of the prop that the condition is based on.
 * @param condition - Whether the condition is met.
 */
function warnConditionallyRequiredProps(componentName, props, requiredProps, conditionalPropName, condition) {
    if (condition === true && process.env.NODE_ENV !== 'production') {
        for (var _i = 0, requiredProps_1 = requiredProps; _i < requiredProps_1.length; _i++) {
            var requiredPropName = requiredProps_1[_i];
            if (!(requiredPropName in props)) {
                warn(componentName + " property '" + requiredPropName + "' is required when '" + conditionalPropName + "' is used.'");
            }
        }
    }
}

/**
 * Warns when two props which are mutually exclusive are both being used.
 *
 * @public
 * @param componentName - The name of the component being used.
 * @param props - The props passed into the component.
 * @param exclusiveMap - A map where the key is a parameter, and the value is the other parameter.
 */
function warnMutuallyExclusive(componentName, props, exclusiveMap) {
    if (process.env.NODE_ENV !== 'production') {
        for (var propName in exclusiveMap) {
            if (props && props[propName] !== undefined) {
                var propInExclusiveMapValue = exclusiveMap[propName];
                if (propInExclusiveMapValue && props[propInExclusiveMapValue] !== undefined) {
                    warn(componentName + " property '" + propName + "' is mutually exclusive with '" + exclusiveMap[propName] + "'. " +
                        "Use one or the other.");
                }
            }
        }
    }
}

/**
 * Warns when a deprecated props are being used.
 *
 * @public
 * @param componentName - The name of the component being used.
 * @param props - The props passed into the component.
 * @param deprecationMap - The map of deprecations, where key is the prop name and the value is
 * either null or a replacement prop name.
 */
function warnDeprecations(componentName, props, deprecationMap) {
    if (process.env.NODE_ENV !== 'production') {
        for (var propName in deprecationMap) {
            if (props && propName in props) {
                var deprecationMessage = componentName + " property '" + propName + "' was used but has been deprecated.";
                var replacementPropName = deprecationMap[propName];
                if (replacementPropName) {
                    deprecationMessage += " Use '" + replacementPropName + "' instead.";
                }
                warn(deprecationMessage);
            }
        }
    }
}

/**
 * BaseComponent class, which provides basic helpers for all components.
 *
 * @public
 * {@docCategory BaseComponent}
 *
 * @deprecated Do not use. We are moving away from class component.
 */
var BaseComponent = /** @class */ (function (_super) {
    __extends(BaseComponent, _super);
    /**
     * BaseComponent constructor
     * @param props - The props for the component.
     * @param context - The context for the component.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    function BaseComponent(props, context) {
        var _this = _super.call(this, props, context) || this;
        // eslint-disable-next-line deprecation/deprecation
        _makeAllSafe(_this, BaseComponent.prototype, [
            'componentDidMount',
            'shouldComponentUpdate',
            'getSnapshotBeforeUpdate',
            'render',
            'componentDidUpdate',
            'componentWillUnmount',
        ]);
        return _this;
    }
    /**
     * When the component receives props, make sure the componentRef is updated.
     */
    BaseComponent.prototype.componentDidUpdate = function (prevProps, prevState) {
        this._updateComponentRef(prevProps, this.props);
    };
    /**
     * When the component has mounted, update the componentRef.
     */
    BaseComponent.prototype.componentDidMount = function () {
        this._setComponentRef(this.props.componentRef, this);
    };
    /**
     * If we have disposables, dispose them automatically on unmount.
     */
    BaseComponent.prototype.componentWillUnmount = function () {
        this._setComponentRef(this.props.componentRef, null);
        if (this.__disposables) {
            for (var i = 0, len = this._disposables.length; i < len; i++) {
                var disposable = this.__disposables[i];
                if (disposable.dispose) {
                    disposable.dispose();
                }
            }
            this.__disposables = null;
        }
    };
    Object.defineProperty(BaseComponent.prototype, "className", {
        /**
         * Gets the object's class name.
         */
        get: function () {
            if (!this.__className) {
                var funcNameRegex = /function (.{1,})\(/;
                var results = funcNameRegex.exec(this.constructor.toString());
                this.__className = results && results.length > 1 ? results[1] : '';
            }
            return this.__className;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseComponent.prototype, "_disposables", {
        /**
         * Allows subclasses to push things to this._disposables to be auto disposed.
         */
        get: function () {
            if (!this.__disposables) {
                this.__disposables = [];
            }
            return this.__disposables;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseComponent.prototype, "_async", {
        /**
         * Gets the async instance associated with the component, created on demand. The async instance gives
         * subclasses a way to execute setTimeout/setInterval async calls safely, where the callbacks
         * will be cleared/ignored automatically after unmounting. The helpers within the async object also
         * preserve the this pointer so that you don't need to "bind" the callbacks.
         */
        get: function () {
            if (!this.__async) {
                this.__async = new Async(this);
                this._disposables.push(this.__async);
            }
            return this.__async;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseComponent.prototype, "_events", {
        /**
         * Gets the event group instance assocaited with the component, created on demand. The event instance
         * provides on/off methods for listening to DOM (or regular javascript object) events. The event callbacks
         * will be automatically disconnected after unmounting. The helpers within the events object also
         * preserve the this reference so that you don't need to "bind" the callbacks.
         */
        get: function () {
            if (!this.__events) {
                this.__events = new EventGroup(this);
                this._disposables.push(this.__events);
            }
            return this.__events;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Helper to return a memoized ref resolver function.
     * @param refName - Name of the member to assign the ref to.
     * @returns A function instance keyed from the given refname.
     * @deprecated Use `createRef` from React.createRef.
     */
    BaseComponent.prototype._resolveRef = function (refName) {
        var _this = this;
        if (!this.__resolves) {
            this.__resolves = {};
        }
        if (!this.__resolves[refName]) {
            this.__resolves[refName] = function (ref) {
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
                return (_this[refName] = ref);
            };
        }
        return this.__resolves[refName];
    };
    /**
     * Updates the componentRef (by calling it with "this" when necessary.)
     */
    BaseComponent.prototype._updateComponentRef = function (currentProps, newProps) {
        if (newProps === void 0) { newProps = {}; }
        // currentProps *should* always be defined, but verify that just in case a subclass is manually
        // calling a lifecycle method with no parameters (which has happened) or other odd usage.
        if (currentProps && newProps && currentProps.componentRef !== newProps.componentRef) {
            this._setComponentRef(currentProps.componentRef, null);
            this._setComponentRef(newProps.componentRef, this);
        }
    };
    /**
     * Warns when a deprecated props are being used.
     *
     * @param deprecationMap - The map of deprecations, where key is the prop name and the value is
     * either null or a replacement prop name.
     */
    BaseComponent.prototype._warnDeprecations = function (deprecationMap) {
        warnDeprecations(this.className, this.props, deprecationMap);
    };
    /**
     * Warns when props which are mutually exclusive with each other are both used.
     *
     * @param mutuallyExclusiveMap - The map of mutually exclusive props.
     */
    BaseComponent.prototype._warnMutuallyExclusive = function (mutuallyExclusiveMap) {
        warnMutuallyExclusive(this.className, this.props, mutuallyExclusiveMap);
    };
    /**
     * Warns when props are required if a condition is met.
     *
     * @param requiredProps - The name of the props that are required when the condition is met.
     * @param conditionalPropName - The name of the prop that the condition is based on.
     * @param condition - Whether the condition is met.
     */
    BaseComponent.prototype._warnConditionallyRequiredProps = function (requiredProps, conditionalPropName, condition) {
        warnConditionallyRequiredProps(this.className, this.props, requiredProps, conditionalPropName, condition);
    };
    BaseComponent.prototype._setComponentRef = function (ref, value) {
        if (!this._skipComponentRefResolution && ref) {
            if (typeof ref === 'function') {
                ref(value);
            }
            if (typeof ref === 'object') {
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
                ref.current = value;
            }
        }
    };
    return BaseComponent;
}(Component));
/**
 * Helper to override a given method with a wrapper method that can try/catch the original, but also
 * ensures that the BaseComponent's methods are called before the subclass's. This ensures that
 * componentWillUnmount in the base is called and that things in the _disposables array are disposed.
 */
// eslint-disable-next-line deprecation/deprecation
function _makeAllSafe(obj, prototype, methodNames) {
    for (var i = 0, len = methodNames.length; i < len; i++) {
        _makeSafe(obj, prototype, methodNames[i]);
    }
}
// eslint-disable-next-line deprecation/deprecation
function _makeSafe(obj, prototype, methodName) {
    /* eslint-disable @typescript-eslint/no-explicit-any */
    var classMethod = obj[methodName];
    var prototypeMethod = prototype[methodName];
    if (classMethod || prototypeMethod) {
        obj[methodName] = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            /* eslint-enable @typescript-eslint/no-explicit-any */
            var retVal;
            if (prototypeMethod) {
                retVal = prototypeMethod.apply(this, args);
            }
            if (classMethod !== prototypeMethod) {
                retVal = classMethod.apply(this, args);
            }
            return retVal;
        };
    }
}
/**
 * Simple constant function for returning null, used to render empty templates in JSX.
 *
 * @public
 */
function nullRender() {
    return null;
}

/**
 * Utility component for delaying the render of a child component after a given delay. This component
 * requires a single child component; don't pass in many components. Wrap multiple components in a DIV
 * if necessary.
 *
 * @public
 * {@docCategory DelayedRender}
 */
var DelayedRender = /** @class */ (function (_super) {
    __extends(DelayedRender, _super);
    function DelayedRender(props) {
        var _this = _super.call(this, props) || this;
        _this.state = {
            isRendered: false,
        };
        return _this;
    }
    DelayedRender.prototype.componentDidMount = function () {
        var _this = this;
        var delay = this.props.delay;
        this._timeoutId = window.setTimeout(function () {
            _this.setState({
                isRendered: true,
            });
        }, delay);
    };
    DelayedRender.prototype.componentWillUnmount = function () {
        if (this._timeoutId) {
            clearTimeout(this._timeoutId);
        }
    };
    DelayedRender.prototype.render = function () {
        return this.state.isRendered ? Children.only(this.props.children) : null;
    };
    DelayedRender.defaultProps = {
        delay: 0,
    };
    return DelayedRender;
}(Component));

/**
 * Storing global state in local module variables has issues when more than one copy
 * if the module gets loaded on the page (due to a bundling error or simply by consuming
 * a prebundled script.)
 *
 * This file contains helpers to deal with the getting and setting local state, and allows
 * callers to get called back when it mutates.
 */
var GLOBAL_SETTINGS_PROP_NAME = '__globalSettings__';
var CALLBACK_STATE_PROP_NAME = '__callbacks__';
var _counter = 0;
/**
 * Global settings helper, which stores settings in the global (window) namespace.
 * If window is not provided, it will store settings in module scope. Provides a
 * way to observe changes as well when their values change.
 *
 * @public
 * {@docCategory GlobalSettings}
 */
var GlobalSettings = /** @class */ (function () {
    function GlobalSettings() {
    }
    GlobalSettings.getValue = function (key, defaultValue) {
        var globalSettings = _getGlobalSettings();
        if (globalSettings[key] === undefined) {
            globalSettings[key] = typeof defaultValue === 'function' ? defaultValue() : defaultValue;
        }
        return globalSettings[key];
    };
    GlobalSettings.setValue = function (key, value) {
        var globalSettings = _getGlobalSettings();
        var callbacks = globalSettings[CALLBACK_STATE_PROP_NAME];
        var oldValue = globalSettings[key];
        if (value !== oldValue) {
            globalSettings[key] = value;
            var changeDescription = {
                oldValue: oldValue,
                value: value,
                key: key,
            };
            for (var id in callbacks) {
                if (callbacks.hasOwnProperty(id)) {
                    callbacks[id](changeDescription);
                }
            }
        }
        return value;
    };
    GlobalSettings.addChangeListener = function (cb) {
        // Note: we use generated ids on the callbacks to create a map of the callbacks, which optimizes removal.
        // (It's faster to delete a key than it is to look up the index of an object and splice an array.)
        var id = cb.__id__;
        var callbacks = _getCallbacks();
        if (!id) {
            id = cb.__id__ = String(_counter++);
        }
        callbacks[id] = cb;
    };
    GlobalSettings.removeChangeListener = function (cb) {
        var callbacks = _getCallbacks();
        delete callbacks[cb.__id__];
    };
    return GlobalSettings;
}());
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function _getGlobalSettings() {
    var _a;
    var win = getWindow();
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    var globalObj = win || {};
    if (!globalObj[GLOBAL_SETTINGS_PROP_NAME]) {
        globalObj[GLOBAL_SETTINGS_PROP_NAME] = (_a = {},
            _a[CALLBACK_STATE_PROP_NAME] = {},
            _a);
    }
    return globalObj[GLOBAL_SETTINGS_PROP_NAME];
}
function _getCallbacks() {
    var globalSettings = _getGlobalSettings();
    return globalSettings[CALLBACK_STATE_PROP_NAME];
}

/**
 * Simulated enum for keycodes. These will get inlined by uglify when used much like an enum
 *
 * @public
 * {@docCategory KeyCodes}
 */
var KeyCodes = {
    backspace: 8,
    tab: 9,
    enter: 13,
    shift: 16,
    ctrl: 17,
    alt: 18,
    pauseBreak: 19,
    capslock: 20,
    escape: 27,
    space: 32,
    pageUp: 33,
    pageDown: 34,
    end: 35,
    home: 36,
    left: 37,
    up: 38,
    right: 39,
    down: 40,
    insert: 45,
    del: 46,
    zero: 48,
    one: 49,
    two: 50,
    three: 51,
    four: 52,
    five: 53,
    six: 54,
    seven: 55,
    eight: 56,
    nine: 57,
    a: 65,
    b: 66,
    c: 67,
    d: 68,
    e: 69,
    f: 70,
    g: 71,
    h: 72,
    i: 73,
    j: 74,
    k: 75,
    l: 76,
    m: 77,
    n: 78,
    o: 79,
    p: 80,
    q: 81,
    r: 82,
    s: 83,
    t: 84,
    u: 85,
    v: 86,
    w: 87,
    x: 88,
    y: 89,
    z: 90,
    leftWindow: 91,
    rightWindow: 92,
    select: 93,
    /* eslint-disable @typescript-eslint/naming-convention */
    zero_numpad: 96,
    one_numpad: 97,
    two_numpad: 98,
    three_numpad: 99,
    four_numpad: 100,
    five_numpad: 101,
    six_numpad: 102,
    seven_numpad: 103,
    eight_numpad: 104,
    nine_numpad: 105,
    /* eslint-enable @typescript-eslint/naming-convention */
    multiply: 106,
    add: 107,
    subtract: 109,
    decimalPoint: 110,
    divide: 111,
    f1: 112,
    f2: 113,
    f3: 114,
    f4: 115,
    f5: 116,
    f6: 117,
    f7: 118,
    f8: 119,
    f9: 120,
    f10: 121,
    f11: 122,
    f12: 123,
    numlock: 144,
    scrollLock: 145,
    semicolon: 186,
    equalSign: 187,
    comma: 188,
    dash: 189,
    period: 190,
    forwardSlash: 191,
    graveAccent: 192,
    openBracket: 219,
    backSlash: 220,
    closeBracket: 221,
    singleQuote: 222,
};

/**
 * Rectangle helper class.
 *
 * @public
 * {@docCategory Rectangle}
 */
var Rectangle = /** @class */ (function () {
    function Rectangle(left, right, top, bottom) {
        if (left === void 0) { left = 0; }
        if (right === void 0) { right = 0; }
        if (top === void 0) { top = 0; }
        if (bottom === void 0) { bottom = 0; }
        this.top = top;
        this.bottom = bottom;
        this.left = left;
        this.right = right;
    }
    Object.defineProperty(Rectangle.prototype, "width", {
        /**
         * Calculated automatically by subtracting the right from left
         */
        get: function () {
            return this.right - this.left;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Rectangle.prototype, "height", {
        /**
         * Calculated automatically by subtracting the bottom from top.
         */
        get: function () {
            return this.bottom - this.top;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Tests if another rect is approximately equal to this rect (within 4 decimal places.)
     */
    Rectangle.prototype.equals = function (rect) {
        // Fixing to 4 decimal places because it allows enough precision and will handle cases when something
        // should be rounded, like .999999 should round to 1.
        return (parseFloat(this.top.toFixed(4)) === parseFloat(rect.top.toFixed(4)) &&
            parseFloat(this.bottom.toFixed(4)) === parseFloat(rect.bottom.toFixed(4)) &&
            parseFloat(this.left.toFixed(4)) === parseFloat(rect.left.toFixed(4)) &&
            parseFloat(this.right.toFixed(4)) === parseFloat(rect.right.toFixed(4)));
    };
    return Rectangle;
}());

/* eslint-disable @typescript-eslint/no-explicit-any */
/**
 * Returns a single function which will call each of the given functions in the context of the
 * parent.
 */
function appendFunction(parent) {
    var functions = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        functions[_i - 1] = arguments[_i];
    }
    if (functions.length < 2) {
        return functions[0];
    }
    return function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        functions.forEach(function (f) { return f && f.apply(parent, args); });
    };
}

/**
 * ARIA helper to concatenate attributes, returning undefined if all attributes
 * are undefined. (Empty strings are not a valid ARIA attribute value.)
 *
 * @param ariaAttributes - ARIA attributes to merge
 */
function mergeAriaAttributeValues() {
    var ariaAttributes = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        ariaAttributes[_i] = arguments[_i];
    }
    var mergedAttribute = ariaAttributes
        .filter(function (arg) { return arg; })
        .join(' ')
        .trim();
    return mergedAttribute === '' ? undefined : mergedAttribute;
}

/**
 * Helper to find the index of an item within an array, using a callback to
 * determine the match.
 *
 * @public
 * @param array - Array to search.
 * @param cb - Callback which returns true on matches.
 * @param fromIndex - Optional index to start from (defaults to 0)
 */
/**
 * Given an array, this function returns a new array where an element has been inserted at the given index.
 * @param array - The array to operate on
 * @param index - The index where an element should be inserted
 * @param itemToAdd - The element to insert
 */
function addElementAtIndex(array, index, itemToAdd) {
    var copy = array.slice();
    copy.splice(index, 0, itemToAdd);
    return copy;
}

/**
 * Fetches an item from session storage without throwing an exception
 * @param key The key of the item to fetch from session storage
 */
function getItem(key) {
    var result = null;
    try {
        result = window.sessionStorage.getItem(key);
    }
    catch (e) {
        /* Eat the exception */
    }
    return result;
}
/**
 * Inserts an item into session storage without throwing an exception
 * @param key The key of the item to add to session storage
 * @param data The data to put into session storage
 */
function setItem(key, data) {
    try {
        window.sessionStorage.setItem(key, data);
    }
    catch (e) {
        /* Eat the exception */
    }
}

var RTL_LOCAL_STORAGE_KEY = 'isRTL';
// Default to undefined so that we initialize on first read.
var _isRTL;
/**
 * Gets the rtl state of the page (returns true if in rtl.)
 */
function getRTL$1(theme) {
    if (theme === void 0) { theme = {}; }
    if (theme.rtl !== undefined) {
        return theme.rtl;
    }
    if (_isRTL === undefined) {
        // Fabric supports persisting the RTL setting between page refreshes via session storage
        var savedRTL = getItem(RTL_LOCAL_STORAGE_KEY);
        if (savedRTL !== null) {
            _isRTL = savedRTL === '1';
            setRTL$1(_isRTL);
        }
        var doc = getDocument();
        if (_isRTL === undefined && doc) {
            _isRTL = ((doc.body && doc.body.getAttribute('dir')) || doc.documentElement.getAttribute('dir')) === 'rtl';
            setRTL(_isRTL);
        }
    }
    return !!_isRTL;
}
/**
 * Sets the rtl state of the page (by adjusting the dir attribute of the html element.)
 */
function setRTL$1(isRTL, persistSetting) {
    if (persistSetting === void 0) { persistSetting = false; }
    var doc = getDocument();
    if (doc) {
        doc.documentElement.setAttribute('dir', isRTL ? 'rtl' : 'ltr');
    }
    if (persistSetting) {
        setItem(RTL_LOCAL_STORAGE_KEY, isRTL ? '1' : '0');
    }
    _isRTL = isRTL;
    setRTL(_isRTL);
}

/**
 * Determines whether or not an element has the virtual hierarchy extension.
 *
 * @public
 */
function isVirtualElement(element) {
    return element && !!element._virtual;
}

/**
 * Gets the virtual parent given the child element, if it exists.
 *
 * @public
 */
function getVirtualParent(child) {
    var parent;
    if (child && isVirtualElement(child)) {
        parent = child._virtual.parent;
    }
    return parent;
}

/**
 * Gets the element which is the parent of a given element.
 * If `allowVirtuaParents` is `true`, this method prefers the virtual parent over
 * real DOM parent when present.
 *
 * @public
 */
function getParent(child, allowVirtualParents) {
    if (allowVirtualParents === void 0) { allowVirtualParents = true; }
    return (child &&
        ((allowVirtualParents && getVirtualParent(child)) || (child.parentNode && child.parentNode)));
}

/**
 * Determines whether or not a parent element contains a given child element.
 * If `allowVirtualParents` is true, this method may return `true` if the child
 * has the parent in its virtual element hierarchy.
 *
 * @public
 */
function elementContains(parent, child, allowVirtualParents) {
    if (allowVirtualParents === void 0) { allowVirtualParents = true; }
    var isContained = false;
    if (parent && child) {
        if (allowVirtualParents) {
            isContained = false;
            while (child) {
                var nextParent = getParent(child);
                if (nextParent === parent) {
                    isContained = true;
                    break;
                }
                child = nextParent;
            }
        }
        else if (parent.contains) {
            isContained = parent.contains(child);
        }
    }
    return isContained;
}

/**
 * Finds the first parent element where the matchFunction returns true
 * @param element - element to start searching at
 * @param matchFunction - the function that determines if the element is a match
 * @returns the matched element or null no match was found
 */
function findElementRecursive(element, matchFunction) {
    if (!element || element === document.body) {
        return null;
    }
    return matchFunction(element) ? element : findElementRecursive(getParent(element), matchFunction);
}

/**
 * Determines if an element, or any of its ancestors, contain the given attribute
 * @param element - element to start searching at
 * @param attribute - the attribute to search for
 * @returns the value of the first instance found
 */
function elementContainsAttribute(element, attribute) {
    var elementMatch = findElementRecursive(element, function (testElement) { return testElement.hasAttribute(attribute); });
    return elementMatch && elementMatch.getAttribute(attribute);
}

function on(element, eventName, callback, options) {
    element.addEventListener(eventName, callback, options);
    return function () { return element.removeEventListener(eventName, callback, options); };
}

var DATA_PORTAL_ATTRIBUTE = 'data-portal-element';
/**
 * Identify element as a portal by setting an attribute.
 * @param element - Element to mark as a portal.
 */
function setPortalAttribute(element) {
    element.setAttribute(DATA_PORTAL_ATTRIBUTE, 'true');
}

/**
 * Determine whether a target is within a portal from perspective of root or optional parent.
 * This function only works against portal components that use the setPortalAttribute function.
 * If both parent and child are within the same portal this function will return false.
 * @param target - Element to query portal containment status of.
 * @param parent - Optional parent perspective. Search for containing portal stops at parent
 * (or root if parent is undefined or invalid.)
 */
function portalContainsElement(target, parent) {
    var elementMatch = findElementRecursive(target, function (testElement) { return parent === testElement || testElement.hasAttribute(DATA_PORTAL_ATTRIBUTE); });
    return elementMatch !== null && elementMatch.hasAttribute(DATA_PORTAL_ATTRIBUTE);
}

/** Raises a click event. */
function raiseClick(target) {
    var event = createNewEvent('MouseEvents');
    event.initEvent('click', true, true);
    target.dispatchEvent(event);
}
function createNewEvent(eventName) {
    var event;
    if (typeof Event === 'function') {
        // Chrome, Opera, Firefox
        event = new Event(eventName);
    }
    else {
        // IE
        event = document.createEvent('Event');
        event.initEvent(eventName, true, true);
    }
    return event;
}

/**
 * Sets the virtual parent of an element.
 * Pass `undefined` as the `parent` to clear the virtual parent.
 *
 * @public
 */
function setVirtualParent(child, parent) {
    var virtualChild = child;
    var virtualParent = parent;
    if (!virtualChild._virtual) {
        virtualChild._virtual = {
            children: [],
        };
    }
    var oldParent = virtualChild._virtual.parent;
    if (oldParent && oldParent !== parent) {
        // Remove the child from its old parent.
        var index = oldParent._virtual.children.indexOf(virtualChild);
        if (index > -1) {
            oldParent._virtual.children.splice(index, 1);
        }
    }
    virtualChild._virtual.parent = virtualParent || undefined;
    if (virtualParent) {
        if (!virtualParent._virtual) {
            virtualParent._virtual = {
                children: [],
            };
        }
        virtualParent._virtual.children.push(virtualChild);
    }
}

var MAX_CACHE_COUNT = 50;
var DEFAULT_SPECIFICITY_MULTIPLIER = 5;
var _memoizedClassNames = 0;
var stylesheet = Stylesheet.getInstance();
if (stylesheet && stylesheet.onReset) {
    stylesheet.onReset(function () { return _memoizedClassNames++; });
}
// Note that because of the caching nature within the classNames memoization,
// I've disabled this rule to simply be able to work with any types.
/* eslint-disable @typescript-eslint/no-explicit-any */
// This represents a prop we attach to each Map to indicate the cached return value
// associated with the graph node.
var retVal = '__retval__';
/**
 * Creates a getClassNames function which calls getStyles given the props, and injects them
 * into mergeStyleSets.
 *
 * Note that the props you pass in on every render should be in the same order and
 * immutable (numbers, strings, and booleans). This will allow the results to be memoized. Violating
 * these will cause extra recalcs to occur.
 */
function classNamesFunction(options) {
    // We build a trie where each node is a Map. The map entry key represents an argument
    // value, and the entry value is another node (Map). Each node has a `__retval__`
    // property which is used to hold the cached response.
    if (options === void 0) { options = {}; }
    // To derive the response, we can simply ensure the arguments are added or already
    // exist in the trie. At the last node, if there is a `__retval__` we return that. Otherwise
    // we call the `getStyles` api to evaluate, cache on the property, and return that.
    var map = new Map();
    var styleCalcCount = 0;
    var getClassNamesCount = 0;
    var currentMemoizedClassNames = _memoizedClassNames;
    var getClassNames = function (styleFunctionOrObject, styleProps) {
        if (styleProps === void 0) { styleProps = {}; }
        var _a, _b;
        // If useStaticStyles is true, styleFunctionOrObject returns slot to classname mappings.
        // If there is also no style overrides, we can skip merge styles completely and
        // simply return the result from the style funcion.
        if (options.useStaticStyles &&
            typeof styleFunctionOrObject === 'function' &&
            styleFunctionOrObject.__noStyleOverride__) {
            return styleFunctionOrObject(styleProps);
        }
        getClassNamesCount++;
        var current = map;
        var theme = styleProps.theme;
        var rtl = theme && theme.rtl !== undefined ? theme.rtl : getRTL$1();
        var disableCaching = options.disableCaching;
        // On reset of our stylesheet, reset memoized cache.
        if (currentMemoizedClassNames !== _memoizedClassNames) {
            currentMemoizedClassNames = _memoizedClassNames;
            map = new Map();
            styleCalcCount = 0;
        }
        if (!options.disableCaching) {
            current = _traverseMap(map, styleFunctionOrObject);
            current = _traverseMap(current, styleProps);
        }
        if (disableCaching || !current[retVal]) {
            if (styleFunctionOrObject === undefined) {
                current[retVal] = {};
            }
            else {
                current[retVal] = mergeCssSets([
                    (typeof styleFunctionOrObject === 'function'
                        ? styleFunctionOrObject(styleProps)
                        : styleFunctionOrObject),
                ], { rtl: !!rtl, specificityMultiplier: options.useStaticStyles ? DEFAULT_SPECIFICITY_MULTIPLIER : undefined });
            }
            if (!disableCaching) {
                styleCalcCount++;
            }
        }
        if (styleCalcCount > (options.cacheSize || MAX_CACHE_COUNT)) {
            var win = getWindow();
            if ((_b = (_a = win) === null || _a === void 0 ? void 0 : _a.FabricConfig) === null || _b === void 0 ? void 0 : _b.enableClassNameCacheFullWarning) {
                // eslint-disable-next-line no-console
                console.warn("Styles are being recalculated too frequently. Cache miss rate is " + styleCalcCount + "/" + getClassNamesCount + ".");
                // eslint-disable-next-line no-console
                console.trace();
            }
            map.clear();
            styleCalcCount = 0;
            // Mutate the options passed in, that's all we can do.
            options.disableCaching = true;
        }
        // Note: the retVal is an attached property on the Map; not a key in the Map. We use this attached property to
        // cache the return value for this branch of the graph.
        return current[retVal];
    };
    return getClassNames;
}
function _traverseEdge(current, value) {
    value = _normalizeValue(value);
    if (!current.has(value)) {
        current.set(value, new Map());
    }
    return current.get(value);
}
function _traverseMap(current, inputs) {
    if (typeof inputs === 'function') {
        var cachedInputsFromStyled = inputs.__cachedInputs__;
        if (cachedInputsFromStyled) {
            // The styled helper will generate the styles function and will attach the cached
            // inputs (consisting of the default styles, customzied styles, and user provided styles.)
            // These should be used as cache keys for deriving the memoized value.
            for (var _i = 0, _a = inputs.__cachedInputs__; _i < _a.length; _i++) {
                var input = _a[_i];
                current = _traverseEdge(current, input);
            }
        }
        else {
            current = _traverseEdge(current, inputs);
        }
    }
    else if (typeof inputs === 'object') {
        for (var propName in inputs) {
            if (inputs.hasOwnProperty(propName)) {
                current = _traverseEdge(current, inputs[propName]);
            }
        }
    }
    return current;
}
function _normalizeValue(value) {
    switch (value) {
        case undefined:
            return '__undefined__';
        case null:
            return '__null__';
        default:
            return value;
    }
}

var _initializedStylesheetResets = false;
var _resetCounter = 0;
var _emptyObject = { empty: true };
var _dictionary = {};
var _weakMap = typeof WeakMap === 'undefined' ? null : WeakMap;
/**
 * Reset memoizations.
 */
function resetMemoizations() {
    _resetCounter++;
}
/**
 * Memoizes a function; when you pass in the same parameters multiple times, it returns a cached result.
 * Be careful when passing in objects, you need to pass in the same INSTANCE for caching to work. Otherwise
 * it will grow the cache unnecessarily. Also avoid using default values that evaluate functions; passing in
 * undefined for a value and relying on a default function will execute it the first time, but will not
 * re-evaluate subsequent times which may have been unexpected.
 *
 * By default, the cache will reset after 100 permutations, to avoid abuse cases where the function is
 * unintendedly called with unique objects. Without a reset, the cache could grow infinitely, so we safeguard
 * by resetting. To override this behavior, pass a value of 0 to the maxCacheSize parameter.
 *
 * @public
 * @param cb - The function to memoize.
 * @param maxCacheSize - Max results to cache. If the cache exceeds this value, it will reset on the next call.
 * @param ignoreNullOrUndefinedResult - Flag to decide whether to cache callback result if it is undefined/null.
 * If the flag is set to true, the callback result is recomputed every time till the callback result is
 * not undefined/null for the first time, and then the non-undefined/null version gets cached.
 * @returns A memoized version of the function.
 */
function memoizeFunction(cb, maxCacheSize, ignoreNullOrUndefinedResult) {
    if (maxCacheSize === void 0) { maxCacheSize = 100; }
    if (ignoreNullOrUndefinedResult === void 0) { ignoreNullOrUndefinedResult = false; }
    // Avoid breaking scenarios which don't have weak map.
    if (!_weakMap) {
        return cb;
    }
    if (!_initializedStylesheetResets) {
        var stylesheet = Stylesheet.getInstance();
        if (stylesheet && stylesheet.onReset) {
            Stylesheet.getInstance().onReset(resetMemoizations);
        }
        _initializedStylesheetResets = true;
    }
    var rootNode;
    var cacheSize = 0;
    var localResetCounter = _resetCounter;
    return function memoizedFunction() {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        var currentNode = rootNode;
        if (rootNode === undefined ||
            localResetCounter !== _resetCounter ||
            (maxCacheSize > 0 && cacheSize > maxCacheSize)) {
            rootNode = _createNode();
            cacheSize = 0;
            localResetCounter = _resetCounter;
        }
        currentNode = rootNode;
        // Traverse the tree until we find the match.
        for (var i = 0; i < args.length; i++) {
            var arg = _normalizeArg(args[i]);
            if (!currentNode.map.has(arg)) {
                currentNode.map.set(arg, _createNode());
            }
            currentNode = currentNode.map.get(arg);
        }
        if (!currentNode.hasOwnProperty('value')) {
            currentNode.value = cb.apply(void 0, args);
            cacheSize++;
        }
        if (ignoreNullOrUndefinedResult && (currentNode.value === null || currentNode.value === undefined)) {
            currentNode.value = cb.apply(void 0, args);
        }
        return currentNode.value;
    };
}
function _normalizeArg(val) {
    if (!val) {
        return _emptyObject;
    }
    else if (typeof val === 'object' || typeof val === 'function') {
        return val;
    }
    else if (!_dictionary[val]) {
        _dictionary[val] = { val: val };
    }
    return _dictionary[val];
}
function _createNode() {
    return {
        map: _weakMap ? new _weakMap() : null,
    };
}

/**
 * Concatination helper, which can merge class names together. Skips over falsey values.
 *
 * @public
 */
function css() {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    var classes = [];
    for (var _a = 0, args_1 = args; _a < args_1.length; _a++) {
        var arg = args_1[_a];
        if (arg) {
            if (typeof arg === 'string') {
                classes.push(arg);
            }
            else if (arg.hasOwnProperty('toString') && typeof arg.toString === 'function') {
                classes.push(arg.toString());
            }
            else {
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
                for (var key in arg) {
                    // eslint-disable-next-line @typescript-eslint/no-explicit-any
                    if (arg[key]) {
                        classes.push(key);
                    }
                }
            }
        }
    }
    return classes.join(' ');
}

var CustomizationsGlobalKey = 'customizations';
var NO_CUSTOMIZATIONS = { settings: {}, scopedSettings: {}, inCustomizerContext: false };
var _allSettings = GlobalSettings.getValue(CustomizationsGlobalKey, {
    settings: {},
    scopedSettings: {},
    inCustomizerContext: false,
});
var _events = [];
var Customizations = /** @class */ (function () {
    function Customizations() {
    }
    Customizations.reset = function () {
        _allSettings.settings = {};
        _allSettings.scopedSettings = {};
    };
    /** Apply global Customization settings.
     * @example Customizations.applySettings(\{ theme: \{...\} \});
     */
    Customizations.applySettings = function (settings) {
        _allSettings.settings = __assign(__assign({}, _allSettings.settings), settings);
        Customizations._raiseChange();
    };
    /** Apply Customizations to a particular named scope, like a component.
     * @example Customizations.applyScopedSettings('Nav', \{ styles: () =\> \{\} \});
     */
    Customizations.applyScopedSettings = function (scopeName, settings) {
        _allSettings.scopedSettings[scopeName] = __assign(__assign({}, _allSettings.scopedSettings[scopeName]), settings);
        Customizations._raiseChange();
    };
    Customizations.getSettings = function (properties, scopeName, localSettings) {
        if (localSettings === void 0) { localSettings = NO_CUSTOMIZATIONS; }
        var settings = {};
        var localScopedSettings = (scopeName && localSettings.scopedSettings[scopeName]) || {};
        var globalScopedSettings = (scopeName && _allSettings.scopedSettings[scopeName]) || {};
        for (var _i = 0, properties_1 = properties; _i < properties_1.length; _i++) {
            var property = properties_1[_i];
            settings[property] =
                localScopedSettings[property] ||
                    localSettings.settings[property] ||
                    globalScopedSettings[property] ||
                    _allSettings.settings[property];
        }
        return settings;
    };
    /** Used to run some code that sets Customizations without triggering an update until the end.
     * Useful for applying Customizations that don't affect anything currently rendered, or for
     * applying many customizations at once.
     * @param suppressUpdate - Do not raise the change event at the end, preventing all updates
     */
    Customizations.applyBatchedUpdates = function (code, suppressUpdate) {
        Customizations._suppressUpdates = true;
        try {
            code();
        }
        catch (_a) {
            /* do nothing */
        }
        Customizations._suppressUpdates = false;
        if (!suppressUpdate) {
            Customizations._raiseChange();
        }
    };
    Customizations.observe = function (onChange) {
        _events.push(onChange);
    };
    Customizations.unobserve = function (onChange) {
        _events = _events.filter(function (cb) { return cb !== onChange; });
    };
    Customizations._raiseChange = function () {
        if (!Customizations._suppressUpdates) {
            _events.forEach(function (cb) { return cb(); });
        }
    };
    return Customizations;
}());

var CustomizerContext = createContext({
    customizations: {
        inCustomizerContext: false,
        settings: {},
        scopedSettings: {},
    },
});

/**
 * Merge new and old settings, giving priority to new settings.
 * New settings is optional in which case oldSettings is returned as-is.
 * @param oldSettings - Old settings to fall back to.
 * @param newSettings - New settings that will be merged over oldSettings.
 * @returns Merged settings.
 */
function mergeSettings(oldSettings, newSettings) {
    if (oldSettings === void 0) { oldSettings = {}; }
    var mergeSettingsWith = _isSettingsFunction(newSettings) ? newSettings : _settingsMergeWith(newSettings);
    return mergeSettingsWith(oldSettings);
}
function mergeScopedSettings(oldSettings, newSettings) {
    if (oldSettings === void 0) { oldSettings = {}; }
    var mergeSettingsWith = _isSettingsFunction(newSettings) ? newSettings : _scopedSettingsMergeWith(newSettings);
    return mergeSettingsWith(oldSettings);
}
function _isSettingsFunction(settings) {
    return typeof settings === 'function';
}
function _settingsMergeWith(newSettings) {
    return function (settings) { return (newSettings ? __assign(__assign({}, settings), newSettings) : settings); };
}
function _scopedSettingsMergeWith(scopedSettingsFromProps) {
    if (scopedSettingsFromProps === void 0) { scopedSettingsFromProps = {}; }
    return function (oldScopedSettings) {
        var newScopedSettings = __assign({}, oldScopedSettings);
        for (var scopeName in scopedSettingsFromProps) {
            if (scopedSettingsFromProps.hasOwnProperty(scopeName)) {
                newScopedSettings[scopeName] = __assign(__assign({}, oldScopedSettings[scopeName]), scopedSettingsFromProps[scopeName]);
            }
        }
        return newScopedSettings;
    };
}

/**
 * Merge props and customizations giving priority to props over context.
 * NOTE: This function will always perform multiple merge operations. Use with caution.
 * @param props - New settings to merge in.
 * @param parentContext - Context containing current settings.
 * @returns Merged customizations.
 */
function mergeCustomizations(props, parentContext) {
    var _a = (parentContext || {}).customizations, customizations = _a === void 0 ? { settings: {}, scopedSettings: {} } : _a;
    return {
        customizations: {
            settings: mergeSettings(customizations.settings, props.settings),
            scopedSettings: mergeScopedSettings(customizations.scopedSettings, props.scopedSettings),
            inCustomizerContext: true,
        },
    };
}

/**
 * The Customizer component allows for default props to be mixed into components which
 * are decorated with the customizable() decorator, or use the styled HOC. This enables
 * injection scenarios like:
 *
 * 1. render svg icons instead of the icon font within all buttons
 * 2. inject a custom theme object into a component
 *
 * Props are provided via the settings prop which should be one of the following:
 * - A json map which contains 1 or more name/value pairs representing injectable props.
 * - A function that receives the current settings and returns the new ones that apply to the scope
 *
 * @public
 */
var Customizer = /** @class */ (function (_super) {
    __extends(Customizer, _super);
    function Customizer() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._onCustomizationChange = function () { return _this.forceUpdate(); };
        return _this;
    }
    Customizer.prototype.componentDidMount = function () {
        Customizations.observe(this._onCustomizationChange);
    };
    Customizer.prototype.componentWillUnmount = function () {
        Customizations.unobserve(this._onCustomizationChange);
    };
    Customizer.prototype.render = function () {
        var _this = this;
        var contextTransform = this.props.contextTransform;
        return (createElement(CustomizerContext.Consumer, null, function (parentContext) {
            var newContext = mergeCustomizations(_this.props, parentContext);
            if (contextTransform) {
                newContext = contextTransform(newContext);
            }
            return createElement(CustomizerContext.Provider, { value: newContext }, _this.props.children);
        }));
    };
    return Customizer;
}(Component));

/**
 * Allows you to hoist static functions in components.
 * Created for the purpose of fixing broken static functions in classes
 * that utilize decorators.
 *
 * @public
 * @param source - The object where the methods are hoisted from.
 * @param dest - The object to hoist the methods onto.
 * @returns The dest object with methods added
 */
function hoistStatics(source, dest) {
    for (var name_1 in source) {
        if (source.hasOwnProperty(name_1)) {
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            dest[name_1] = source[name_1];
        }
    }
    return dest;
}

function customizable(scope, fields, concatStyles) {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    return function customizableFactory(ComposedComponent) {
        var _a;
        var resultClass = (_a = /** @class */ (function (_super) {
                __extends(ComponentWithInjectedProps, _super);
                function ComponentWithInjectedProps(props) {
                    var _this = _super.call(this, props) || this;
                    // eslint-disable-next-line @typescript-eslint/no-explicit-any
                    _this._styleCache = {};
                    _this._onSettingChanged = _this._onSettingChanged.bind(_this);
                    return _this;
                }
                ComponentWithInjectedProps.prototype.componentDidMount = function () {
                    Customizations.observe(this._onSettingChanged);
                };
                ComponentWithInjectedProps.prototype.componentWillUnmount = function () {
                    Customizations.unobserve(this._onSettingChanged);
                };
                ComponentWithInjectedProps.prototype.render = function () {
                    var _this = this;
                    return (createElement(CustomizerContext.Consumer, null, function (context) {
                        var defaultProps = Customizations.getSettings(fields, scope, context.customizations);
                        // eslint-disable-next-line @typescript-eslint/no-explicit-any
                        var componentProps = _this.props;
                        // If defaultProps.styles is a function, evaluate it before calling concatStyleSets
                        if (defaultProps.styles && typeof defaultProps.styles === 'function') {
                            defaultProps.styles = defaultProps.styles(__assign(__assign({}, defaultProps), componentProps));
                        }
                        // If concatStyles is true and custom styles have been defined compute those styles
                        if (concatStyles && defaultProps.styles) {
                            if (_this._styleCache.default !== defaultProps.styles ||
                                _this._styleCache.component !== componentProps.styles) {
                                var mergedStyles = concatStyleSets(defaultProps.styles, componentProps.styles);
                                _this._styleCache.default = defaultProps.styles;
                                _this._styleCache.component = componentProps.styles;
                                _this._styleCache.merged = mergedStyles;
                            }
                            return createElement(ComposedComponent, __assign({}, defaultProps, componentProps, { styles: _this._styleCache.merged }));
                        }
                        return createElement(ComposedComponent, __assign({}, defaultProps, componentProps));
                    }));
                };
                ComponentWithInjectedProps.prototype._onSettingChanged = function () {
                    this.forceUpdate();
                };
                return ComponentWithInjectedProps;
            }(Component)),
            _a.displayName = 'Customized' + scope,
            _a);
        return hoistStatics(ComposedComponent, resultClass);
    };
}

/**
 * Hook to get Customizations settings from Customizations singleton or CustomizerContext.
 * It will trigger component state update on settings change observed.
 */
function useCustomizationSettings(properties, scopeName) {
    var forceUpdate = useForceUpdate();
    var customizations = useContext(CustomizerContext).customizations;
    var inCustomizerContext = customizations.inCustomizerContext;
    useEffect(function () {
        if (!inCustomizerContext) {
            Customizations.observe(forceUpdate);
        }
        return function () {
            if (!inCustomizerContext) {
                Customizations.unobserve(forceUpdate);
            }
        };
        // eslint-disable-next-line react-hooks/exhaustive-deps -- exclude forceUpdate
    }, [inCustomizerContext]);
    return Customizations.getSettings(properties, scopeName, customizations);
}
function useForceUpdate() {
    var _a = useState(0), setValue = _a[1];
    return function () { return setValue(function (value) { return ++value; }); };
}

/**
 * Extends a component's lifetime methods by appending new functions to the existing lifetime functions.
 */
function extendComponent(parent, methods) {
    for (var name_1 in methods) {
        if (methods.hasOwnProperty(name_1)) {
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            parent[name_1] = appendFunction(parent, parent[name_1], methods[name_1]);
        }
    }
}

var IS_FOCUSABLE_ATTRIBUTE = 'data-is-focusable';
var IS_VISIBLE_ATTRIBUTE = 'data-is-visible';
var FOCUSZONE_ID_ATTRIBUTE = 'data-focuszone-id';
var FOCUSZONE_SUB_ATTRIBUTE = 'data-is-sub-focuszone';
/**
 * Gets the first focusable element.
 *
 * @public
 */
function getFirstFocusable(rootElement, currentElement, includeElementsInFocusZones) {
    return getNextElement(rootElement, currentElement, true /*checkNode*/, false /*suppressParentTraversal*/, false /*suppressChildTraversal*/, includeElementsInFocusZones);
}
/**
 * Gets the last focusable element.
 *
 * @public
 */
function getLastFocusable(rootElement, currentElement, includeElementsInFocusZones) {
    return getPreviousElement(rootElement, currentElement, true /*checkNode*/, false /*suppressParentTraversal*/, true /*traverseChildren*/, includeElementsInFocusZones);
}
/**
 * Attempts to focus the first focusable element that is a child or child's child of the rootElement.
 *
 * @public
 * @param rootElement - Element to start the search for a focusable child.
 * @returns True if focus was set, false if it was not.
 */
function focusFirstChild(rootElement) {
    var element = getNextElement(rootElement, rootElement, true, false, false, true);
    if (element) {
        focusAsync(element);
        return true;
    }
    return false;
}
/**
 * Traverse to find the previous element.
 * If tabbable is true, the element must have tabIndex != -1.
 *
 * @public
 */
function getPreviousElement(rootElement, currentElement, checkNode, suppressParentTraversal, traverseChildren, includeElementsInFocusZones, allowFocusRoot, tabbable) {
    if (!currentElement || (!allowFocusRoot && currentElement === rootElement)) {
        return null;
    }
    var isCurrentElementVisible = isElementVisible(currentElement);
    // Check its children.
    if (traverseChildren &&
        isCurrentElementVisible &&
        (includeElementsInFocusZones || !(isElementFocusZone(currentElement) || isElementFocusSubZone(currentElement)))) {
        var childMatch = getPreviousElement(rootElement, currentElement.lastElementChild, true, true, true, includeElementsInFocusZones, allowFocusRoot, tabbable);
        if (childMatch) {
            if ((tabbable && isElementTabbable(childMatch, true)) || !tabbable) {
                return childMatch;
            }
            var childMatchSiblingMatch = getPreviousElement(rootElement, childMatch.previousElementSibling, true, true, true, includeElementsInFocusZones, allowFocusRoot, tabbable);
            if (childMatchSiblingMatch) {
                return childMatchSiblingMatch;
            }
            var childMatchParent = childMatch.parentElement;
            // At this point if we have not found any potential matches
            // start looking at the rest of the subtree under the currentParent.
            // NOTE: We do not want to recurse here because doing so could
            // cause elements to get skipped.
            while (childMatchParent && childMatchParent !== currentElement) {
                var childMatchParentMatch = getPreviousElement(rootElement, childMatchParent.previousElementSibling, true, true, true, includeElementsInFocusZones, allowFocusRoot, tabbable);
                if (childMatchParentMatch) {
                    return childMatchParentMatch;
                }
                childMatchParent = childMatchParent.parentElement;
            }
        }
    }
    // Check the current node, if it's not the first traversal.
    if (checkNode && isCurrentElementVisible && isElementTabbable(currentElement, tabbable)) {
        return currentElement;
    }
    // Check its previous sibling.
    var siblingMatch = getPreviousElement(rootElement, currentElement.previousElementSibling, true, true, true, includeElementsInFocusZones, allowFocusRoot, tabbable);
    if (siblingMatch) {
        return siblingMatch;
    }
    // Check its parent.
    if (!suppressParentTraversal) {
        return getPreviousElement(rootElement, currentElement.parentElement, true, false, false, includeElementsInFocusZones, allowFocusRoot, tabbable);
    }
    return null;
}
/**
 * Traverse to find the next focusable element.
 * If tabbable is true, the element must have tabIndex != -1.
 *
 * @public
 * @param checkNode - Include currentElement in search when true.
 */
function getNextElement(rootElement, currentElement, checkNode, suppressParentTraversal, suppressChildTraversal, includeElementsInFocusZones, allowFocusRoot, tabbable) {
    if (!currentElement || (currentElement === rootElement && suppressChildTraversal && !allowFocusRoot)) {
        return null;
    }
    var isCurrentElementVisible = isElementVisible(currentElement);
    // Check the current node, if it's not the first traversal.
    if (checkNode && isCurrentElementVisible && isElementTabbable(currentElement, tabbable)) {
        return currentElement;
    }
    // Check its children.
    if (!suppressChildTraversal &&
        isCurrentElementVisible &&
        (includeElementsInFocusZones || !(isElementFocusZone(currentElement) || isElementFocusSubZone(currentElement)))) {
        var childMatch = getNextElement(rootElement, currentElement.firstElementChild, true, true, false, includeElementsInFocusZones, allowFocusRoot, tabbable);
        if (childMatch) {
            return childMatch;
        }
    }
    if (currentElement === rootElement) {
        return null;
    }
    // Check its sibling.
    var siblingMatch = getNextElement(rootElement, currentElement.nextElementSibling, true, true, false, includeElementsInFocusZones, allowFocusRoot, tabbable);
    if (siblingMatch) {
        return siblingMatch;
    }
    if (!suppressParentTraversal) {
        return getNextElement(rootElement, currentElement.parentElement, false, false, true, includeElementsInFocusZones, allowFocusRoot, tabbable);
    }
    return null;
}
/**
 * Determines if an element is visible.
 *
 * @public
 */
function isElementVisible(element) {
    // If the element is not valid, return false.
    if (!element || !element.getAttribute) {
        return false;
    }
    var visibilityAttribute = element.getAttribute(IS_VISIBLE_ATTRIBUTE);
    // If the element is explicitly marked with the visibility attribute, return that value as boolean.
    if (visibilityAttribute !== null && visibilityAttribute !== undefined) {
        return visibilityAttribute === 'true';
    }
    // Fallback to other methods of determining actual visibility.
    return (element.offsetHeight !== 0 ||
        element.offsetParent !== null ||
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        element.isVisible === true); // used as a workaround for testing.
}
/**
 * Determines if an element can receive focus programmatically or via a mouse click.
 * If checkTabIndex is true, additionally checks to ensure the element can be focused with the tab key,
 * meaning tabIndex != -1.
 *
 * @public
 */
function isElementTabbable(element, checkTabIndex) {
    // If this element is null or is disabled, it is not considered tabbable.
    if (!element || element.disabled) {
        return false;
    }
    var tabIndex = 0;
    var tabIndexAttributeValue = null;
    if (element && element.getAttribute) {
        tabIndexAttributeValue = element.getAttribute('tabIndex');
        if (tabIndexAttributeValue) {
            tabIndex = parseInt(tabIndexAttributeValue, 10);
        }
    }
    var isFocusableAttribute = element.getAttribute ? element.getAttribute(IS_FOCUSABLE_ATTRIBUTE) : null;
    var isTabIndexSet = tabIndexAttributeValue !== null && tabIndex >= 0;
    var result = !!element &&
        isFocusableAttribute !== 'false' &&
        (element.tagName === 'A' ||
            element.tagName === 'BUTTON' ||
            element.tagName === 'INPUT' ||
            element.tagName === 'TEXTAREA' ||
            element.tagName === 'SELECT' ||
            isFocusableAttribute === 'true' ||
            isTabIndexSet);
    return checkTabIndex ? tabIndex !== -1 && result : result;
}
/**
 * Determines if a given element is a focus zone.
 *
 * @public
 */
function isElementFocusZone(element) {
    return !!(element && element.getAttribute && !!element.getAttribute(FOCUSZONE_ID_ATTRIBUTE));
}
/**
 * Determines if a given element is a focus sub zone.
 *
 * @public
 */
function isElementFocusSubZone(element) {
    return !!(element && element.getAttribute && element.getAttribute(FOCUSZONE_SUB_ATTRIBUTE) === 'true');
}
/**
 * Determines if an element, or any of its children, contain focus.
 *
 * @public
 */
function doesElementContainFocus(element) {
    var document = getDocument(element);
    var currentActiveElement = document && document.activeElement;
    if (currentActiveElement && elementContains(element, currentActiveElement)) {
        return true;
    }
    return false;
}
/**
 * Determines if an, or any of its ancestors, sepcificies that it doesn't want focus to wrap
 * @param element - element to start searching from
 * @param noWrapDataAttribute - the no wrap data attribute to match (either)
 * @returns true if focus should wrap, false otherwise
 */
function shouldWrapFocus(element, noWrapDataAttribute) {
    return elementContainsAttribute(element, noWrapDataAttribute) === 'true' ? false : true;
}
var targetToFocusOnNextRepaint = undefined;
/**
 * Sets focus to an element asynchronously. The focus will be set at the next browser repaint,
 * meaning it won't cause any extra recalculations. If more than one focusAsync is called during one frame,
 * only the latest called focusAsync element will actually be focused
 * @param element - The element to focus
 */
function focusAsync(element) {
    if (element) {
        // An element was already queued to be focused, so replace that one with the new element
        if (targetToFocusOnNextRepaint) {
            targetToFocusOnNextRepaint = element;
            return;
        }
        targetToFocusOnNextRepaint = element;
        var win = getWindow(element);
        if (win) {
            // element.focus() is a no-op if the element is no longer in the DOM, meaning this is always safe
            win.requestAnimationFrame(function () {
                targetToFocusOnNextRepaint && targetToFocusOnNextRepaint.focus();
                // We are done focusing for this frame, so reset the queued focus element
                targetToFocusOnNextRepaint = undefined;
            });
        }
    }
}
/**
 * Finds the closest focusable element via an index path from a parent. See
 * `getElementIndexPath` for getting an index path from an element to a child.
 */
function getFocusableByIndexPath(parent, path) {
    var element = parent;
    for (var _i = 0, path_1 = path; _i < path_1.length; _i++) {
        var index = path_1[_i];
        var nextChild = element.children[Math.min(index, element.children.length - 1)];
        if (!nextChild) {
            break;
        }
        element = nextChild;
    }
    element =
        isElementTabbable(element) && isElementVisible(element)
            ? element
            : getNextElement(parent, element, true) || getPreviousElement(parent, element);
    return element;
}
/**
 * Finds the element index path from a parent element to a child element.
 *
 * If you had this node structure: "A has children [B, C] and C has child D",
 * the index path from A to D would be [1, 0], or `parent.chidren[1].children[0]`.
 */
function getElementIndexPath(fromElement, toElement) {
    var path = [];
    while (toElement && fromElement && toElement !== fromElement) {
        var parent_1 = getParent(toElement, true);
        if (parent_1 === null) {
            return [];
        }
        path.unshift(Array.prototype.indexOf.call(parent_1.children, toElement));
        toElement = parent_1;
    }
    return path;
}

// Initialize global window id.
var CURRENT_ID_PROPERTY = '__currentId__';
var DEFAULT_ID_STRING = 'id__';
// eslint-disable-next-line @typescript-eslint/no-explicit-any
var _global$1 = getWindow() || {};
if (_global$1[CURRENT_ID_PROPERTY] === undefined) {
    _global$1[CURRENT_ID_PROPERTY] = 0;
}
var _initializedStylesheetResets$1 = false;
/**
 * Generates a unique id in the global scope (this spans across duplicate copies of the same library.)
 *
 * @public
 */
function getId(prefix) {
    if (!_initializedStylesheetResets$1) {
        // Configure ids to reset on stylesheet resets.
        var stylesheet = Stylesheet.getInstance();
        if (stylesheet && stylesheet.onReset) {
            stylesheet.onReset(resetIds);
        }
        _initializedStylesheetResets$1 = true;
    }
    var index = _global$1[CURRENT_ID_PROPERTY]++;
    return (prefix || DEFAULT_ID_STRING) + index;
}
/**
 * Resets id counter to an (optional) number.
 *
 * @public
 */
function resetIds(counter) {
    if (counter === void 0) { counter = 0; }
    _global$1[CURRENT_ID_PROPERTY] = counter;
}

var toObjectMap = function () {
    var items = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        items[_i] = arguments[_i];
    }
    var result = {};
    for (var _a = 0, items_1 = items; _a < items_1.length; _a++) {
        var item = items_1[_a];
        var keys = Array.isArray(item) ? item : Object.keys(item);
        for (var _b = 0, keys_1 = keys; _b < keys_1.length; _b++) {
            var key = keys_1[_b];
            result[key] = 1;
        }
    }
    return result;
};
/**
 * An array of events that are allowed on every html element type.
 *
 * @public
 */
var baseElementEvents = toObjectMap([
    'onCopy',
    'onCut',
    'onPaste',
    'onCompositionEnd',
    'onCompositionStart',
    'onCompositionUpdate',
    'onFocus',
    'onFocusCapture',
    'onBlur',
    'onBlurCapture',
    'onChange',
    'onInput',
    'onSubmit',
    'onLoad',
    'onError',
    'onKeyDown',
    'onKeyDownCapture',
    'onKeyPress',
    'onKeyUp',
    'onAbort',
    'onCanPlay',
    'onCanPlayThrough',
    'onDurationChange',
    'onEmptied',
    'onEncrypted',
    'onEnded',
    'onLoadedData',
    'onLoadedMetadata',
    'onLoadStart',
    'onPause',
    'onPlay',
    'onPlaying',
    'onProgress',
    'onRateChange',
    'onSeeked',
    'onSeeking',
    'onStalled',
    'onSuspend',
    'onTimeUpdate',
    'onVolumeChange',
    'onWaiting',
    'onClick',
    'onClickCapture',
    'onContextMenu',
    'onDoubleClick',
    'onDrag',
    'onDragEnd',
    'onDragEnter',
    'onDragExit',
    'onDragLeave',
    'onDragOver',
    'onDragStart',
    'onDrop',
    'onMouseDown',
    'onMouseDownCapture',
    'onMouseEnter',
    'onMouseLeave',
    'onMouseMove',
    'onMouseOut',
    'onMouseOver',
    'onMouseUp',
    'onMouseUpCapture',
    'onSelect',
    'onTouchCancel',
    'onTouchEnd',
    'onTouchMove',
    'onTouchStart',
    'onScroll',
    'onWheel',
    'onPointerCancel',
    'onPointerDown',
    'onPointerEnter',
    'onPointerLeave',
    'onPointerMove',
    'onPointerOut',
    'onPointerOver',
    'onPointerUp',
    'onGotPointerCapture',
    'onLostPointerCapture',
]);
/**
 * An array of element attributes which are allowed on every html element type.
 *
 * @public
 */
var baseElementProperties = toObjectMap([
    'accessKey',
    'children',
    'className',
    'contentEditable',
    'dir',
    'draggable',
    'hidden',
    'htmlFor',
    'id',
    'lang',
    'ref',
    'role',
    'style',
    'tabIndex',
    'title',
    'translate',
    'spellCheck',
    'name',
]);
/**
 * An array of HTML element properties and events.
 *
 * @public
 */
var htmlElementProperties = toObjectMap(baseElementProperties, baseElementEvents);
/**
 * An array of LABEL tag properties and events.
 *
 * @public
 */
var labelProperties = toObjectMap(htmlElementProperties, [
    'form',
]);
/**
 * An array of AUDIO tag properties and events.

 * @public
 */
var audioProperties = toObjectMap(htmlElementProperties, [
    'height',
    'loop',
    'muted',
    'preload',
    'src',
    'width',
]);
/**
 * An array of VIDEO tag properties and events.
 *
 * @public
 */
var videoProperties = toObjectMap(audioProperties, [
    'poster',
]);
/**
 * An array of OL tag properties and events.
 *
 * @public
 */
var olProperties = toObjectMap(htmlElementProperties, [
    'start',
]);
/**
 * An array of LI tag properties and events.
 *
 * @public
 */
var liProperties = toObjectMap(htmlElementProperties, [
    'value',
]);
/**
 * An array of A tag properties and events.
 *
 * @public
 */
var anchorProperties = toObjectMap(htmlElementProperties, [
    'download',
    'href',
    'hrefLang',
    'media',
    'rel',
    'target',
    'type',
]);
/**
 * An array of BUTTON tag properties and events.
 *
 * @public
 */
var buttonProperties = toObjectMap(htmlElementProperties, [
    'autoFocus',
    'disabled',
    'form',
    'formAction',
    'formEncType',
    'formMethod',
    'formNoValidate',
    'formTarget',
    'type',
    'value',
]);
/**
 * An array of INPUT tag properties and events.
 *
 * @public
 */
var inputProperties = toObjectMap(buttonProperties, [
    'accept',
    'alt',
    'autoCapitalize',
    'autoComplete',
    'checked',
    'dirname',
    'form',
    'height',
    'inputMode',
    'list',
    'max',
    'maxLength',
    'min',
    'multiple',
    'pattern',
    'placeholder',
    'readOnly',
    'required',
    'src',
    'step',
    'size',
    'type',
    'value',
    'width',
]);
/**
 * An array of TEXTAREA tag properties and events.
 *
 * @public
 */
var textAreaProperties = toObjectMap(buttonProperties, [
    'autoCapitalize',
    'cols',
    'dirname',
    'form',
    'maxLength',
    'placeholder',
    'readOnly',
    'required',
    'rows',
    'wrap',
]);
/**
 * An array of SELECT tag properties and events.
 *
 * @public
 */
var selectProperties = toObjectMap(buttonProperties, [
    'form',
    'multiple',
    'required',
]);
var optionProperties = toObjectMap(htmlElementProperties, [
    'selected',
    'value',
]);
/**
 * An array of TABLE tag properties and events.
 *
 * @public
 */
var tableProperties = toObjectMap(htmlElementProperties, [
    'cellPadding',
    'cellSpacing',
]);
/**
 * An array of TH tag properties and events.
 *
 * @public
 */
var thProperties = toObjectMap(htmlElementProperties, [
    'rowSpan',
    'scope',
]);
/**
 * An array of TD tag properties and events.
 *
 * @public
 */
var tdProperties = toObjectMap(htmlElementProperties, [
    'colSpan',
    'headers',
    'rowSpan',
    'scope',
]);
var colGroupProperties = toObjectMap(htmlElementProperties, [
    'span',
]);
var colProperties = toObjectMap(htmlElementProperties, [
    'span',
]);
/**
 * An array of FORM tag properties and events.
 *
 * @public
 */
var formProperties = toObjectMap(htmlElementProperties, [
    'acceptCharset',
    'action',
    'encType',
    'encType',
    'method',
    'noValidate',
    'target',
]);
/**
 * An array of IFRAME tag properties and events.
 *
 * @public
 */
var iframeProperties = toObjectMap(htmlElementProperties, [
    'allow',
    'allowFullScreen',
    'allowPaymentRequest',
    'allowTransparency',
    'csp',
    'height',
    'importance',
    'referrerPolicy',
    'sandbox',
    'src',
    'srcDoc',
    'width',
]);
/**
 * An array of IMAGE tag properties and events.
 *
 * @public
 */
var imgProperties = toObjectMap(htmlElementProperties, [
    'alt',
    'crossOrigin',
    'height',
    'src',
    'srcSet',
    'useMap',
    'width',
]);
/**
 * An array of DIV tag properties and events.
 *
 * @public
 */
var divProperties = htmlElementProperties;
/**
 * Gets native supported props for an html element provided the allowance set. Use one of the property
 * sets defined (divProperties, buttonPropertes, etc) to filter out supported properties from a given
 * props set. Note that all data- and aria- prefixed attributes will be allowed.
 * NOTE: getNativeProps should always be applied first when adding props to a react component. The
 * non-native props should be applied second. This will prevent getNativeProps from overriding your custom props.
 * For example, if props passed to getNativeProps has an onClick function and getNativeProps is added to
 * the component after an onClick function is added, then the getNativeProps onClick will override it.
 *
 * @public
 * @param props - The unfiltered input props
 * @param allowedPropsNames - The array or record of allowed prop names.
 * @returns The filtered props
 */
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function getNativeProps(
// eslint-disable-next-line @typescript-eslint/no-explicit-any
props, allowedPropNames, excludedPropNames) {
    // It'd be great to properly type this while allowing 'aria-` and 'data-' attributes like TypeScript does for
    // JSX attributes, but that ability is hardcoded into the TS compiler with no analog in TypeScript typings.
    // Then we'd be able to enforce props extends native props (including aria- and data- attributes), and then
    // return native props.
    // We should be able to do this once this PR is merged: https://github.com/microsoft/TypeScript/pull/26797
    var _a;
    var isArray = Array.isArray(allowedPropNames);
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    var result = {};
    var keys = Object.keys(props);
    for (var _i = 0, keys_2 = keys; _i < keys_2.length; _i++) {
        var key = keys_2[_i];
        var isNativeProp = (!isArray && allowedPropNames[key]) ||
            (isArray && allowedPropNames.indexOf(key) >= 0) ||
            key.indexOf('data-') === 0 ||
            key.indexOf('aria-') === 0;
        if (isNativeProp && (!excludedPropNames || ((_a = excludedPropNames) === null || _a === void 0 ? void 0 : _a.indexOf(key)) === -1)) {
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            result[key] = props[key];
        }
    }
    return result;
}

var REACT_LIFECYCLE_EXCLUSIONS = [
    'setState',
    'render',
    'componentWillMount',
    'UNSAFE_componentWillMount',
    'componentDidMount',
    'componentWillReceiveProps',
    'UNSAFE_componentWillReceiveProps',
    'shouldComponentUpdate',
    'componentWillUpdate',
    'getSnapshotBeforeUpdate',
    'UNSAFE_componentWillUpdate',
    'componentDidUpdate',
    'componentWillUnmount',
];
/**
 * Allows you to hoist methods, except those in an exclusion set from a source object into a destination object.
 *
 * @public
 * @param destination - The instance of the object to hoist the methods onto.
 * @param source - The instance of the object where the methods are hoisted from.
 * @param exclusions - (Optional) What methods to exclude from being hoisted.
 * @returns An array of names of methods that were hoisted.
 */
function hoistMethods(
// eslint-disable-next-line @typescript-eslint/no-explicit-any
destination, 
// eslint-disable-next-line @typescript-eslint/no-explicit-any
source, exclusions) {
    if (exclusions === void 0) { exclusions = REACT_LIFECYCLE_EXCLUSIONS; }
    var hoisted = [];
    var _loop_1 = function (methodName) {
        if (typeof source[methodName] === 'function' &&
            destination[methodName] === undefined &&
            (!exclusions || exclusions.indexOf(methodName) === -1)) {
            hoisted.push(methodName);
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            destination[methodName] = function () {
                var args = [];
                for (var _i = 0; _i < arguments.length; _i++) {
                    args[_i] = arguments[_i];
                }
                source[methodName].apply(source, args);
            };
        }
    };
    for (var methodName in source) {
        _loop_1(methodName);
    }
    return hoisted;
}
/**
 * Provides a method for convenience to unhoist hoisted methods.
 *
 * @public
 * @param source - The source object upon which methods were hoisted.
 * @param methodNames - An array of method names to unhoist.
 */
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function unhoistMethods(source, methodNames) {
    methodNames.forEach(function (methodName) { return delete source[methodName]; });
}

/**
 * Helper to manage componentRef resolution. Internally appends logic to
 * lifetime methods to resolve componentRef to the passed in object.
 *
 * Usage: call initializeComponentRef(this) in the constructor,
 */
function initializeComponentRef(obj) {
    extendComponent(obj, {
        componentDidMount: _onMount,
        componentDidUpdate: _onUpdate,
        componentWillUnmount: _onUnmount,
    });
}
function _onMount() {
    _setComponentRef(this.props.componentRef, this);
}
function _onUpdate(prevProps) {
    if (prevProps.componentRef !== this.props.componentRef) {
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        _setComponentRef(prevProps.componentRef, null);
        _setComponentRef(this.props.componentRef, this);
    }
}
function _onUnmount() {
    _setComponentRef(this.props.componentRef, null);
}
function _setComponentRef(componentRef, value) {
    if (componentRef) {
        if (typeof componentRef === 'object') {
            componentRef.current = value;
        }
        else if (typeof componentRef === 'function') {
            componentRef(value);
        }
    }
}

var _a$1;
var DirectionalKeyCodes = (_a$1 = {},
    _a$1[KeyCodes.up] = 1,
    _a$1[KeyCodes.down] = 1,
    _a$1[KeyCodes.left] = 1,
    _a$1[KeyCodes.right] = 1,
    _a$1[KeyCodes.home] = 1,
    _a$1[KeyCodes.end] = 1,
    _a$1[KeyCodes.tab] = 1,
    _a$1[KeyCodes.pageUp] = 1,
    _a$1[KeyCodes.pageDown] = 1,
    _a$1);
/**
 * Returns true if the keycode is a directional keyboard key.
 */
function isDirectionalKeyCode(which) {
    return !!DirectionalKeyCodes[which];
}

var IsFocusVisibleClassName = 'ms-Fabric--isFocusVisible';
var IsFocusHiddenClassName = 'ms-Fabric--isFocusHidden';
/**
 * Sets the visibility of focus styling.
 *
 * By default, focus styles (the box surrounding a focused Button, for example) only show up when navigational
 * keypresses occur (through Tab, arrows, PgUp/PgDn, Home and End), and are hidden when mouse interactions occur.
 * This API provides an imperative way to turn them on/off.
 *
 * A use case might be when you have a keypress like ctrl-f6 navigate to a particular region on the page,
 * and want focus to show up.
 *
 * @param enabled - whether to remove or add focus
 * @param target - optional target
 */
function setFocusVisibility(enabled, target) {
    var win = target ? getWindow(target) : getWindow();
    if (win) {
        var classList = win.document.body.classList;
        classList.add(enabled ? IsFocusVisibleClassName : IsFocusHiddenClassName);
        classList.remove(enabled ? IsFocusHiddenClassName : IsFocusVisibleClassName);
    }
}

/**
 * Counter for mounted component that uses focus rectangle.
 * We want to cleanup the listners before last component that uses focus rectangle unmounts.
 */
var mountCounters = new WeakMap();
function setMountCounters(key, delta) {
    var newValue;
    var currValue = mountCounters.get(key);
    if (currValue) {
        newValue = currValue + delta;
    }
    else {
        newValue = 1;
    }
    mountCounters.set(key, newValue);
    return newValue;
}
/**
 * Initializes the logic which:
 *
 * 1. Subscribes keydown and mousedown events. (It will only do it once per window,
 *    so it's safe to call this method multiple times.)
 * 2. When the user presses directional keyboard keys, adds the 'ms-Fabric--isFocusVisible' classname
 *    to the document body, removes the 'ms-Fabric-isFocusHidden' classname.
 * 3. When the user clicks a mouse button, adds the 'ms-Fabric-isFocusHidden' classname to the
 *    document body, removes the 'ms-Fabric--isFocusVisible' classname.
 *
 * This logic allows components on the page to conditionally render focus treatments based on
 * the existence of global classnames, which simplifies logic overall.
 *
 * @param rootRef - A Ref object. Focus rectangle can be applied on itself and all its children.
 */
function useFocusRects(rootRef) {
    useEffect(function () {
        var _a, _b;
        var win = getWindow((_a = rootRef) === null || _a === void 0 ? void 0 : _a.current);
        if (!win || ((_b = win.FabricConfig) === null || _b === void 0 ? void 0 : _b.disableFocusRects) === true) {
            return undefined;
        }
        var count = setMountCounters(win, 1);
        if (count <= 1) {
            win.addEventListener('mousedown', _onMouseDown, true);
            win.addEventListener('pointerdown', _onPointerDown, true);
            win.addEventListener('keydown', _onKeyDown, true);
        }
        return function () {
            var _a;
            if (!win || ((_a = win.FabricConfig) === null || _a === void 0 ? void 0 : _a.disableFocusRects) === true) {
                return;
            }
            count = setMountCounters(win, -1);
            if (count === 0) {
                win.removeEventListener('mousedown', _onMouseDown, true);
                win.removeEventListener('pointerdown', _onPointerDown, true);
                win.removeEventListener('keydown', _onKeyDown, true);
            }
        };
    }, [rootRef]);
}
/**
 * Function Component wrapper which enables calling `useFocusRects` hook.
 * Renders nothing.
 */
var FocusRects = function (props) {
    useFocusRects(props.rootRef);
    return null;
};
function _onMouseDown(ev) {
    setFocusVisibility(false, ev.target);
}
function _onPointerDown(ev) {
    if (ev.pointerType !== 'mouse') {
        setFocusVisibility(false, ev.target);
    }
}
function _onKeyDown(ev) {
    // eslint-disable-next-line deprecation/deprecation
    if (isDirectionalKeyCode(ev.which)) {
        setFocusVisibility(true, ev.target);
    }
}

/**
 * Fetches an item from local storage without throwing an exception
 * @param key The key of the item to fetch from local storage
 */
function getItem$1(key) {
    var result = null;
    try {
        var win = getWindow();
        result = win ? win.localStorage.getItem(key) : null;
    }
    catch (e) {
        /* Eat the exception */
    }
    return result;
}

// Default to undefined so that we initialize on first read.
var _language;
/**
 * Gets the rtl state of the page (returns true if in rtl.)
 *
 * @public
 */
function getLanguage() {
    if (_language === undefined) {
        var doc = getDocument();
        var savedLanguage = getItem$1('language');
        if (savedLanguage !== null) {
            _language = savedLanguage;
        }
        if (_language === undefined && doc) {
            _language = doc.documentElement.getAttribute('lang');
        }
        if (_language === undefined) {
            _language = 'en';
        }
    }
    return _language;
}

/**
 * Simple deep merge function. Takes all arguments and returns a deep copy of the objects merged
 * together in the order provided. If an object creates a circular reference, it will assign the
 * original reference.
 */
function merge(target) {
    var args = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        args[_i - 1] = arguments[_i];
    }
    for (var _a = 0, args_1 = args; _a < args_1.length; _a++) {
        var arg = args_1[_a];
        _merge(target || {}, arg);
    }
    return target;
}
/**
 * The _merge helper iterates through all props on source and assigns them to target.
 * When the value is an object, we will create a deep clone of the object. However if
 * there is a circular reference, the value will not be deep cloned and will persist
 * the reference.
 */
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function _merge(target, source, circularReferences) {
    if (circularReferences === void 0) { circularReferences = []; }
    circularReferences.push(source);
    for (var name_1 in source) {
        if (source.hasOwnProperty(name_1)) {
            if (name_1 !== '__proto__' && name_1 !== 'constructor' && name_1 !== 'prototype') {
                var value = source[name_1];
                if (typeof value === 'object' && value !== null) {
                    var isCircularReference = circularReferences.indexOf(value) > -1;
                    target[name_1] = (isCircularReference
                        ? value
                        : _merge(target[name_1] || {}, value, circularReferences));
                }
                else {
                    target[name_1] = value;
                }
            }
        }
    }
    circularReferences.pop();
    return target;
}

/**
 * Returns true if and only if the user is on a iOS device.
 * Used to determine whether iOS-specific behavior should be applied.
 */
var isIOS = function () {
    if (!window || !window.navigator || !window.navigator.userAgent) {
        return false;
    }
    return /iPad|iPhone|iPod/i.test(window.navigator.userAgent);
};

var isMacResult;
/**
 * Returns true if the user is on a Mac. Caches the result value.
 * @param reset - Reset the cached result value (mainly for testing).
 */
function isMac(reset) {
    if (typeof isMacResult === 'undefined' || reset) {
        var win = getWindow();
        var userAgent = win && win.navigator.userAgent;
        isMacResult = !!userAgent && userAgent.indexOf('Macintosh') !== -1;
    }
    return !!isMacResult;
}

var DefaultFields = ['theme', 'styles'];
function styled(Component, baseStyles, getProps, customizable, pure) {
    customizable = customizable || { scope: '', fields: undefined };
    var scope = customizable.scope, _a = customizable.fields, fields = _a === void 0 ? DefaultFields : _a;
    var Wrapped = forwardRef(function (props, forwardedRef) {
        var styles = useRef();
        var settings = useCustomizationSettings(fields, scope);
        var customizedStyles = settings.styles, dir = settings.dir, rest = __rest(settings, ["styles", "dir"]);
        var additionalProps = getProps ? getProps(props) : undefined;
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        var cache = (styles.current && styles.current.__cachedInputs__) || [];
        if (!styles.current || customizedStyles !== cache[1] || props.styles !== cache[2]) {
            // Using styled components as the Component arg will result in nested styling arrays.
            var concatenatedStyles = function (styleProps) {
                return concatStyleSetsWithProps(styleProps, baseStyles, customizedStyles, props.styles);
            };
            // The __cachedInputs__ array is attached to the function and consumed by the
            // classNamesFunction as a list of keys to include for memoizing classnames.
            concatenatedStyles.__cachedInputs__ = [
                baseStyles,
                customizedStyles,
                props.styles,
            ];
            concatenatedStyles.__noStyleOverride__ =
                !customizedStyles && !props.styles;
            styles.current = concatenatedStyles;
        }
        return createElement(Component, __assign({ ref: forwardedRef }, rest, additionalProps, props, { styles: styles.current }));
    });
    // Function.prototype.name is an ES6 feature, so the cast to any is required until we're
    // able to drop IE 11 support and compile with ES6 libs
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    Wrapped.displayName = "Styled" + (Component.displayName || Component.name);
    // This preserves backwards compatibility.
    return pure ? memo(Wrapped) : Wrapped;
}

/**
 * @deprecated Icon type is inferred based on presence of `IIconProps.imageProps`
 * {@docCategory Icon}
 */
var IconType;
(function (IconType) {
    /**
     * Render using the fabric icon font.
     * @deprecated Icon type is inferred based on presence of `IIconProps.imageProps`
     */
    IconType[IconType["default"] = 0] = "default";
    /**
     * Render using an image, where imageProps would be used.
     * @deprecated Icon type is inferred based on presence of `IIconProps.imageProps`
     */
    IconType[IconType["image"] = 1] = "image";
    /**
     * Deprecated, use `default`.
     * @deprecated Use `default`.
     */
    IconType[IconType["Default"] = 100000] = "Default";
    /**
     * Deprecated, use `image`.
     * @deprecated Use `image`.
     */
    IconType[IconType["Image"] = 100001] = "Image";
})(IconType || (IconType = {}));

/**
 * The possible methods that can be used to fit the image.
 * {@docCategory Image}
 */
var ImageFit;
(function (ImageFit) {
    /**
     * The image is not scaled. The image is centered and cropped within the content box.
     */
    ImageFit[ImageFit["center"] = 0] = "center";
    /**
     * The image is scaled to maintain its aspect ratio while being fully contained within the frame. The image will
     * be centered horizontally and vertically within the frame. The space in the top and bottom or in the sides of
     * the frame will be empty depending on the difference in aspect ratio between the image and the frame.
     */
    ImageFit[ImageFit["contain"] = 1] = "contain";
    /**
     * The image is scaled to maintain its aspect ratio while filling the frame. Portions of the image will be cropped
     * from the top and bottom, or the sides, depending on the difference in aspect ratio between the image and the frame.
     */
    ImageFit[ImageFit["cover"] = 2] = "cover";
    /**
     * Neither the image nor the frame are scaled. If their sizes do not match, the image will either be cropped or the
     * frame will have empty space.
     */
    ImageFit[ImageFit["none"] = 3] = "none";
    /**
     * The image will be centered horizontally and vertically within the frame and maintains its aspect ratio. It will
     * behave as ImageFit.center if the image's natural height or width is less than the Image frame's height or width,
     * but if both natural height and width are larger than the frame it will behave as ImageFit.cover.
     */
    ImageFit[ImageFit["centerCover"] = 4] = "centerCover";
    /**
     * The image will be centered horizontally and vertically within the frame and maintains its aspect ratio. It will
     * behave as ImageFit.center if the image's natural height and width is less than the Image frame's height and width,
     * but if either natural height or width are larger than the frame it will behave as ImageFit.contain.
     */
    ImageFit[ImageFit["centerContain"] = 5] = "centerContain";
})(ImageFit || (ImageFit = {}));
/**
 * The cover style to be used on the image
 * {@docCategory Image}
 */
var ImageCoverStyle;
(function (ImageCoverStyle) {
    /**
     * The image will be shown at 100% height of container and the width will be scaled accordingly
     */
    ImageCoverStyle[ImageCoverStyle["landscape"] = 0] = "landscape";
    /**
     * The image will be shown at 100% width of container and the height will be scaled accordingly
     */
    ImageCoverStyle[ImageCoverStyle["portrait"] = 1] = "portrait";
})(ImageCoverStyle || (ImageCoverStyle = {}));
/**
 * {@docCategory Image}
 */
var ImageLoadState;
(function (ImageLoadState) {
    /**
     * The image has not yet been loaded, and there is no error yet.
     */
    ImageLoadState[ImageLoadState["notLoaded"] = 0] = "notLoaded";
    /**
     * The image has been loaded successfully.
     */
    ImageLoadState[ImageLoadState["loaded"] = 1] = "loaded";
    /**
     * An error has been encountered while loading the image.
     */
    ImageLoadState[ImageLoadState["error"] = 2] = "error";
    /**
     * Deprecated at v1.3.6, to replace the src in case of errors, use `onLoadingStateChange` instead
     * and rerender the Image with a difference src.
     * @deprecated Use `onLoadingStateChange` instead
     * and rerender the Image with a difference src.
     */
    ImageLoadState[ImageLoadState["errorLoaded"] = 3] = "errorLoaded";
})(ImageLoadState || (ImageLoadState = {}));

var getClassNames = classNamesFunction();
var KEY_PREFIX = 'fabricImage';
var ImageBase = /** @class */ (function (_super) {
    __extends(ImageBase, _super);
    function ImageBase(props) {
        var _this = _super.call(this, props) || this;
        // Make an initial assumption about the image layout until we can
        // check the rendered element. The value here only takes effect when
        // shouldStartVisible is true.
        _this._coverStyle = ImageCoverStyle.portrait;
        _this._imageElement = createRef();
        _this._frameElement = createRef();
        _this._onImageLoaded = function (ev) {
            var _a = _this.props, src = _a.src, onLoad = _a.onLoad;
            if (onLoad) {
                onLoad(ev);
            }
            _this._computeCoverStyle(_this.props);
            if (src) {
                _this.setState({
                    loadState: ImageLoadState.loaded,
                });
            }
        };
        _this._onImageError = function (ev) {
            if (_this.props.onError) {
                _this.props.onError(ev);
            }
            _this.setState({
                loadState: ImageLoadState.error,
            });
        };
        _this.state = {
            loadState: ImageLoadState.notLoaded,
        };
        return _this;
    }
    ImageBase.prototype.UNSAFE_componentWillReceiveProps = function (nextProps) {
        if (nextProps.src !== this.props.src) {
            this.setState({
                loadState: ImageLoadState.notLoaded,
            });
        }
        else if (this.state.loadState === ImageLoadState.loaded) {
            this._computeCoverStyle(nextProps);
        }
    };
    ImageBase.prototype.componentDidUpdate = function (prevProps, prevState) {
        this._checkImageLoaded();
        if (this.props.onLoadingStateChange && prevState.loadState !== this.state.loadState) {
            this.props.onLoadingStateChange(this.state.loadState);
        }
    };
    ImageBase.prototype.render = function () {
        var imageProps = getNativeProps(this.props, imgProperties, [
            'width',
            'height',
        ]);
        var _a = this.props, src = _a.src, alt = _a.alt, width = _a.width, height = _a.height, shouldFadeIn = _a.shouldFadeIn, shouldStartVisible = _a.shouldStartVisible, className = _a.className, imageFit = _a.imageFit, role = _a.role, maximizeFrame = _a.maximizeFrame, styles = _a.styles, theme = _a.theme;
        var loadState = this.state.loadState;
        var coverStyle = this.props.coverStyle !== undefined ? this.props.coverStyle : this._coverStyle;
        var classNames = getClassNames(styles, {
            theme: theme,
            className: className,
            width: width,
            height: height,
            maximizeFrame: maximizeFrame,
            shouldFadeIn: shouldFadeIn,
            shouldStartVisible: shouldStartVisible,
            isLoaded: loadState === ImageLoadState.loaded ||
                (loadState === ImageLoadState.notLoaded && this.props.shouldStartVisible),
            isLandscape: coverStyle === ImageCoverStyle.landscape,
            isCenter: imageFit === ImageFit.center,
            isCenterContain: imageFit === ImageFit.centerContain,
            isCenterCover: imageFit === ImageFit.centerCover,
            isContain: imageFit === ImageFit.contain,
            isCover: imageFit === ImageFit.cover,
            isNone: imageFit === ImageFit.none,
            isError: loadState === ImageLoadState.error,
            isNotImageFit: imageFit === undefined,
        });
        // If image dimensions aren't specified, the natural size of the image is used.
        return (createElement("div", { className: classNames.root, style: { width: width, height: height }, ref: this._frameElement },
            createElement("img", __assign({}, imageProps, { onLoad: this._onImageLoaded, onError: this._onImageError, key: KEY_PREFIX + this.props.src || '', className: classNames.image, ref: this._imageElement, src: src, alt: alt, role: role }))));
    };
    ImageBase.prototype._checkImageLoaded = function () {
        var src = this.props.src;
        var loadState = this.state.loadState;
        if (loadState === ImageLoadState.notLoaded) {
            // testing if naturalWidth and naturalHeight are greater than zero is better than checking
            // .complete, because .complete will also be set to true if the image breaks. However,
            // for some browsers, SVG images do not have a naturalWidth or naturalHeight, so fall back
            // to checking .complete for these images.
            var isLoaded = this._imageElement.current
                ? (src && this._imageElement.current.naturalWidth > 0 && this._imageElement.current.naturalHeight > 0) ||
                    (this._imageElement.current.complete && ImageBase._svgRegex.test(src))
                : false;
            if (isLoaded) {
                this._computeCoverStyle(this.props);
                this.setState({
                    loadState: ImageLoadState.loaded,
                });
            }
        }
    };
    ImageBase.prototype._computeCoverStyle = function (props) {
        var imageFit = props.imageFit, width = props.width, height = props.height;
        // Do not compute cover style if it was already specified in props
        if ((imageFit === ImageFit.cover ||
            imageFit === ImageFit.contain ||
            imageFit === ImageFit.centerContain ||
            imageFit === ImageFit.centerCover) &&
            this.props.coverStyle === undefined &&
            this._imageElement.current &&
            this._frameElement.current) {
            // Determine the desired ratio using the width and height props.
            // If those props aren't available, measure measure the frame.
            var desiredRatio = void 0;
            if (typeof width === 'number' &&
                typeof height === 'number' &&
                imageFit !== ImageFit.centerContain &&
                imageFit !== ImageFit.centerCover) {
                desiredRatio = width / height;
            }
            else {
                desiredRatio = this._frameElement.current.clientWidth / this._frameElement.current.clientHeight;
            }
            // Examine the source image to determine its original ratio.
            var naturalRatio = this._imageElement.current.naturalWidth / this._imageElement.current.naturalHeight;
            // Should we crop from the top or the sides?
            if (naturalRatio > desiredRatio) {
                this._coverStyle = ImageCoverStyle.landscape;
            }
            else {
                this._coverStyle = ImageCoverStyle.portrait;
            }
        }
    };
    ImageBase.defaultProps = {
        shouldFadeIn: true,
    };
    ImageBase._svgRegex = /\.svg$/i;
    return ImageBase;
}(Component));

/**
 * Builds a class names object from a given map.
 *
 * @param styles - Map of unprocessed styles.
 * @returns Map of property name to class name.
 */
function buildClassMap(styles) {
    var classes = {};
    var _loop_1 = function (styleName) {
        if (styles.hasOwnProperty(styleName)) {
            var className_1;
            Object.defineProperty(classes, styleName, {
                get: function () {
                    if (className_1 === undefined) {
                        // eslint-disable-next-line @typescript-eslint/no-explicit-any
                        className_1 = mergeStyles(styles[styleName]).toString();
                    }
                    return className_1;
                },
                enumerable: true,
                configurable: true,
            });
        }
    };
    for (var styleName in styles) {
        _loop_1(styleName);
    }
    return classes;
}

/* Register the keyframes */
var EASING_FUNCTION_1 = 'cubic-bezier(.1,.9,.2,1)';
var EASING_FUNCTION_2 = 'cubic-bezier(.1,.25,.75,.9)';
var DURATION_1 = '0.167s';
var DURATION_2 = '0.267s';
var DURATION_3 = '0.367s';
var DURATION_4 = '0.467s';
var FADE_IN = keyframes({
    from: { opacity: 0 },
    to: { opacity: 1 },
});
var FADE_OUT = keyframes({
    from: { opacity: 1 },
    to: { opacity: 0, visibility: 'hidden' },
});
var SLIDE_RIGHT_IN10 = _createSlideInX(-10);
var SLIDE_RIGHT_IN20 = _createSlideInX(-20);
var SLIDE_RIGHT_IN40 = _createSlideInX(-40);
var SLIDE_RIGHT_IN400 = _createSlideInX(-400);
var SLIDE_LEFT_IN10 = _createSlideInX(10);
var SLIDE_LEFT_IN20 = _createSlideInX(20);
var SLIDE_LEFT_IN40 = _createSlideInX(40);
var SLIDE_LEFT_IN400 = _createSlideInX(400);
var SLIDE_UP_IN10 = _createSlideInY(10);
var SLIDE_UP_IN20 = _createSlideInY(20);
var SLIDE_DOWN_IN10 = _createSlideInY(-10);
var SLIDE_DOWN_IN20 = _createSlideInY(-20);
var SLIDE_RIGHT_OUT10 = _createSlideOutX(10);
var SLIDE_RIGHT_OUT20 = _createSlideOutX(20);
var SLIDE_RIGHT_OUT40 = _createSlideOutX(40);
var SLIDE_RIGHT_OUT400 = _createSlideOutX(400);
var SLIDE_LEFT_OUT10 = _createSlideOutX(-10);
var SLIDE_LEFT_OUT20 = _createSlideOutX(-20);
var SLIDE_LEFT_OUT40 = _createSlideOutX(-40);
var SLIDE_LEFT_OUT400 = _createSlideOutX(-400);
var SLIDE_UP_OUT10 = _createSlideOutY(-10);
var SLIDE_UP_OUT20 = _createSlideOutY(-20);
var SLIDE_DOWN_OUT10 = _createSlideOutY(10);
var SLIDE_DOWN_OUT20 = _createSlideOutY(20);
var SCALE_UP100 = keyframes({
    from: { transform: 'scale3d(.98,.98,1)' },
    to: { transform: 'scale3d(1,1,1)' },
});
var SCALE_DOWN98 = keyframes({
    from: { transform: 'scale3d(1,1,1)' },
    to: { transform: 'scale3d(.98,.98,1)' },
});
var SCALE_DOWN100 = keyframes({
    from: { transform: 'scale3d(1.03,1.03,1)' },
    to: { transform: 'scale3d(1,1,1)' },
});
var SCALE_UP103 = keyframes({
    from: { transform: 'scale3d(1,1,1)' },
    to: { transform: 'scale3d(1.03,1.03,1)' },
});
var ROTATE90 = keyframes({
    from: { transform: 'rotateZ(0deg)' },
    to: { transform: 'rotateZ(90deg)' },
});
var ROTATE_N90 = keyframes({
    from: { transform: 'rotateZ(0deg)' },
    to: { transform: 'rotateZ(-90deg)' },
});
/**
 * All Fabric standard animations, exposed as json objects referencing predefined
 * keyframes. These objects can be mixed in with other class definitions.
 */
var AnimationStyles = {
    slideRightIn10: _createAnimation(FADE_IN + "," + SLIDE_RIGHT_IN10, DURATION_3, EASING_FUNCTION_1),
    slideRightIn20: _createAnimation(FADE_IN + "," + SLIDE_RIGHT_IN20, DURATION_3, EASING_FUNCTION_1),
    slideRightIn40: _createAnimation(FADE_IN + "," + SLIDE_RIGHT_IN40, DURATION_3, EASING_FUNCTION_1),
    slideRightIn400: _createAnimation(FADE_IN + "," + SLIDE_RIGHT_IN400, DURATION_3, EASING_FUNCTION_1),
    slideLeftIn10: _createAnimation(FADE_IN + "," + SLIDE_LEFT_IN10, DURATION_3, EASING_FUNCTION_1),
    slideLeftIn20: _createAnimation(FADE_IN + "," + SLIDE_LEFT_IN20, DURATION_3, EASING_FUNCTION_1),
    slideLeftIn40: _createAnimation(FADE_IN + "," + SLIDE_LEFT_IN40, DURATION_3, EASING_FUNCTION_1),
    slideLeftIn400: _createAnimation(FADE_IN + "," + SLIDE_LEFT_IN400, DURATION_3, EASING_FUNCTION_1),
    slideUpIn10: _createAnimation(FADE_IN + "," + SLIDE_UP_IN10, DURATION_3, EASING_FUNCTION_1),
    slideUpIn20: _createAnimation(FADE_IN + "," + SLIDE_UP_IN20, DURATION_3, EASING_FUNCTION_1),
    slideDownIn10: _createAnimation(FADE_IN + "," + SLIDE_DOWN_IN10, DURATION_3, EASING_FUNCTION_1),
    slideDownIn20: _createAnimation(FADE_IN + "," + SLIDE_DOWN_IN20, DURATION_3, EASING_FUNCTION_1),
    slideRightOut10: _createAnimation(FADE_OUT + "," + SLIDE_RIGHT_OUT10, DURATION_3, EASING_FUNCTION_1),
    slideRightOut20: _createAnimation(FADE_OUT + "," + SLIDE_RIGHT_OUT20, DURATION_3, EASING_FUNCTION_1),
    slideRightOut40: _createAnimation(FADE_OUT + "," + SLIDE_RIGHT_OUT40, DURATION_3, EASING_FUNCTION_1),
    slideRightOut400: _createAnimation(FADE_OUT + "," + SLIDE_RIGHT_OUT400, DURATION_3, EASING_FUNCTION_1),
    slideLeftOut10: _createAnimation(FADE_OUT + "," + SLIDE_LEFT_OUT10, DURATION_3, EASING_FUNCTION_1),
    slideLeftOut20: _createAnimation(FADE_OUT + "," + SLIDE_LEFT_OUT20, DURATION_3, EASING_FUNCTION_1),
    slideLeftOut40: _createAnimation(FADE_OUT + "," + SLIDE_LEFT_OUT40, DURATION_3, EASING_FUNCTION_1),
    slideLeftOut400: _createAnimation(FADE_OUT + "," + SLIDE_LEFT_OUT400, DURATION_3, EASING_FUNCTION_1),
    slideUpOut10: _createAnimation(FADE_OUT + "," + SLIDE_UP_OUT10, DURATION_3, EASING_FUNCTION_1),
    slideUpOut20: _createAnimation(FADE_OUT + "," + SLIDE_UP_OUT20, DURATION_3, EASING_FUNCTION_1),
    slideDownOut10: _createAnimation(FADE_OUT + "," + SLIDE_DOWN_OUT10, DURATION_3, EASING_FUNCTION_1),
    slideDownOut20: _createAnimation(FADE_OUT + "," + SLIDE_DOWN_OUT20, DURATION_3, EASING_FUNCTION_1),
    scaleUpIn100: _createAnimation(FADE_IN + "," + SCALE_UP100, DURATION_3, EASING_FUNCTION_1),
    scaleDownIn100: _createAnimation(FADE_IN + "," + SCALE_DOWN100, DURATION_3, EASING_FUNCTION_1),
    scaleUpOut103: _createAnimation(FADE_OUT + "," + SCALE_UP103, DURATION_1, EASING_FUNCTION_2),
    scaleDownOut98: _createAnimation(FADE_OUT + "," + SCALE_DOWN98, DURATION_1, EASING_FUNCTION_2),
    fadeIn100: _createAnimation(FADE_IN, DURATION_1, EASING_FUNCTION_2),
    fadeIn200: _createAnimation(FADE_IN, DURATION_2, EASING_FUNCTION_2),
    fadeIn400: _createAnimation(FADE_IN, DURATION_3, EASING_FUNCTION_2),
    fadeIn500: _createAnimation(FADE_IN, DURATION_4, EASING_FUNCTION_2),
    fadeOut100: _createAnimation(FADE_OUT, DURATION_1, EASING_FUNCTION_2),
    fadeOut200: _createAnimation(FADE_OUT, DURATION_2, EASING_FUNCTION_2),
    fadeOut400: _createAnimation(FADE_OUT, DURATION_3, EASING_FUNCTION_2),
    fadeOut500: _createAnimation(FADE_OUT, DURATION_4, EASING_FUNCTION_2),
    rotate90deg: _createAnimation(ROTATE90, '0.1s', EASING_FUNCTION_2),
    rotateN90deg: _createAnimation(ROTATE_N90, '0.1s', EASING_FUNCTION_2),
};
function _createAnimation(animationName, animationDuration, animationTimingFunction) {
    return {
        animationName: animationName,
        animationDuration: animationDuration,
        animationTimingFunction: animationTimingFunction,
        animationFillMode: 'both',
    };
}
function _createSlideInX(fromX) {
    return keyframes({
        from: { transform: "translate3d(" + fromX + "px,0,0)" },
        to: { transform: "translate3d(0,0,0)" },
    });
}
function _createSlideInY(fromY) {
    return keyframes({
        from: { transform: "translate3d(0," + fromY + "px,0)" },
        to: { transform: "translate3d(0,0,0)" },
    });
}
function _createSlideOutX(toX) {
    return keyframes({
        from: { transform: "translate3d(0,0,0)" },
        to: { transform: "translate3d(" + toX + "px,0,0)" },
    });
}
function _createSlideOutY(toY) {
    return keyframes({
        from: { transform: "translate3d(0,0,0)" },
        to: { transform: "translate3d(0," + toY + "px,0)" },
    });
}

// When adding or removing a color, make sure you keep this consistent with IColorClassNames
// by adding the color variants.
var DefaultPalette = {
    themeDarker: '#004578',
    themeDark: '#005a9e',
    themeDarkAlt: '#106ebe',
    themePrimary: '#0078d4',
    themeSecondary: '#2b88d8',
    themeTertiary: '#71afe5',
    themeLight: '#c7e0f4',
    themeLighter: '#deecf9',
    themeLighterAlt: '#eff6fc',
    black: '#000000',
    blackTranslucent40: 'rgba(0,0,0,.4)',
    neutralDark: '#201f1e',
    neutralPrimary: '#323130',
    neutralPrimaryAlt: '#3b3a39',
    neutralSecondary: '#605e5c',
    neutralSecondaryAlt: '#8a8886',
    neutralTertiary: '#a19f9d',
    neutralTertiaryAlt: '#c8c6c4',
    neutralQuaternary: '#d2d0ce',
    neutralQuaternaryAlt: '#e1dfdd',
    neutralLight: '#edebe9',
    neutralLighter: '#f3f2f1',
    neutralLighterAlt: '#faf9f8',
    accent: '#0078d4',
    white: '#ffffff',
    whiteTranslucent40: 'rgba(255,255,255,.4)',
    yellowDark: '#d29200',
    yellow: '#ffb900',
    yellowLight: '#fff100',
    orange: '#d83b01',
    orangeLight: '#ea4300',
    orangeLighter: '#ff8c00',
    redDark: '#a4262c',
    red: '#e81123',
    magentaDark: '#5c005c',
    magenta: '#b4009e',
    magentaLight: '#e3008c',
    purpleDark: '#32145a',
    purple: '#5c2d91',
    purpleLight: '#b4a0ff',
    blueDark: '#002050',
    blueMid: '#00188f',
    blue: '#0078d4',
    blueLight: '#00bcf2',
    tealDark: '#004b50',
    teal: '#008272',
    tealLight: '#00b294',
    greenDark: '#004b1c',
    green: '#107c10',
    greenLight: '#bad80a',
};

var DefaultEffects = {
    elevation4: '0 1.6px 3.6px 0 rgba(0, 0, 0, 0.132), 0 0.3px 0.9px 0 rgba(0, 0, 0, 0.108)',
    elevation8: '0 3.2px 7.2px 0 rgba(0, 0, 0, 0.132), 0 0.6px 1.8px 0 rgba(0, 0, 0, 0.108)',
    elevation16: '0 6.4px 14.4px 0 rgba(0, 0, 0, 0.132), 0 1.2px 3.6px 0 rgba(0, 0, 0, 0.108)',
    elevation64: '0 25.6px 57.6px 0 rgba(0, 0, 0, 0.22), 0 4.8px 14.4px 0 rgba(0, 0, 0, 0.18)',
    roundedCorner2: '2px',
    roundedCorner4: '4px',
    roundedCorner6: '6px',
};

// Fallback fonts, if specified system or web fonts are unavailable.
var FontFamilyFallbacks = "'Segoe UI', -apple-system, BlinkMacSystemFont, 'Roboto', 'Helvetica Neue', sans-serif";
// Font face names to be registered.
var LocalizedFontNames;
(function (LocalizedFontNames) {
    LocalizedFontNames.Arabic = 'Segoe UI Web (Arabic)';
    LocalizedFontNames.Cyrillic = 'Segoe UI Web (Cyrillic)';
    LocalizedFontNames.EastEuropean = 'Segoe UI Web (East European)';
    LocalizedFontNames.Greek = 'Segoe UI Web (Greek)';
    LocalizedFontNames.Hebrew = 'Segoe UI Web (Hebrew)';
    LocalizedFontNames.Thai = 'Leelawadee UI Web';
    LocalizedFontNames.Vietnamese = 'Segoe UI Web (Vietnamese)';
    LocalizedFontNames.WestEuropean = 'Segoe UI Web (West European)';
    LocalizedFontNames.Selawik = 'Selawik Web';
    LocalizedFontNames.Armenian = 'Segoe UI Web (Armenian)';
    LocalizedFontNames.Georgian = 'Segoe UI Web (Georgian)';
})(LocalizedFontNames || (LocalizedFontNames = {}));
// Font families with fallbacks, for the general regions.
var LocalizedFontFamilies;
(function (LocalizedFontFamilies) {
    LocalizedFontFamilies.Arabic = "'" + LocalizedFontNames.Arabic + "'";
    LocalizedFontFamilies.ChineseSimplified = "'Microsoft Yahei UI', Verdana, Simsun";
    LocalizedFontFamilies.ChineseTraditional = "'Microsoft Jhenghei UI', Pmingliu";
    LocalizedFontFamilies.Cyrillic = "'" + LocalizedFontNames.Cyrillic + "'";
    LocalizedFontFamilies.EastEuropean = "'" + LocalizedFontNames.EastEuropean + "'";
    LocalizedFontFamilies.Greek = "'" + LocalizedFontNames.Greek + "'";
    LocalizedFontFamilies.Hebrew = "'" + LocalizedFontNames.Hebrew + "'";
    LocalizedFontFamilies.Hindi = "'Nirmala UI'";
    LocalizedFontFamilies.Japanese = "'Yu Gothic UI', 'Meiryo UI', Meiryo, 'MS Pgothic', Osaka";
    LocalizedFontFamilies.Korean = "'Malgun Gothic', Gulim";
    LocalizedFontFamilies.Selawik = "'" + LocalizedFontNames.Selawik + "'";
    LocalizedFontFamilies.Thai = "'Leelawadee UI Web', 'Kmer UI'";
    LocalizedFontFamilies.Vietnamese = "'" + LocalizedFontNames.Vietnamese + "'";
    LocalizedFontFamilies.WestEuropean = "'" + LocalizedFontNames.WestEuropean + "'";
    LocalizedFontFamilies.Armenian = "'" + LocalizedFontNames.Armenian + "'";
    LocalizedFontFamilies.Georgian = "'" + LocalizedFontNames.Georgian + "'";
})(LocalizedFontFamilies || (LocalizedFontFamilies = {}));
// By default, we favor system fonts for the default.
// All localized fonts use a web font and never use the system font.
var defaultFontFamily = "'Segoe UI', '" + LocalizedFontNames.WestEuropean + "'";
// Mapping of language prefix to to font family.
var LanguageToFontMap = {
    ar: LocalizedFontFamilies.Arabic,
    bg: LocalizedFontFamilies.Cyrillic,
    cs: LocalizedFontFamilies.EastEuropean,
    el: LocalizedFontFamilies.Greek,
    et: LocalizedFontFamilies.EastEuropean,
    he: LocalizedFontFamilies.Hebrew,
    hi: LocalizedFontFamilies.Hindi,
    hr: LocalizedFontFamilies.EastEuropean,
    hu: LocalizedFontFamilies.EastEuropean,
    ja: LocalizedFontFamilies.Japanese,
    kk: LocalizedFontFamilies.EastEuropean,
    ko: LocalizedFontFamilies.Korean,
    lt: LocalizedFontFamilies.EastEuropean,
    lv: LocalizedFontFamilies.EastEuropean,
    pl: LocalizedFontFamilies.EastEuropean,
    ru: LocalizedFontFamilies.Cyrillic,
    sk: LocalizedFontFamilies.EastEuropean,
    'sr-latn': LocalizedFontFamilies.EastEuropean,
    th: LocalizedFontFamilies.Thai,
    tr: LocalizedFontFamilies.EastEuropean,
    uk: LocalizedFontFamilies.Cyrillic,
    vi: LocalizedFontFamilies.Vietnamese,
    'zh-hans': LocalizedFontFamilies.ChineseSimplified,
    'zh-hant': LocalizedFontFamilies.ChineseTraditional,
    hy: LocalizedFontFamilies.Armenian,
    ka: LocalizedFontFamilies.Georgian,
};
// Standard font sizes.
var FontSizes;
(function (FontSizes) {
    FontSizes.mini = '10px';
    FontSizes.xSmall = '10px';
    FontSizes.small = '12px';
    FontSizes.smallPlus = '12px';
    FontSizes.medium = '14px';
    FontSizes.mediumPlus = '16px';
    FontSizes.icon = '16px';
    FontSizes.large = '18px';
    FontSizes.xLarge = '20px';
    FontSizes.xLargePlus = '24px';
    FontSizes.xxLarge = '28px';
    FontSizes.xxLargePlus = '32px';
    FontSizes.superLarge = '42px';
    FontSizes.mega = '68px';
})(FontSizes || (FontSizes = {}));
// Standard font weights.
var FontWeights;
(function (FontWeights) {
    FontWeights.light = 100;
    FontWeights.semilight = 300;
    FontWeights.regular = 400;
    FontWeights.semibold = 600;
    FontWeights.bold = 700;
})(FontWeights || (FontWeights = {}));
// Standard Icon Sizes.
var IconFontSizes;
(function (IconFontSizes) {
    IconFontSizes.xSmall = '10px';
    IconFontSizes.small = '12px';
    IconFontSizes.medium = '16px';
    IconFontSizes.large = '20px';
})(IconFontSizes || (IconFontSizes = {}));
function _fontFamilyWithFallbacks(fontFamily) {
    return fontFamily + ", " + FontFamilyFallbacks;
}
function createFontStyles(localeCode) {
    var localizedFont = _getLocalizedFontFamily(localeCode);
    var fontFamilyWithFallback = _fontFamilyWithFallbacks(localizedFont);
    var fontStyles = {
        tiny: _createFont(FontSizes.mini, FontWeights.regular, fontFamilyWithFallback),
        xSmall: _createFont(FontSizes.xSmall, FontWeights.regular, fontFamilyWithFallback),
        small: _createFont(FontSizes.small, FontWeights.regular, fontFamilyWithFallback),
        smallPlus: _createFont(FontSizes.smallPlus, FontWeights.regular, fontFamilyWithFallback),
        medium: _createFont(FontSizes.medium, FontWeights.regular, fontFamilyWithFallback),
        mediumPlus: _createFont(FontSizes.mediumPlus, FontWeights.regular, fontFamilyWithFallback),
        large: _createFont(FontSizes.large, FontWeights.regular, fontFamilyWithFallback),
        xLarge: _createFont(FontSizes.xLarge, FontWeights.semibold, fontFamilyWithFallback),
        xLargePlus: _createFont(FontSizes.xLargePlus, FontWeights.semibold, fontFamilyWithFallback),
        xxLarge: _createFont(FontSizes.xxLarge, FontWeights.semibold, fontFamilyWithFallback),
        xxLargePlus: _createFont(FontSizes.xxLargePlus, FontWeights.semibold, fontFamilyWithFallback),
        superLarge: _createFont(FontSizes.superLarge, FontWeights.semibold, fontFamilyWithFallback),
        mega: _createFont(FontSizes.mega, FontWeights.semibold, fontFamilyWithFallback),
    };
    return fontStyles;
}
/**
 * If there is a localized font for this language, return that.
 * Returns undefined if there is no localized font for that language.
 */
function _getLocalizedFontFamily(language) {
    for (var lang in LanguageToFontMap) {
        if (LanguageToFontMap.hasOwnProperty(lang) && language && lang.indexOf(language) === 0) {
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            return LanguageToFontMap[lang];
        }
    }
    return defaultFontFamily;
}
function _createFont(size, weight, fontFamily) {
    return {
        fontFamily: fontFamily,
        MozOsxFontSmoothing: 'grayscale',
        WebkitFontSmoothing: 'antialiased',
        fontSize: size,
        fontWeight: weight,
    };
}

// Default urls.
var DefaultBaseUrl = 'https://static2.sharepointonline.com/files/fabric/assets';
// Standard font styling.
var DefaultFontStyles = createFontStyles(getLanguage());
function _registerFontFace(fontFamily, url, fontWeight, localFontName) {
    fontFamily = "'" + fontFamily + "'";
    var localFontSrc = localFontName !== undefined ? "local('" + localFontName + "')," : '';
    fontFace({
        fontFamily: fontFamily,
        src: localFontSrc + ("url('" + url + ".woff2') format('woff2'),") + ("url('" + url + ".woff') format('woff')"),
        fontWeight: fontWeight,
        fontStyle: 'normal',
        fontDisplay: 'swap',
    });
}
function _registerFontFaceSet(baseUrl, fontFamily, cdnFolder, cdnFontName, localFontName) {
    if (cdnFontName === void 0) { cdnFontName = 'segoeui'; }
    var urlBase = baseUrl + "/" + cdnFolder + "/" + cdnFontName;
    _registerFontFace(fontFamily, urlBase + '-light', FontWeights.light, localFontName && localFontName + ' Light');
    _registerFontFace(fontFamily, urlBase + '-semilight', FontWeights.semilight, localFontName && localFontName + ' SemiLight');
    _registerFontFace(fontFamily, urlBase + '-regular', FontWeights.regular, localFontName);
    _registerFontFace(fontFamily, urlBase + '-semibold', FontWeights.semibold, localFontName && localFontName + ' SemiBold');
    _registerFontFace(fontFamily, urlBase + '-bold', FontWeights.bold, localFontName && localFontName + ' Bold');
}
function registerDefaultFontFaces(baseUrl) {
    if (baseUrl) {
        var fontUrl = baseUrl + "/fonts";
        // Produce @font-face definitions for all supported web fonts.
        _registerFontFaceSet(fontUrl, LocalizedFontNames.Thai, 'leelawadeeui-thai', 'leelawadeeui');
        _registerFontFaceSet(fontUrl, LocalizedFontNames.Arabic, 'segoeui-arabic');
        _registerFontFaceSet(fontUrl, LocalizedFontNames.Cyrillic, 'segoeui-cyrillic');
        _registerFontFaceSet(fontUrl, LocalizedFontNames.EastEuropean, 'segoeui-easteuropean');
        _registerFontFaceSet(fontUrl, LocalizedFontNames.Greek, 'segoeui-greek');
        _registerFontFaceSet(fontUrl, LocalizedFontNames.Hebrew, 'segoeui-hebrew');
        _registerFontFaceSet(fontUrl, LocalizedFontNames.Vietnamese, 'segoeui-vietnamese');
        _registerFontFaceSet(fontUrl, LocalizedFontNames.WestEuropean, 'segoeui-westeuropean', 'segoeui', 'Segoe UI');
        _registerFontFaceSet(fontUrl, LocalizedFontFamilies.Selawik, 'selawik', 'selawik');
        _registerFontFaceSet(fontUrl, LocalizedFontNames.Armenian, 'segoeui-armenian');
        _registerFontFaceSet(fontUrl, LocalizedFontNames.Georgian, 'segoeui-georgian');
        // Leelawadee UI (Thai) does not have a 'light' weight, so we override
        // the font-face generated above to use the 'semilight' weight instead.
        _registerFontFace('Leelawadee UI Web', fontUrl + "/leelawadeeui-thai/leelawadeeui-semilight", FontWeights.light);
        // Leelawadee UI (Thai) does not have a 'semibold' weight, so we override
        // the font-face generated above to use the 'bold' weight instead.
        _registerFontFace('Leelawadee UI Web', fontUrl + "/leelawadeeui-thai/leelawadeeui-bold", FontWeights.semibold);
    }
}
/**
 * Reads the fontBaseUrl from window.FabricConfig.fontBaseUrl or falls back to a default.
 */
function _getFontBaseUrl() {
    var _a, _b, _c;
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    var fabricConfig = (_a = getWindow()) === null || _a === void 0 ? void 0 : _a.FabricConfig;
    return _c = (_b = fabricConfig) === null || _b === void 0 ? void 0 : _b.fontBaseUrl, (_c !== null && _c !== void 0 ? _c : DefaultBaseUrl);
}
/**
 * Register the font faces.
 */
registerDefaultFontFaces(_getFontBaseUrl());

var HighContrastSelector = '@media screen and (-ms-high-contrast: active)';
var EdgeChromiumHighContrastSelector = '@media screen and (forced-colors: active)';
var ScreenWidthMinLarge = 640;
var ScreenWidthMaxMedium = ScreenWidthMinLarge - 1;
function getScreenSelector(min, max) {
    return "@media only screen and (min-width: " + min + "px) and (max-width: " + max + "px)";
}
/**
 * The style which turns off high contrast adjustment in (only) Edge Chromium browser.
 */
function getEdgeChromiumNoHighContrastAdjustSelector() {
    var _a;
    return _a = {},
        _a[EdgeChromiumHighContrastSelector] = {
            forcedColorAdjust: 'none',
        },
        _a;
}

var ZIndexes;
(function (ZIndexes) {
    ZIndexes.Nav = 1;
    /**
     * @deprecated ScrollablePane
     */
    ZIndexes.ScrollablePane = 1;
    ZIndexes.FocusStyle = 1;
    ZIndexes.Coachmark = 1000;
    ZIndexes.Layer = 1000000;
    ZIndexes.KeytipLayer = 1000001;
})(ZIndexes || (ZIndexes = {}));

function getFocusStyle(theme, insetOrOptions, position, highContrastStyle, borderColor, outlineColor, isFocusedOnly) {
    if (typeof insetOrOptions === 'number' || !insetOrOptions) {
        return _getFocusStyleInternal(theme, {
            inset: insetOrOptions,
            position: position,
            highContrastStyle: highContrastStyle,
            borderColor: borderColor,
            outlineColor: outlineColor,
            isFocusedOnly: isFocusedOnly,
        });
    }
    else {
        return _getFocusStyleInternal(theme, insetOrOptions);
    }
}
function _getFocusStyleInternal(theme, options) {
    var _a, _b;
    if (options === void 0) { options = {}; }
    var _c = options.inset, inset = _c === void 0 ? 0 : _c, _d = options.width, width = _d === void 0 ? 1 : _d, _e = options.position, position = _e === void 0 ? 'relative' : _e, highContrastStyle = options.highContrastStyle, _f = options.borderColor, borderColor = _f === void 0 ? theme.palette.white : _f, _g = options.outlineColor, outlineColor = _g === void 0 ? theme.palette.neutralSecondary : _g, _h = options.isFocusedOnly, isFocusedOnly = _h === void 0 ? true : _h;
    return {
        // Clear browser-specific focus styles and use 'transparent' as placeholder for focus style.
        outline: 'transparent',
        // Requirement because pseudo-element is absolutely positioned.
        position: position,
        selectors: (_a = {
                // Clear the focus border in Firefox.
                // Reference: http://stackoverflow.com/a/199319/1436671
                '::-moz-focus-inner': {
                    border: '0',
                }
            },
            // When the element that uses this mixin is in a :focus state, add a pseudo-element to
            // create a border.
            _a["." + IsFocusVisibleClassName + " &" + (isFocusedOnly ? ':focus' : '') + ":after"] = {
                content: '""',
                position: 'absolute',
                left: inset + 1,
                top: inset + 1,
                bottom: inset + 1,
                right: inset + 1,
                border: width + "px solid " + borderColor,
                outline: width + "px solid " + outlineColor,
                zIndex: ZIndexes.FocusStyle,
                selectors: (_b = {},
                    _b[HighContrastSelector] = highContrastStyle,
                    _b),
            },
            _a),
    };
}
/**
 * Generates style to clear browser specific focus styles.
 */
function focusClear() {
    return {
        selectors: {
            '&::-moz-focus-inner': {
                // Clear the focus border in Firefox. Reference: http://stackoverflow.com/a/199319/1436671
                border: 0,
            },
            '&': {
                // Clear browser specific focus styles and use transparent as placeholder for focus style
                outline: 'transparent',
            },
        },
    };
}

var hiddenContentStyle = {
    position: 'absolute',
    width: 1,
    height: 1,
    margin: -1,
    padding: 0,
    border: 0,
    overflow: 'hidden',
};

/**
 * Internal memoized function which simply takes in the class map and the
 * disable boolean. These immutable values can be memoized.
 */
var _getGlobalClassNames = memoizeFunction(function (classNames, disableGlobalClassNames) {
    var styleSheet = Stylesheet.getInstance();
    if (disableGlobalClassNames) {
        // disable global classnames
        return Object.keys(classNames).reduce(function (acc, className) {
            acc[className] = styleSheet.getClassName(classNames[className]);
            return acc;
        }, {});
    }
    // use global classnames
    return classNames;
});
/**
 * Checks for the `disableGlobalClassNames` property on the `theme` to determine if it should return `classNames`
 * Note that calls to this function are memoized.
 *
 * @param classNames - The collection of global class names that apply when the flag is false. Make sure to pass in
 * the same instance on each call to benefit from memoization.
 * @param theme - The theme to check the flag on
 * @param disableGlobalClassNames - Optional. Explicitly opt in/out of disabling global classnames. Defaults to false.
 */
function getGlobalClassNames(classNames, theme, disableGlobalClassNames) {
    return _getGlobalClassNames(classNames, disableGlobalClassNames !== undefined ? disableGlobalClassNames : theme.disableGlobalClassNames);
}

var DefaultSpacing = {
    s2: '4px',
    s1: '8px',
    m: '16px',
    l1: '20px',
    l2: '32px',
};

// Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license.
// See LICENSE in the project root for license information.
var __assign$1 = (window && window.__assign) || function () {
    __assign$1 = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign$1.apply(this, arguments);
};
// Store the theming state in __themeState__ global scope for reuse in the case of duplicate
// load-themed-styles hosted on the page.
var _root = typeof window === 'undefined' ? global : window; // eslint-disable-line @typescript-eslint/no-explicit-any
// Nonce string to inject into script tag if one provided. This is used in CSP (Content Security Policy).
var _styleNonce = _root && _root.CSPSettings && _root.CSPSettings.nonce;
var _themeState = initializeThemeState();
/**
 * initialize global state object
 */
function initializeThemeState() {
    var state = _root.__themeState__ || {
        theme: undefined,
        lastStyleElement: undefined,
        registeredStyles: []
    };
    if (!state.runState) {
        state = __assign$1({}, state, { perf: {
                count: 0,
                duration: 0
            }, runState: {
                flushTimer: 0,
                mode: 0 /* sync */,
                buffer: []
            } });
    }
    if (!state.registeredThemableStyles) {
        state = __assign$1({}, state, { registeredThemableStyles: [] });
    }
    _root.__themeState__ = state;
    return state;
}

var _theme = createTheme({
    palette: DefaultPalette,
    semanticColors: _makeSemanticColors(DefaultPalette, DefaultEffects, undefined, false, false),
    fonts: DefaultFontStyles,
    isInverted: false,
    disableGlobalClassNames: false,
});
var ThemeSettingName = 'theme';
function initializeThemeInCustomizations() {
    var _a;
    var _b, _c;
    if (!Customizations.getSettings([ThemeSettingName]).theme) {
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        var win = getWindow();
        if ((_c = (_b = win) === null || _b === void 0 ? void 0 : _b.FabricConfig) === null || _c === void 0 ? void 0 : _c.theme) {
            _theme = createTheme(win.FabricConfig.theme);
        }
        // Set the default theme.
        Customizations.applySettings((_a = {}, _a[ThemeSettingName] = _theme, _a));
    }
}
initializeThemeInCustomizations();
/**
 * Gets the theme object
 * @param depComments - Whether to include deprecated tags as comments for deprecated slots.
 */
function getTheme(depComments) {
    if (depComments === void 0) { depComments = false; }
    if (depComments === true) {
        _theme = createTheme({}, depComments);
    }
    return _theme;
}
/**
 * Creates a custom theme definition which can be used with the Customizer.
 * @param theme - Partial theme object.
 * @param depComments - Whether to include deprecated tags as comments for deprecated slots.
 */
function createTheme(theme, depComments) {
    if (depComments === void 0) { depComments = false; }
    var newPalette = __assign(__assign({}, DefaultPalette), theme.palette);
    var newEffects = __assign(__assign({}, DefaultEffects), theme.effects);
    if (!theme.palette || !theme.palette.accent) {
        newPalette.accent = newPalette.themePrimary;
    }
    // mix in custom overrides with good slots first, since custom overrides might be used in fixing deprecated slots
    var newSemanticColors = __assign(__assign({}, _makeSemanticColors(newPalette, newEffects, theme.semanticColors, !!theme.isInverted, depComments)), theme.semanticColors);
    var defaultFontStyles = __assign({}, DefaultFontStyles);
    if (theme.defaultFontStyle) {
        for (var _i = 0, _a = Object.keys(defaultFontStyles); _i < _a.length; _i++) {
            var fontStyle = _a[_i];
            defaultFontStyles[fontStyle] = merge({}, defaultFontStyles[fontStyle], theme.defaultFontStyle);
        }
    }
    if (theme.fonts) {
        for (var _b = 0, _c = Object.keys(theme.fonts); _b < _c.length; _b++) {
            var fontStyle = _c[_b];
            defaultFontStyles[fontStyle] = merge({}, defaultFontStyles[fontStyle], theme.fonts[fontStyle]);
        }
    }
    return {
        palette: newPalette,
        fonts: __assign({}, defaultFontStyles),
        rtl: theme.rtl,
        semanticColors: newSemanticColors,
        isInverted: !!theme.isInverted,
        disableGlobalClassNames: !!theme.disableGlobalClassNames,
        spacing: __assign(__assign({}, DefaultSpacing), theme.spacing),
        effects: newEffects,
    };
}
/** Generates all the semantic slot colors based on the theme so far
 * We'll use these as fallbacks for semantic slots that the passed in theme did not define.
 * The caller must still mix in the customized semantic slots at the end.
 */
function _makeSemanticColors(p, e, s, isInverted, depComments) {
    var toReturn = __assign({ 
        // DEFAULTS
        bodyBackground: p.white, bodyBackgroundHovered: p.neutralLighter, bodyBackgroundChecked: p.neutralLight, bodyStandoutBackground: p.neutralLighterAlt, bodyFrameBackground: p.white, bodyFrameDivider: p.neutralLight, bodyText: p.neutralPrimary, bodyTextChecked: p.black, bodySubtext: p.neutralSecondary, bodyDivider: p.neutralLight, disabledBodyText: p.neutralTertiary, disabledBodySubtext: p.neutralTertiaryAlt, disabledBorder: p.neutralTertiaryAlt, focusBorder: p.neutralSecondary, cardStandoutBackground: p.white, cardShadow: e.elevation4, cardShadowHovered: '', variantBorder: p.neutralLight, variantBorderHovered: p.neutralTertiary, defaultStateBackground: p.neutralLighterAlt, 
        // LINKS
        actionLink: p.neutralPrimary, actionLinkHovered: p.neutralDark, link: p.themePrimary, linkHovered: p.themeDarker, 
        // BUTTONS
        buttonBackground: p.white, buttonBackgroundChecked: p.neutralTertiaryAlt, buttonBackgroundHovered: p.neutralLighter, buttonBackgroundCheckedHovered: p.neutralLight, buttonBackgroundPressed: p.neutralLight, buttonBackgroundDisabled: p.neutralLighter, buttonBorder: p.neutralSecondaryAlt, buttonText: p.neutralPrimary, buttonTextHovered: p.neutralDark, buttonTextChecked: p.neutralDark, buttonTextCheckedHovered: p.black, buttonTextPressed: p.neutralDark, buttonTextDisabled: p.neutralTertiary, buttonBorderDisabled: p.neutralLighter, primaryButtonBackground: p.themePrimary, primaryButtonBackgroundHovered: p.themeDarkAlt, primaryButtonBackgroundPressed: p.themeDark, primaryButtonBackgroundDisabled: p.neutralLighter, primaryButtonBorder: 'transparent', primaryButtonText: p.white, primaryButtonTextHovered: p.white, primaryButtonTextPressed: p.white, primaryButtonTextDisabled: p.neutralQuaternary, accentButtonBackground: p.accent, accentButtonText: p.white, 
        // INPUTS
        inputBorder: p.neutralSecondary, inputBorderHovered: p.neutralPrimary, inputBackground: p.white, inputBackgroundChecked: p.themePrimary, inputBackgroundCheckedHovered: p.themeDark, inputPlaceholderBackgroundChecked: p.themeLighter, inputForegroundChecked: p.white, inputIcon: p.themePrimary, inputIconHovered: p.themeDark, inputIconDisabled: p.neutralTertiary, inputFocusBorderAlt: p.themePrimary, smallInputBorder: p.neutralSecondary, inputText: p.neutralPrimary, inputTextHovered: p.neutralDark, inputPlaceholderText: p.neutralSecondary, disabledBackground: p.neutralLighter, disabledText: p.neutralTertiary, disabledSubtext: p.neutralQuaternary, 
        // LISTS
        listBackground: p.white, listText: p.neutralPrimary, listItemBackgroundHovered: p.neutralLighter, listItemBackgroundChecked: p.neutralLight, listItemBackgroundCheckedHovered: p.neutralQuaternaryAlt, listHeaderBackgroundHovered: p.neutralLighter, listHeaderBackgroundPressed: p.neutralLight, 
        // MENUS
        menuBackground: p.white, menuDivider: p.neutralTertiaryAlt, menuIcon: p.themePrimary, menuHeader: p.themePrimary, menuItemBackgroundHovered: p.neutralLighter, menuItemBackgroundPressed: p.neutralLight, menuItemText: p.neutralPrimary, menuItemTextHovered: p.neutralDark, errorText: !isInverted ? '#a4262c' : '#F1707B', messageText: !isInverted ? '#323130' : '#F3F2F1', messageLink: !isInverted ? '#005A9E' : '#6CB8F6', messageLinkHovered: !isInverted ? '#004578' : '#82C7FF', infoIcon: !isInverted ? '#605e5c' : '#C8C6C4', errorIcon: !isInverted ? '#A80000' : '#F1707B', blockingIcon: !isInverted ? '#FDE7E9' : '#442726', warningIcon: !isInverted ? '#797775' : '#C8C6C4', severeWarningIcon: !isInverted ? '#D83B01' : '#FCE100', successIcon: !isInverted ? '#107C10' : '#92C353', infoBackground: !isInverted ? '#f3f2f1' : '#323130', errorBackground: !isInverted ? '#FDE7E9' : '#442726', blockingBackground: !isInverted ? '#FDE7E9' : '#442726', warningBackground: !isInverted ? '#FFF4CE' : '#433519', severeWarningBackground: !isInverted ? '#FED9CC' : '#4F2A0F', successBackground: !isInverted ? '#DFF6DD' : '#393D1B', 
        // Deprecated slots, later pass by _fixDeprecatedSlots() for self-referential slots
        warningHighlight: !isInverted ? '#ffb900' : '#fff100', warningText: '', successText: !isInverted ? '#107C10' : '#92c353', listTextColor: '', menuItemBackgroundChecked: p.neutralLight }, s);
    // second pass for self-referential slots
    toReturn = __assign(__assign({}, toReturn), { cardShadowHovered: !isInverted ? e.elevation8 : '0 0 1px ' + toReturn.variantBorderHovered });
    return _fixDeprecatedSlots(toReturn, depComments);
}
function _fixDeprecatedSlots(s, depComments) {
    // Add @deprecated tag as comment if enabled
    var dep = '';
    if (depComments === true) {
        dep = ' /* @deprecated */';
    }
    /* eslint-disable deprecation/deprecation */
    s.listTextColor = s.listText + dep;
    s.menuItemBackgroundChecked += dep;
    s.warningHighlight += dep;
    s.warningText = s.messageText + dep;
    s.successText += dep;
    /* eslint-enable deprecation/deprecation */
    return s;
}

/**
 * {@docCategory AnimationClassNames}
 */
var AnimationClassNames = buildClassMap(AnimationStyles);

// Do not modify this file; it is generated as part of publish.
setVersion('@uifabric/styling', '7.14.12');

initializeThemeInCustomizations();

var GlobalClassNames = {
    root: 'ms-Image',
    rootMaximizeFrame: 'ms-Image--maximizeFrame',
    image: 'ms-Image-image',
    imageCenter: 'ms-Image-image--center',
    imageContain: 'ms-Image-image--contain',
    imageCover: 'ms-Image-image--cover',
    imageCenterContain: 'ms-Image-image--centerContain',
    imageCenterCover: 'ms-Image-image--centerCover',
    imageNone: 'ms-Image-image--none',
    imageLandscape: 'ms-Image-image--landscape',
    imagePortrait: 'ms-Image-image--portrait',
};
var getStyles = function (props) {
    var className = props.className, width = props.width, height = props.height, maximizeFrame = props.maximizeFrame, isLoaded = props.isLoaded, shouldFadeIn = props.shouldFadeIn, shouldStartVisible = props.shouldStartVisible, isLandscape = props.isLandscape, isCenter = props.isCenter, isContain = props.isContain, isCover = props.isCover, isCenterContain = props.isCenterContain, isCenterCover = props.isCenterCover, isNone = props.isNone, isError = props.isError, isNotImageFit = props.isNotImageFit, theme = props.theme;
    var classNames = getGlobalClassNames(GlobalClassNames, theme);
    var ImageFitStyles = {
        position: 'absolute',
        left: '50% /* @noflip */',
        top: '50%',
        transform: 'translate(-50%,-50%)',
    };
    // Cut the mustard using msMaxTouchPoints to detect IE11 which does not support CSS object-fit
    var window = getWindow();
    var supportsObjectFit = window !== undefined && window.navigator.msMaxTouchPoints === undefined;
    var fallbackObjectFitStyles = (isContain && isLandscape) || (isCover && !isLandscape)
        ? { width: '100%', height: 'auto' }
        : { width: 'auto', height: '100%' };
    return {
        root: [
            classNames.root,
            theme.fonts.medium,
            {
                overflow: 'hidden',
            },
            maximizeFrame && [
                classNames.rootMaximizeFrame,
                {
                    height: '100%',
                    width: '100%',
                },
            ],
            isLoaded && shouldFadeIn && !shouldStartVisible && AnimationClassNames.fadeIn400,
            (isCenter || isContain || isCover || isCenterContain || isCenterCover) && {
                position: 'relative',
            },
            className,
        ],
        image: [
            classNames.image,
            {
                display: 'block',
                opacity: 0,
            },
            isLoaded && [
                'is-loaded',
                {
                    opacity: 1,
                },
            ],
            isCenter && [classNames.imageCenter, ImageFitStyles],
            isContain && [
                classNames.imageContain,
                supportsObjectFit && {
                    width: '100%',
                    height: '100%',
                    objectFit: 'contain',
                },
                !supportsObjectFit && fallbackObjectFitStyles,
                ImageFitStyles,
            ],
            isCover && [
                classNames.imageCover,
                supportsObjectFit && {
                    width: '100%',
                    height: '100%',
                    objectFit: 'cover',
                },
                !supportsObjectFit && fallbackObjectFitStyles,
                ImageFitStyles,
            ],
            isCenterContain && [
                classNames.imageCenterContain,
                isLandscape && {
                    maxWidth: '100%',
                },
                !isLandscape && {
                    maxHeight: '100%',
                },
                ImageFitStyles,
            ],
            isCenterCover && [
                classNames.imageCenterCover,
                isLandscape && {
                    maxHeight: '100%',
                },
                !isLandscape && {
                    maxWidth: '100%',
                },
                ImageFitStyles,
            ],
            isNone && [
                classNames.imageNone,
                {
                    width: 'auto',
                    height: 'auto',
                },
            ],
            isNotImageFit && [
                !!width &&
                    !height && {
                    height: 'auto',
                    width: '100%',
                },
                !width &&
                    !!height && {
                    height: '100%',
                    width: 'auto',
                },
                !!width &&
                    !!height && {
                    height: '100%',
                    width: '100%',
                },
            ],
            isLandscape && classNames.imageLandscape,
            !isLandscape && classNames.imagePortrait,
            !isLoaded && 'is-notLoaded',
            shouldFadeIn && 'is-fadeIn',
            isError && 'is-error',
        ],
    };
};

var Image = styled(ImageBase, getStyles, undefined, {
    scope: 'Image',
}, true);

/** Class names used in themeable and non-themeable Icon components */
var classNames = mergeStyleSets({
    root: {
        display: 'inline-block',
    },
    placeholder: [
        'ms-Icon-placeHolder',
        {
            width: '1em',
        },
    ],
    image: [
        'ms-Icon-imageContainer',
        {
            overflow: 'hidden',
        },
    ],
});
/** Class name used only in non-themeable Icon components */
var MS_ICON = 'ms-Icon';
var getStyles$1 = function (props) {
    var className = props.className, iconClassName = props.iconClassName, isPlaceholder = props.isPlaceholder, isImage = props.isImage, styles = props.styles;
    return {
        root: [
            isPlaceholder && classNames.placeholder,
            classNames.root,
            isImage && classNames.image,
            iconClassName,
            className,
            styles && styles.root,
            // eslint-disable-next-line deprecation/deprecation
            styles && styles.imageContainer,
        ],
    };
};

var getIconContent = memoizeFunction(function (iconName) {
    {
        return null;
    }
}, undefined, true /*ignoreNullOrUndefinedResult */);
/**
 * Fast icon component which only supports font glyphs (not images) and can't be targeted by customizations.
 * To style the icon, use `className` or reference `ms-Icon` in CSS.
 * {@docCategory Icon}
 */
var FontIcon = function (props) {
    var iconName = props.iconName, className = props.className, _a = props.style, style = _a === void 0 ? {} : _a;
    var iconContent = getIconContent(iconName) || {};
    var iconClassName = iconContent.iconClassName, children = iconContent.children, fontFamily = iconContent.fontFamily;
    var nativeProps = getNativeProps(props, htmlElementProperties);
    var containerProps = props['aria-label']
        ? {}
        : {
            role: 'presentation',
            'aria-hidden': true,
        };
    return (createElement("i", __assign({ "data-icon-name": iconName }, containerProps, nativeProps, { className: css(MS_ICON, classNames.root, iconClassName, !iconName && classNames.placeholder, className), 
        // Apply the font family this way to ensure it doesn't get overridden by Fabric Core ms-Icon styles
        // https://github.com/microsoft/fluentui/issues/10449
        style: __assign({ fontFamily: fontFamily }, style) }), children));
};
/**
 * Memoized helper for rendering a FontIcon.
 * @param iconName - The name of the icon to use from the icon font.
 * @param className - Class name for styling the icon.
 * @param ariaLabel - Label for the icon for the benefit of screen readers.
 * {@docCategory Icon}
 */
var getFontIcon = memoizeFunction(function (iconName, className, ariaLabel) {
    return FontIcon({ iconName: iconName, className: className, 'aria-label': ariaLabel });
});

var getClassNames$1 = classNamesFunction({
    // Icon is used a lot by other components.
    // It's likely to see expected cases which pass different className to the Icon.
    // Therefore setting a larger cache size.
    cacheSize: 100,
});
var IconBase = /** @class */ (function (_super) {
    __extends(IconBase, _super);
    function IconBase(props) {
        var _this = _super.call(this, props) || this;
        _this._onImageLoadingStateChange = function (state) {
            if (_this.props.imageProps && _this.props.imageProps.onLoadingStateChange) {
                _this.props.imageProps.onLoadingStateChange(state);
            }
            if (state === ImageLoadState.error) {
                _this.setState({ imageLoadError: true });
            }
        };
        _this.state = {
            imageLoadError: false,
        };
        return _this;
    }
    IconBase.prototype.render = function () {
        var _a = this.props, children = _a.children, className = _a.className, styles = _a.styles, iconName = _a.iconName, imageErrorAs = _a.imageErrorAs, theme = _a.theme;
        var isPlaceholder = typeof iconName === 'string' && iconName.length === 0;
        var isImage = 
        // eslint-disable-next-line deprecation/deprecation
        !!this.props.imageProps || this.props.iconType === IconType.image || this.props.iconType === IconType.Image;
        var iconContent = getIconContent(iconName) || {};
        var iconClassName = iconContent.iconClassName, iconContentChildren = iconContent.children;
        var classNames = getClassNames$1(styles, {
            theme: theme,
            className: className,
            iconClassName: iconClassName,
            isImage: isImage,
            isPlaceholder: isPlaceholder,
        });
        var RootType = isImage ? 'span' : 'i';
        var nativeProps = getNativeProps(this.props, htmlElementProperties, [
            'aria-label',
        ]);
        var imageLoadError = this.state.imageLoadError;
        var imageProps = __assign(__assign({}, this.props.imageProps), { onLoadingStateChange: this._onImageLoadingStateChange });
        var ImageType = (imageLoadError && imageErrorAs) || Image;
        // eslint-disable-next-line deprecation/deprecation
        var ariaLabel = this.props['aria-label'] || this.props.ariaLabel;
        var containerProps = ariaLabel
            ? {
                'aria-label': ariaLabel,
            }
            : {
                'aria-hidden': this.props['aria-labelledby'] || imageProps['aria-labelledby'] ? false : true,
            };
        return (createElement(RootType, __assign({ "data-icon-name": iconName }, containerProps, nativeProps, { className: classNames.root }), isImage ? createElement(ImageType, __assign({}, imageProps)) : children || iconContentChildren));
    };
    return IconBase;
}(Component));

/**
 * Legacy Icon component which can be targeted by customization. It's recommended to use `FontIcon`
 * or `ImageIcon` instead, especially in scenarios where rendering performance is important.
 * {@docCategory Icon}
 */
var Icon = styled(IconBase, getStyles$1, undefined, {
    scope: 'Icon',
}, true);

/**
 * Fast icon component which only supports images (not font glyphs) and can't be targeted by customizations.
 * To style the icon, use `className` or reference `ms-Icon` in CSS.
 * {@docCategory Icon}
 */
var ImageIcon = function (props) {
    var className = props.className, imageProps = props.imageProps;
    var nativeProps = getNativeProps(props, htmlElementProperties);
    var containerProps = props['aria-label']
        ? {}
        : {
            role: 'presentation',
            'aria-hidden': imageProps.alt || imageProps['aria-labelledby'] ? false : true,
        };
    return (createElement("div", __assign({}, containerProps, nativeProps, { className: css(MS_ICON, classNames.root, classNames.image, className) }),
        createElement(Image, __assign({}, imageProps))));
};

var DirectionalHint = {
    /**
     * Appear above the target element, with the left edges of the callout and target aligning.
     */
    topLeftEdge: 0,
    /**
     * Appear above the target element, with the centers of the callout and target aligning.
     */
    topCenter: 1,
    /**
     * Appear above the target element, with the right edges of the callout and target aligning.
     */
    topRightEdge: 2,
    /**
     * Appear above the target element, aligning with the target element such that the callout tends toward
     * the center of the screen.
     */
    topAutoEdge: 3,
    /**
     * Appear below the target element, with the left edges of the callout and target aligning.
     */
    bottomLeftEdge: 4,
    /**
     * Appear below the target element, with the centers of the callout and target aligning.
     */
    bottomCenter: 5,
    /**
     * Appear below the target element, with the right edges of the callout and target aligning.
     */
    bottomRightEdge: 6,
    /**
     * Appear below the target element, aligning with the target element such that the callout tends toward
     * the center of the screen.
     */
    bottomAutoEdge: 7,
    /**
     * Appear to the left of the target element, with the top edges of the callout and target aligning.
     */
    leftTopEdge: 8,
    /**
     * Appear to the left of the target element, with the centers of the callout and target aligning.
     */
    leftCenter: 9,
    /**
     * Appear to the left of the target element, with the bottom edges of the callout and target aligning.
     */
    leftBottomEdge: 10,
    /**
     * Appear to the right of the target element, with the top edges of the callout and target aligning.
     */
    rightTopEdge: 11,
    /**
     * Appear to the right of the target element, with the centers of the callout and target aligning.
     */
    rightCenter: 12,
    /**
     * Appear to the right of the target element, with the bottom edges of the callout and target aligning.
     */
    rightBottomEdge: 13,
};

/**
 * {@docCategory ContextualMenu}
 */
var ContextualMenuItemType;
(function (ContextualMenuItemType) {
    ContextualMenuItemType[ContextualMenuItemType["Normal"] = 0] = "Normal";
    ContextualMenuItemType[ContextualMenuItemType["Divider"] = 1] = "Divider";
    ContextualMenuItemType[ContextualMenuItemType["Header"] = 2] = "Header";
    ContextualMenuItemType[ContextualMenuItemType["Section"] = 3] = "Section";
})(ContextualMenuItemType || (ContextualMenuItemType = {}));

/**
 * {@docCategory FocusZone}
 */
var FocusZoneTabbableElements = {
    /** Tabbing is not allowed */
    none: 0,
    /** All tabbing action is allowed */
    all: 1,
    /** Tabbing is allowed only on input elements */
    inputOnly: 2,
};
/**
 * {@docCategory FocusZone}
 */
var FocusZoneDirection;
(function (FocusZoneDirection) {
    /** Only react to up/down arrows. */
    FocusZoneDirection[FocusZoneDirection["vertical"] = 0] = "vertical";
    /** Only react to left/right arrows. */
    FocusZoneDirection[FocusZoneDirection["horizontal"] = 1] = "horizontal";
    /** React to all arrows. */
    FocusZoneDirection[FocusZoneDirection["bidirectional"] = 2] = "bidirectional";
    /**
     * React to all arrows. Navigate next item in DOM on right/down arrow keys and previous - left/up arrow keys.
     * Right and Left arrow keys are swapped in RTL mode.
     */
    FocusZoneDirection[FocusZoneDirection["domOrder"] = 3] = "domOrder";
})(FocusZoneDirection || (FocusZoneDirection = {}));

var IS_FOCUSABLE_ATTRIBUTE$1 = 'data-is-focusable';
var IS_ENTER_DISABLED_ATTRIBUTE = 'data-disable-click-on-enter';
var FOCUSZONE_ID_ATTRIBUTE$1 = 'data-focuszone-id';
var TABINDEX = 'tabindex';
var NO_VERTICAL_WRAP = 'data-no-vertical-wrap';
var NO_HORIZONTAL_WRAP = 'data-no-horizontal-wrap';
var LARGE_DISTANCE_FROM_CENTER = 999999999;
var LARGE_NEGATIVE_DISTANCE_FROM_CENTER = -999999999;
var focusZoneStyles;
var focusZoneClass = 'ms-FocusZone';
// Helper function that will return a class for when the root is focused
function getRootClass() {
    if (!focusZoneStyles) {
        focusZoneStyles = mergeStyles({
            selectors: {
                ':focus': {
                    outline: 'none',
                },
            },
        }, focusZoneClass);
    }
    return focusZoneStyles;
}
var _allInstances = {};
var _outerZones = new Set();
var ALLOWED_INPUT_TYPES = ['text', 'number', 'password', 'email', 'tel', 'url', 'search'];
var ALLOW_VIRTUAL_ELEMENTS = false;
var FocusZone = /** @class */ (function (_super) {
    __extends(FocusZone, _super);
    function FocusZone(props) {
        var _this = _super.call(this, props) || this;
        _this._root = createRef();
        _this._onFocus = function (ev) {
            if (_this._portalContainsElement(ev.target)) {
                // If the event target is inside a portal do not process the event.
                return;
            }
            var _a = _this.props, onActiveElementChanged = _a.onActiveElementChanged, 
            // eslint-disable-next-line deprecation/deprecation
            doNotAllowFocusEventToPropagate = _a.doNotAllowFocusEventToPropagate, stopFocusPropagation = _a.stopFocusPropagation, 
            // eslint-disable-next-line deprecation/deprecation
            onFocusNotification = _a.onFocusNotification, onFocus = _a.onFocus, shouldFocusInnerElementWhenReceivedFocus = _a.shouldFocusInnerElementWhenReceivedFocus, defaultTabbableElement = _a.defaultTabbableElement;
            var isImmediateDescendant = _this._isImmediateDescendantOfZone(ev.target);
            var newActiveElement;
            if (onFocus) {
                onFocus(ev);
            }
            else if (onFocusNotification) {
                onFocusNotification();
            }
            if (isImmediateDescendant) {
                newActiveElement = ev.target;
            }
            else {
                var parentElement = ev.target;
                while (parentElement && parentElement !== _this._root.current) {
                    if (isElementTabbable(parentElement) && _this._isImmediateDescendantOfZone(parentElement)) {
                        newActiveElement = parentElement;
                        break;
                    }
                    parentElement = getParent(parentElement, ALLOW_VIRTUAL_ELEMENTS);
                }
            }
            // If an inner focusable element should be focused when FocusZone container receives focus
            if (shouldFocusInnerElementWhenReceivedFocus && ev.target === _this._root.current) {
                var maybeElementToFocus = defaultTabbableElement &&
                    typeof defaultTabbableElement === 'function' &&
                    defaultTabbableElement(_this._root.current);
                // try to focus defaultTabbable element
                if (maybeElementToFocus && isElementTabbable(maybeElementToFocus)) {
                    newActiveElement = maybeElementToFocus;
                    maybeElementToFocus.focus();
                }
                else {
                    // force focus on first focusable element
                    _this.focus(true);
                    if (_this._activeElement) {
                        // set to null as new active element was handled in method above
                        newActiveElement = null;
                    }
                }
            }
            var initialElementFocused = !_this._activeElement;
            // If the new active element is a child of this zone and received focus,
            // update alignment an immediate descendant
            if (newActiveElement && newActiveElement !== _this._activeElement) {
                if (isImmediateDescendant || initialElementFocused) {
                    _this._setFocusAlignment(newActiveElement, true, true);
                }
                _this._activeElement = newActiveElement;
                if (initialElementFocused) {
                    _this._updateTabIndexes();
                }
            }
            if (onActiveElementChanged) {
                onActiveElementChanged(_this._activeElement, ev);
            }
            if (stopFocusPropagation || doNotAllowFocusEventToPropagate) {
                ev.stopPropagation();
            }
        };
        _this._onBlur = function () {
            _this._setParkedFocus(false);
        };
        _this._onMouseDown = function (ev) {
            if (_this._portalContainsElement(ev.target)) {
                // If the event target is inside a portal do not process the event.
                return;
            }
            var disabled = _this.props.disabled;
            if (disabled) {
                return;
            }
            var target = ev.target;
            var path = [];
            while (target && target !== _this._root.current) {
                path.push(target);
                target = getParent(target, ALLOW_VIRTUAL_ELEMENTS);
            }
            while (path.length) {
                target = path.pop();
                if (target && isElementTabbable(target)) {
                    _this._setActiveElement(target, true);
                }
                if (isElementFocusZone(target)) {
                    // Stop here since the focus zone will take care of its own children.
                    break;
                }
            }
        };
        /**
         * Handle the keystrokes.
         */
        _this._onKeyDown = function (ev) {
            if (_this._portalContainsElement(ev.target)) {
                // If the event target is inside a portal do not process the event.
                return;
            }
            // eslint-disable-next-line deprecation/deprecation
            var _a = _this.props, direction = _a.direction, disabled = _a.disabled, isInnerZoneKeystroke = _a.isInnerZoneKeystroke, pagingSupportDisabled = _a.pagingSupportDisabled, shouldEnterInnerZone = _a.shouldEnterInnerZone;
            if (disabled) {
                return;
            }
            if (_this.props.onKeyDown) {
                _this.props.onKeyDown(ev);
            }
            // If the default has been prevented, do not process keyboard events.
            if (ev.isDefaultPrevented()) {
                return;
            }
            if (_this._getDocument().activeElement === _this._root.current && _this._isInnerZone) {
                // If this element has focus, it is being controlled by a parent.
                // Ignore the keystroke.
                return;
            }
            if (((shouldEnterInnerZone && shouldEnterInnerZone(ev)) || (isInnerZoneKeystroke && isInnerZoneKeystroke(ev))) &&
                _this._isImmediateDescendantOfZone(ev.target)) {
                // Try to focus
                var innerZone = _this._getFirstInnerZone();
                if (innerZone) {
                    if (!innerZone.focus(true)) {
                        return;
                    }
                }
                else if (isElementFocusSubZone(ev.target)) {
                    if (!_this.focusElement(getNextElement(ev.target, ev.target.firstChild, true))) {
                        return;
                    }
                }
                else {
                    return;
                }
            }
            else if (ev.altKey) {
                return;
            }
            else {
                // eslint-disable-next-line @fluentui/deprecated-keyboard-event-props
                switch (ev.which) {
                    case KeyCodes.space:
                        if (_this._tryInvokeClickForFocusable(ev.target)) {
                            break;
                        }
                        return;
                    case KeyCodes.left:
                        if (direction !== FocusZoneDirection.vertical) {
                            _this._preventDefaultWhenHandled(ev);
                            if (_this._moveFocusLeft()) {
                                break;
                            }
                        }
                        return;
                    case KeyCodes.right:
                        if (direction !== FocusZoneDirection.vertical) {
                            _this._preventDefaultWhenHandled(ev);
                            if (_this._moveFocusRight()) {
                                break;
                            }
                        }
                        return;
                    case KeyCodes.up:
                        if (direction !== FocusZoneDirection.horizontal) {
                            _this._preventDefaultWhenHandled(ev);
                            if (_this._moveFocusUp()) {
                                break;
                            }
                        }
                        return;
                    case KeyCodes.down:
                        if (direction !== FocusZoneDirection.horizontal) {
                            _this._preventDefaultWhenHandled(ev);
                            if (_this._moveFocusDown()) {
                                break;
                            }
                        }
                        return;
                    case KeyCodes.pageDown:
                        if (!pagingSupportDisabled && _this._moveFocusPaging(true)) {
                            break;
                        }
                        return;
                    case KeyCodes.pageUp:
                        if (!pagingSupportDisabled && _this._moveFocusPaging(false)) {
                            break;
                        }
                        return;
                    case KeyCodes.tab:
                        if (
                        // eslint-disable-next-line deprecation/deprecation
                        _this.props.allowTabKey ||
                            _this.props.handleTabKey === FocusZoneTabbableElements.all ||
                            (_this.props.handleTabKey === FocusZoneTabbableElements.inputOnly &&
                                _this._isElementInput(ev.target))) {
                            var focusChanged = false;
                            _this._processingTabKey = true;
                            if (direction === FocusZoneDirection.vertical ||
                                !_this._shouldWrapFocus(_this._activeElement, NO_HORIZONTAL_WRAP)) {
                                focusChanged = ev.shiftKey ? _this._moveFocusUp() : _this._moveFocusDown();
                            }
                            else {
                                var tabWithDirection = getRTL$1() ? !ev.shiftKey : ev.shiftKey;
                                focusChanged = tabWithDirection ? _this._moveFocusLeft() : _this._moveFocusRight();
                            }
                            _this._processingTabKey = false;
                            if (focusChanged) {
                                break;
                            }
                            else if (_this.props.shouldResetActiveElementWhenTabFromZone) {
                                _this._activeElement = null;
                            }
                        }
                        return;
                    case KeyCodes.home:
                        if (_this._isContentEditableElement(ev.target) ||
                            (_this._isElementInput(ev.target) &&
                                !_this._shouldInputLoseFocus(ev.target, false))) {
                            return false;
                        }
                        var firstChild = _this._root.current && _this._root.current.firstChild;
                        if (_this._root.current &&
                            firstChild &&
                            _this.focusElement(getNextElement(_this._root.current, firstChild, true))) {
                            break;
                        }
                        return;
                    case KeyCodes.end:
                        if (_this._isContentEditableElement(ev.target) ||
                            (_this._isElementInput(ev.target) &&
                                !_this._shouldInputLoseFocus(ev.target, true))) {
                            return false;
                        }
                        var lastChild = _this._root.current && _this._root.current.lastChild;
                        if (_this._root.current &&
                            _this.focusElement(getPreviousElement(_this._root.current, lastChild, true, true, true))) {
                            break;
                        }
                        return;
                    case KeyCodes.enter:
                        if (_this._tryInvokeClickForFocusable(ev.target)) {
                            break;
                        }
                        return;
                    default:
                        return;
                }
            }
            ev.preventDefault();
            ev.stopPropagation();
        };
        _this._getHorizontalDistanceFromCenter = function (isForward, activeRect, targetRect) {
            // eslint-disable-next-line deprecation/deprecation
            var leftAlignment = _this._focusAlignment.left || _this._focusAlignment.x || 0;
            // ClientRect values can be floats that differ by very small fractions of a decimal.
            // If the difference between top and bottom are within a pixel then we should treat
            // them as equivalent by using Math.floor. For instance 5.2222 and 5.222221 should be equivalent,
            // but without Math.Floor they will be handled incorrectly.
            var targetRectTop = Math.floor(targetRect.top);
            var activeRectBottom = Math.floor(activeRect.bottom);
            var targetRectBottom = Math.floor(targetRect.bottom);
            var activeRectTop = Math.floor(activeRect.top);
            var isValidCandidateOnpagingDown = isForward && targetRectTop > activeRectBottom;
            var isValidCandidateOnpagingUp = !isForward && targetRectBottom < activeRectTop;
            if (isValidCandidateOnpagingDown || isValidCandidateOnpagingUp) {
                if (leftAlignment >= targetRect.left && leftAlignment <= targetRect.left + targetRect.width) {
                    return 0;
                }
                return Math.abs(targetRect.left + targetRect.width / 2 - leftAlignment);
            }
            if (!_this._shouldWrapFocus(_this._activeElement, NO_VERTICAL_WRAP)) {
                return LARGE_NEGATIVE_DISTANCE_FROM_CENTER;
            }
            return LARGE_DISTANCE_FROM_CENTER;
        };
        // Manage componentRef resolution.
        initializeComponentRef(_this);
        if (process.env.NODE_ENV !== 'production') {
            warnDeprecations('FocusZone', props, {
                rootProps: undefined,
                allowTabKey: 'handleTabKey',
                elementType: 'as',
                ariaDescribedBy: 'aria-describedby',
                ariaLabelledBy: 'aria-labelledby',
            });
        }
        _this._id = getId('FocusZone');
        _this._focusAlignment = {
            left: 0,
            top: 0,
        };
        _this._processingTabKey = false;
        return _this;
    }
    /** Used for testing purposes only. */
    FocusZone.getOuterZones = function () {
        return _outerZones.size;
    };
    /**
     * Handle global tab presses so that we can patch tabindexes on the fly.
     * HEADS UP: This must not be an arrow function in order to be referentially equal among instances
     * for ref counting to work correctly!
     */
    FocusZone._onKeyDownCapture = function (ev) {
        // eslint-disable-next-line deprecation/deprecation, @fluentui/deprecated-keyboard-event-props
        if (ev.which === KeyCodes.tab) {
            _outerZones.forEach(function (zone) { return zone._updateTabIndexes(); });
        }
    };
    FocusZone.prototype.componentDidMount = function () {
        var root = this._root.current;
        _allInstances[this._id] = this;
        if (root) {
            this._windowElement = getWindow(root);
            var parentElement = getParent(root, ALLOW_VIRTUAL_ELEMENTS);
            while (parentElement && parentElement !== this._getDocument().body && parentElement.nodeType === 1) {
                if (isElementFocusZone(parentElement)) {
                    this._isInnerZone = true;
                    break;
                }
                parentElement = getParent(parentElement, ALLOW_VIRTUAL_ELEMENTS);
            }
            if (!this._isInnerZone) {
                _outerZones.add(this);
                if (this._windowElement && _outerZones.size === 1) {
                    this._windowElement.addEventListener('keydown', FocusZone._onKeyDownCapture, true);
                }
            }
            this._root.current && this._root.current.addEventListener('blur', this._onBlur, true);
            // Assign initial tab indexes so that we can set initial focus as appropriate.
            this._updateTabIndexes();
            if (this.props.defaultTabbableElement && typeof this.props.defaultTabbableElement === 'string') {
                this._activeElement = this._getDocument().querySelector(this.props.defaultTabbableElement);
                // eslint-disable-next-line deprecation/deprecation
            }
            else if (this.props.defaultActiveElement) {
                // eslint-disable-next-line deprecation/deprecation
                this._activeElement = this._getDocument().querySelector(this.props.defaultActiveElement);
            }
            if (this.props.shouldFocusOnMount) {
                this.focus();
            }
        }
    };
    FocusZone.prototype.componentDidUpdate = function () {
        var root = this._root.current;
        var doc = this._getDocument();
        if (doc &&
            this._lastIndexPath &&
            (doc.activeElement === doc.body ||
                doc.activeElement === null ||
                (!this.props.preventFocusRestoration && doc.activeElement === root))) {
            // The element has been removed after the render, attempt to restore focus.
            var elementToFocus = getFocusableByIndexPath(root, this._lastIndexPath);
            if (elementToFocus) {
                this._setActiveElement(elementToFocus, true);
                elementToFocus.focus();
                this._setParkedFocus(false);
            }
            else {
                // We had a focus path to restore, but now that path is unresolvable. Park focus
                // on the container until we can try again.
                this._setParkedFocus(true);
            }
        }
    };
    FocusZone.prototype.componentWillUnmount = function () {
        delete _allInstances[this._id];
        if (!this._isInnerZone) {
            _outerZones.delete(this);
            // If this is the last outer zone, remove the keydown listener.
            if (this._windowElement && _outerZones.size === 0) {
                this._windowElement.removeEventListener('keydown', FocusZone._onKeyDownCapture, true);
            }
        }
        if (this._root.current) {
            this._root.current.removeEventListener('blur', this._onBlur, true);
        }
        this._activeElement = null;
        this._defaultFocusElement = null;
    };
    FocusZone.prototype.render = function () {
        // eslint-disable-next-line deprecation/deprecation
        var _a = this.props, tag = _a.as, elementType = _a.elementType, rootProps = _a.rootProps, ariaDescribedBy = _a.ariaDescribedBy, ariaLabelledBy = _a.ariaLabelledBy, className = _a.className;
        var divProps = getNativeProps(this.props, htmlElementProperties);
        var Tag = tag || elementType || 'div';
        // Note, right before rendering/reconciling proceeds, we need to record if focus
        // was in the zone before the update. This helper will track this and, if focus
        // was actually in the zone, what the index path to the element is at this time.
        // Then, later in componentDidUpdate, we can evaluate if we need to restore it in
        // the case the element was removed.
        this._evaluateFocusBeforeRender();
        return (createElement(Tag, __assign({ "aria-labelledby": ariaLabelledBy, "aria-describedby": ariaDescribedBy }, divProps, rootProps, { 
            // Once the getClassName correctly memoizes inputs this should
            // be replaced so that className is passed to getRootClass and is included there so
            // the class names will always be in the same order.
            className: css(getRootClass(), className), ref: this._root, "data-focuszone-id": this._id, onKeyDown: this._onKeyDown, onFocus: this._onFocus, onMouseDownCapture: this._onMouseDown }), this.props.children));
    };
    /**
     * Sets focus to the first tabbable item in the zone.
     * @param forceIntoFirstElement - If true, focus will be forced into the first element, even
     * if focus is already in the focus zone.
     * @returns True if focus could be set to an active element, false if no operation was taken.
     */
    FocusZone.prototype.focus = function (forceIntoFirstElement) {
        if (forceIntoFirstElement === void 0) { forceIntoFirstElement = false; }
        if (this._root.current) {
            if (!forceIntoFirstElement &&
                this._root.current.getAttribute(IS_FOCUSABLE_ATTRIBUTE$1) === 'true' &&
                this._isInnerZone) {
                var ownerZoneElement = this._getOwnerZone(this._root.current);
                if (ownerZoneElement !== this._root.current) {
                    var ownerZone = _allInstances[ownerZoneElement.getAttribute(FOCUSZONE_ID_ATTRIBUTE$1)];
                    return !!ownerZone && ownerZone.focusElement(this._root.current);
                }
                return false;
            }
            else if (!forceIntoFirstElement &&
                this._activeElement &&
                elementContains(this._root.current, this._activeElement) &&
                isElementTabbable(this._activeElement)) {
                this._activeElement.focus();
                return true;
            }
            else {
                var firstChild = this._root.current.firstChild;
                return this.focusElement(getNextElement(this._root.current, firstChild, true));
            }
        }
        return false;
    };
    /**
     * Sets focus to the last tabbable item in the zone.
     * @returns True if focus could be set to an active element, false if no operation was taken.
     */
    FocusZone.prototype.focusLast = function () {
        if (this._root.current) {
            var lastChild = this._root.current && this._root.current.lastChild;
            return this.focusElement(getPreviousElement(this._root.current, lastChild, true, true, true));
        }
        return false;
    };
    /**
     * Sets focus to a specific child element within the zone. This can be used in conjunction with
     * shouldReceiveFocus to create delayed focus scenarios (like animate the scroll position to the correct
     * location and then focus.)
     * @param element - The child element within the zone to focus.
     * @returns True if focus could be set to an active element, false if no operation was taken.
     */
    FocusZone.prototype.focusElement = function (element) {
        // eslint-disable-next-line deprecation/deprecation
        var _a = this.props, onBeforeFocus = _a.onBeforeFocus, shouldReceiveFocus = _a.shouldReceiveFocus;
        if ((shouldReceiveFocus && !shouldReceiveFocus(element)) || (onBeforeFocus && !onBeforeFocus(element))) {
            return false;
        }
        if (element) {
            // when we Set focus to a specific child, we should recalculate the alignment depend on its position
            this._setActiveElement(element);
            if (this._activeElement) {
                this._activeElement.focus();
            }
            return true;
        }
        return false;
    };
    /**
     * Forces horizontal alignment in the context of vertical arrowing to use specific point as the reference,
     * rather than a center based on the last horizontal motion.
     * @param point - the new reference point.
     */
    FocusZone.prototype.setFocusAlignment = function (point) {
        this._focusAlignment = point;
    };
    FocusZone.prototype._evaluateFocusBeforeRender = function () {
        var root = this._root.current;
        var doc = this._getDocument();
        if (doc) {
            var focusedElement = doc.activeElement;
            // Only update the index path if we are not parked on the root.
            if (focusedElement !== root) {
                var shouldRestoreFocus = elementContains(root, focusedElement, false);
                this._lastIndexPath = shouldRestoreFocus ? getElementIndexPath(root, focusedElement) : undefined;
            }
        }
    };
    /**
     * When focus is in the zone at render time but then all focusable elements are removed,
     * we "park" focus temporarily on the root. Once we update with focusable children, we restore
     * focus to the closest path from previous. If the user tabs away from the parked container,
     * we restore focusability to the pre-parked state.
     */
    FocusZone.prototype._setParkedFocus = function (isParked) {
        var root = this._root.current;
        if (root && this._isParked !== isParked) {
            this._isParked = isParked;
            if (isParked) {
                if (!this.props.allowFocusRoot) {
                    this._parkedTabIndex = root.getAttribute('tabindex');
                    root.setAttribute('tabindex', '-1');
                }
                root.focus();
            }
            else if (!this.props.allowFocusRoot) {
                if (this._parkedTabIndex) {
                    root.setAttribute('tabindex', this._parkedTabIndex);
                    this._parkedTabIndex = undefined;
                }
                else {
                    root.removeAttribute('tabindex');
                }
            }
        }
    };
    FocusZone.prototype._setActiveElement = function (element, forceAlignment) {
        var previousActiveElement = this._activeElement;
        this._activeElement = element;
        if (previousActiveElement) {
            if (isElementFocusZone(previousActiveElement)) {
                this._updateTabIndexes(previousActiveElement);
            }
            previousActiveElement.tabIndex = -1;
        }
        if (this._activeElement) {
            if (!this._focusAlignment || forceAlignment) {
                this._setFocusAlignment(element, true, true);
            }
            this._activeElement.tabIndex = 0;
        }
    };
    FocusZone.prototype._preventDefaultWhenHandled = function (ev) {
        this.props.preventDefaultWhenHandled && ev.preventDefault();
    };
    /**
     * Walk up the dom try to find a focusable element.
     */
    FocusZone.prototype._tryInvokeClickForFocusable = function (target) {
        if (target === this._root.current || !this.props.shouldRaiseClicks) {
            return false;
        }
        do {
            if (target.tagName === 'BUTTON' ||
                target.tagName === 'A' ||
                target.tagName === 'INPUT' ||
                target.tagName === 'TEXTAREA') {
                return false;
            }
            if (this._isImmediateDescendantOfZone(target) &&
                target.getAttribute(IS_FOCUSABLE_ATTRIBUTE$1) === 'true' &&
                target.getAttribute(IS_ENTER_DISABLED_ATTRIBUTE) !== 'true') {
                raiseClick(target);
                return true;
            }
            target = getParent(target, ALLOW_VIRTUAL_ELEMENTS);
        } while (target !== this._root.current);
        return false;
    };
    /**
     * Traverse to find first child zone.
     */
    FocusZone.prototype._getFirstInnerZone = function (rootElement) {
        rootElement = rootElement || this._activeElement || this._root.current;
        if (!rootElement) {
            return null;
        }
        if (isElementFocusZone(rootElement)) {
            return _allInstances[rootElement.getAttribute(FOCUSZONE_ID_ATTRIBUTE$1)];
        }
        var child = rootElement.firstElementChild;
        while (child) {
            if (isElementFocusZone(child)) {
                return _allInstances[child.getAttribute(FOCUSZONE_ID_ATTRIBUTE$1)];
            }
            var match = this._getFirstInnerZone(child);
            if (match) {
                return match;
            }
            child = child.nextElementSibling;
        }
        return null;
    };
    FocusZone.prototype._moveFocus = function (isForward, getDistanceFromCenter, ev, useDefaultWrap) {
        if (useDefaultWrap === void 0) { useDefaultWrap = true; }
        var element = this._activeElement;
        var candidateDistance = -1;
        var candidateElement = undefined;
        var changedFocus = false;
        var isBidirectional = this.props.direction === FocusZoneDirection.bidirectional;
        if (!element || !this._root.current) {
            return false;
        }
        if (this._isElementInput(element)) {
            if (!this._shouldInputLoseFocus(element, isForward)) {
                return false;
            }
        }
        var activeRect = isBidirectional ? element.getBoundingClientRect() : null;
        do {
            element = (isForward
                ? getNextElement(this._root.current, element)
                : getPreviousElement(this._root.current, element));
            if (isBidirectional) {
                if (element) {
                    var targetRect = element.getBoundingClientRect();
                    var elementDistance = getDistanceFromCenter(activeRect, targetRect);
                    if (elementDistance === -1 && candidateDistance === -1) {
                        candidateElement = element;
                        break;
                    }
                    if (elementDistance > -1 && (candidateDistance === -1 || elementDistance < candidateDistance)) {
                        candidateDistance = elementDistance;
                        candidateElement = element;
                    }
                    if (candidateDistance >= 0 && elementDistance < 0) {
                        break;
                    }
                }
            }
            else {
                candidateElement = element;
                break;
            }
        } while (element);
        // Focus the closest candidate
        if (candidateElement && candidateElement !== this._activeElement) {
            changedFocus = true;
            this.focusElement(candidateElement);
        }
        else if (this.props.isCircularNavigation && useDefaultWrap) {
            if (isForward) {
                return this.focusElement(getNextElement(this._root.current, this._root.current.firstElementChild, true));
            }
            else {
                return this.focusElement(getPreviousElement(this._root.current, this._root.current.lastElementChild, true, true, true));
            }
        }
        return changedFocus;
    };
    FocusZone.prototype._moveFocusDown = function () {
        var _this = this;
        var targetTop = -1;
        // eslint-disable-next-line deprecation/deprecation
        var leftAlignment = this._focusAlignment.left || this._focusAlignment.x || 0;
        if (this._moveFocus(true, function (activeRect, targetRect) {
            var distance = -1;
            // ClientRect values can be floats that differ by very small fractions of a decimal.
            // If the difference between top and bottom are within a pixel then we should treat
            // them as equivalent by using Math.floor. For instance 5.2222 and 5.222221 should be equivalent,
            // but without Math.Floor they will be handled incorrectly.
            var targetRectTop = Math.floor(targetRect.top);
            var activeRectBottom = Math.floor(activeRect.bottom);
            if (targetRectTop < activeRectBottom) {
                if (!_this._shouldWrapFocus(_this._activeElement, NO_VERTICAL_WRAP)) {
                    return LARGE_NEGATIVE_DISTANCE_FROM_CENTER;
                }
                return LARGE_DISTANCE_FROM_CENTER;
            }
            if ((targetTop === -1 && targetRectTop >= activeRectBottom) || targetRectTop === targetTop) {
                targetTop = targetRectTop;
                if (leftAlignment >= targetRect.left && leftAlignment <= targetRect.left + targetRect.width) {
                    distance = 0;
                }
                else {
                    distance = Math.abs(targetRect.left + targetRect.width / 2 - leftAlignment);
                }
            }
            return distance;
        })) {
            this._setFocusAlignment(this._activeElement, false, true);
            return true;
        }
        return false;
    };
    FocusZone.prototype._moveFocusUp = function () {
        var _this = this;
        var targetTop = -1;
        // eslint-disable-next-line deprecation/deprecation
        var leftAlignment = this._focusAlignment.left || this._focusAlignment.x || 0;
        if (this._moveFocus(false, function (activeRect, targetRect) {
            var distance = -1;
            // ClientRect values can be floats that differ by very small fractions of a decimal.
            // If the difference between top and bottom are within a pixel then we should treat
            // them as equivalent by using Math.floor. For instance 5.2222 and 5.222221 should be equivalent,
            // but without Math.Floor they will be handled incorrectly.
            var targetRectBottom = Math.floor(targetRect.bottom);
            var targetRectTop = Math.floor(targetRect.top);
            var activeRectTop = Math.floor(activeRect.top);
            if (targetRectBottom > activeRectTop) {
                if (!_this._shouldWrapFocus(_this._activeElement, NO_VERTICAL_WRAP)) {
                    return LARGE_NEGATIVE_DISTANCE_FROM_CENTER;
                }
                return LARGE_DISTANCE_FROM_CENTER;
            }
            if ((targetTop === -1 && targetRectBottom <= activeRectTop) || targetRectTop === targetTop) {
                targetTop = targetRectTop;
                if (leftAlignment >= targetRect.left && leftAlignment <= targetRect.left + targetRect.width) {
                    distance = 0;
                }
                else {
                    distance = Math.abs(targetRect.left + targetRect.width / 2 - leftAlignment);
                }
            }
            return distance;
        })) {
            this._setFocusAlignment(this._activeElement, false, true);
            return true;
        }
        return false;
    };
    FocusZone.prototype._moveFocusLeft = function () {
        var _this = this;
        var shouldWrap = this._shouldWrapFocus(this._activeElement, NO_HORIZONTAL_WRAP);
        if (this._moveFocus(getRTL$1(), function (activeRect, targetRect) {
            var distance = -1;
            var topBottomComparison;
            if (getRTL$1()) {
                // When in RTL, this comparison should be the same as the one in _moveFocusRight for LTR.
                // Going left at a leftmost rectangle will go down a line instead of up a line like in LTR.
                // This is important, because we want to be comparing the top of the target rect
                // with the bottom of the active rect.
                topBottomComparison = parseFloat(targetRect.top.toFixed(3)) < parseFloat(activeRect.bottom.toFixed(3));
            }
            else {
                topBottomComparison = parseFloat(targetRect.bottom.toFixed(3)) > parseFloat(activeRect.top.toFixed(3));
            }
            if (topBottomComparison &&
                targetRect.right <= activeRect.right &&
                _this.props.direction !== FocusZoneDirection.vertical) {
                distance = activeRect.right - targetRect.right;
            }
            else if (!shouldWrap) {
                distance = LARGE_NEGATIVE_DISTANCE_FROM_CENTER;
            }
            return distance;
        }, undefined /*ev*/, shouldWrap)) {
            this._setFocusAlignment(this._activeElement, true, false);
            return true;
        }
        return false;
    };
    FocusZone.prototype._moveFocusRight = function () {
        var _this = this;
        var shouldWrap = this._shouldWrapFocus(this._activeElement, NO_HORIZONTAL_WRAP);
        if (this._moveFocus(!getRTL$1(), function (activeRect, targetRect) {
            var distance = -1;
            var topBottomComparison;
            if (getRTL$1()) {
                // When in RTL, this comparison should be the same as the one in _moveFocusLeft for LTR.
                // Going right at a rightmost rectangle will go up a line instead of down a line like in LTR.
                // This is important, because we want to be comparing the bottom of the target rect
                // with the top of the active rect.
                topBottomComparison = parseFloat(targetRect.bottom.toFixed(3)) > parseFloat(activeRect.top.toFixed(3));
            }
            else {
                topBottomComparison = parseFloat(targetRect.top.toFixed(3)) < parseFloat(activeRect.bottom.toFixed(3));
            }
            if (topBottomComparison &&
                targetRect.left >= activeRect.left &&
                _this.props.direction !== FocusZoneDirection.vertical) {
                distance = targetRect.left - activeRect.left;
            }
            else if (!shouldWrap) {
                distance = LARGE_NEGATIVE_DISTANCE_FROM_CENTER;
            }
            return distance;
        }, undefined /*ev*/, shouldWrap)) {
            this._setFocusAlignment(this._activeElement, true, false);
            return true;
        }
        return false;
    };
    FocusZone.prototype._moveFocusPaging = function (isForward, useDefaultWrap) {
        if (useDefaultWrap === void 0) { useDefaultWrap = true; }
        var element = this._activeElement;
        if (!element || !this._root.current) {
            return false;
        }
        if (this._isElementInput(element)) {
            if (!this._shouldInputLoseFocus(element, isForward)) {
                return false;
            }
        }
        var scrollableParent = findScrollableParent(element);
        if (!scrollableParent) {
            return false;
        }
        var candidateDistance = -1;
        var candidateElement = undefined;
        var targetTop = -1;
        var targetBottom = -1;
        var pagesize = scrollableParent.clientHeight;
        var activeRect = element.getBoundingClientRect();
        do {
            element = isForward
                ? getNextElement(this._root.current, element)
                : getPreviousElement(this._root.current, element);
            if (element) {
                var targetRect = element.getBoundingClientRect();
                var targetRectTop = Math.floor(targetRect.top);
                var activeRectBottom = Math.floor(activeRect.bottom);
                var targetRectBottom = Math.floor(targetRect.bottom);
                var activeRectTop = Math.floor(activeRect.top);
                var elementDistance = this._getHorizontalDistanceFromCenter(isForward, activeRect, targetRect);
                var isElementPassedPageSizeOnPagingDown = isForward && targetRectTop > activeRectBottom + pagesize;
                var isElementPassedPageSizeOnPagingUp = !isForward && targetRectBottom < activeRectTop - pagesize;
                if (isElementPassedPageSizeOnPagingDown || isElementPassedPageSizeOnPagingUp) {
                    break;
                }
                if (elementDistance > -1) {
                    // for paging down
                    if (isForward && targetRectTop > targetTop) {
                        targetTop = targetRectTop;
                        candidateDistance = elementDistance;
                        candidateElement = element;
                    }
                    else if (!isForward && targetRectBottom < targetBottom) {
                        // for paging up
                        targetBottom = targetRectBottom;
                        candidateDistance = elementDistance;
                        candidateElement = element;
                    }
                    else if (candidateDistance === -1 || elementDistance <= candidateDistance) {
                        candidateDistance = elementDistance;
                        candidateElement = element;
                    }
                }
            }
        } while (element);
        var changedFocus = false;
        // Focus the closest candidate
        if (candidateElement && candidateElement !== this._activeElement) {
            changedFocus = true;
            this.focusElement(candidateElement);
            this._setFocusAlignment(candidateElement, false, true);
        }
        else if (this.props.isCircularNavigation && useDefaultWrap) {
            if (isForward) {
                return this.focusElement(getNextElement(this._root.current, this._root.current.firstElementChild, true));
            }
            return this.focusElement(getPreviousElement(this._root.current, this._root.current.lastElementChild, true, true, true));
        }
        return changedFocus;
    };
    FocusZone.prototype._setFocusAlignment = function (element, isHorizontal, isVertical) {
        if (this.props.direction === FocusZoneDirection.bidirectional &&
            (!this._focusAlignment || isHorizontal || isVertical)) {
            var rect = element.getBoundingClientRect();
            var left = rect.left + rect.width / 2;
            var top_1 = rect.top + rect.height / 2;
            if (!this._focusAlignment) {
                this._focusAlignment = { left: left, top: top_1 };
            }
            if (isHorizontal) {
                this._focusAlignment.left = left;
            }
            if (isVertical) {
                this._focusAlignment.top = top_1;
            }
        }
    };
    FocusZone.prototype._isImmediateDescendantOfZone = function (element) {
        return this._getOwnerZone(element) === this._root.current;
    };
    FocusZone.prototype._getOwnerZone = function (element) {
        var parentElement = getParent(element, ALLOW_VIRTUAL_ELEMENTS);
        while (parentElement && parentElement !== this._root.current && parentElement !== this._getDocument().body) {
            if (isElementFocusZone(parentElement)) {
                return parentElement;
            }
            parentElement = getParent(parentElement, ALLOW_VIRTUAL_ELEMENTS);
        }
        return parentElement;
    };
    FocusZone.prototype._updateTabIndexes = function (element) {
        if (!this._activeElement &&
            this.props.defaultTabbableElement &&
            typeof this.props.defaultTabbableElement === 'function') {
            this._activeElement = this.props.defaultTabbableElement(this._root.current);
        }
        if (!element && this._root.current) {
            this._defaultFocusElement = null;
            element = this._root.current;
            if (this._activeElement && !elementContains(element, this._activeElement)) {
                this._activeElement = null;
            }
        }
        // If active element changes state to disabled, set it to null.
        // Otherwise, we lose keyboard accessibility to other elements in focus zone.
        if (this._activeElement && !isElementTabbable(this._activeElement)) {
            this._activeElement = null;
        }
        var childNodes = element && element.children;
        for (var childIndex = 0; childNodes && childIndex < childNodes.length; childIndex++) {
            var child = childNodes[childIndex];
            if (!isElementFocusZone(child)) {
                // If the item is explicitly set to not be focusable then TABINDEX needs to be set to -1.
                if (child.getAttribute && child.getAttribute(IS_FOCUSABLE_ATTRIBUTE$1) === 'false') {
                    child.setAttribute(TABINDEX, '-1');
                }
                if (isElementTabbable(child)) {
                    if (this.props.disabled) {
                        child.setAttribute(TABINDEX, '-1');
                    }
                    else if (!this._isInnerZone &&
                        ((!this._activeElement && !this._defaultFocusElement) || this._activeElement === child)) {
                        this._defaultFocusElement = child;
                        if (child.getAttribute(TABINDEX) !== '0') {
                            child.setAttribute(TABINDEX, '0');
                        }
                    }
                    else if (child.getAttribute(TABINDEX) !== '-1') {
                        child.setAttribute(TABINDEX, '-1');
                    }
                }
                else if (child.tagName === 'svg' && child.getAttribute('focusable') !== 'false') {
                    // Disgusting IE hack. Sad face.
                    child.setAttribute('focusable', 'false');
                }
            }
            else if (child.getAttribute(IS_FOCUSABLE_ATTRIBUTE$1) === 'true') {
                if (!this._isInnerZone &&
                    ((!this._activeElement && !this._defaultFocusElement) || this._activeElement === child)) {
                    this._defaultFocusElement = child;
                    if (child.getAttribute(TABINDEX) !== '0') {
                        child.setAttribute(TABINDEX, '0');
                    }
                }
                else if (child.getAttribute(TABINDEX) !== '-1') {
                    child.setAttribute(TABINDEX, '-1');
                }
            }
            this._updateTabIndexes(child);
        }
    };
    FocusZone.prototype._isContentEditableElement = function (element) {
        return element && element.getAttribute('contenteditable') === 'true';
    };
    FocusZone.prototype._isElementInput = function (element) {
        if (element &&
            element.tagName &&
            (element.tagName.toLowerCase() === 'input' || element.tagName.toLowerCase() === 'textarea')) {
            return true;
        }
        return false;
    };
    FocusZone.prototype._shouldInputLoseFocus = function (element, isForward) {
        // If a tab was used, we want to focus on the next element.
        if (!this._processingTabKey &&
            element &&
            element.type &&
            ALLOWED_INPUT_TYPES.indexOf(element.type.toLowerCase()) > -1) {
            var selectionStart = element.selectionStart;
            var selectionEnd = element.selectionEnd;
            var isRangeSelected = selectionStart !== selectionEnd;
            var inputValue = element.value;
            var isReadonly = element.readOnly;
            // We shouldn't lose focus in the following cases:
            // 1. There is range selected.
            // 2. When selection start is larger than 0 and it is backward and not readOnly.
            // 3. when selection start is not the end of length, it is forward and not readOnly.
            // 4. We press any of the arrow keys when our handleTabKey isn't none or undefined (only losing focus if we hit
            // tab) and if shouldInputLoseFocusOnArrowKey is defined, if scenario prefers to not loose the focus which is
            // determined by calling the callback shouldInputLoseFocusOnArrowKey
            if (isRangeSelected ||
                (selectionStart > 0 && !isForward && !isReadonly) ||
                (selectionStart !== inputValue.length && isForward && !isReadonly) ||
                (!!this.props.handleTabKey &&
                    !(this.props.shouldInputLoseFocusOnArrowKey && this.props.shouldInputLoseFocusOnArrowKey(element)))) {
                return false;
            }
        }
        return true;
    };
    FocusZone.prototype._shouldWrapFocus = function (element, noWrapDataAttribute) {
        return this.props.checkForNoWrap ? shouldWrapFocus(element, noWrapDataAttribute) : true;
    };
    /**
     * Returns true if the element is a descendant of the FocusZone through a React portal.
     */
    FocusZone.prototype._portalContainsElement = function (element) {
        return element && !!this._root.current && portalContainsElement(element, this._root.current);
    };
    FocusZone.prototype._getDocument = function () {
        return getDocument(this._root.current);
    };
    FocusZone.defaultProps = {
        isCircularNavigation: false,
        direction: FocusZoneDirection.bidirectional,
        shouldRaiseClicks: true,
    };
    return FocusZone;
}(Component));

/**
 * Determines the effective checked state of a menu item.
 *
 * @param item {IContextualMenuItem} to get the check state of.
 * @returns {true} if the item is checked.
 * @returns {false} if the item is unchecked.
 * @returns {null} if the item is not checkable.
 */
function getIsChecked(item) {
    if (item.canCheck) {
        return !!(item.isChecked || item.checked);
    }
    if (typeof item.isChecked === 'boolean') {
        return item.isChecked;
    }
    if (typeof item.checked === 'boolean') {
        return item.checked;
    }
    // Item is not checkable.
    return null;
}
function hasSubmenu(item) {
    return !!(item.subMenuProps || item.items);
}
function isItemDisabled(item) {
    return !!(item.isDisabled || item.disabled);
}
function getMenuItemAriaRole(item) {
    var isChecked = getIsChecked(item);
    var canCheck = isChecked !== null;
    return canCheck ? 'menuitemcheckbox' : 'menuitem';
}

var BaseDecorator = /** @class */ (function (_super) {
    __extends(BaseDecorator, _super);
    function BaseDecorator(props) {
        var _this = _super.call(this, props) || this;
        _this._updateComposedComponentRef = _this._updateComposedComponentRef.bind(_this);
        return _this;
    }
    /**
     * Updates the ref to the component composed by the decorator, which will also take care of hoisting
     * (and unhoisting as appropriate) methods from said component.
     *
     * Pass this method as the argument to the 'ref' property of the composed component.
     */
    BaseDecorator.prototype._updateComposedComponentRef = function (composedComponentInstance) {
        this._composedComponentInstance = composedComponentInstance;
        if (composedComponentInstance) {
            this._hoisted = hoistMethods(this, composedComponentInstance);
        }
        else if (this._hoisted) {
            unhoistMethods(this, this._hoisted);
        }
    };
    return BaseDecorator;
}(Component));

var ResponsiveMode;
(function (ResponsiveMode) {
    ResponsiveMode[ResponsiveMode["small"] = 0] = "small";
    ResponsiveMode[ResponsiveMode["medium"] = 1] = "medium";
    ResponsiveMode[ResponsiveMode["large"] = 2] = "large";
    ResponsiveMode[ResponsiveMode["xLarge"] = 3] = "xLarge";
    ResponsiveMode[ResponsiveMode["xxLarge"] = 4] = "xxLarge";
    ResponsiveMode[ResponsiveMode["xxxLarge"] = 5] = "xxxLarge";
    ResponsiveMode[ResponsiveMode["unknown"] = 999] = "unknown";
})(ResponsiveMode || (ResponsiveMode = {}));
var RESPONSIVE_MAX_CONSTRAINT = [479, 639, 1023, 1365, 1919, 99999999];
/**
 * Tracking the last mode we successfully rendered, which allows us to
 * paint initial renders with the correct size.
 */
var _lastMode;
function getInitialResponsiveMode() {
    return  _lastMode || ResponsiveMode.large;
}
function withResponsiveMode(ComposedComponent) {
    var resultClass = /** @class */ (function (_super) {
        __extends(WithResponsiveMode, _super);
        function WithResponsiveMode(props) {
            var _this = _super.call(this, props) || this;
            _this._onResize = function () {
                var element = findDOMNode(_this);
                var currentWindow = (element && getWindow(element)) || window;
                var responsiveMode = getResponsiveMode(currentWindow);
                if (responsiveMode !== _this.state.responsiveMode) {
                    _this.setState({
                        responsiveMode: responsiveMode,
                    });
                }
            };
            _this._events = new EventGroup(_this);
            _this._updateComposedComponentRef = _this._updateComposedComponentRef.bind(_this);
            _this.state = {
                responsiveMode: getInitialResponsiveMode(),
            };
            return _this;
        }
        WithResponsiveMode.prototype.componentDidMount = function () {
            this._events.on(window, 'resize', this._onResize);
            this._onResize();
        };
        WithResponsiveMode.prototype.componentWillUnmount = function () {
            this._events.dispose();
        };
        WithResponsiveMode.prototype.render = function () {
            var responsiveMode = this.state.responsiveMode;
            return responsiveMode === ResponsiveMode.unknown ? null : (createElement(ComposedComponent, __assign({ ref: this._updateComposedComponentRef, responsiveMode: responsiveMode }, this.props)));
        };
        return WithResponsiveMode;
    }(BaseDecorator));
    return hoistStatics(ComposedComponent, resultClass);
}
function getResponsiveMode(currentWindow) {
    var responsiveMode = ResponsiveMode.small;
    if (currentWindow) {
        try {
            while (currentWindow.innerWidth > RESPONSIVE_MAX_CONSTRAINT[responsiveMode]) {
                responsiveMode++;
            }
        }
        catch (e) {
            // Return a best effort result in cases where we're in the browser but it throws on getting innerWidth.
            responsiveMode = getInitialResponsiveMode();
        }
        // Tracking last mode just gives us a better default in future renders,
        // which avoids starting with the wrong value if we've measured once.
        _lastMode = responsiveMode;
    }
    else {
        {
            throw new Error('Content was rendered in a server environment without providing a default responsive mode. ' +
                'Call setResponsiveMode to define what the responsive mode is.');
        }
    }
    return responsiveMode;
}

var RectangleEdge;
(function (RectangleEdge) {
    RectangleEdge[RectangleEdge["top"] = 1] = "top";
    RectangleEdge[RectangleEdge["bottom"] = -1] = "bottom";
    RectangleEdge[RectangleEdge["left"] = 2] = "left";
    RectangleEdge[RectangleEdge["right"] = -2] = "right";
})(RectangleEdge || (RectangleEdge = {}));
var Position;
(function (Position) {
    Position[Position["top"] = 0] = "top";
    Position[Position["bottom"] = 1] = "bottom";
    Position[Position["start"] = 2] = "start";
    Position[Position["end"] = 3] = "end";
})(Position || (Position = {}));

var _a$2;
var Rectangle$1 = /** @class */ (function (_super) {
    __extends(Rectangle, _super);
    function Rectangle() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Rectangle;
}(Rectangle));
function _createPositionData(targetEdge, alignmentEdge, isAuto) {
    return {
        targetEdge: targetEdge,
        alignmentEdge: alignmentEdge,
        isAuto: isAuto,
    };
}
// Currently the beakPercent is set to 50 for all positions meaning that it should tend to the center of the target
var DirectionalDictionary = (_a$2 = {},
    _a$2[DirectionalHint.topLeftEdge] = _createPositionData(RectangleEdge.top, RectangleEdge.left),
    _a$2[DirectionalHint.topCenter] = _createPositionData(RectangleEdge.top),
    _a$2[DirectionalHint.topRightEdge] = _createPositionData(RectangleEdge.top, RectangleEdge.right),
    _a$2[DirectionalHint.topAutoEdge] = _createPositionData(RectangleEdge.top, undefined, true),
    _a$2[DirectionalHint.bottomLeftEdge] = _createPositionData(RectangleEdge.bottom, RectangleEdge.left),
    _a$2[DirectionalHint.bottomCenter] = _createPositionData(RectangleEdge.bottom),
    _a$2[DirectionalHint.bottomRightEdge] = _createPositionData(RectangleEdge.bottom, RectangleEdge.right),
    _a$2[DirectionalHint.bottomAutoEdge] = _createPositionData(RectangleEdge.bottom, undefined, true),
    _a$2[DirectionalHint.leftTopEdge] = _createPositionData(RectangleEdge.left, RectangleEdge.top),
    _a$2[DirectionalHint.leftCenter] = _createPositionData(RectangleEdge.left),
    _a$2[DirectionalHint.leftBottomEdge] = _createPositionData(RectangleEdge.left, RectangleEdge.bottom),
    _a$2[DirectionalHint.rightTopEdge] = _createPositionData(RectangleEdge.right, RectangleEdge.top),
    _a$2[DirectionalHint.rightCenter] = _createPositionData(RectangleEdge.right),
    _a$2[DirectionalHint.rightBottomEdge] = _createPositionData(RectangleEdge.right, RectangleEdge.bottom),
    _a$2);
function _isRectangleWithinBounds(rect, boundingRect) {
    if (rect.top < boundingRect.top) {
        return false;
    }
    if (rect.bottom > boundingRect.bottom) {
        return false;
    }
    if (rect.left < boundingRect.left) {
        return false;
    }
    if (rect.right > boundingRect.right) {
        return false;
    }
    return true;
}
/**
 * Gets all of the edges of a rectangle that are outside of the given bounds.
 * If there are no out of bounds edges it returns an empty array.
 */
function _getOutOfBoundsEdges(rect, boundingRect) {
    var outOfBounds = [];
    if (rect.top < boundingRect.top) {
        outOfBounds.push(RectangleEdge.top);
    }
    if (rect.bottom > boundingRect.bottom) {
        outOfBounds.push(RectangleEdge.bottom);
    }
    if (rect.left < boundingRect.left) {
        outOfBounds.push(RectangleEdge.left);
    }
    if (rect.right > boundingRect.right) {
        outOfBounds.push(RectangleEdge.right);
    }
    return outOfBounds;
}
function _getEdgeValue(rect, edge) {
    return rect[RectangleEdge[edge]];
}
function _setEdgeValue(rect, edge, value) {
    rect[RectangleEdge[edge]] = value;
    return rect;
}
/**
 * Returns the middle value of an edge. Only returns 1 value rather than xy coordinates as
 * the itself already contains the other coordinate.
 * For instance, a bottom edge's current value is it's y coordinate, so the number returned is the x.
 */
function _getCenterValue(rect, edge) {
    var edges = _getFlankingEdges(edge);
    return (_getEdgeValue(rect, edges.positiveEdge) + _getEdgeValue(rect, edges.negativeEdge)) / 2;
}
/**
 * Flips the value depending on the edge.
 * If the edge is a "positive" edge, Top or Left, then the value should stay as it is.
 * If the edge is a "negative" edge, Bottom or Right, then the value should be flipped.
 * This is to account for the fact that the coordinates are effectively reveserved in certain cases for the
 * "negative" edges.
 *
 * For example, when testing to see if a bottom edge 1 is within the bounds of another bottom edge 2:
 * If edge 1 is greater than edge 2 then it is out of bounds. This is reversed for top edge 1 and top edge 2.
 * If top edge 1 is less than edge 2 then it is out of bounds.
 */
function _getRelativeEdgeValue(edge, value) {
    if (edge > 0) {
        return value;
    }
    else {
        return value * -1;
    }
}
function _getRelativeRectEdgeValue(edge, rect) {
    return _getRelativeEdgeValue(edge, _getEdgeValue(rect, edge));
}
function _getRelativeEdgeDifference(rect, hostRect, edge) {
    var edgeDifference = _getEdgeValue(rect, edge) - _getEdgeValue(hostRect, edge);
    return _getRelativeEdgeValue(edge, edgeDifference);
}
/**
 * Moves the edge of a rectangle to the value given. It only moves the edge in a linear direction based on that edge.
 * For example, if it's a bottom edge it will only change y coordinates.
 */
function _moveEdge(rect, edge, newValue) {
    var difference = _getEdgeValue(rect, edge) - newValue;
    rect = _setEdgeValue(rect, edge, newValue);
    rect = _setEdgeValue(rect, edge * -1, _getEdgeValue(rect, edge * -1) - difference);
    return rect;
}
/**
 * Aligns the edge on the passed in rect to the target. If there is a gap then it will have that space between the two.
 */
function _alignEdges(rect, target, edge, gap) {
    if (gap === void 0) { gap = 0; }
    return _moveEdge(rect, edge, _getEdgeValue(target, edge) + _getRelativeEdgeValue(edge, gap));
}
/**
 * Aligns the targetEdge on the passed in target to the rects corresponding opposite edge.
 * For instance if targetEdge is bottom, then the rects top will be moved to match it.
 */
function _alignOppositeEdges(rect, target, targetEdge, gap) {
    if (gap === void 0) { gap = 0; }
    var oppositeEdge = targetEdge * -1;
    var adjustedGap = _getRelativeEdgeValue(oppositeEdge, gap);
    return _moveEdge(rect, targetEdge * -1, _getEdgeValue(target, targetEdge) + adjustedGap);
}
/**
 * Tests to see if the given edge is within the bounds of the given rectangle.
 */
function _isEdgeInBounds(rect, bounds, edge) {
    var adjustedRectValue = _getRelativeRectEdgeValue(edge, rect);
    return adjustedRectValue > _getRelativeRectEdgeValue(edge, bounds);
}
/**
 * Attempts to move the rectangle through various sides of the target to find a place to fit.
 * If no fit is found, the original position should be returned.
 */
function _flipToFit(rect, target, bounding, positionData, gap) {
    if (gap === void 0) { gap = 0; }
    var directions = [
        RectangleEdge.left,
        RectangleEdge.right,
        RectangleEdge.bottom,
        RectangleEdge.top,
    ];
    // In RTL page, RectangleEdge.right has a higher priority than RectangleEdge.left, so the order should be updated.
    if (getRTL$1()) {
        directions[0] *= -1;
        directions[1] *= -1;
    }
    var currentEstimate = rect;
    var currentEdge = positionData.targetEdge;
    var currentAlignment = positionData.alignmentEdge;
    // Keep switching sides until one is found with enough space.
    // If all sides don't fit then return the unmodified element.
    for (var i = 0; i < 4; i++) {
        if (!_isEdgeInBounds(currentEstimate, bounding, currentEdge)) {
            directions.splice(directions.indexOf(currentEdge), 1);
            if (directions.length > 0) {
                if (directions.indexOf(currentEdge * -1) > -1) {
                    currentEdge = currentEdge * -1;
                }
                else {
                    currentAlignment = currentEdge;
                    currentEdge = directions.slice(-1)[0];
                }
                currentEstimate = _estimatePosition(rect, target, { targetEdge: currentEdge, alignmentEdge: currentAlignment }, gap);
            }
        }
        else {
            return {
                elementRectangle: currentEstimate,
                targetEdge: currentEdge,
                alignmentEdge: currentAlignment,
            };
        }
    }
    return {
        elementRectangle: rect,
        targetEdge: positionData.targetEdge,
        alignmentEdge: currentAlignment,
    };
}
/**
 * Flips only the alignment edge of an element rectangle. This is used instead of nudging the alignment edges
 * into position, when alignTargetEdge is specified.
 */
function _flipAlignmentEdge(elementEstimate, target, gap, coverTarget) {
    var alignmentEdge = elementEstimate.alignmentEdge, targetEdge = elementEstimate.targetEdge, elementRectangle = elementEstimate.elementRectangle;
    var oppositeEdge = alignmentEdge * -1;
    var newEstimate = _estimatePosition(elementRectangle, target, { targetEdge: targetEdge, alignmentEdge: oppositeEdge }, gap, coverTarget);
    return {
        elementRectangle: newEstimate,
        targetEdge: targetEdge,
        alignmentEdge: oppositeEdge,
    };
}
/**
 * Adjusts a element rectangle to fit within the bounds given. If directionalHintFixed or covertarget is passed in
 * then the element will not flip sides on the target. They will, however, be nudged to fit within the bounds given.
 */
function _adjustFitWithinBounds(element, target, bounding, positionData, gap, directionalHintFixed, coverTarget) {
    if (gap === void 0) { gap = 0; }
    var alignmentEdge = positionData.alignmentEdge, alignTargetEdge = positionData.alignTargetEdge;
    var elementEstimate = {
        elementRectangle: element,
        targetEdge: positionData.targetEdge,
        alignmentEdge: alignmentEdge,
    };
    if (!directionalHintFixed && !coverTarget) {
        elementEstimate = _flipToFit(element, target, bounding, positionData, gap);
    }
    var outOfBounds = _getOutOfBoundsEdges(element, bounding);
    if (alignTargetEdge) {
        // The edge opposite to the alignment edge might be out of bounds.
        // Flip alignment to see if we can get it within bounds.
        if (elementEstimate.alignmentEdge && outOfBounds.indexOf(elementEstimate.alignmentEdge * -1) > -1) {
            var flippedElementEstimate = _flipAlignmentEdge(elementEstimate, target, gap, coverTarget);
            if (_isRectangleWithinBounds(flippedElementEstimate.elementRectangle, bounding)) {
                return flippedElementEstimate;
            }
            else {
                // If the flipped elements edges are still out of bounds, try nudging it.
                elementEstimate = _alignOutOfBoundsEdges(_getOutOfBoundsEdges(flippedElementEstimate.elementRectangle, bounding), elementEstimate, bounding);
            }
        }
    }
    else {
        elementEstimate = _alignOutOfBoundsEdges(outOfBounds, elementEstimate, bounding);
    }
    return elementEstimate;
}
/**
 * Iterates through a list of out of bounds edges and tries to nudge and align them.
 * @param outOfBoundsEdges - Array of edges that are out of bounds
 * @param elementEstimate - The current element positioning estimate
 * @param bounding - The current bounds
 */
function _alignOutOfBoundsEdges(outOfBoundsEdges, elementEstimate, bounding) {
    for (var _i = 0, outOfBoundsEdges_1 = outOfBoundsEdges; _i < outOfBoundsEdges_1.length; _i++) {
        var direction = outOfBoundsEdges_1[_i];
        elementEstimate.elementRectangle = _alignEdges(elementEstimate.elementRectangle, bounding, direction);
    }
    return elementEstimate;
}
/**
 * Moves the middle point on an edge to the point given.
 * Only moves in one direction. For instance if a bottom edge is passed in, then
 * the bottom edge will be moved in the x axis to match the point.
 */
function _centerEdgeToPoint(rect, edge, point) {
    var positiveEdge = _getFlankingEdges(edge).positiveEdge;
    var elementMiddle = _getCenterValue(rect, edge);
    var distanceToMiddle = elementMiddle - _getEdgeValue(rect, positiveEdge);
    return _moveEdge(rect, positiveEdge, point - distanceToMiddle);
}
/**
 * Moves the element rectangle to be appropriately positioned relative to a given target.
 * Does not flip or adjust the element.
 */
function _estimatePosition(elementToPosition, target, positionData, gap, coverTarget) {
    if (gap === void 0) { gap = 0; }
    var estimatedElementPosition;
    var alignmentEdge = positionData.alignmentEdge, targetEdge = positionData.targetEdge;
    var elementEdge = coverTarget ? targetEdge : targetEdge * -1;
    estimatedElementPosition = coverTarget
        ? _alignEdges(elementToPosition, target, targetEdge, gap)
        : _alignOppositeEdges(elementToPosition, target, targetEdge, gap);
    // if no alignment edge is provided it's supposed to be centered.
    if (!alignmentEdge) {
        var targetMiddlePoint = _getCenterValue(target, targetEdge);
        estimatedElementPosition = _centerEdgeToPoint(estimatedElementPosition, elementEdge, targetMiddlePoint);
    }
    else {
        estimatedElementPosition = _alignEdges(estimatedElementPosition, target, alignmentEdge);
    }
    return estimatedElementPosition;
}
/**
 * Returns the non-opposite edges of the target edge.
 * For instance if bottom is passed in then left and right will be returned.
 */
function _getFlankingEdges(edge) {
    if (edge === RectangleEdge.top || edge === RectangleEdge.bottom) {
        return {
            positiveEdge: RectangleEdge.left,
            negativeEdge: RectangleEdge.right,
        };
    }
    else {
        return {
            positiveEdge: RectangleEdge.top,
            negativeEdge: RectangleEdge.bottom,
        };
    }
}
/**
 * Retrieve the final value for the return edge of elementRectangle. If the elementRectangle is closer to one side
 * of the bounds versus the other, the return edge is flipped to grow inward.
 */
function _finalizeReturnEdge(elementRectangle, returnEdge, bounds) {
    if (bounds &&
        Math.abs(_getRelativeEdgeDifference(elementRectangle, bounds, returnEdge)) >
            Math.abs(_getRelativeEdgeDifference(elementRectangle, bounds, returnEdge * -1))) {
        return returnEdge * -1;
    }
    return returnEdge;
}
/**
 * Finalizes the element positon based on the hostElement. Only returns the
 * rectangle values to position such that they are anchored to the target.
 * This helps prevent resizing from looking very strange.
 * For instance, if the target edge is top and aligned with the left side then
 * the bottom and left values are returned so as the callou shrinks it shrinks towards that corner.
 */
function _finalizeElementPosition(elementRectangle, hostElement, targetEdge, bounds, alignmentEdge, coverTarget, doNotFinalizeReturnEdge) {
    var returnValue = {};
    var hostRect = _getRectangleFromElement(hostElement);
    var elementEdge = coverTarget ? targetEdge : targetEdge * -1;
    var elementEdgeString = RectangleEdge[elementEdge];
    var returnEdge = alignmentEdge ? alignmentEdge : _getFlankingEdges(targetEdge).positiveEdge;
    if (!doNotFinalizeReturnEdge) {
        returnEdge = _finalizeReturnEdge(elementRectangle, returnEdge, bounds);
    }
    returnValue[elementEdgeString] = _getRelativeEdgeDifference(elementRectangle, hostRect, elementEdge);
    returnValue[RectangleEdge[returnEdge]] = _getRelativeEdgeDifference(elementRectangle, hostRect, returnEdge);
    return returnValue;
}
// Since the beak is rotated 45 degrees the actual height/width is the length of the diagonal.
// We still want to position the beak based on it's midpoint which does not change. It will
// be at (beakwidth / 2, beakwidth / 2)
function _calculateActualBeakWidthInPixels(beakWidth) {
    return Math.sqrt(beakWidth * beakWidth * 2);
}
/**
 * Returns the appropriate IPositionData based on the props altered for RTL.
 * If directionalHintForRTL is passed in that is used if the page is RTL.
 * If directionalHint is specified, no directionalHintForRTL is available, and the page is RTL, the hint will be
 * flipped (e.g. bottomLeftEdge would become bottomRightEdge).
 *
 * If there is no directionalHint passed in, bottomAutoEdge is chosen automatically.
 */
function _getPositionData(directionalHint, directionalHintForRTL, previousPositions) {
    if (directionalHint === void 0) { directionalHint = DirectionalHint.bottomAutoEdge; }
    if (previousPositions) {
        return {
            alignmentEdge: previousPositions.alignmentEdge,
            isAuto: previousPositions.isAuto,
            targetEdge: previousPositions.targetEdge,
        };
    }
    var positionInformation = __assign({}, DirectionalDictionary[directionalHint]);
    if (getRTL$1()) {
        // If alignment edge exists and that alignment edge is -2 or 2, right or left, then flip it.
        if (positionInformation.alignmentEdge && positionInformation.alignmentEdge % 2 === 0) {
            positionInformation.alignmentEdge = positionInformation.alignmentEdge * -1;
        }
        return directionalHintForRTL !== undefined ? DirectionalDictionary[directionalHintForRTL] : positionInformation;
    }
    return positionInformation;
}
/**
 * Get's the alignment data for the given information. This only really matters if the positioning is Auto.
 * If it is auto then the alignmentEdge should be chosen based on the target edge's position relative to
 * the center of the page.
 */
function _getAlignmentData(positionData, target, boundingRect, coverTarget, alignTargetEdge) {
    if (positionData.isAuto) {
        positionData.alignmentEdge = getClosestEdge(positionData.targetEdge, target, boundingRect);
    }
    positionData.alignTargetEdge = alignTargetEdge;
    return positionData;
}
function getClosestEdge(targetEdge, target, boundingRect) {
    var targetCenter = _getCenterValue(target, targetEdge);
    var boundingCenter = _getCenterValue(boundingRect, targetEdge);
    var _a = _getFlankingEdges(targetEdge), positiveEdge = _a.positiveEdge, negativeEdge = _a.negativeEdge;
    if (targetCenter <= boundingCenter) {
        return positiveEdge;
    }
    else {
        return negativeEdge;
    }
}
function _positionElementWithinBounds(elementToPosition, target, bounding, positionData, gap, directionalHintFixed, coverTarget) {
    var estimatedElementPosition = _estimatePosition(elementToPosition, target, positionData, gap, coverTarget);
    if (_isRectangleWithinBounds(estimatedElementPosition, bounding)) {
        return {
            elementRectangle: estimatedElementPosition,
            targetEdge: positionData.targetEdge,
            alignmentEdge: positionData.alignmentEdge,
        };
    }
    else {
        return _adjustFitWithinBounds(elementToPosition, target, bounding, positionData, gap, directionalHintFixed, coverTarget);
    }
}
function _finalizeBeakPosition(elementPosition, positionedBeak, bounds) {
    var targetEdge = elementPosition.targetEdge * -1;
    // The "host" element that we will use to help position the beak.
    var actualElement = new Rectangle$1(0, elementPosition.elementRectangle.width, 0, elementPosition.elementRectangle.height);
    var returnValue = {};
    var returnEdge = _finalizeReturnEdge(elementPosition.elementRectangle, elementPosition.alignmentEdge ? elementPosition.alignmentEdge : _getFlankingEdges(targetEdge).positiveEdge, bounds);
    returnValue[RectangleEdge[targetEdge]] = _getEdgeValue(positionedBeak, targetEdge);
    returnValue[RectangleEdge[returnEdge]] = _getRelativeEdgeDifference(positionedBeak, actualElement, returnEdge);
    return {
        elementPosition: __assign({}, returnValue),
        closestEdge: getClosestEdge(elementPosition.targetEdge, positionedBeak, actualElement),
        targetEdge: targetEdge,
    };
}
function _positionBeak(beakWidth, elementPosition) {
    var target = elementPosition.targetRectangle;
    /**
     * Note about beak positioning: The actual beak width only matters for getting the gap between the callout and
     * target, it does not impact the beak placement within the callout. For example example, if the beakWidth is 8,
     * then the actual beakWidth is sqrroot(8^2 + 8^2) = 11.31x11.31. So the callout will need to be an extra 3 pixels
     * away from its target. While the beak is being positioned in the callout it still acts as though it were 8x8.
     */
    var _a = _getFlankingEdges(elementPosition.targetEdge), positiveEdge = _a.positiveEdge, negativeEdge = _a.negativeEdge;
    var beakTargetPoint = _getCenterValue(target, elementPosition.targetEdge);
    var elementBounds = new Rectangle$1(beakWidth / 2, elementPosition.elementRectangle.width - beakWidth / 2, beakWidth / 2, elementPosition.elementRectangle.height - beakWidth / 2);
    var beakPosition = new Rectangle$1(0, beakWidth, 0, beakWidth);
    beakPosition = _moveEdge(beakPosition, elementPosition.targetEdge * -1, -beakWidth / 2);
    beakPosition = _centerEdgeToPoint(beakPosition, elementPosition.targetEdge * -1, beakTargetPoint - _getRelativeRectEdgeValue(positiveEdge, elementPosition.elementRectangle));
    if (!_isEdgeInBounds(beakPosition, elementBounds, positiveEdge)) {
        beakPosition = _alignEdges(beakPosition, elementBounds, positiveEdge);
    }
    else if (!_isEdgeInBounds(beakPosition, elementBounds, negativeEdge)) {
        beakPosition = _alignEdges(beakPosition, elementBounds, negativeEdge);
    }
    return beakPosition;
}
function _getRectangleFromElement(element) {
    var clientRect = element.getBoundingClientRect();
    return new Rectangle$1(clientRect.left, clientRect.right, clientRect.top, clientRect.bottom);
}
function _getRectangleFromIRect(rect) {
    return new Rectangle$1(rect.left, rect.right, rect.top, rect.bottom);
}
function _getTargetRect(bounds, target) {
    var targetRectangle;
    if (target) {
        // eslint-disable-next-line no-extra-boolean-cast
        if (!!target.preventDefault) {
            var ev = target;
            targetRectangle = new Rectangle$1(ev.clientX, ev.clientX, ev.clientY, ev.clientY);
            // eslint-disable-next-line no-extra-boolean-cast
        }
        else if (!!target.getBoundingClientRect) {
            targetRectangle = _getRectangleFromElement(target);
            // HTMLImgElements can have x and y values. The check for it being a point must go last.
        }
        else {
            var point = target;
            // eslint-disable-next-line deprecation/deprecation
            var left = point.left || point.x;
            // eslint-disable-next-line deprecation/deprecation
            var top_1 = point.top || point.y;
            targetRectangle = new Rectangle$1(left, left, top_1, top_1);
        }
        if (!_isRectangleWithinBounds(targetRectangle, bounds)) {
            var outOfBounds = _getOutOfBoundsEdges(targetRectangle, bounds);
            for (var _i = 0, outOfBounds_1 = outOfBounds; _i < outOfBounds_1.length; _i++) {
                var direction = outOfBounds_1[_i];
                targetRectangle[RectangleEdge[direction]] = bounds[RectangleEdge[direction]];
            }
        }
    }
    else {
        targetRectangle = new Rectangle$1(0, 0, 0, 0);
    }
    return targetRectangle;
}
/**
 * If max height is less than zero it returns the bounds height instead.
 */
function _getMaxHeightFromTargetRectangle(targetRectangle, targetEdge, gapSpace, bounds, coverTarget) {
    var maxHeight = 0;
    var directionalHint = DirectionalDictionary[targetEdge];
    // If cover target is set, then the max height should be calculated using the opposite of the target edge since
    // that's the direction that the callout will expand in.
    // For instance, if the directionalhint is bottomLeftEdge then the callout will position so it's bottom edge
    // is aligned with the bottom of the target and expand up towards the top of the screen and the calculated max height
    // is (bottom of target) - (top of screen) - gapSpace.
    var target = coverTarget ? directionalHint.targetEdge * -1 : directionalHint.targetEdge;
    if (target === RectangleEdge.top) {
        maxHeight = _getEdgeValue(targetRectangle, directionalHint.targetEdge) - bounds.top - gapSpace;
    }
    else if (target === RectangleEdge.bottom) {
        maxHeight = bounds.bottom - _getEdgeValue(targetRectangle, directionalHint.targetEdge) - gapSpace;
    }
    else {
        maxHeight = bounds.bottom - targetRectangle.top - gapSpace;
    }
    return maxHeight > 0 ? maxHeight : bounds.height;
}
function _positionElementRelative(props, elementToPosition, boundingRect, previousPositions) {
    var gap = props.gapSpace ? props.gapSpace : 0;
    var targetRect = _getTargetRect(boundingRect, props.target);
    var positionData = _getAlignmentData(_getPositionData(props.directionalHint, props.directionalHintForRTL, previousPositions), targetRect, boundingRect, props.coverTarget, props.alignTargetEdge);
    var positionedElement = _positionElementWithinBounds(_getRectangleFromElement(elementToPosition), targetRect, boundingRect, positionData, gap, props.directionalHintFixed, props.coverTarget);
    return __assign(__assign({}, positionedElement), { targetRectangle: targetRect });
}
function _finalizePositionData(positionedElement, hostElement, bounds, coverTarget, doNotFinalizeReturnEdge) {
    var finalizedElement = _finalizeElementPosition(positionedElement.elementRectangle, hostElement, positionedElement.targetEdge, bounds, positionedElement.alignmentEdge, coverTarget, doNotFinalizeReturnEdge);
    return {
        elementPosition: finalizedElement,
        targetEdge: positionedElement.targetEdge,
        alignmentEdge: positionedElement.alignmentEdge,
    };
}
function _positionCallout(props, hostElement, callout, previousPositions, doNotFinalizeReturnEdge) {
    var beakWidth = props.isBeakVisible ? props.beakWidth || 0 : 0;
    var gap = _calculateActualBeakWidthInPixels(beakWidth) / 2 + (props.gapSpace ? props.gapSpace : 0);
    var positionProps = props;
    positionProps.gapSpace = gap;
    var boundingRect = props.bounds
        ? _getRectangleFromIRect(props.bounds)
        : new Rectangle$1(0, window.innerWidth - getScrollbarWidth(), 0, window.innerHeight);
    var positionedElement = _positionElementRelative(positionProps, callout, boundingRect, previousPositions);
    var beakPositioned = _positionBeak(beakWidth, positionedElement);
    var finalizedBeakPosition = _finalizeBeakPosition(positionedElement, beakPositioned, boundingRect);
    return __assign(__assign({}, _finalizePositionData(positionedElement, hostElement, boundingRect, props.coverTarget, doNotFinalizeReturnEdge)), { beakPosition: finalizedBeakPosition });
}
function _positionCard(props, hostElement, callout, previousPositions) {
    return _positionCallout(props, hostElement, callout, previousPositions, true);
}
function positionCallout(props, hostElement, elementToPosition, previousPositions) {
    return _positionCallout(props, hostElement, elementToPosition, previousPositions);
}
function positionCard(props, hostElement, elementToPosition, previousPositions) {
    return _positionCard(props, hostElement, elementToPosition, previousPositions);
}
/**
 * Get's the maximum height that a rectangle can have in order to fit below or above a target.
 * If the directional hint specifies a left or right edge (i.e. leftCenter) it will limit the height to the topBorder
 * of the target given.
 * If no bounds are provided then the window is treated as the bounds.
 */
function getMaxHeight(target, targetEdge, gapSpace, bounds, coverTarget) {
    if (gapSpace === void 0) { gapSpace = 0; }
    var mouseTarget = target;
    var elementTarget = target;
    var pointTarget = target;
    var targetRect;
    var boundingRectangle = bounds
        ? _getRectangleFromIRect(bounds)
        : new Rectangle$1(0, window.innerWidth - getScrollbarWidth(), 0, window.innerHeight);
    // eslint-disable-next-line deprecation/deprecation
    var left = pointTarget.left || pointTarget.x;
    // eslint-disable-next-line deprecation/deprecation
    var top = pointTarget.top || pointTarget.y;
    // eslint-disable-next-line no-extra-boolean-cast -- may not actually be a MouseEvent
    if (!!mouseTarget.stopPropagation) {
        targetRect = new Rectangle$1(mouseTarget.clientX, mouseTarget.clientX, mouseTarget.clientY, mouseTarget.clientY);
    }
    else if (left !== undefined && top !== undefined) {
        targetRect = new Rectangle$1(left, left, top, top);
    }
    else {
        targetRect = _getRectangleFromElement(elementTarget);
    }
    return _getMaxHeightFromTargetRectangle(targetRect, targetEdge, gapSpace, boundingRectangle, coverTarget);
}
function _getBoundsFromTargetWindow(target, targetWindow) {
    var segments = undefined;
    if (targetWindow.getWindowSegments) {
        segments = targetWindow.getWindowSegments();
    }
    // Identify if we're dealing with single screen scenarios.
    if (segments === undefined || segments.length <= 1) {
        return {
            top: 0,
            left: 0,
            right: targetWindow.innerWidth,
            bottom: targetWindow.innerHeight,
            width: targetWindow.innerWidth,
            height: targetWindow.innerHeight,
        };
    }
    // Logic for determining dual screen scenarios.
    var x = 0;
    var y = 0;
    // If the target is an Element get coordinates for its center.
    if (target !== null && !!target.getBoundingClientRect) {
        var clientRect = target.getBoundingClientRect();
        x = (clientRect.left + clientRect.right) / 2;
        y = (clientRect.top + clientRect.bottom) / 2;
    }
    // If the target is not null get x-axis and y-axis coordinates directly.
    else if (target !== null) {
        // eslint-disable-next-line deprecation/deprecation
        x = target.left || target.x;
        // eslint-disable-next-line deprecation/deprecation
        y = target.top || target.y;
    }
    var bounds = { top: 0, left: 0, right: 0, bottom: 0, width: 0, height: 0 };
    // Define which window segment are the coordinates in and calculate bounds based on that.
    for (var _i = 0, segments_1 = segments; _i < segments_1.length; _i++) {
        var segment = segments_1[_i];
        if (x && segment.left <= x && segment.right >= x && y && segment.top <= y && segment.bottom >= y) {
            bounds = {
                top: segment.top,
                left: segment.left,
                right: segment.right,
                bottom: segment.bottom,
                width: segment.width,
                height: segment.height,
            };
        }
    }
    return bounds;
}
function getBoundsFromTargetWindow(target, targetWindow) {
    return _getBoundsFromTargetWindow(target, targetWindow);
}

/**
 * This adds accessibility to Dialog and Panel controls
 */
var Popup = /** @class */ (function (_super) {
    __extends(Popup, _super);
    function Popup(props) {
        var _this = _super.call(this, props) || this;
        _this._root = createRef();
        _this._disposables = [];
        _this._onKeyDown = function (ev) {
            switch (ev.which) {
                case KeyCodes.escape:
                    if (_this.props.onDismiss) {
                        _this.props.onDismiss(ev);
                        ev.preventDefault();
                        ev.stopPropagation();
                    }
                    break;
            }
        };
        _this._onFocus = function () {
            _this._containsFocus = true;
        };
        _this._onBlur = function (ev) {
            /** The popup should update this._containsFocus when:
             * relatedTarget exists AND
             * the relatedTarget is not contained within the popup.
             * If the relatedTarget is within the popup, that means the popup still has focus
             * and focused moved from one element to another within the popup.
             * If relatedTarget is undefined or null that usually means that a
             * keyboard event occured and focus didn't change
             */
            if (_this._root.current &&
                ev.relatedTarget &&
                !elementContains(_this._root.current, ev.relatedTarget)) {
                _this._containsFocus = false;
            }
        };
        _this._async = new Async(_this);
        _this.state = { needsVerticalScrollBar: false };
        return _this;
    }
    Popup.prototype.UNSAFE_componentWillMount = function () {
        this._originalFocusedElement = getDocument().activeElement;
    };
    Popup.prototype.componentDidMount = function () {
        if (this._root.current) {
            this._disposables.push(on(this._root.current, 'focus', this._onFocus, true), on(this._root.current, 'blur', this._onBlur, true));
            var currentWindow = getWindow(this._root.current);
            if (currentWindow) {
                this._disposables.push(on(currentWindow, 'keydown', this._onKeyDown));
            }
            if (doesElementContainFocus(this._root.current)) {
                this._containsFocus = true;
            }
        }
        this._updateScrollBarAsync();
    };
    Popup.prototype.componentDidUpdate = function () {
        this._updateScrollBarAsync();
        this._async.dispose();
    };
    Popup.prototype.componentWillUnmount = function () {
        this._disposables.forEach(function (dispose) { return dispose(); });
        // eslint-disable-next-line deprecation/deprecation
        if (this.props.shouldRestoreFocus) {
            var _a = this.props.onRestoreFocus, onRestoreFocus = _a === void 0 ? defaultFocusRestorer : _a;
            onRestoreFocus({ originalElement: this._originalFocusedElement, containsFocus: this._containsFocus });
        }
        // De-reference DOM Node to avoid retainment via transpiled closure of _onKeyDown
        delete this._originalFocusedElement;
    };
    Popup.prototype.render = function () {
        var _a = this.props, role = _a.role, className = _a.className, ariaLabel = _a.ariaLabel, ariaLabelledBy = _a.ariaLabelledBy, ariaDescribedBy = _a.ariaDescribedBy, style = _a.style;
        return (createElement("div", __assign({ ref: this._root }, getNativeProps(this.props, divProperties), { className: className, role: role, "aria-label": ariaLabel, "aria-labelledby": ariaLabelledBy, "aria-describedby": ariaDescribedBy, onKeyDown: this._onKeyDown, style: __assign({ overflowY: this.state.needsVerticalScrollBar ? 'scroll' : undefined, outline: 'none' }, style) }), this.props.children));
    };
    Popup.prototype._updateScrollBarAsync = function () {
        var _this = this;
        this._async.requestAnimationFrame(function () {
            _this._getScrollBar();
        });
    };
    Popup.prototype._getScrollBar = function () {
        // If overflowY is overriden, don't waste time calculating whether the scrollbar is necessary.
        if (this.props.style && this.props.style.overflowY) {
            return;
        }
        var needsVerticalScrollBar = false;
        if (this._root && this._root.current && this._root.current.firstElementChild) {
            // ClientHeight returns the client height of an element rounded to an
            // integer. On some browsers at different zoom levels this rounding
            // can generate different results for the root container and child even
            // though they are the same height. This causes us to show a scroll bar
            // when not needed. Ideally we would use BoundingClientRect().height
            // instead however seems that the API is 90% slower than using ClientHeight.
            // Therefore instead we will calculate the difference between heights and
            // allow for a 1px difference to still be considered ok and not show the
            // scroll bar.
            var rootHeight = this._root.current.clientHeight;
            var firstChildHeight = this._root.current.firstElementChild.clientHeight;
            if (rootHeight > 0 && firstChildHeight > rootHeight) {
                needsVerticalScrollBar = firstChildHeight - rootHeight > 1;
            }
        }
        if (this.state.needsVerticalScrollBar !== needsVerticalScrollBar) {
            this.setState({
                needsVerticalScrollBar: needsVerticalScrollBar,
            });
        }
    };
    Popup.defaultProps = {
        shouldRestoreFocus: true,
    };
    return Popup;
}(Component));
function defaultFocusRestorer(options) {
    var originalElement = options.originalElement, containsFocus = options.containsFocus;
    if (originalElement && containsFocus && originalElement !== window) {
        // Make sure that the focus method actually exists
        // In some cases the object might exist but not be a real element.
        // This is primarily for IE 11 and should be removed once IE 11 is no longer in use.
        if (originalElement.focus) {
            originalElement.focus();
        }
    }
}

var _a$3;
var ANIMATIONS = (_a$3 = {},
    _a$3[RectangleEdge.top] = AnimationClassNames.slideUpIn10,
    _a$3[RectangleEdge.bottom] = AnimationClassNames.slideDownIn10,
    _a$3[RectangleEdge.left] = AnimationClassNames.slideLeftIn10,
    _a$3[RectangleEdge.right] = AnimationClassNames.slideRightIn10,
    _a$3);
var getClassNames$2 = classNamesFunction({
    disableCaching: true,
});
var BEAK_ORIGIN_POSITION = { top: 0, left: 0 };
// Microsoft Edge will overwrite inline styles if there is an animation pertaining to that style.
// To help ensure that edge will respect the offscreen style opacity
// filter needs to be added as an additional way to set opacity.
var OFF_SCREEN_STYLE = { opacity: 0, filter: 'opacity(0)' };
// role and role description go hand-in-hand. Both would be included by spreading getNativeProps for a basic element
// This constant array can be used to filter these out of native props spread on callout root and apply them together on
// calloutMain (the Popup component within the callout)
var ARIA_ROLE_ATTRIBUTES = ['role', 'aria-roledescription'];
var CalloutContentBase = /** @class */ (function (_super) {
    __extends(CalloutContentBase, _super);
    function CalloutContentBase(props) {
        var _this = _super.call(this, props) || this;
        _this._hostElement = createRef();
        _this._calloutElement = createRef();
        _this._hasListeners = false;
        _this._disposables = [];
        _this.dismiss = function (ev) {
            var onDismiss = _this.props.onDismiss;
            if (onDismiss) {
                onDismiss(ev);
            }
        };
        _this._dismissOnScroll = function (ev) {
            var preventDismissOnScroll = _this.props.preventDismissOnScroll;
            if (_this.state.positions && !preventDismissOnScroll) {
                _this._dismissOnClickOrScroll(ev);
            }
        };
        _this._dismissOnResize = function (ev) {
            var preventDismissOnResize = _this.props.preventDismissOnResize;
            if (!preventDismissOnResize) {
                _this.dismiss(ev);
            }
        };
        _this._dismissOnLostFocus = function (ev) {
            var preventDismissOnLostFocus = _this.props.preventDismissOnLostFocus;
            if (!preventDismissOnLostFocus) {
                _this._dismissOnClickOrScroll(ev);
            }
        };
        _this._setInitialFocus = function () {
            if (_this.props.setInitialFocus &&
                !_this._didSetInitialFocus &&
                _this.state.positions &&
                _this._calloutElement.current) {
                _this._didSetInitialFocus = true;
                _this._async.requestAnimationFrame(function () { return focusFirstChild(_this._calloutElement.current); }, _this._calloutElement.current);
            }
        };
        _this._onComponentDidMount = function () {
            _this._addListeners();
            if (_this.props.onLayerMounted) {
                _this.props.onLayerMounted();
            }
            _this._updateAsyncPosition();
            _this._setHeightOffsetEveryFrame();
        };
        _this._mouseDownOnPopup = function () {
            _this._isMouseDownOnPopup = true;
        };
        _this._mouseUpOnPopup = function () {
            _this._isMouseDownOnPopup = false;
        };
        _this._async = new Async(_this);
        _this._didSetInitialFocus = false;
        _this.state = {
            positions: undefined,
            slideDirectionalClassName: undefined,
            // @TODO it looks like this is not even being used anymore.
            calloutElementRect: undefined,
            heightOffset: 0,
        };
        _this._positionAttempts = 0;
        return _this;
    }
    CalloutContentBase.prototype.componentDidUpdate = function () {
        if (!this.props.hidden) {
            this._setInitialFocus();
            if (!this._hasListeners) {
                this._addListeners();
            }
            this._updateAsyncPosition();
        }
        else {
            if (this._hasListeners) {
                this._removeListeners();
            }
        }
    };
    CalloutContentBase.prototype.shouldComponentUpdate = function (newProps, newState) {
        if (!newProps.shouldUpdateWhenHidden && this.props.hidden && newProps.hidden) {
            // Do not update when hidden.
            return false;
        }
        return !shallowCompare(this.props, newProps) || !shallowCompare(this.state, newState);
    };
    CalloutContentBase.prototype.UNSAFE_componentWillMount = function () {
        this._setTargetWindowAndElement(this._getTarget());
    };
    CalloutContentBase.prototype.componentWillUnmount = function () {
        this._async.dispose();
        this._disposables.forEach(function (dispose) { return dispose(); });
    };
    CalloutContentBase.prototype.UNSAFE_componentWillUpdate = function (newProps) {
        // If the target element changed, find the new one. If we are tracking target with class name, always find element
        // because we do not know if fabric has rendered a new element and disposed the old element.
        var newTarget = this._getTarget(newProps);
        var oldTarget = this._getTarget();
        if ((newTarget !== oldTarget || typeof newTarget === 'string' || newTarget instanceof String) &&
            !this._blockResetHeight) {
            this._maxHeight = undefined;
            this._setTargetWindowAndElement(newTarget);
        }
        if (newProps.gapSpace !== this.props.gapSpace || this.props.beakWidth !== newProps.beakWidth) {
            this._maxHeight = undefined;
        }
        if (newProps.finalHeight !== this.props.finalHeight) {
            this._setHeightOffsetEveryFrame();
        }
        // Ensure positioning is recalculated when we are about to show a persisted menu.
        if (this._didPositionPropsChange(newProps, this.props)) {
            this._maxHeight = undefined;
            // Target might have been updated while hidden.
            this._setTargetWindowAndElement(newTarget);
            this.setState({
                positions: undefined,
            });
            this._didSetInitialFocus = false;
            this._bounds = undefined;
        }
        this._blockResetHeight = false;
    };
    CalloutContentBase.prototype.componentDidMount = function () {
        if (!this.props.hidden) {
            this._onComponentDidMount();
        }
    };
    CalloutContentBase.prototype.render = function () {
        // If there is no target window then we are likely in server side rendering and we should not render anything.
        if (!this._targetWindow) {
            return null;
        }
        var target = this.props.target;
        var _a = this.props, styles = _a.styles, style = _a.style, ariaLabel = _a.ariaLabel, ariaDescribedBy = _a.ariaDescribedBy, ariaLabelledBy = _a.ariaLabelledBy, className = _a.className, isBeakVisible = _a.isBeakVisible, children = _a.children, beakWidth = _a.beakWidth, calloutWidth = _a.calloutWidth, calloutMaxWidth = _a.calloutMaxWidth, finalHeight = _a.finalHeight, _b = _a.hideOverflow, hideOverflow = _b === void 0 ? !!finalHeight : _b, backgroundColor = _a.backgroundColor, calloutMaxHeight = _a.calloutMaxHeight, onScroll = _a.onScroll, 
        // eslint-disable-next-line deprecation/deprecation
        _c = _a.shouldRestoreFocus, 
        // eslint-disable-next-line deprecation/deprecation
        shouldRestoreFocus = _c === void 0 ? true : _c;
        target = this._getTarget();
        var positions = this.state.positions;
        var getContentMaxHeight = this._getMaxHeight()
            ? this._getMaxHeight() + this.state.heightOffset
            : undefined;
        var contentMaxHeight = calloutMaxHeight && getContentMaxHeight && calloutMaxHeight < getContentMaxHeight
            ? calloutMaxHeight
            : getContentMaxHeight;
        var overflowYHidden = hideOverflow;
        var beakVisible = isBeakVisible && !!target;
        this._classNames = getClassNames$2(styles, {
            theme: this.props.theme,
            className: className,
            overflowYHidden: overflowYHidden,
            calloutWidth: calloutWidth,
            positions: positions,
            beakWidth: beakWidth,
            backgroundColor: backgroundColor,
            calloutMaxWidth: calloutMaxWidth,
        });
        var overflowStyle = __assign(__assign(__assign({}, style), { maxHeight: contentMaxHeight }), (overflowYHidden && { overflowY: 'hidden' }));
        var visibilityStyle = this.props.hidden ? { visibility: 'hidden' } : undefined;
        // React.CSSProperties does not understand IRawStyle, so the inline animations will need to be cast as any for now.
        var content = (createElement("div", { ref: this._hostElement, className: this._classNames.container, style: visibilityStyle },
            createElement("div", __assign({}, getNativeProps(this.props, divProperties, ARIA_ROLE_ATTRIBUTES), { className: css(this._classNames.root, positions && positions.targetEdge && ANIMATIONS[positions.targetEdge]), style: positions ? positions.elementPosition : OFF_SCREEN_STYLE, 
                // Safari and Firefox on Mac OS requires this to back-stop click events so focus remains in the Callout.
                // See https://developer.mozilla.org/en-US/docs/Web/HTML/Element/button#Clicking_and_focus
                tabIndex: -1, ref: this._calloutElement }),
                beakVisible && createElement("div", { className: this._classNames.beak, style: this._getBeakPosition() }),
                beakVisible && createElement("div", { className: this._classNames.beakCurtain }),
                createElement(Popup, __assign({}, getNativeProps(this.props, ARIA_ROLE_ATTRIBUTES), { ariaLabel: ariaLabel, onRestoreFocus: this.props.onRestoreFocus, ariaDescribedBy: ariaDescribedBy, ariaLabelledBy: ariaLabelledBy, className: this._classNames.calloutMain, onDismiss: this.dismiss, onScroll: onScroll, shouldRestoreFocus: shouldRestoreFocus, style: overflowStyle, onMouseDown: this._mouseDownOnPopup, onMouseUp: this._mouseUpOnPopup }), children))));
        return content;
    };
    CalloutContentBase.prototype._dismissOnClickOrScroll = function (ev) {
        var target = ev.target;
        var isEventTargetOutsideCallout = this._hostElement.current && !elementContains(this._hostElement.current, target);
        // If mouse is pressed down on callout but moved outside then released, don't dismiss the callout.
        if (isEventTargetOutsideCallout && this._isMouseDownOnPopup) {
            this._isMouseDownOnPopup = false;
            return;
        }
        if ((!this._target && isEventTargetOutsideCallout) ||
            (ev.target !== this._targetWindow &&
                isEventTargetOutsideCallout &&
                (this._target.stopPropagation ||
                    !this._target ||
                    (target !== this._target && !elementContains(this._target, target))))) {
            this.dismiss(ev);
        }
    };
    CalloutContentBase.prototype._addListeners = function () {
        var _this = this;
        // This is added so the callout will dismiss when the window is scrolled
        // but not when something inside the callout is scrolled. The delay seems
        // to be required to avoid React firing an async focus event in IE from
        // the target changing focus quickly prior to rendering the callout.
        this._async.setTimeout(function () {
            _this._disposables.push(on(_this._targetWindow, 'scroll', _this._dismissOnScroll, true), on(_this._targetWindow, 'resize', _this._dismissOnResize, true), on(_this._targetWindow.document.documentElement, 'focus', _this._dismissOnLostFocus, true), on(_this._targetWindow.document.documentElement, 'click', _this._dismissOnLostFocus, true));
            _this._hasListeners = true;
        }, 0);
    };
    CalloutContentBase.prototype._removeListeners = function () {
        this._disposables.forEach(function (dispose) { return dispose(); });
        this._disposables = [];
        this._hasListeners = false;
    };
    CalloutContentBase.prototype._updateAsyncPosition = function () {
        var _this = this;
        this._async.requestAnimationFrame(function () { return _this._updatePosition(); }, this._calloutElement.current);
    };
    CalloutContentBase.prototype._getBeakPosition = function () {
        var positions = this.state.positions;
        var beakPostionStyle = __assign({}, (positions && positions.beakPosition ? positions.beakPosition.elementPosition : null));
        if (!beakPostionStyle.top && !beakPostionStyle.bottom && !beakPostionStyle.left && !beakPostionStyle.right) {
            beakPostionStyle.left = BEAK_ORIGIN_POSITION.left;
            beakPostionStyle.top = BEAK_ORIGIN_POSITION.top;
        }
        return beakPostionStyle;
    };
    CalloutContentBase.prototype._updatePosition = function () {
        // Try to update the target, page might have changed
        this._setTargetWindowAndElement(this._getTarget());
        var positions = this.state.positions;
        var hostElement = this._hostElement.current;
        var calloutElement = this._calloutElement.current;
        // If we expect a target element to position against, we need to wait until `this._target` is resolved. Otherwise
        // we can try to position.
        var expectsTarget = !!this.props.target;
        if (hostElement && calloutElement && (!expectsTarget || this._target)) {
            var currentProps = __assign({}, this.props);
            currentProps.bounds = this._getBounds();
            currentProps.target = this._target;
            // If there is a finalHeight given then we assume that the user knows and will handle
            // additional positioning adjustments so we should call positionCard
            var newPositions = this.props.finalHeight
                ? positionCard(currentProps, hostElement, calloutElement, positions)
                : positionCallout(currentProps, hostElement, calloutElement, positions);
            // Set the new position only when the positions are not exists or one of the new callout positions are different.
            // The position should not change if the position is within 2 decimal places.
            if ((!positions && newPositions) ||
                (positions && newPositions && !this._arePositionsEqual(positions, newPositions) && this._positionAttempts < 5)) {
                // We should not reposition the callout more than a few times, if it is then the content is likely resizing
                // and we should stop trying to reposition to prevent a stack overflow.
                this._positionAttempts++;
                this.setState({
                    positions: newPositions,
                });
            }
            else if (this._positionAttempts > 0) {
                // Only call the onPositioned callback if the callout has been re-positioned at least once.
                this._positionAttempts = 0;
                if (this.props.onPositioned) {
                    this.props.onPositioned(this.state.positions);
                }
            }
        }
    };
    CalloutContentBase.prototype._getBounds = function () {
        if (!this._bounds) {
            var bounds = this.props.bounds;
            var currentBounds = typeof bounds === 'function' ? bounds(this.props.target, this._targetWindow) : bounds;
            if (!currentBounds) {
                currentBounds = getBoundsFromTargetWindow(this._target, this._targetWindow);
                currentBounds = {
                    top: currentBounds.top + this.props.minPagePadding,
                    left: currentBounds.left + this.props.minPagePadding,
                    right: currentBounds.right - this.props.minPagePadding,
                    bottom: currentBounds.bottom - this.props.minPagePadding,
                    width: currentBounds.width - this.props.minPagePadding * 2,
                    height: currentBounds.height - this.props.minPagePadding * 2,
                };
            }
            this._bounds = currentBounds;
        }
        return this._bounds;
    };
    // Max height should remain as synchronous as possible, which is why it is not done using set state.
    // It needs to be synchronous since it will impact the ultimate position of the callout.
    CalloutContentBase.prototype._getMaxHeight = function () {
        var _this = this;
        if (!this._maxHeight) {
            if (this.props.directionalHintFixed && this._target) {
                var beakWidth = this.props.isBeakVisible ? this.props.beakWidth : 0;
                var gapSpace = this.props.gapSpace ? this.props.gapSpace : 0;
                // Since the callout cannot measure it's border size it must be taken into account here. Otherwise it will
                // overlap with the target.
                var totalGap_1 = gapSpace + beakWidth;
                this._async.requestAnimationFrame(function () {
                    if (_this._target) {
                        _this._maxHeight = getMaxHeight(_this._target, _this.props.directionalHint, totalGap_1, _this._getBounds(), _this.props.coverTarget);
                        _this._blockResetHeight = true;
                        _this.forceUpdate();
                    }
                }, this._target);
            }
            else {
                this._maxHeight = this._getBounds().height;
            }
        }
        return this._maxHeight;
    };
    CalloutContentBase.prototype._arePositionsEqual = function (positions, newPosition) {
        return (this._comparePositions(positions.elementPosition, newPosition.elementPosition) &&
            this._comparePositions(positions.beakPosition.elementPosition, newPosition.beakPosition.elementPosition));
    };
    CalloutContentBase.prototype._comparePositions = function (oldPositions, newPositions) {
        for (var key in newPositions) {
            if (newPositions.hasOwnProperty(key)) {
                var oldPositionEdge = oldPositions[key];
                var newPositionEdge = newPositions[key];
                if (oldPositionEdge !== undefined && newPositionEdge !== undefined) {
                    if (oldPositionEdge.toFixed(2) !== newPositionEdge.toFixed(2)) {
                        return false;
                    }
                }
                else {
                    return false;
                }
            }
        }
        return true;
    };
    CalloutContentBase.prototype._setTargetWindowAndElement = function (target) {
        var currentElement = this._calloutElement.current;
        if (target) {
            if (typeof target === 'string') {
                var currentDoc = getDocument(currentElement);
                this._target = currentDoc ? currentDoc.querySelector(target) : null;
                this._targetWindow = getWindow(currentElement);
                // Cast to any prevents error about stopPropagation always existing
            }
            else if (target.stopPropagation) {
                this._targetWindow = getWindow(target.target);
                this._target = target;
                // Same reason here
            }
            else if (target.getBoundingClientRect) {
                var targetElement = target;
                this._targetWindow = getWindow(targetElement);
                this._target = targetElement;
            }
            else if (target.current !== undefined) {
                this._target = target.current;
                this._targetWindow = getWindow(this._target);
                // HTMLImgElements can have x and y values. The check for it being a point must go last.
            }
            else {
                this._targetWindow = getWindow(currentElement);
                this._target = target;
            }
        }
        else {
            this._targetWindow = getWindow(currentElement);
        }
    };
    CalloutContentBase.prototype._setHeightOffsetEveryFrame = function () {
        var _this = this;
        if (this._calloutElement.current && this.props.finalHeight) {
            this._setHeightOffsetTimer = this._async.requestAnimationFrame(function () {
                var calloutMainElem = _this._calloutElement.current && _this._calloutElement.current.lastChild;
                if (!calloutMainElem) {
                    return;
                }
                var cardScrollHeight = calloutMainElem.scrollHeight;
                var cardCurrHeight = calloutMainElem.offsetHeight;
                var scrollDiff = cardScrollHeight - cardCurrHeight;
                _this.setState({
                    heightOffset: _this.state.heightOffset + scrollDiff,
                });
                if (calloutMainElem.offsetHeight < _this.props.finalHeight) {
                    _this._setHeightOffsetEveryFrame();
                }
                else {
                    _this._async.cancelAnimationFrame(_this._setHeightOffsetTimer, _this._calloutElement.current);
                }
            }, this._calloutElement.current);
        }
    };
    // Whether or not the current positions should be reset
    CalloutContentBase.prototype._didPositionPropsChange = function (newProps, oldProps) {
        return ((!newProps.hidden && newProps.hidden !== oldProps.hidden) || newProps.directionalHint !== oldProps.directionalHint);
    };
    CalloutContentBase.prototype._getTarget = function (props) {
        if (props === void 0) { props = this.props; }
        var target = props.target;
        return target;
    };
    CalloutContentBase.defaultProps = {
        preventDismissOnLostFocus: false,
        preventDismissOnScroll: false,
        preventDismissOnResize: false,
        isBeakVisible: true,
        beakWidth: 16,
        gapSpace: 0,
        minPagePadding: 8,
        directionalHint: DirectionalHint.bottomAutoEdge,
    };
    return CalloutContentBase;
}(Component));

function getBeakStyle(beakWidth) {
    return {
        height: beakWidth,
        width: beakWidth,
    };
}
var GlobalClassNames$1 = {
    container: 'ms-Callout-container',
    root: 'ms-Callout',
    beak: 'ms-Callout-beak',
    beakCurtain: 'ms-Callout-beakCurtain',
    calloutMain: 'ms-Callout-main',
};
var getStyles$2 = function (props) {
    var _a;
    var theme = props.theme, className = props.className, overflowYHidden = props.overflowYHidden, calloutWidth = props.calloutWidth, beakWidth = props.beakWidth, backgroundColor = props.backgroundColor, calloutMaxWidth = props.calloutMaxWidth;
    var classNames = getGlobalClassNames(GlobalClassNames$1, theme);
    var semanticColors = theme.semanticColors, effects = theme.effects;
    return {
        container: [
            classNames.container,
            {
                position: 'relative',
            },
        ],
        root: [
            classNames.root,
            theme.fonts.medium,
            {
                position: 'absolute',
                boxSizing: 'border-box',
                borderRadius: effects.roundedCorner2,
                boxShadow: effects.elevation16,
                selectors: (_a = {},
                    _a[HighContrastSelector] = {
                        borderWidth: 1,
                        borderStyle: 'solid',
                        borderColor: 'WindowText',
                    },
                    _a),
            },
            focusClear(),
            className,
            !!calloutWidth && { width: calloutWidth },
            !!calloutMaxWidth && { maxWidth: calloutMaxWidth },
        ],
        beak: [
            classNames.beak,
            {
                position: 'absolute',
                backgroundColor: semanticColors.menuBackground,
                boxShadow: 'inherit',
                border: 'inherit',
                boxSizing: 'border-box',
                transform: 'rotate(45deg)',
            },
            getBeakStyle(beakWidth),
            backgroundColor && {
                backgroundColor: backgroundColor,
            },
        ],
        beakCurtain: [
            classNames.beakCurtain,
            {
                position: 'absolute',
                top: 0,
                right: 0,
                bottom: 0,
                left: 0,
                backgroundColor: semanticColors.menuBackground,
                borderRadius: effects.roundedCorner2,
            },
        ],
        calloutMain: [
            classNames.calloutMain,
            {
                backgroundColor: semanticColors.menuBackground,
                overflowX: 'hidden',
                overflowY: 'auto',
                position: 'relative',
                borderRadius: effects.roundedCorner2,
            },
            overflowYHidden && {
                overflowY: 'hidden',
            },
            backgroundColor && {
                backgroundColor: backgroundColor,
            },
        ],
    };
};

var CalloutContent = styled(CalloutContentBase, getStyles$2, undefined, { scope: 'CalloutContent' });

var inheritFont = { fontFamily: 'inherit' };
var GlobalClassNames$2 = {
    root: 'ms-Fabric',
    bodyThemed: 'ms-Fabric-bodyThemed',
};
var getStyles$3 = function (props) {
    var theme = props.theme, className = props.className, applyTheme = props.applyTheme;
    var classNames = getGlobalClassNames(GlobalClassNames$2, theme);
    return {
        root: [
            classNames.root,
            theme.fonts.medium,
            {
                color: theme.palette.neutralPrimary,
                selectors: {
                    '& button': inheritFont,
                    '& input': inheritFont,
                    '& textarea': inheritFont,
                },
            },
            // apply theme to only if applyTheme is true
            applyTheme && {
                color: theme.semanticColors.bodyText,
                backgroundColor: theme.semanticColors.bodyBackground,
            },
            className,
        ],
        bodyThemed: [
            {
                backgroundColor: theme.semanticColors.bodyBackground,
            },
        ],
    };
};

var getClassNames$3 = classNamesFunction();
var getFabricTheme = memoizeFunction(function (theme, isRTL) { return createTheme(__assign(__assign({}, theme), { rtl: isRTL })); });
var getDir = function (theme, dir) {
    var contextDir = getRTL$1(theme) ? 'rtl' : 'ltr';
    var pageDir = getRTL$1() ? 'rtl' : 'ltr';
    var componentDir = dir ? dir : contextDir;
    return {
        // If Fabric dir !== contextDir
        // Or If contextDir !== pageDir
        // Then we need to set dir of the Fabric root
        rootDir: componentDir !== contextDir || componentDir !== pageDir ? componentDir : dir,
        // If dir !== contextDir || pageDir
        // then set contextual theme around content
        needsTheme: componentDir !== contextDir,
    };
};
var FabricBase = /** @class */ (function (_super) {
    __extends(FabricBase, _super);
    function FabricBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._rootElement = createRef();
        _this._removeClassNameFromBody = undefined;
        return _this;
    }
    FabricBase.prototype.render = function () {
        var _a = this.props, _b = _a.as, Root = _b === void 0 ? 'div' : _b, theme = _a.theme, dir = _a.dir;
        var classNames = this._getClassNames();
        var divProps = getNativeProps(this.props, divProperties, ['dir']);
        var _c = getDir(theme, dir), rootDir = _c.rootDir, needsTheme = _c.needsTheme;
        var renderedContent = createElement(Root, __assign({ dir: rootDir }, divProps, { className: classNames.root, ref: this._rootElement }));
        if (needsTheme) {
            renderedContent = (createElement(Customizer, { settings: { theme: getFabricTheme(theme, dir === 'rtl') } }, renderedContent));
        }
        return (createElement(Fragment, null,
            renderedContent,
            createElement(FocusRects, { rootRef: this._rootElement })));
    };
    FabricBase.prototype.componentDidMount = function () {
        this._addClassNameToBody();
    };
    FabricBase.prototype.componentWillUnmount = function () {
        if (this._removeClassNameFromBody) {
            this._removeClassNameFromBody();
        }
    };
    FabricBase.prototype._getClassNames = function () {
        var _a = this.props, className = _a.className, theme = _a.theme, applyTheme = _a.applyTheme;
        var classNames = getClassNames$3(getStyles$3, {
            theme: theme,
            applyTheme: applyTheme,
            className: className,
        });
        return classNames;
    };
    FabricBase.prototype._addClassNameToBody = function () {
        if (this.props.applyThemeToBody) {
            var classNames_1 = this._getClassNames();
            var currentDoc_1 = getDocument(this._rootElement.current);
            if (currentDoc_1) {
                currentDoc_1.body.classList.add(classNames_1.bodyThemed);
                this._removeClassNameFromBody = function () {
                    currentDoc_1.body.classList.remove(classNames_1.bodyThemed);
                };
            }
        }
    };
    return FabricBase;
}(Component));

var Fabric = styled(FabricBase, getStyles$3, undefined, {
    scope: 'Fabric',
});

var _layersByHostId = {};
var _defaultHostSelector;
/**
 * Register a layer for a given host id
 * @param hostId Id of the layer host
 * @param layer Layer instance
 */
function registerLayer(hostId, callback) {
    if (!_layersByHostId[hostId]) {
        _layersByHostId[hostId] = [];
    }
    _layersByHostId[hostId].push(callback);
}
/**
 * Unregister a layer for a given host id
 * @param hostId Id of the layer host
 * @param layer Layer instance
 */
function unregisterLayer(hostId, callback) {
    if (_layersByHostId[hostId]) {
        var idx = _layersByHostId[hostId].indexOf(callback);
        if (idx >= 0) {
            _layersByHostId[hostId].splice(idx, 1);
            if (_layersByHostId[hostId].length === 0) {
                delete _layersByHostId[hostId];
            }
        }
    }
}
/**
 * Get the default target selector when determining a host
 */
function getDefaultTarget() {
    return _defaultHostSelector;
}

var getClassNames$4 = classNamesFunction();
var LayerBase = /** @class */ (function (_super) {
    __extends(LayerBase, _super);
    function LayerBase(props) {
        var _this = _super.call(this, props) || this;
        _this._rootRef = createRef();
        _this._createLayerElement = function () {
            var hostId = _this.props.hostId;
            var doc = getDocument(_this._rootRef.current);
            var host = _this._getHost();
            if (!doc || !host) {
                return;
            }
            // If one was already existing, remove.
            _this._removeLayerElement();
            var layerElement = doc.createElement('div');
            var classNames = _this._getClassNames();
            layerElement.className = classNames.root;
            setPortalAttribute(layerElement);
            setVirtualParent(layerElement, _this._rootRef.current);
            _this.props.insertFirst ? host.insertBefore(layerElement, host.firstChild) : host.appendChild(layerElement);
            _this.setState({
                hostId: hostId,
                layerElement: layerElement,
            }, function () {
                // eslint-disable-next-line deprecation/deprecation
                var _a = _this.props, onLayerDidMount = _a.onLayerDidMount, onLayerMounted = _a.onLayerMounted;
                if (onLayerMounted) {
                    onLayerMounted();
                }
                if (onLayerDidMount) {
                    onLayerDidMount();
                }
            });
        };
        _this.state = {};
        if (process.env.NODE_ENV !== 'production') {
            warnDeprecations('Layer', props, {
                onLayerMounted: 'onLayerDidMount',
            });
        }
        return _this;
    }
    LayerBase.prototype.componentDidMount = function () {
        var hostId = this.props.hostId;
        this._createLayerElement();
        if (hostId) {
            registerLayer(hostId, this._createLayerElement);
        }
    };
    LayerBase.prototype.render = function () {
        var layerElement = this.state.layerElement;
        var classNames = this._getClassNames();
        var eventBubblingEnabled = this.props.eventBubblingEnabled;
        return (createElement("span", { className: "ms-layer", ref: this._rootRef }, layerElement &&
            createPortal(createElement(Fabric, __assign({}, (!eventBubblingEnabled && _getFilteredEvents()), { className: classNames.content }), this.props.children), layerElement)));
    };
    LayerBase.prototype.componentDidUpdate = function () {
        if (this.props.hostId !== this.state.hostId) {
            this._createLayerElement();
        }
    };
    LayerBase.prototype.componentWillUnmount = function () {
        var hostId = this.props.hostId;
        this._removeLayerElement();
        if (hostId) {
            unregisterLayer(hostId, this._createLayerElement);
        }
    };
    LayerBase.prototype._removeLayerElement = function () {
        var onLayerWillUnmount = this.props.onLayerWillUnmount;
        var layerElement = this.state.layerElement;
        if (onLayerWillUnmount) {
            onLayerWillUnmount();
        }
        if (layerElement && layerElement.parentNode) {
            var parentNode = layerElement.parentNode;
            if (parentNode) {
                parentNode.removeChild(layerElement);
            }
        }
    };
    LayerBase.prototype._getClassNames = function () {
        var _a = this.props, className = _a.className, styles = _a.styles, theme = _a.theme;
        var classNames = getClassNames$4(styles, {
            theme: theme,
            className: className,
            isNotHost: !this.props.hostId,
        });
        return classNames;
    };
    LayerBase.prototype._getHost = function () {
        var hostId = this.props.hostId;
        var doc = getDocument(this._rootRef.current);
        if (!doc) {
            return undefined;
        }
        if (hostId) {
            return doc.getElementById(hostId);
        }
        else {
            var defaultHostSelector = getDefaultTarget();
            return defaultHostSelector ? doc.querySelector(defaultHostSelector) : doc.body;
        }
    };
    LayerBase.defaultProps = {
        onLayerDidMount: function () { return undefined; },
        onLayerWillUnmount: function () { return undefined; },
    };
    LayerBase = __decorate([
        customizable('Layer', ['theme', 'hostId'])
    ], LayerBase);
    return LayerBase;
}(Component));
var _onFilterEvent = function (ev) {
    // We should just be able to check ev.bubble here and only stop events that are bubbling up. However, even though
    // mouseenter and mouseleave do NOT bubble up, they are showing up as bubbling. Therefore we stop events based on
    // event name rather than ev.bubble.
    if (ev.eventPhase === Event.BUBBLING_PHASE &&
        ev.type !== 'mouseenter' &&
        ev.type !== 'mouseleave' &&
        ev.type !== 'touchstart' &&
        ev.type !== 'touchend') {
        ev.stopPropagation();
    }
};
var _filteredEventProps;
function _getFilteredEvents() {
    if (!_filteredEventProps) {
        _filteredEventProps = {};
        [
            'onClick',
            'onContextMenu',
            'onDoubleClick',
            'onDrag',
            'onDragEnd',
            'onDragEnter',
            'onDragExit',
            'onDragLeave',
            'onDragOver',
            'onDragStart',
            'onDrop',
            'onMouseDown',
            'onMouseEnter',
            'onMouseLeave',
            'onMouseMove',
            'onMouseOver',
            'onMouseOut',
            'onMouseUp',
            'onTouchMove',
            'onTouchStart',
            'onTouchCancel',
            'onTouchEnd',
            'onKeyDown',
            'onKeyPress',
            'onKeyUp',
            'onFocus',
            'onBlur',
            'onChange',
            'onInput',
            'onInvalid',
            'onSubmit',
        ].forEach(function (name) { return (_filteredEventProps[name] = _onFilterEvent); });
    }
    return _filteredEventProps;
}

var GlobalClassNames$3 = {
    root: 'ms-Layer',
    rootNoHost: 'ms-Layer--fixed',
    content: 'ms-Layer-content',
};
var getStyles$4 = function (props) {
    var className = props.className, isNotHost = props.isNotHost, theme = props.theme;
    var classNames = getGlobalClassNames(GlobalClassNames$3, theme);
    return {
        root: [
            classNames.root,
            theme.fonts.medium,
            isNotHost && [
                classNames.rootNoHost,
                {
                    position: 'fixed',
                    zIndex: ZIndexes.Layer,
                    top: 0,
                    left: 0,
                    bottom: 0,
                    right: 0,
                    visibility: 'hidden',
                },
            ],
            className,
        ],
        content: [
            classNames.content,
            {
                visibility: 'visible',
            },
        ],
    };
};

var Layer = styled(LayerBase, getStyles$4, undefined, {
    scope: 'Layer',
    fields: ['hostId', 'theme', 'styles'],
});

var Callout = /** @class */ (function (_super) {
    __extends(Callout, _super);
    function Callout() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Callout.prototype.render = function () {
        var _a = this.props, layerProps = _a.layerProps, rest = __rest(_a, ["layerProps"]);
        var content = createElement(CalloutContent, __assign({}, rest));
        return this.props.doNotLayer ? content : createElement(Layer, __assign({}, layerProps), content);
    };
    return Callout;
}(Component));

var renderItemIcon = function (props) {
    var item = props.item, hasIcons = props.hasIcons, classNames = props.classNames;
    var iconProps = item.iconProps;
    if (!hasIcons) {
        return null;
    }
    if (item.onRenderIcon) {
        return item.onRenderIcon(props);
    }
    return createElement(Icon, __assign({}, iconProps, { className: classNames.icon }));
};
var renderCheckMarkIcon = function (_a) {
    var onCheckmarkClick = _a.onCheckmarkClick, item = _a.item, classNames = _a.classNames;
    var isItemChecked = getIsChecked(item);
    if (onCheckmarkClick) {
        // Ensures that the item is passed as the first argument to the checkmark click callback.
        var onClick = function (e) { return onCheckmarkClick(item, e); };
        return (createElement(Icon, { iconName: item.canCheck !== false && isItemChecked ? 'CheckMark' : '', className: classNames.checkmarkIcon, 
            // eslint-disable-next-line react/jsx-no-bind
            onClick: onClick }));
    }
    return null;
};
var renderItemName = function (_a) {
    var item = _a.item, classNames = _a.classNames;
    /* eslint-disable deprecation/deprecation */
    if (item.text || item.name) {
        return createElement("span", { className: classNames.label }, item.text || item.name);
    }
    /* eslint-enable deprecation/deprecation */
    return null;
};
var renderSecondaryText = function (_a) {
    var item = _a.item, classNames = _a.classNames;
    if (item.secondaryText) {
        return createElement("span", { className: classNames.secondaryText }, item.secondaryText);
    }
    return null;
};
var renderSubMenuIcon = function (_a) {
    var item = _a.item, classNames = _a.classNames, theme = _a.theme;
    if (hasSubmenu(item)) {
        return (createElement(Icon, __assign({ iconName: getRTL$1(theme) ? 'ChevronLeft' : 'ChevronRight' }, item.submenuIconProps, { className: classNames.subMenuIcon })));
    }
    return null;
};
var ContextualMenuItemBase = /** @class */ (function (_super) {
    __extends(ContextualMenuItemBase, _super);
    function ContextualMenuItemBase(props) {
        var _this = _super.call(this, props) || this;
        _this.openSubMenu = function () {
            var _a = _this.props, item = _a.item, openSubMenu = _a.openSubMenu, getSubmenuTarget = _a.getSubmenuTarget;
            if (getSubmenuTarget) {
                var submenuTarget = getSubmenuTarget();
                if (hasSubmenu(item) && openSubMenu && submenuTarget) {
                    openSubMenu(item, submenuTarget);
                }
            }
        };
        _this.dismissSubMenu = function () {
            var _a = _this.props, item = _a.item, dismissSubMenu = _a.dismissSubMenu;
            if (hasSubmenu(item) && dismissSubMenu) {
                dismissSubMenu();
            }
        };
        _this.dismissMenu = function (dismissAll) {
            var dismissMenu = _this.props.dismissMenu;
            if (dismissMenu) {
                dismissMenu(undefined /* ev */, dismissAll);
            }
        };
        initializeComponentRef(_this);
        return _this;
    }
    ContextualMenuItemBase.prototype.render = function () {
        var _a = this.props, item = _a.item, classNames = _a.classNames;
        return (createElement("div", { className: item.split ? classNames.linkContentMenu : classNames.linkContent },
            renderCheckMarkIcon(this.props),
            renderItemIcon(this.props),
            renderItemName(this.props),
            renderSecondaryText(this.props),
            renderSubMenuIcon(this.props)));
    };
    return ContextualMenuItemBase;
}(Component));

/**
 * @deprecated use getStyles exported from VerticalDivider.styles.ts
 */
var getDividerClassNames = memoizeFunction(
// eslint-disable-next-line deprecation/deprecation
function (theme) {
    return mergeStyleSets({
        wrapper: {
            display: 'inline-flex',
            height: '100%',
            alignItems: 'center',
        },
        divider: {
            width: 1,
            height: '100%',
            backgroundColor: theme.palette.neutralTertiaryAlt,
        },
    });
});

var CONTEXTUAL_MENU_ITEM_HEIGHT = 36;
var MediumScreenSelector = getScreenSelector(0, ScreenWidthMaxMedium);
var getItemHighContrastStyles = memoizeFunction(function () {
    var _a;
    return {
        selectors: (_a = {},
            _a[HighContrastSelector] = {
                backgroundColor: 'Highlight',
                borderColor: 'Highlight',
                color: 'HighlightText',
                MsHighContrastAdjust: 'none',
            },
            _a),
    };
});
var getMenuItemStyles = memoizeFunction(function (theme) {
    var _a, _b, _c, _d, _e, _f, _g;
    var semanticColors = theme.semanticColors, fonts = theme.fonts, palette = theme.palette;
    var ContextualMenuItemBackgroundHoverColor = semanticColors.menuItemBackgroundHovered;
    var ContextualMenuItemTextHoverColor = semanticColors.menuItemTextHovered;
    var ContextualMenuItemBackgroundSelectedColor = semanticColors.menuItemBackgroundPressed;
    var ContextualMenuItemDividerColor = semanticColors.bodyDivider;
    var menuItemStyles = {
        item: [
            fonts.medium,
            {
                color: semanticColors.bodyText,
                position: 'relative',
                boxSizing: 'border-box',
            },
        ],
        divider: {
            display: 'block',
            height: '1px',
            backgroundColor: ContextualMenuItemDividerColor,
            position: 'relative',
        },
        root: [
            getFocusStyle(theme),
            fonts.medium,
            {
                color: semanticColors.bodyText,
                backgroundColor: 'transparent',
                border: 'none',
                width: '100%',
                height: CONTEXTUAL_MENU_ITEM_HEIGHT,
                lineHeight: CONTEXTUAL_MENU_ITEM_HEIGHT,
                display: 'block',
                cursor: 'pointer',
                padding: '0px 8px 0 4px',
                textAlign: 'left',
            },
        ],
        rootDisabled: {
            color: semanticColors.disabledBodyText,
            cursor: 'default',
            pointerEvents: 'none',
            selectors: __assign((_a = {}, _a[HighContrastSelector] = {
                color: 'GrayText',
                opacity: 1,
            }, _a), getEdgeChromiumNoHighContrastAdjustSelector()),
        },
        rootHovered: __assign({ backgroundColor: ContextualMenuItemBackgroundHoverColor, color: ContextualMenuItemTextHoverColor, selectors: {
                '.ms-ContextualMenu-icon': {
                    color: palette.themeDarkAlt,
                },
                '.ms-ContextualMenu-submenuIcon': {
                    color: palette.neutralPrimary,
                },
            } }, getItemHighContrastStyles()),
        rootFocused: __assign({ backgroundColor: palette.white }, getItemHighContrastStyles()),
        rootChecked: __assign({ selectors: {
                '.ms-ContextualMenu-checkmarkIcon': {
                    color: palette.neutralPrimary,
                },
            } }, getItemHighContrastStyles()),
        rootPressed: __assign({ backgroundColor: ContextualMenuItemBackgroundSelectedColor, selectors: {
                '.ms-ContextualMenu-icon': {
                    color: palette.themeDark,
                },
                '.ms-ContextualMenu-submenuIcon': {
                    color: palette.neutralPrimary,
                },
            } }, getItemHighContrastStyles()),
        rootExpanded: __assign({ backgroundColor: ContextualMenuItemBackgroundSelectedColor, color: semanticColors.bodyTextChecked }, getItemHighContrastStyles()),
        linkContent: {
            whiteSpace: 'nowrap',
            height: 'inherit',
            display: 'flex',
            alignItems: 'center',
            maxWidth: '100%',
        },
        anchorLink: {
            padding: '0px 8px 0 4px',
            textRendering: 'auto',
            color: 'inherit',
            letterSpacing: 'normal',
            wordSpacing: 'normal',
            textTransform: 'none',
            textIndent: '0px',
            textShadow: 'none',
            textDecoration: 'none',
            boxSizing: 'border-box',
        },
        label: {
            margin: '0 4px',
            verticalAlign: 'middle',
            display: 'inline-block',
            flexGrow: '1',
            textOverflow: 'ellipsis',
            overflow: 'hidden',
            whiteSpace: 'nowrap',
        },
        secondaryText: {
            color: theme.palette.neutralSecondary,
            paddingLeft: '20px',
            textAlign: 'right',
        },
        icon: {
            display: 'inline-block',
            minHeight: '1px',
            maxHeight: CONTEXTUAL_MENU_ITEM_HEIGHT,
            fontSize: IconFontSizes.medium,
            width: IconFontSizes.medium,
            margin: '0 4px',
            verticalAlign: 'middle',
            flexShrink: '0',
            selectors: (_b = {},
                _b[MediumScreenSelector] = {
                    fontSize: IconFontSizes.large,
                    width: IconFontSizes.large,
                },
                _b),
        },
        iconColor: {
            color: semanticColors.menuIcon,
            selectors: (_c = {},
                _c[HighContrastSelector] = {
                    color: 'inherit',
                },
                _c['$root:hover &'] = {
                    selectors: (_d = {},
                        _d[HighContrastSelector] = {
                            color: 'HighlightText',
                        },
                        _d),
                },
                _c['$root:focus &'] = {
                    selectors: (_e = {},
                        _e[HighContrastSelector] = {
                            color: 'HighlightText',
                        },
                        _e),
                },
                _c),
        },
        iconDisabled: {
            color: semanticColors.disabledBodyText,
        },
        checkmarkIcon: {
            color: semanticColors.bodySubtext,
            selectors: (_f = {},
                _f[HighContrastSelector] = {
                    color: 'HighlightText',
                },
                _f),
        },
        subMenuIcon: {
            height: CONTEXTUAL_MENU_ITEM_HEIGHT,
            lineHeight: CONTEXTUAL_MENU_ITEM_HEIGHT,
            color: palette.neutralSecondary,
            textAlign: 'center',
            display: 'inline-block',
            verticalAlign: 'middle',
            flexShrink: '0',
            fontSize: IconFontSizes.small,
            selectors: (_g = {
                    ':hover': {
                        color: palette.neutralPrimary,
                    },
                    ':active': {
                        color: palette.neutralPrimary,
                    }
                },
                _g[MediumScreenSelector] = {
                    fontSize: IconFontSizes.medium,
                },
                _g[HighContrastSelector] = {
                    color: 'HighlightText',
                },
                _g),
        },
        splitButtonFlexContainer: [
            getFocusStyle(theme),
            {
                display: 'flex',
                height: CONTEXTUAL_MENU_ITEM_HEIGHT,
                flexWrap: 'nowrap',
                justifyContent: 'center',
                alignItems: 'flex-start',
            },
        ],
    };
    return concatStyleSets(menuItemStyles);
});

var CONTEXTUAL_SPLIT_MENU_MINWIDTH = '28px';
var MediumScreenSelector$1 = getScreenSelector(0, ScreenWidthMaxMedium);
var getSplitButtonVerticalDividerClassNames = memoizeFunction(
/* eslint-disable deprecation/deprecation */
function (theme) {
    var _a;
    return mergeStyleSets(getDividerClassNames(theme), {
        /* eslint-enable deprecation/deprecation */
        wrapper: {
            position: 'absolute',
            right: 28,
            selectors: (_a = {},
                _a[MediumScreenSelector$1] = {
                    right: 32,
                },
                _a),
        },
        divider: {
            height: 16,
            width: 1,
        },
    });
});
var GlobalClassNames$4 = {
    item: 'ms-ContextualMenu-item',
    divider: 'ms-ContextualMenu-divider',
    root: 'ms-ContextualMenu-link',
    isChecked: 'is-checked',
    isExpanded: 'is-expanded',
    isDisabled: 'is-disabled',
    linkContent: 'ms-ContextualMenu-linkContent',
    linkContentMenu: 'ms-ContextualMenu-linkContent',
    icon: 'ms-ContextualMenu-icon',
    iconColor: 'ms-ContextualMenu-iconColor',
    checkmarkIcon: 'ms-ContextualMenu-checkmarkIcon',
    subMenuIcon: 'ms-ContextualMenu-submenuIcon',
    label: 'ms-ContextualMenu-itemText',
    secondaryText: 'ms-ContextualMenu-secondaryText',
    splitMenu: 'ms-ContextualMenu-splitMenu',
};
/**
 * @deprecated To be removed in 7.0.
 * @internal
 * This is a package-internal method that has been depended on.
 * It is being kept in this form for backwards compatibility.
 * It should be cleaned up in 7.0.
 *
 * TODO: Audit perf. impact of and potentially remove memoizeFunction.
 * https://github.com/microsoft/fluentui/issues/5534
 */
var getItemClassNames = memoizeFunction(function (theme, disabled, expanded, checked, isAnchorLink, knownIcon, itemClassName, dividerClassName, iconClassName, subMenuClassName, primaryDisabled, className) {
    var _a, _b, _c, _d;
    var styles = getMenuItemStyles(theme);
    var classNames = getGlobalClassNames(GlobalClassNames$4, theme);
    return mergeStyleSets({
        item: [classNames.item, styles.item, itemClassName],
        divider: [classNames.divider, styles.divider, dividerClassName],
        root: [
            classNames.root,
            styles.root,
            checked && [classNames.isChecked, styles.rootChecked],
            isAnchorLink && styles.anchorLink,
            expanded && [classNames.isExpanded, styles.rootExpanded],
            disabled && [classNames.isDisabled, styles.rootDisabled],
            !disabled &&
                !expanded && [
                {
                    selectors: (_a = {
                            ':hover': styles.rootHovered,
                            ':active': styles.rootPressed
                        },
                        _a["." + IsFocusVisibleClassName + " &:focus, ." + IsFocusVisibleClassName + " &:focus:hover"] = styles.rootFocused,
                        _a["." + IsFocusVisibleClassName + " &:hover"] = { background: 'inherit;' },
                        _a),
                },
            ],
            className,
        ],
        splitPrimary: [
            styles.root,
            {
                width: "calc(100% - " + CONTEXTUAL_SPLIT_MENU_MINWIDTH + ")",
            },
            checked && ['is-checked', styles.rootChecked],
            (disabled || primaryDisabled) && ['is-disabled', styles.rootDisabled],
            !(disabled || primaryDisabled) &&
                !checked && [
                {
                    selectors: (_b = {
                            ':hover': styles.rootHovered
                        },
                        // when hovering over the splitPrimary also affect the splitMenu
                        _b[":hover ~ ." + classNames.splitMenu] = styles.rootHovered,
                        _b[':active'] = styles.rootPressed,
                        _b["." + IsFocusVisibleClassName + " &:focus, ." + IsFocusVisibleClassName + " &:focus:hover"] = styles.rootFocused,
                        _b["." + IsFocusVisibleClassName + " &:hover"] = { background: 'inherit;' },
                        _b),
                },
            ],
        ],
        splitMenu: [
            classNames.splitMenu,
            styles.root,
            {
                flexBasis: '0',
                padding: '0 8px',
                minWidth: CONTEXTUAL_SPLIT_MENU_MINWIDTH,
            },
            expanded && ['is-expanded', styles.rootExpanded],
            disabled && ['is-disabled', styles.rootDisabled],
            !disabled &&
                !expanded && [
                {
                    selectors: (_c = {
                            ':hover': styles.rootHovered,
                            ':active': styles.rootPressed
                        },
                        _c["." + IsFocusVisibleClassName + " &:focus, ." + IsFocusVisibleClassName + " &:focus:hover"] = styles.rootFocused,
                        _c["." + IsFocusVisibleClassName + " &:hover"] = { background: 'inherit;' },
                        _c),
                },
            ],
        ],
        anchorLink: styles.anchorLink,
        linkContent: [classNames.linkContent, styles.linkContent],
        linkContentMenu: [
            classNames.linkContentMenu,
            styles.linkContent,
            {
                justifyContent: 'center',
            },
        ],
        icon: [
            classNames.icon,
            knownIcon && styles.iconColor,
            styles.icon,
            iconClassName,
            disabled && [classNames.isDisabled, styles.iconDisabled],
        ],
        iconColor: styles.iconColor,
        checkmarkIcon: [classNames.checkmarkIcon, knownIcon && styles.checkmarkIcon, styles.icon, iconClassName],
        subMenuIcon: [
            classNames.subMenuIcon,
            styles.subMenuIcon,
            subMenuClassName,
            expanded && { color: theme.palette.neutralPrimary },
            disabled && [styles.iconDisabled],
        ],
        label: [classNames.label, styles.label],
        secondaryText: [classNames.secondaryText, styles.secondaryText],
        splitContainer: [
            styles.splitButtonFlexContainer,
            !disabled &&
                !checked && [
                {
                    selectors: (_d = {},
                        _d["." + IsFocusVisibleClassName + " &:focus, ." + IsFocusVisibleClassName + " &:focus:hover"] = styles.rootFocused,
                        _d),
                },
            ],
        ],
    });
});
/**
 * Wrapper function for generating ContextualMenuItem classNames which adheres to
 * the getStyles API, but invokes memoized className generator function with
 * primitive values.
 *
 * @param props the ContextualMenuItem style props used to generate its styles.
 */
var getItemStyles = function (props) {
    var theme = props.theme, disabled = props.disabled, expanded = props.expanded, checked = props.checked, isAnchorLink = props.isAnchorLink, knownIcon = props.knownIcon, itemClassName = props.itemClassName, dividerClassName = props.dividerClassName, iconClassName = props.iconClassName, subMenuClassName = props.subMenuClassName, primaryDisabled = props.primaryDisabled, className = props.className;
    // eslint-disable-next-line deprecation/deprecation
    return getItemClassNames(theme, disabled, expanded, checked, isAnchorLink, knownIcon, itemClassName, dividerClassName, iconClassName, subMenuClassName, primaryDisabled, className);
};

/**
 * ContextualMenuItem description
 */
var ContextualMenuItem = styled(ContextualMenuItemBase, getItemStyles, undefined, { scope: 'ContextualMenuItem' });

var ContextualMenuItemWrapper = /** @class */ (function (_super) {
    __extends(ContextualMenuItemWrapper, _super);
    function ContextualMenuItemWrapper(props) {
        var _this = _super.call(this, props) || this;
        _this._onItemMouseEnter = function (ev) {
            var _a = _this.props, item = _a.item, onItemMouseEnter = _a.onItemMouseEnter;
            if (onItemMouseEnter) {
                onItemMouseEnter(item, ev, ev.currentTarget);
            }
        };
        _this._onItemClick = function (ev) {
            var _a = _this.props, item = _a.item, onItemClickBase = _a.onItemClickBase;
            if (onItemClickBase) {
                onItemClickBase(item, ev, ev.currentTarget);
            }
        };
        _this._onItemMouseLeave = function (ev) {
            var _a = _this.props, item = _a.item, onItemMouseLeave = _a.onItemMouseLeave;
            if (onItemMouseLeave) {
                onItemMouseLeave(item, ev);
            }
        };
        _this._onItemKeyDown = function (ev) {
            var _a = _this.props, item = _a.item, onItemKeyDown = _a.onItemKeyDown;
            if (onItemKeyDown) {
                onItemKeyDown(item, ev);
            }
        };
        _this._onItemMouseMove = function (ev) {
            var _a = _this.props, item = _a.item, onItemMouseMove = _a.onItemMouseMove;
            if (onItemMouseMove) {
                onItemMouseMove(item, ev, ev.currentTarget);
            }
        };
        _this._getSubMenuId = function (item) {
            var getSubMenuId = _this.props.getSubMenuId;
            if (getSubMenuId) {
                return getSubMenuId(item);
            }
        };
        _this._getSubmenuTarget = function () {
            return undefined;
        };
        initializeComponentRef(_this);
        return _this;
    }
    ContextualMenuItemWrapper.prototype.shouldComponentUpdate = function (newProps) {
        return !shallowCompare(newProps, this.props);
    };
    return ContextualMenuItemWrapper;
}(Component));

var KTP_PREFIX = 'ktp';
var KTP_SEPARATOR = '-';
var DATAKTP_TARGET = 'data-ktp-target';
var DATAKTP_EXECUTE_TARGET = 'data-ktp-execute-target';
var KTP_LAYER_ID = 'ktp-layer-id';
// Events
var KeytipEvents;
(function (KeytipEvents) {
    KeytipEvents.KEYTIP_ADDED = 'keytipAdded';
    KeytipEvents.KEYTIP_REMOVED = 'keytipRemoved';
    KeytipEvents.KEYTIP_UPDATED = 'keytipUpdated';
    KeytipEvents.PERSISTED_KEYTIP_ADDED = 'persistedKeytipAdded';
    KeytipEvents.PERSISTED_KEYTIP_REMOVED = 'persistedKeytipRemoved';
    KeytipEvents.PERSISTED_KEYTIP_EXECUTE = 'persistedKeytipExecute';
    KeytipEvents.ENTER_KEYTIP_MODE = 'enterKeytipMode';
    KeytipEvents.EXIT_KEYTIP_MODE = 'exitKeytipMode';
})(KeytipEvents || (KeytipEvents = {}));

/**
 * This class is responsible for handling registering, updating, and unregistering of keytips
 */
var KeytipManager = /** @class */ (function () {
    function KeytipManager() {
        this.keytips = {};
        this.persistedKeytips = {};
        this.sequenceMapping = {};
        // This is (and should be) updated and kept in sync
        // with the inKeytipMode in KeytipLayer.
        this.inKeytipMode = false;
        // Boolean that gets checked before entering keytip mode by the KeytipLayer
        // Used for an override in special cases (e.g. Disable entering keytip mode when a modal is shown)
        this.shouldEnterKeytipMode = true;
        // Boolean to indicate whether to delay firing an event to update subscribers of
        // keytip data changed.
        this.delayUpdatingKeytipChange = false;
    }
    /**
     * Static function to get singleton KeytipManager instance
     *
     * @returns {KeytipManager} Singleton KeytipManager instance
     */
    KeytipManager.getInstance = function () {
        return this._instance;
    };
    /**
     * Initialization code to set set parameters to define
     * how the KeytipManager handles keytip data.
     *
     * @param delayUpdatingKeytipChange - T/F if we should delay notifiying keytip subscribers
     * of keytip changes
     */
    KeytipManager.prototype.init = function (delayUpdatingKeytipChange) {
        this.delayUpdatingKeytipChange = delayUpdatingKeytipChange;
    };
    /**
     * Registers a keytip
     *
     * @param keytipProps - Keytip to register
     * @param persisted - T/F if this keytip should be persisted, default is false
     * @returns {string} Unique ID for this keytip
     */
    KeytipManager.prototype.register = function (keytipProps, persisted) {
        if (persisted === void 0) { persisted = false; }
        var props = keytipProps;
        if (!persisted) {
            // Add the overflowSetSequence if necessary
            props = this.addParentOverflow(keytipProps);
            this.sequenceMapping[props.keySequences.toString()] = props;
        }
        // Create a unique keytip
        var uniqueKeytip = this._getUniqueKtp(props);
        // Add to dictionary
        persisted
            ? (this.persistedKeytips[uniqueKeytip.uniqueID] = uniqueKeytip)
            : (this.keytips[uniqueKeytip.uniqueID] = uniqueKeytip);
        // We only want to add something new if we are currently showing keytip mode
        if (this.inKeytipMode || !this.delayUpdatingKeytipChange) {
            var event_1 = persisted ? KeytipEvents.PERSISTED_KEYTIP_ADDED : KeytipEvents.KEYTIP_ADDED;
            EventGroup.raise(this, event_1, {
                keytip: props,
                uniqueID: uniqueKeytip.uniqueID,
            });
        }
        return uniqueKeytip.uniqueID;
    };
    /**
     * Update a keytip
     *
     * @param keytipProps - Keytip to update
     * @param uniqueID - Unique ID of this keytip
     */
    KeytipManager.prototype.update = function (keytipProps, uniqueID) {
        var newKeytipProps = this.addParentOverflow(keytipProps);
        var uniqueKeytip = this._getUniqueKtp(newKeytipProps, uniqueID);
        var oldKeyTip = this.keytips[uniqueID];
        if (oldKeyTip) {
            // Update everything except 'visible'
            uniqueKeytip.keytip.visible = oldKeyTip.keytip.visible;
            // Update keytip in this.keytips
            this.keytips[uniqueID] = uniqueKeytip;
            // Update the sequence to be up to date
            delete this.sequenceMapping[oldKeyTip.keytip.keySequences.toString()];
            this.sequenceMapping[uniqueKeytip.keytip.keySequences.toString()] = uniqueKeytip.keytip;
            // Raise event only if we are currently in keytip mode
            if (this.inKeytipMode || !this.delayUpdatingKeytipChange) {
                EventGroup.raise(this, KeytipEvents.KEYTIP_UPDATED, {
                    keytip: uniqueKeytip.keytip,
                    uniqueID: uniqueKeytip.uniqueID,
                });
            }
        }
    };
    /**
     * Unregisters a keytip
     *
     * @param keytipToRemove - IKeytipProps of the keytip to remove
     * @param uniqueID - Unique ID of this keytip
     * @param persisted - T/F if this keytip should be persisted, default is false
     */
    KeytipManager.prototype.unregister = function (keytipToRemove, uniqueID, persisted) {
        if (persisted === void 0) { persisted = false; }
        persisted ? delete this.persistedKeytips[uniqueID] : delete this.keytips[uniqueID];
        !persisted && delete this.sequenceMapping[keytipToRemove.keySequences.toString()];
        var event = persisted ? KeytipEvents.PERSISTED_KEYTIP_REMOVED : KeytipEvents.KEYTIP_REMOVED;
        // Update keytips only if we're in keytip mode
        if (this.inKeytipMode || !this.delayUpdatingKeytipChange) {
            EventGroup.raise(this, event, {
                keytip: keytipToRemove,
                uniqueID: uniqueID,
            });
        }
    };
    /**
     * Manual call to enter keytip mode
     */
    KeytipManager.prototype.enterKeytipMode = function () {
        EventGroup.raise(this, KeytipEvents.ENTER_KEYTIP_MODE);
    };
    /**
     * Manual call to exit keytip mode
     */
    KeytipManager.prototype.exitKeytipMode = function () {
        EventGroup.raise(this, KeytipEvents.EXIT_KEYTIP_MODE);
    };
    /**
     * Gets all IKeytipProps from this.keytips
     *
     * @returns {IKeytipProps[]} All keytips stored in the manager
     */
    KeytipManager.prototype.getKeytips = function () {
        var _this = this;
        return Object.keys(this.keytips).map(function (key) { return _this.keytips[key].keytip; });
    };
    /**
     * Adds the overflowSetSequence to the keytipProps if its parent keytip also has it
     *
     * @param keytipProps - Keytip props to add overflowSetSequence to if necessary
     * @returns {IKeytipProps} - Modified keytip props, if needed to be modified
     */
    KeytipManager.prototype.addParentOverflow = function (keytipProps) {
        var fullSequence = __spreadArrays(keytipProps.keySequences);
        fullSequence.pop();
        if (fullSequence.length !== 0) {
            var parentKeytip = this.sequenceMapping[fullSequence.toString()];
            if (parentKeytip && parentKeytip.overflowSetSequence) {
                return __assign(__assign({}, keytipProps), { overflowSetSequence: parentKeytip.overflowSetSequence });
            }
        }
        return keytipProps;
    };
    /**
     * Public function to bind for overflow items that have a submenu
     *
     * @param overflowButtonSequences
     * @param keytipSequences
     */
    KeytipManager.prototype.menuExecute = function (overflowButtonSequences, keytipSequences) {
        EventGroup.raise(this, KeytipEvents.PERSISTED_KEYTIP_EXECUTE, {
            overflowButtonSequences: overflowButtonSequences,
            keytipSequences: keytipSequences,
        });
    };
    /**
     * Creates an IUniqueKeytip object
     *
     * @param keytipProps - IKeytipProps
     * @param uniqueID - Unique ID, will default to the next unique ID if not passed
     * @returns {IUniqueKeytip} IUniqueKeytip object
     */
    KeytipManager.prototype._getUniqueKtp = function (keytipProps, uniqueID) {
        if (uniqueID === void 0) { uniqueID = getId(); }
        return { keytip: __assign({}, keytipProps), uniqueID: uniqueID };
    };
    KeytipManager._instance = new KeytipManager();
    return KeytipManager;
}());

/**
 * Converts a whole set of KeySequences into one keytip ID, which will be the ID for the last keytip sequence specified
 * keySequences should not include the initial keytip 'start' sequence.
 *
 * @param keySequences - Full path of IKeySequences for one keytip.
 * @returns {string} String to use for the keytip ID.
 */
function sequencesToID(keySequences) {
    return keySequences.reduce(function (prevValue, keySequence) {
        return prevValue + KTP_SEPARATOR + keySequence.split('').join(KTP_SEPARATOR);
    }, KTP_PREFIX);
}
/**
 * Merges an overflow sequence with a key sequence.
 *
 * @param keySequences - Full sequence for one keytip.
 * @param overflowKeySequences - Full overflow keytip sequence.
 * @returns {string[]} Sequence that will be used by the keytip when in the overflow.
 */
function mergeOverflows(keySequences, overflowKeySequences) {
    var overflowSequenceLen = overflowKeySequences.length;
    var overflowSequence = __spreadArrays(overflowKeySequences).pop();
    var newKeySequences = __spreadArrays(keySequences);
    return addElementAtIndex(newKeySequences, overflowSequenceLen - 1, overflowSequence);
}
/**
 * Gets the aria-describedby value to put on the component with this keytip.
 *
 * @param keySequences - KeySequences of the keytip.
 * @returns {string} The aria-describedby value to set on the component with this keytip.
 */
function getAriaDescribedBy(keySequences) {
    var describedby = ' ' + KTP_LAYER_ID;
    if (!keySequences.length) {
        // Return just the layer ID
        return describedby;
    }
    return describedby + ' ' + sequencesToID(keySequences);
}

/**
 * Hook to initialize and return a constant value. Unlike `React.useMemo`, this is guaranteed to
 * always return the same value (and if the initializer is a function, only call it once).
 * This is similar to setting a private member in a class constructor.
 *
 * If the value should ever change based on dependencies, use `React.useMemo` instead.
 *
 * If the value itself is a function, consider using `useConstCallback` instead.
 *
 * @param initialValue - Initial value, or function to get the initial value. Similar to `useState`,
 * only the value/function passed in the first time this is called is respected.
 * @returns The value. The identity of this value will always be the same.
 */
function useConst(initialValue) {
    // Use useRef to store the value because it's the least expensive built-in hook that works here
    // (we could also use `const [value] = React.useState(initialValue)` but that's more expensive
    // internally due to reducer handling which we don't need)
    var ref = useRef();
    if (ref.current === undefined) {
        // Box the value in an object so we can tell if it's initialized even if the initializer
        // returns/is undefined
        ref.current = {
            value: typeof initialValue === 'function' ? initialValue() : initialValue,
        };
    }
    return ref.current.value;
}

/**
 * Hook keeping track of a given value from a previous execution of the component the Hook is used in.
 *
 * See [React Hooks FAQ](https://reactjs.org/docs/hooks-faq.html#how-to-get-the-previous-props-or-state)
 */
function usePrevious(value) {
    var ref = useRef();
    useEffect(function () {
        ref.current = value;
    });
    return ref.current;
}

/**
 * Hook that creates attributes for components which are enabled with Keytip.
 */
function useKeytipData(options) {
    var _a, _b;
    var uniqueId = useRef();
    var keytipProps = options.keytipProps
        ? __assign({ disabled: options.disabled }, options.keytipProps) : undefined;
    var keytipManager = useConst(KeytipManager.getInstance());
    useEffect(function () {
        // Register Keytip in KeytipManager
        if (keytipProps) {
            uniqueId.current = keytipManager.register(keytipProps);
        }
        return function () {
            // Unregister Keytip in KeytipManager
            keytipProps && keytipManager.unregister(keytipProps, uniqueId.current);
        };
        // this is meant to run only at mount, and updates are handled separately
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    var prevOptions = usePrevious(options);
    if (uniqueId.current &&
        keytipProps &&
        (((_a = prevOptions) === null || _a === void 0 ? void 0 : _a.keytipProps) !== options.keytipProps || ((_b = prevOptions) === null || _b === void 0 ? void 0 : _b.disabled) !== options.disabled)) {
        keytipManager.update(keytipProps, uniqueId.current);
    }
    var nativeKeytipProps = {
        ariaDescribedBy: undefined,
        keytipId: undefined,
    };
    if (keytipProps) {
        nativeKeytipProps = getKeytipData(keytipManager, keytipProps, options.ariaDescribedBy);
    }
    return nativeKeytipProps;
}
/**
 * Gets the aria- and data- attributes to attach to the component
 * @param keytipProps - options for Keytip
 * @param describedByPrepend - ariaDescribedBy value to prepend
 */
function getKeytipData(keytipManager, keytipProps, describedByPrepend) {
    // Add the parent overflow sequence if necessary
    var newKeytipProps = keytipManager.addParentOverflow(keytipProps);
    // Construct aria-describedby and data-ktp-id attributes
    var ariaDescribedBy = mergeAriaAttributeValues(describedByPrepend, getAriaDescribedBy(newKeytipProps.keySequences));
    var keySequences = __spreadArrays(newKeytipProps.keySequences);
    if (newKeytipProps.overflowSetSequence) {
        keySequences = mergeOverflows(keySequences, newKeytipProps.overflowSetSequence);
    }
    var keytipId = sequencesToID(keySequences);
    return {
        ariaDescribedBy: ariaDescribedBy,
        keytipId: keytipId,
    };
}

/**
 * A small element to help the target component correctly read out its aria-describedby for its Keytip
 * {@docCategory Keytips}
 */
var KeytipData = function (props) {
    var _a;
    var children = props.children, keytipDataProps = __rest(props, ["children"]);
    var _b = useKeytipData(keytipDataProps), keytipId = _b.keytipId, ariaDescribedBy = _b.ariaDescribedBy;
    return children((_a = {},
        _a[DATAKTP_TARGET] = keytipId,
        _a[DATAKTP_EXECUTE_TARGET] = keytipId,
        _a['aria-describedby'] = ariaDescribedBy,
        _a));
};

var ContextualMenuAnchor = /** @class */ (function (_super) {
    __extends(ContextualMenuAnchor, _super);
    function ContextualMenuAnchor() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._anchor = createRef();
        _this._getMemoizedMenuButtonKeytipProps = memoizeFunction(function (keytipProps) {
            return __assign(__assign({}, keytipProps), { hasMenu: true });
        });
        _this._getSubmenuTarget = function () {
            return _this._anchor.current ? _this._anchor.current : undefined;
        };
        _this._onItemClick = function (ev) {
            var _a = _this.props, item = _a.item, onItemClick = _a.onItemClick;
            if (onItemClick) {
                onItemClick(item, ev);
            }
        };
        return _this;
    }
    ContextualMenuAnchor.prototype.render = function () {
        var _this = this;
        var _a = this.props, item = _a.item, classNames = _a.classNames, index = _a.index, focusableElementIndex = _a.focusableElementIndex, totalItemCount = _a.totalItemCount, hasCheckmarks = _a.hasCheckmarks, hasIcons = _a.hasIcons, _b = _a.contextualMenuItemAs, ChildrenRenderer = _b === void 0 ? ContextualMenuItem : _b, expandedMenuItemKey = _a.expandedMenuItemKey, onItemClick = _a.onItemClick, openSubMenu = _a.openSubMenu, dismissSubMenu = _a.dismissSubMenu, dismissMenu = _a.dismissMenu;
        var anchorRel = item.rel;
        if (item.target && item.target.toLowerCase() === '_blank') {
            anchorRel = anchorRel ? anchorRel : 'nofollow noopener noreferrer'; // Safe default to prevent tabjacking
        }
        var subMenuId = this._getSubMenuId(item);
        var itemHasSubmenu = hasSubmenu(item);
        var nativeProps = getNativeProps(item, anchorProperties);
        var disabled = isItemDisabled(item);
        var itemProps = item.itemProps;
        var keytipProps = item.keytipProps;
        if (keytipProps && itemHasSubmenu) {
            keytipProps = this._getMemoizedMenuButtonKeytipProps(keytipProps);
        }
        return (createElement("div", null,
            createElement(KeytipData, { keytipProps: item.keytipProps, ariaDescribedBy: nativeProps['aria-describedby'], disabled: disabled }, function (keytipAttributes) { return (createElement("a", __assign({}, nativeProps, keytipAttributes, { ref: _this._anchor, href: item.href, target: item.target, rel: anchorRel, className: classNames.root, role: "menuitem", "aria-owns": item.key === expandedMenuItemKey ? subMenuId : undefined, "aria-haspopup": itemHasSubmenu || undefined, "aria-expanded": itemHasSubmenu ? item.key === expandedMenuItemKey : undefined, "aria-posinset": focusableElementIndex + 1, "aria-setsize": totalItemCount, "aria-disabled": isItemDisabled(item), 
                // eslint-disable-next-line deprecation/deprecation
                style: item.style, onClick: _this._onItemClick, onMouseEnter: _this._onItemMouseEnter, onMouseLeave: _this._onItemMouseLeave, onMouseMove: _this._onItemMouseMove, onKeyDown: itemHasSubmenu ? _this._onItemKeyDown : undefined }),
                createElement(ChildrenRenderer, __assign({ componentRef: item.componentRef, item: item, classNames: classNames, index: index, onCheckmarkClick: hasCheckmarks && onItemClick ? onItemClick : undefined, hasIcons: hasIcons, openSubMenu: openSubMenu, dismissSubMenu: dismissSubMenu, dismissMenu: dismissMenu, getSubmenuTarget: _this._getSubmenuTarget }, itemProps)))); })));
    };
    return ContextualMenuAnchor;
}(ContextualMenuItemWrapper));

var ContextualMenuButton = /** @class */ (function (_super) {
    __extends(ContextualMenuButton, _super);
    function ContextualMenuButton() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._btn = createRef();
        _this._getMemoizedMenuButtonKeytipProps = memoizeFunction(function (keytipProps) {
            return __assign(__assign({}, keytipProps), { hasMenu: true });
        });
        _this._getSubmenuTarget = function () {
            return _this._btn.current ? _this._btn.current : undefined;
        };
        return _this;
    }
    ContextualMenuButton.prototype.render = function () {
        var _this = this;
        var _a = this.props, item = _a.item, classNames = _a.classNames, index = _a.index, focusableElementIndex = _a.focusableElementIndex, totalItemCount = _a.totalItemCount, hasCheckmarks = _a.hasCheckmarks, hasIcons = _a.hasIcons, _b = _a.contextualMenuItemAs, ChildrenRenderer = _b === void 0 ? ContextualMenuItem : _b, expandedMenuItemKey = _a.expandedMenuItemKey, onItemMouseDown = _a.onItemMouseDown, onItemClick = _a.onItemClick, openSubMenu = _a.openSubMenu, dismissSubMenu = _a.dismissSubMenu, dismissMenu = _a.dismissMenu;
        var subMenuId = this._getSubMenuId(item);
        var isChecked = getIsChecked(item);
        var canCheck = isChecked !== null;
        var defaultRole = getMenuItemAriaRole(item);
        var itemHasSubmenu = hasSubmenu(item);
        var itemProps = item.itemProps, ariaLabel = item.ariaLabel;
        var buttonNativeProperties = getNativeProps(item, buttonProperties);
        // Do not add the disabled attribute to the button so that it is focusable
        delete buttonNativeProperties.disabled;
        var itemRole = item.role || defaultRole;
        var itemButtonProperties = {
            className: classNames.root,
            onClick: this._onItemClick,
            onKeyDown: itemHasSubmenu ? this._onItemKeyDown : undefined,
            onMouseEnter: this._onItemMouseEnter,
            onMouseLeave: this._onItemMouseLeave,
            onMouseDown: function (ev) {
                return onItemMouseDown ? onItemMouseDown(item, ev) : undefined;
            },
            onMouseMove: this._onItemMouseMove,
            href: item.href,
            title: item.title,
            'aria-label': ariaLabel,
            'aria-haspopup': itemHasSubmenu || undefined,
            'aria-owns': item.key === expandedMenuItemKey ? subMenuId : undefined,
            'aria-expanded': itemHasSubmenu ? item.key === expandedMenuItemKey : undefined,
            'aria-posinset': focusableElementIndex + 1,
            'aria-setsize': totalItemCount,
            'aria-disabled': isItemDisabled(item),
            'aria-checked': (itemRole === 'menuitemcheckbox' || itemRole === 'menuitemradio') && canCheck ? !!isChecked : undefined,
            'aria-selected': itemRole === 'menuitem' && canCheck ? !!isChecked : undefined,
            role: itemRole,
            // eslint-disable-next-line deprecation/deprecation
            style: item.style,
        };
        var keytipProps = item.keytipProps;
        if (keytipProps && itemHasSubmenu) {
            keytipProps = this._getMemoizedMenuButtonKeytipProps(keytipProps);
        }
        return (createElement(KeytipData, { keytipProps: keytipProps, ariaDescribedBy: buttonNativeProperties['aria-describedby'], disabled: isItemDisabled(item) }, function (keytipAttributes) { return (createElement("button", __assign({ ref: _this._btn }, buttonNativeProperties, itemButtonProperties, keytipAttributes),
            createElement(ChildrenRenderer, __assign({ componentRef: item.componentRef, item: item, classNames: classNames, index: index, onCheckmarkClick: hasCheckmarks && onItemClick ? onItemClick : undefined, hasIcons: hasIcons, openSubMenu: openSubMenu, dismissSubMenu: dismissSubMenu, dismissMenu: dismissMenu, getSubmenuTarget: _this._getSubmenuTarget }, itemProps)))); }));
    };
    return ContextualMenuButton;
}(ContextualMenuItemWrapper));

var getStyles$5 = function (props) {
    // eslint-disable-next-line deprecation/deprecation
    var theme = props.theme, getClassNames = props.getClassNames, className = props.className;
    if (!theme) {
        throw new Error('Theme is undefined or null.');
    }
    if (getClassNames) {
        var names = getClassNames(theme);
        return {
            wrapper: [names.wrapper],
            divider: [names.divider],
        };
    }
    return {
        wrapper: [
            {
                display: 'inline-flex',
                height: '100%',
                alignItems: 'center',
            },
            className,
        ],
        divider: [
            {
                width: 1,
                height: '100%',
                backgroundColor: theme.palette.neutralTertiaryAlt,
            },
        ],
    };
};

var getClassNames$5 = classNamesFunction();
var VerticalDividerBase = function (props) {
    // eslint-disable-next-line deprecation/deprecation
    var styles = props.styles, theme = props.theme, deprecatedGetClassNames = props.getClassNames, className = props.className;
    var classNames = getClassNames$5(styles, { theme: theme, getClassNames: deprecatedGetClassNames, className: className });
    return (createElement("span", { className: classNames.wrapper },
        createElement("span", { className: classNames.divider })));
};

var VerticalDivider = styled(VerticalDividerBase, getStyles$5, undefined, {
    scope: 'VerticalDivider',
});

var TouchIdleDelay = 500; /* ms */
var ContextualMenuSplitButton = /** @class */ (function (_super) {
    __extends(ContextualMenuSplitButton, _super);
    function ContextualMenuSplitButton(props) {
        var _this = _super.call(this, props) || this;
        _this._getMemoizedMenuButtonKeytipProps = memoizeFunction(function (keytipProps) {
            return __assign(__assign({}, keytipProps), { hasMenu: true });
        });
        _this._onItemKeyDown = function (ev) {
            var _a = _this.props, item = _a.item, onItemKeyDown = _a.onItemKeyDown;
            if (ev.which === KeyCodes.enter) {
                _this._executeItemClick(ev);
                ev.preventDefault();
                ev.stopPropagation();
            }
            else if (onItemKeyDown) {
                onItemKeyDown(item, ev);
            }
        };
        _this._getSubmenuTarget = function () {
            return _this._splitButton;
        };
        _this._onItemMouseEnterPrimary = function (ev) {
            var _a = _this.props, item = _a.item, onItemMouseEnter = _a.onItemMouseEnter;
            if (onItemMouseEnter) {
                onItemMouseEnter(__assign(__assign({}, item), { subMenuProps: undefined, items: undefined }), ev, _this._splitButton);
            }
        };
        _this._onItemMouseEnterIcon = function (ev) {
            var _a = _this.props, item = _a.item, onItemMouseEnter = _a.onItemMouseEnter;
            if (onItemMouseEnter) {
                onItemMouseEnter(item, ev, _this._splitButton);
            }
        };
        _this._onItemMouseMovePrimary = function (ev) {
            var _a = _this.props, item = _a.item, onItemMouseMove = _a.onItemMouseMove;
            if (onItemMouseMove) {
                onItemMouseMove(__assign(__assign({}, item), { subMenuProps: undefined, items: undefined }), ev, _this._splitButton);
            }
        };
        _this._onItemMouseMoveIcon = function (ev) {
            var _a = _this.props, item = _a.item, onItemMouseMove = _a.onItemMouseMove;
            if (onItemMouseMove) {
                onItemMouseMove(item, ev, _this._splitButton);
            }
        };
        _this._onIconItemClick = function (ev) {
            var _a = _this.props, item = _a.item, onItemClickBase = _a.onItemClickBase;
            if (onItemClickBase) {
                onItemClickBase(item, ev, (_this._splitButton ? _this._splitButton : ev.currentTarget));
            }
        };
        _this._executeItemClick = function (ev) {
            var _a = _this.props, item = _a.item, executeItemClick = _a.executeItemClick, onItemClick = _a.onItemClick;
            if (item.disabled || item.isDisabled) {
                return;
            }
            if (_this._processingTouch && onItemClick) {
                return onItemClick(item, ev);
            }
            if (executeItemClick) {
                executeItemClick(item, ev);
            }
        };
        _this._onTouchStart = function (ev) {
            if (_this._splitButton && !('onpointerdown' in _this._splitButton)) {
                _this._handleTouchAndPointerEvent(ev);
            }
        };
        _this._onPointerDown = function (ev) {
            if (ev.pointerType === 'touch') {
                _this._handleTouchAndPointerEvent(ev);
                ev.preventDefault();
                ev.stopImmediatePropagation();
            }
        };
        _this._async = new Async(_this);
        _this._events = new EventGroup(_this);
        return _this;
    }
    ContextualMenuSplitButton.prototype.componentDidMount = function () {
        if (this._splitButton && 'onpointerdown' in this._splitButton) {
            this._events.on(this._splitButton, 'pointerdown', this._onPointerDown, true);
        }
    };
    ContextualMenuSplitButton.prototype.componentWillUnmount = function () {
        this._async.dispose();
        this._events.dispose();
    };
    ContextualMenuSplitButton.prototype.render = function () {
        var _this = this;
        var _a = this.props, item = _a.item, classNames = _a.classNames, index = _a.index, focusableElementIndex = _a.focusableElementIndex, totalItemCount = _a.totalItemCount, hasCheckmarks = _a.hasCheckmarks, hasIcons = _a.hasIcons, onItemMouseLeave = _a.onItemMouseLeave, expandedMenuItemKey = _a.expandedMenuItemKey;
        var itemHasSubmenu = hasSubmenu(item);
        var keytipProps = item.keytipProps;
        if (keytipProps) {
            keytipProps = this._getMemoizedMenuButtonKeytipProps(keytipProps);
        }
        return (createElement(KeytipData, { keytipProps: keytipProps, disabled: isItemDisabled(item) }, function (keytipAttributes) { return (createElement("div", { "data-ktp-target": keytipAttributes['data-ktp-target'], ref: function (splitButton) { return (_this._splitButton = splitButton); }, role: getMenuItemAriaRole(item), "aria-label": item.ariaLabel, className: classNames.splitContainer, "aria-disabled": isItemDisabled(item), "aria-expanded": itemHasSubmenu ? item.key === expandedMenuItemKey : undefined, "aria-haspopup": true, "aria-describedby": mergeAriaAttributeValues(item.ariaDescription, keytipAttributes['aria-describedby']), "aria-checked": item.isChecked || item.checked, "aria-posinset": focusableElementIndex + 1, "aria-setsize": totalItemCount, onMouseEnter: _this._onItemMouseEnterPrimary, onMouseLeave: onItemMouseLeave ? onItemMouseLeave.bind(_this, __assign(__assign({}, item), { subMenuProps: null, items: null })) : undefined, onMouseMove: _this._onItemMouseMovePrimary, onKeyDown: _this._onItemKeyDown, onClick: _this._executeItemClick, onTouchStart: _this._onTouchStart, tabIndex: 0, "data-is-focusable": true, "aria-roledescription": item['aria-roledescription'] },
            _this._renderSplitPrimaryButton(item, classNames, index, hasCheckmarks, hasIcons),
            _this._renderSplitDivider(item),
            _this._renderSplitIconButton(item, classNames, index, keytipAttributes))); }));
    };
    ContextualMenuSplitButton.prototype._renderSplitPrimaryButton = function (item, 
    // eslint-disable-next-line deprecation/deprecation
    classNames, index, hasCheckmarks, hasIcons) {
        var _a = this.props, _b = _a.contextualMenuItemAs, ChildrenRenderer = _b === void 0 ? ContextualMenuItem : _b, onItemClick = _a.onItemClick;
        var itemProps = {
            key: item.key,
            disabled: isItemDisabled(item) || item.primaryDisabled,
            /* eslint-disable deprecation/deprecation */
            name: item.name,
            text: item.text || item.name,
            secondaryText: item.secondaryText,
            /* eslint-enable deprecation/deprecation */
            className: classNames.splitPrimary,
            canCheck: item.canCheck,
            isChecked: item.isChecked,
            checked: item.checked,
            iconProps: item.iconProps,
            onRenderIcon: item.onRenderIcon,
            data: item.data,
            'data-is-focusable': false,
        };
        var itemComponentProps = item.itemProps;
        return (createElement("button", __assign({}, getNativeProps(itemProps, buttonProperties)),
            createElement(ChildrenRenderer, __assign({ "data-is-focusable": false, item: itemProps, classNames: classNames, index: index, onCheckmarkClick: hasCheckmarks && onItemClick ? onItemClick : undefined, hasIcons: hasIcons }, itemComponentProps))));
    };
    ContextualMenuSplitButton.prototype._renderSplitDivider = function (item) {
        var getDividerClassNames = item.getSplitButtonVerticalDividerClassNames || getSplitButtonVerticalDividerClassNames;
        return createElement(VerticalDivider, { getClassNames: getDividerClassNames });
    };
    ContextualMenuSplitButton.prototype._renderSplitIconButton = function (item, classNames, // eslint-disable-line deprecation/deprecation
    index, keytipAttributes) {
        var _a = this.props, _b = _a.contextualMenuItemAs, ChildrenRenderer = _b === void 0 ? ContextualMenuItem : _b, onItemMouseLeave = _a.onItemMouseLeave, onItemMouseDown = _a.onItemMouseDown, openSubMenu = _a.openSubMenu, dismissSubMenu = _a.dismissSubMenu, dismissMenu = _a.dismissMenu;
        var itemProps = {
            onClick: this._onIconItemClick,
            disabled: isItemDisabled(item),
            className: classNames.splitMenu,
            subMenuProps: item.subMenuProps,
            submenuIconProps: item.submenuIconProps,
            split: true,
            key: item.key,
        };
        var buttonProps = __assign(__assign({}, getNativeProps(itemProps, buttonProperties)), {
            onMouseEnter: this._onItemMouseEnterIcon,
            onMouseLeave: onItemMouseLeave ? onItemMouseLeave.bind(this, item) : undefined,
            onMouseDown: function (ev) {
                return onItemMouseDown ? onItemMouseDown(item, ev) : undefined;
            },
            onMouseMove: this._onItemMouseMoveIcon,
            'data-is-focusable': false,
            'data-ktp-execute-target': keytipAttributes['data-ktp-execute-target'],
            'aria-hidden': true,
        });
        var itemComponentProps = item.itemProps;
        return (createElement("button", __assign({}, buttonProps),
            createElement(ChildrenRenderer, __assign({ componentRef: item.componentRef, item: itemProps, classNames: classNames, index: index, hasIcons: false, openSubMenu: openSubMenu, dismissSubMenu: dismissSubMenu, dismissMenu: dismissMenu, getSubmenuTarget: this._getSubmenuTarget }, itemComponentProps))));
    };
    ContextualMenuSplitButton.prototype._handleTouchAndPointerEvent = function (ev) {
        var _this = this;
        var onTap = this.props.onTap;
        if (onTap) {
            onTap(ev);
        }
        // If we already have an existing timeout from a previous touch/pointer event
        // cancel that timeout so we can set a new one.
        if (this._lastTouchTimeoutId) {
            this._async.clearTimeout(this._lastTouchTimeoutId);
            this._lastTouchTimeoutId = undefined;
        }
        this._processingTouch = true;
        this._lastTouchTimeoutId = this._async.setTimeout(function () {
            _this._processingTouch = false;
            _this._lastTouchTimeoutId = undefined;
        }, TouchIdleDelay);
    };
    return ContextualMenuSplitButton;
}(ContextualMenuItemWrapper));

var getClassNames$6 = classNamesFunction();
var getContextualMenuItemClassNames = classNamesFunction();
function getSubmenuItems(item) {
    return item.subMenuProps ? item.subMenuProps.items : item.items;
}
/**
 * Returns true if a list of menu items can contain a checkbox
 */
function canAnyMenuItemsCheck(items) {
    return items.some(function (item) {
        if (item.canCheck) {
            return true;
        }
        // If the item is a section, check if any of the items in the section can check.
        if (item.sectionProps && item.sectionProps.items.some(function (submenuItem) { return submenuItem.canCheck === true; })) {
            return true;
        }
        return false;
    });
}
var NavigationIdleDelay = 250 /* ms */;
var COMPONENT_NAME = 'ContextualMenu';
var _getMenuItemStylesFunction = memoizeFunction(function () {
    var styles = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        styles[_i] = arguments[_i];
    }
    return function (styleProps) {
        return concatStyleSetsWithProps.apply(void 0, __spreadArrays([styleProps, getItemStyles], styles));
    };
});
var ContextualMenuBase = /** @class */ (function (_super) {
    __extends(ContextualMenuBase, _super);
    function ContextualMenuBase(props) {
        var _this = _super.call(this, props) || this;
        _this._mounted = false;
        _this.dismiss = function (ev, dismissAll) {
            var onDismiss = _this.props.onDismiss;
            if (onDismiss) {
                onDismiss(ev, dismissAll);
            }
        };
        _this._tryFocusPreviousActiveElement = function (options) {
            if (_this.props.onRestoreFocus) {
                _this.props.onRestoreFocus(options);
            }
            else {
                if (options && options.containsFocus && _this._previousActiveElement) {
                    // Make sure that the focus method actually exists
                    // In some cases the object might exist but not be a real element.
                    // This is primarily for IE 11 and should be removed once IE 11 is no longer in use.
                    if (_this._previousActiveElement.focus) {
                        _this._previousActiveElement.focus();
                    }
                }
            }
        };
        _this._onRenderMenuList = function (menuListProps, defaultRender) {
            var indexCorrection = 0;
            var items = menuListProps.items, totalItemCount = menuListProps.totalItemCount, hasCheckmarks = menuListProps.hasCheckmarks, hasIcons = menuListProps.hasIcons, role = menuListProps.role;
            return (createElement("ul", { className: _this._classNames.list, onKeyDown: _this._onKeyDown, onKeyUp: _this._onKeyUp, role: (role !== null && role !== void 0 ? role : 'menu') }, items.map(function (item, index) {
                var menuItem = _this._renderMenuItem(item, index, indexCorrection, totalItemCount, hasCheckmarks, hasIcons);
                if (item.itemType !== ContextualMenuItemType.Divider && item.itemType !== ContextualMenuItemType.Header) {
                    var indexIncrease = item.customOnRenderListLength ? item.customOnRenderListLength : 1;
                    indexCorrection += indexIncrease;
                }
                return menuItem;
            })));
        };
        /**
         * !!!IMPORTANT!!! Avoid mutating `item: IContextualMenuItem` argument. It will
         * cause the menu items to always re-render because the component update is based on shallow comparison.
         */
        _this._renderMenuItem = function (item, index, focusableElementIndex, totalItemCount, hasCheckmarks, hasIcons) {
            var _a;
            var renderedItems = [];
            var iconProps = item.iconProps || { iconName: 'None' };
            var getItemClassNames = item.getItemClassNames, // eslint-disable-line deprecation/deprecation
            itemProps = item.itemProps;
            var styles = itemProps ? itemProps.styles : undefined;
            // We only send a dividerClassName when the item to be rendered is a divider.
            // For all other cases, the default divider style is used.
            var dividerClassName = item.itemType === ContextualMenuItemType.Divider ? item.className : undefined;
            var subMenuIconClassName = item.submenuIconProps ? item.submenuIconProps.className : '';
            // eslint-disable-next-line deprecation/deprecation
            var itemClassNames;
            // IContextualMenuItem#getItemClassNames for backwards compatibility
            // otherwise uses mergeStyles for class names.
            if (getItemClassNames) {
                itemClassNames = getItemClassNames(_this.props.theme, isItemDisabled(item), _this.state.expandedMenuItemKey === item.key, !!getIsChecked(item), !!item.href, iconProps.iconName !== 'None', item.className, dividerClassName, iconProps.className, subMenuIconClassName, item.primaryDisabled);
            }
            else {
                var itemStyleProps = {
                    theme: _this.props.theme,
                    disabled: isItemDisabled(item),
                    expanded: _this.state.expandedMenuItemKey === item.key,
                    checked: !!getIsChecked(item),
                    isAnchorLink: !!item.href,
                    knownIcon: iconProps.iconName !== 'None',
                    itemClassName: item.className,
                    dividerClassName: dividerClassName,
                    iconClassName: iconProps.className,
                    subMenuClassName: subMenuIconClassName,
                    primaryDisabled: item.primaryDisabled,
                };
                // We need to generate default styles then override if styles are provided
                // since the ContextualMenu currently handles item classNames.
                itemClassNames = getContextualMenuItemClassNames(_getMenuItemStylesFunction((_a = _this._classNames.subComponentStyles) === null || _a === void 0 ? void 0 : _a.menuItem, styles), itemStyleProps);
            }
            // eslint-disable-next-line deprecation/deprecation
            if (item.text === '-' || item.name === '-') {
                item.itemType = ContextualMenuItemType.Divider;
            }
            switch (item.itemType) {
                case ContextualMenuItemType.Divider:
                    renderedItems.push(_this._renderSeparator(index, itemClassNames));
                    break;
                case ContextualMenuItemType.Header:
                    renderedItems.push(_this._renderSeparator(index, itemClassNames));
                    var headerItem = _this._renderHeaderMenuItem(item, itemClassNames, index, hasCheckmarks, hasIcons);
                    renderedItems.push(_this._renderListItem(headerItem, item.key || index, itemClassNames, item.title));
                    break;
                case ContextualMenuItemType.Section:
                    renderedItems.push(_this._renderSectionItem(item, itemClassNames, index, hasCheckmarks, hasIcons));
                    break;
                default:
                    var menuItem = _this._renderNormalItem(item, itemClassNames, index, focusableElementIndex, totalItemCount, hasCheckmarks, hasIcons);
                    renderedItems.push(_this._renderListItem(menuItem, item.key || index, itemClassNames, item.title));
                    break;
            }
            // Since multiple nodes *could* be rendered, wrap them all in a fragment with this item's key.
            // This ensures the reconciler handles multi-item output per-node correctly and does not re-mount content.
            return createElement(Fragment, { key: item.key }, renderedItems);
        };
        _this._defaultMenuItemRenderer = function (item) {
            var index = item.index, focusableElementIndex = item.focusableElementIndex, totalItemCount = item.totalItemCount, hasCheckmarks = item.hasCheckmarks, hasIcons = item.hasIcons;
            return _this._renderMenuItem(item, index, focusableElementIndex, totalItemCount, hasCheckmarks, hasIcons);
        };
        _this._onKeyDown = function (ev) {
            // Take note if we are processing an alt (option) or meta (command) keydown.
            // See comment in _shouldHandleKeyUp for reasoning.
            _this._lastKeyDownWasAltOrMeta = _this._isAltOrMeta(ev);
            // On Mac, pressing escape dismisses all levels of native context menus
            var dismissAllMenus = ev.which === KeyCodes.escape && (isMac() || isIOS());
            return _this._keyHandler(ev, _this._shouldHandleKeyDown, dismissAllMenus);
        };
        _this._shouldHandleKeyDown = function (ev) {
            return (ev.which === KeyCodes.escape ||
                _this._shouldCloseSubMenu(ev) ||
                (ev.which === KeyCodes.up && (ev.altKey || ev.metaKey)));
        };
        _this._onMenuFocusCapture = function (ev) {
            if (_this.props.delayUpdateFocusOnHover) {
                _this._shouldUpdateFocusOnMouseEvent = true;
            }
        };
        _this._onKeyUp = function (ev) {
            return _this._keyHandler(ev, _this._shouldHandleKeyUp, true /* dismissAllMenus */);
        };
        /**
         * We close the menu on key up only if ALL of the following are true:
         * - Most recent key down was alt or meta (command)
         * - The alt/meta key down was NOT followed by some other key (such as down/up arrow to
         *   expand/collapse the menu)
         * - We're not on a Mac (or iOS)
         *
         * This is because on Windows, pressing alt moves focus to the application menu bar or similar,
         * closing any open context menus. There is not a similar behavior on Macs.
         */
        _this._shouldHandleKeyUp = function (ev) {
            var keyPressIsAltOrMetaAlone = _this._lastKeyDownWasAltOrMeta && _this._isAltOrMeta(ev);
            _this._lastKeyDownWasAltOrMeta = false;
            return !!keyPressIsAltOrMetaAlone && !(isIOS() || isMac());
        };
        /**
         * Calls `shouldHandleKey` to determine whether the keyboard event should be handled;
         * if so, stops event propagation and dismisses menu(s).
         * @param ev - The keyboard event.
         * @param shouldHandleKey - Returns whether we should handle this keyboard event.
         * @param dismissAllMenus - If true, dismiss all menus. Otherwise, dismiss only the current menu.
         * Only does anything if `shouldHandleKey` returns true.
         * @returns Whether the event was handled.
         */
        _this._keyHandler = function (ev, shouldHandleKey, dismissAllMenus) {
            var handled = false;
            if (shouldHandleKey(ev)) {
                _this._focusingPreviousElement = true;
                _this.dismiss(ev, dismissAllMenus);
                ev.preventDefault();
                ev.stopPropagation();
                handled = true;
            }
            return handled;
        };
        /**
         * Checks if the submenu should be closed
         */
        _this._shouldCloseSubMenu = function (ev) {
            var submenuCloseKey = getRTL$1(_this.props.theme) ? KeyCodes.right : KeyCodes.left;
            if (ev.which !== submenuCloseKey || !_this.props.isSubMenu) {
                return false;
            }
            return (_this._adjustedFocusZoneProps.direction === FocusZoneDirection.vertical ||
                (!!_this._adjustedFocusZoneProps.checkForNoWrap &&
                    !shouldWrapFocus(ev.target, 'data-no-horizontal-wrap')));
        };
        _this._onMenuKeyDown = function (ev) {
            // Mark as handled if onKeyDown returns true (for handling collapse cases)
            // or if we are attempting to expand a submenu
            var handled = _this._onKeyDown(ev);
            if (handled || !_this._host) {
                return;
            }
            // If we have a modifier key being pressed, we do not want to move focus.
            // Otherwise, handle up and down keys.
            var hasModifier = !!(ev.altKey || ev.metaKey);
            var isUp = ev.which === KeyCodes.up;
            var isDown = ev.which === KeyCodes.down;
            if (!hasModifier && (isUp || isDown)) {
                var elementToFocus = isUp
                    ? getLastFocusable(_this._host, _this._host.lastChild, true)
                    : getFirstFocusable(_this._host, _this._host.firstChild, true);
                if (elementToFocus) {
                    elementToFocus.focus();
                    ev.preventDefault();
                    ev.stopPropagation();
                }
            }
        };
        /**
         * Scroll handler for the callout to make sure the mouse events
         * for updating focus are not interacting during scroll
         */
        _this._onScroll = function () {
            if (!_this._isScrollIdle && _this._scrollIdleTimeoutId !== undefined) {
                _this._async.clearTimeout(_this._scrollIdleTimeoutId);
                _this._scrollIdleTimeoutId = undefined;
            }
            else {
                _this._isScrollIdle = false;
            }
            _this._scrollIdleTimeoutId = _this._async.setTimeout(function () {
                _this._isScrollIdle = true;
            }, NavigationIdleDelay);
        };
        _this._onItemMouseEnterBase = function (item, ev, target) {
            if (_this._shouldIgnoreMouseEvent()) {
                return;
            }
            _this._updateFocusOnMouseEvent(item, ev, target);
        };
        _this._onItemMouseMoveBase = function (item, ev, target) {
            var targetElement = ev.currentTarget;
            // Always do this check to make sure we record a mouseMove if needed (even if we are timed out)
            if (_this._shouldUpdateFocusOnMouseEvent) {
                _this._gotMouseMove = true;
            }
            else {
                return;
            }
            if (!_this._isScrollIdle ||
                _this._enterTimerId !== undefined ||
                targetElement === _this._targetWindow.document.activeElement) {
                return;
            }
            _this._updateFocusOnMouseEvent(item, ev, target);
        };
        _this._onMouseItemLeave = function (item, ev) {
            if (_this._shouldIgnoreMouseEvent()) {
                return;
            }
            if (_this._enterTimerId !== undefined) {
                _this._async.clearTimeout(_this._enterTimerId);
                _this._enterTimerId = undefined;
            }
            if (_this.state.expandedMenuItemKey !== undefined) {
                return;
            }
            /**
             * IE11 focus() method forces parents to scroll to top of element.
             * Edge and IE expose a setActive() function for focusable divs that
             * sets the page focus but does not scroll the parent element.
             */
            if (_this._host.setActive) {
                try {
                    _this._host.setActive();
                }
                catch (e) {
                    /* no-op */
                }
            }
            else {
                _this._host.focus();
            }
        };
        _this._onItemMouseDown = function (item, ev) {
            if (item.onMouseDown) {
                item.onMouseDown(item, ev);
            }
        };
        _this._onItemClick = function (item, ev) {
            _this._onItemClickBase(item, ev, ev.currentTarget);
        };
        _this._onItemClickBase = function (item, ev, target) {
            var items = getSubmenuItems(item);
            // Cancel a async menu item hover timeout action from being taken and instead
            // just trigger the click event instead.
            _this._cancelSubMenuTimer();
            if (!hasSubmenu(item) && (!items || !items.length)) {
                // This is an item without a menu. Click it.
                _this._executeItemClick(item, ev);
            }
            else {
                if (item.key !== _this.state.expandedMenuItemKey) {
                    // This has a collapsed sub menu. Expand it.
                    _this.setState({
                        // When Edge + Narrator are used together (regardless of if the button is in a form or not), pressing
                        // "Enter" fires this method and not _onMenuKeyDown. Checking ev.nativeEvent.detail differentiates
                        // between a real click event and a keypress event (detail should be the number of mouse clicks).
                        // ...Plot twist! For a real click event in IE 11, detail is always 0 (Edge sets it properly to 1).
                        // So we also check the pointerType property, which both Edge and IE set to "mouse" for real clicks
                        // and "" for pressing "Enter" with Narrator on.
                        expandedByMouseClick: ev.nativeEvent.detail !== 0 || ev.nativeEvent.pointerType === 'mouse',
                    });
                    _this._onItemSubMenuExpand(item, target);
                }
            }
            ev.stopPropagation();
            ev.preventDefault();
        };
        _this._onAnchorClick = function (item, ev) {
            _this._executeItemClick(item, ev);
            ev.stopPropagation();
        };
        _this._executeItemClick = function (item, ev) {
            if (item.disabled || item.isDisabled) {
                return;
            }
            var dismiss = false;
            if (item.onClick) {
                dismiss = !!item.onClick(ev, item);
            }
            else if (_this.props.onItemClick) {
                dismiss = !!_this.props.onItemClick(ev, item);
            }
            if (dismiss || !ev.defaultPrevented) {
                _this.dismiss(ev, true);
                // This should be removed whenever possible.
                // This ensures that the hidden dismissal action maintains the same behavior.
                // If the menu is being dismissed then the previously focused element should
                // get focused since the dismiss was triggered by a user click on an item
                // Rather than focus being lost.
                _this._focusingPreviousElement = true;
            }
        };
        _this._onItemKeyDown = function (item, ev) {
            var openKey = getRTL$1(_this.props.theme) ? KeyCodes.left : KeyCodes.right;
            if (!item.disabled &&
                (ev.which === openKey || ev.which === KeyCodes.enter || (ev.which === KeyCodes.down && (ev.altKey || ev.metaKey)))) {
                _this.setState({
                    expandedByMouseClick: false,
                });
                _this._onItemSubMenuExpand(item, ev.currentTarget);
                ev.preventDefault();
            }
        };
        // Cancel a async menu item hover timeout action from being taken and instead
        // do new upcoming behavior
        _this._cancelSubMenuTimer = function () {
            if (_this._enterTimerId !== undefined) {
                _this._async.clearTimeout(_this._enterTimerId);
                _this._enterTimerId = undefined;
            }
        };
        _this._onItemSubMenuExpand = function (item, target) {
            if (_this.state.expandedMenuItemKey !== item.key) {
                if (_this.state.expandedMenuItemKey) {
                    _this._onSubMenuDismiss();
                }
                // Focus the target to ensure when we close it, we're focusing on the correct element.
                target.focus();
                _this.setState({
                    expandedMenuItemKey: item.key,
                    submenuTarget: target,
                });
            }
        };
        /**
         * This function is called ASYNCHRONOUSLY, and so there is a chance it is called
         * after the component is unmounted. The _mounted property is added to prevent
         * from calling setState() after unmount. Do NOT copy this pattern in synchronous
         * code.
         */
        _this._onSubMenuDismiss = function (ev, dismissAll) {
            if (dismissAll) {
                _this.dismiss(ev, dismissAll);
            }
            else if (_this._mounted) {
                _this.setState({
                    dismissedMenuItemKey: _this.state.expandedMenuItemKey,
                    expandedMenuItemKey: undefined,
                    submenuTarget: undefined,
                });
            }
        };
        _this._getSubMenuId = function (item) {
            var subMenuId = _this.state.subMenuId;
            if (item.subMenuProps && item.subMenuProps.id) {
                subMenuId = item.subMenuProps.id;
            }
            return subMenuId;
        };
        _this._onPointerAndTouchEvent = function (ev) {
            _this._cancelSubMenuTimer();
        };
        _this._async = new Async(_this);
        _this._events = new EventGroup(_this);
        initializeComponentRef(_this);
        warnDeprecations(COMPONENT_NAME, props, {
            getMenuClassNames: 'styles',
        });
        _this.state = {
            contextualMenuItems: undefined,
            subMenuId: getId('ContextualMenu'),
        };
        _this._id = props.id || getId('ContextualMenu');
        _this._focusingPreviousElement = false;
        _this._isScrollIdle = true;
        _this._shouldUpdateFocusOnMouseEvent = !_this.props.delayUpdateFocusOnHover;
        _this._gotMouseMove = false;
        return _this;
    }
    ContextualMenuBase.prototype.shouldComponentUpdate = function (newProps, newState) {
        if (!newProps.shouldUpdateWhenHidden && this.props.hidden && newProps.hidden) {
            // Do not update when hidden.
            return false;
        }
        return !shallowCompare(this.props, newProps) || !shallowCompare(this.state, newState);
    };
    ContextualMenuBase.prototype.UNSAFE_componentWillUpdate = function (newProps) {
        if (newProps.target !== this.props.target) {
            var newTarget = newProps.target;
            this._setTargetWindowAndElement(newTarget);
        }
        if (this._isHidden(newProps) !== this._isHidden(this.props)) {
            if (this._isHidden(newProps)) {
                this._onMenuClosed();
            }
            else {
                this._onMenuOpened();
                this._previousActiveElement = this._targetWindow
                    ? this._targetWindow.document.activeElement
                    : undefined;
            }
        }
        if (newProps.delayUpdateFocusOnHover !== this.props.delayUpdateFocusOnHover) {
            // update shouldUpdateFocusOnMouseEvent to follow what was passed in
            this._shouldUpdateFocusOnMouseEvent = !newProps.delayUpdateFocusOnHover;
            // If shouldUpdateFocusOnMouseEvent is false, we need to reset gotMouseMove to false
            this._gotMouseMove = this._shouldUpdateFocusOnMouseEvent && this._gotMouseMove;
        }
    };
    // Invoked once, both on the client and server, immediately before the initial rendering occurs.
    ContextualMenuBase.prototype.UNSAFE_componentWillMount = function () {
        var target = this.props.target;
        this._setTargetWindowAndElement(target);
        if (!this.props.hidden) {
            this._previousActiveElement = this._targetWindow
                ? this._targetWindow.document.activeElement
                : undefined;
        }
    };
    // Invoked once, only on the client (not on the server), immediately after the initial rendering occurs.
    ContextualMenuBase.prototype.componentDidMount = function () {
        if (!this.props.hidden) {
            this._onMenuOpened();
        }
        this._mounted = true;
    };
    // Invoked immediately before a component is unmounted from the DOM.
    ContextualMenuBase.prototype.componentWillUnmount = function () {
        if (this.props.onMenuDismissed) {
            this.props.onMenuDismissed(this.props);
        }
        this._events.dispose();
        this._async.dispose();
        this._mounted = false;
    };
    ContextualMenuBase.prototype.render = function () {
        var _this = this;
        var isBeakVisible = this.props.isBeakVisible;
        var _a = this.props, items = _a.items, labelElementId = _a.labelElementId, id = _a.id, className = _a.className, beakWidth = _a.beakWidth, directionalHint = _a.directionalHint, directionalHintForRTL = _a.directionalHintForRTL, alignTargetEdge = _a.alignTargetEdge, gapSpace = _a.gapSpace, coverTarget = _a.coverTarget, ariaLabel = _a.ariaLabel, doNotLayer = _a.doNotLayer, target = _a.target, bounds = _a.bounds, useTargetWidth = _a.useTargetWidth, useTargetAsMinWidth = _a.useTargetAsMinWidth, directionalHintFixed = _a.directionalHintFixed, shouldFocusOnMount = _a.shouldFocusOnMount, shouldFocusOnContainer = _a.shouldFocusOnContainer, title = _a.title, styles = _a.styles, theme = _a.theme, calloutProps = _a.calloutProps, _b = _a.onRenderSubMenu, onRenderSubMenu = _b === void 0 ? this._onRenderSubMenu : _b, _c = _a.onRenderMenuList, onRenderMenuList = _c === void 0 ? this._onRenderMenuList : _c, focusZoneProps = _a.focusZoneProps, 
        // eslint-disable-next-line deprecation/deprecation
        getMenuClassNames = _a.getMenuClassNames;
        this._classNames = getMenuClassNames
            ? getMenuClassNames(theme, className)
            : getClassNames$6(styles, {
                theme: theme,
                className: className,
            });
        var hasIcons = itemsHaveIcons(items);
        function itemsHaveIcons(contextualMenuItems) {
            for (var _i = 0, contextualMenuItems_1 = contextualMenuItems; _i < contextualMenuItems_1.length; _i++) {
                var item = contextualMenuItems_1[_i];
                if (item.iconProps) {
                    return true;
                }
                if (item.itemType === ContextualMenuItemType.Section &&
                    item.sectionProps &&
                    itemsHaveIcons(item.sectionProps.items)) {
                    return true;
                }
            }
            return false;
        }
        this._adjustedFocusZoneProps = __assign(__assign({}, focusZoneProps), { direction: this._getFocusZoneDirection() });
        var hasCheckmarks = canAnyMenuItemsCheck(items);
        var submenuProps = this.state.expandedMenuItemKey && this.props.hidden !== true ? this._getSubmenuProps() : null;
        isBeakVisible = isBeakVisible === undefined ? this.props.responsiveMode <= ResponsiveMode.medium : isBeakVisible;
        /**
         * When useTargetWidth is true, get the width of the target element and apply it for the context menu container
         */
        var contextMenuStyle;
        var targetAsHtmlElement = this._target;
        if ((useTargetWidth || useTargetAsMinWidth) && targetAsHtmlElement && targetAsHtmlElement.offsetWidth) {
            var targetBoundingRect = targetAsHtmlElement.getBoundingClientRect();
            var targetWidth = targetBoundingRect.width - 2 /* Accounts for 1px border */;
            if (useTargetWidth) {
                contextMenuStyle = {
                    width: targetWidth,
                };
            }
            else if (useTargetAsMinWidth) {
                contextMenuStyle = {
                    minWidth: targetWidth,
                };
            }
        }
        // The menu should only return if items were provided, if no items were provided then it should not appear.
        if (items && items.length > 0) {
            var totalItemCount = 0;
            for (var _i = 0, items_1 = items; _i < items_1.length; _i++) {
                var item = items_1[_i];
                if (item.itemType !== ContextualMenuItemType.Divider && item.itemType !== ContextualMenuItemType.Header) {
                    var itemCount = item.customOnRenderListLength ? item.customOnRenderListLength : 1;
                    totalItemCount += itemCount;
                }
            }
            var calloutStyles = this._classNames.subComponentStyles
                ? this._classNames.subComponentStyles.callout
                : undefined;
            return (createElement(Callout, __assign({ styles: calloutStyles, onRestoreFocus: this._tryFocusPreviousActiveElement }, calloutProps, { target: target, isBeakVisible: isBeakVisible, beakWidth: beakWidth, directionalHint: directionalHint, directionalHintForRTL: directionalHintForRTL, gapSpace: gapSpace, coverTarget: coverTarget, doNotLayer: doNotLayer, className: css('ms-ContextualMenu-Callout', calloutProps && calloutProps.className), setInitialFocus: shouldFocusOnMount, onDismiss: this.props.onDismiss, onScroll: this._onScroll, bounds: bounds, directionalHintFixed: directionalHintFixed, alignTargetEdge: alignTargetEdge, hidden: this.props.hidden }),
                createElement("div", { "aria-label": ariaLabel, "aria-labelledby": labelElementId, style: contextMenuStyle, ref: function (host) { return (_this._host = host); }, id: id, className: this._classNames.container, tabIndex: shouldFocusOnContainer ? 0 : -1, onKeyDown: this._onMenuKeyDown, onKeyUp: this._onKeyUp, onFocusCapture: this._onMenuFocusCapture },
                    title && createElement("div", { className: this._classNames.title },
                        " ",
                        title,
                        " "),
                    items && items.length ? (createElement(FocusZone, __assign({ className: this._classNames.root, isCircularNavigation: true, handleTabKey: FocusZoneTabbableElements.all }, this._adjustedFocusZoneProps), onRenderMenuList({
                        items: items,
                        totalItemCount: totalItemCount,
                        hasCheckmarks: hasCheckmarks,
                        hasIcons: hasIcons,
                        defaultMenuItemRenderer: this._defaultMenuItemRenderer,
                    }, this._onRenderMenuList))) : null,
                    submenuProps && onRenderSubMenu(submenuProps, this._onRenderSubMenu))));
        }
        else {
            return null;
        }
    };
    /**
     * Return whether the contextual menu is hidden.
     * Undefined value for hidden is equivalent to hidden being false.
     * @param props - Props for the component
     */
    ContextualMenuBase.prototype._isHidden = function (props) {
        return !!props.hidden;
    };
    ContextualMenuBase.prototype._onMenuOpened = function () {
        this._events.on(this._targetWindow, 'resize', this.dismiss);
        this._shouldUpdateFocusOnMouseEvent = !this.props.delayUpdateFocusOnHover;
        this._gotMouseMove = false;
        this.props.onMenuOpened && this.props.onMenuOpened(this.props);
    };
    ContextualMenuBase.prototype._onMenuClosed = function () {
        this._events.off(this._targetWindow, 'resize', this.dismiss);
        // This is kept for backwards compatability with hidden for right now.
        // This preserves the way that this behaved in the past
        // TODO find a better way to handle this by using the same conventions that
        // Popup uses to determine if focus is contained when dismissal occurs
        this._tryFocusPreviousActiveElement({
            containsFocus: this._focusingPreviousElement,
            originalElement: this._previousActiveElement,
        });
        this._focusingPreviousElement = false;
        if (this.props.onMenuDismissed) {
            this.props.onMenuDismissed(this.props);
        }
        this._shouldUpdateFocusOnMouseEvent = !this.props.delayUpdateFocusOnHover;
        // We need to dismiss any submenu related state properties,
        // so that when the menu is shown again, the submenu is collapsed
        this.setState({
            expandedByMouseClick: undefined,
            dismissedMenuItemKey: undefined,
            expandedMenuItemKey: undefined,
            submenuTarget: undefined,
        });
    };
    /**
     * Gets the focusZoneDirection by using the arrowDirection if specified,
     * the direction specificed in the focusZoneProps, or defaults to FocusZoneDirection.vertical
     */
    ContextualMenuBase.prototype._getFocusZoneDirection = function () {
        var focusZoneProps = this.props.focusZoneProps;
        return focusZoneProps && focusZoneProps.direction !== undefined
            ? focusZoneProps.direction
            : FocusZoneDirection.vertical;
    };
    ContextualMenuBase.prototype._onRenderSubMenu = function (subMenuProps, defaultRender) {
        throw Error('ContextualMenuBase: onRenderSubMenu callback is null or undefined. ' +
            'Please ensure to set `onRenderSubMenu` property either manually or with `styled` helper.');
    };
    ContextualMenuBase.prototype._renderSectionItem = function (sectionItem, 
    // eslint-disable-next-line deprecation/deprecation
    menuClassNames, index, hasCheckmarks, hasIcons) {
        var _this = this;
        var sectionProps = sectionItem.sectionProps;
        if (!sectionProps) {
            return;
        }
        var headerItem;
        var groupProps;
        if (sectionProps.title) {
            // Since title is a user-facing string, it needs to be stripped of whitespace in order to build a valid element ID
            var id = this._id + sectionProps.title.replace(/\s/g, '');
            var headerContextualMenuItem = {
                key: "section-" + sectionProps.title + "-title",
                itemType: ContextualMenuItemType.Header,
                text: sectionProps.title,
                id: id,
            };
            groupProps = {
                role: 'group',
                'aria-labelledby': id,
            };
            headerItem = this._renderHeaderMenuItem(headerContextualMenuItem, menuClassNames, index, hasCheckmarks, hasIcons);
        }
        if (sectionProps.items && sectionProps.items.length > 0) {
            return (createElement("li", { role: "presentation", key: sectionProps.key || sectionItem.key || "section-" + index },
                createElement("div", __assign({}, groupProps),
                    createElement("ul", { className: this._classNames.list },
                        sectionProps.topDivider && this._renderSeparator(index, menuClassNames, true, true),
                        headerItem &&
                            this._renderListItem(headerItem, sectionItem.key || index, menuClassNames, sectionItem.title),
                        sectionProps.items.map(function (contextualMenuItem, itemsIndex) {
                            return _this._renderMenuItem(contextualMenuItem, itemsIndex, itemsIndex, sectionProps.items.length, hasCheckmarks, hasIcons);
                        }),
                        sectionProps.bottomDivider && this._renderSeparator(index, menuClassNames, false, true)))));
        }
    };
    ContextualMenuBase.prototype._renderListItem = function (content, key, classNames, // eslint-disable-line deprecation/deprecation
    title) {
        return (createElement("li", { role: "presentation", title: title, key: key, className: classNames.item }, content));
    };
    ContextualMenuBase.prototype._renderSeparator = function (index, classNames, // eslint-disable-line deprecation/deprecation
    top, fromSection) {
        if (fromSection || index > 0) {
            return (createElement("li", { role: "separator", key: 'separator-' + index + (top === undefined ? '' : top ? '-top' : '-bottom'), className: classNames.divider, "aria-hidden": "true" }));
        }
        return null;
    };
    ContextualMenuBase.prototype._renderNormalItem = function (item, classNames, // eslint-disable-line deprecation/deprecation
    index, focusableElementIndex, totalItemCount, hasCheckmarks, hasIcons) {
        if (item.onRender) {
            return item.onRender(__assign({ 'aria-posinset': focusableElementIndex + 1, 'aria-setsize': totalItemCount }, item), this.dismiss);
        }
        if (item.href) {
            return this._renderAnchorMenuItem(item, classNames, index, focusableElementIndex, totalItemCount, hasCheckmarks, hasIcons);
        }
        if (item.split && hasSubmenu(item)) {
            return this._renderSplitButton(item, classNames, index, focusableElementIndex, totalItemCount, hasCheckmarks, hasIcons);
        }
        return this._renderButtonItem(item, classNames, index, focusableElementIndex, totalItemCount, hasCheckmarks, hasIcons);
    };
    ContextualMenuBase.prototype._renderHeaderMenuItem = function (item, 
    // eslint-disable-next-line deprecation/deprecation
    classNames, index, hasCheckmarks, hasIcons) {
        var _a = this.props.contextualMenuItemAs, ChildrenRenderer = _a === void 0 ? ContextualMenuItem : _a;
        var itemProps = item.itemProps, id = item.id;
        var divHtmlProperties = itemProps && getNativeProps(itemProps, divProperties);
        return (
        // eslint-disable-next-line deprecation/deprecation
        createElement("div", __assign({ id: id, className: this._classNames.header }, divHtmlProperties, { style: item.style }),
            createElement(ChildrenRenderer, __assign({ item: item, classNames: classNames, index: index, onCheckmarkClick: hasCheckmarks ? this._onItemClick : undefined, hasIcons: hasIcons }, itemProps))));
    };
    ContextualMenuBase.prototype._renderAnchorMenuItem = function (item, 
    // eslint-disable-next-line deprecation/deprecation
    classNames, index, focusableElementIndex, totalItemCount, hasCheckmarks, hasIcons) {
        var contextualMenuItemAs = this.props.contextualMenuItemAs;
        var expandedMenuItemKey = this.state.expandedMenuItemKey;
        return (createElement(ContextualMenuAnchor, { item: item, classNames: classNames, index: index, focusableElementIndex: focusableElementIndex, totalItemCount: totalItemCount, hasCheckmarks: hasCheckmarks, hasIcons: hasIcons, contextualMenuItemAs: contextualMenuItemAs, onItemMouseEnter: this._onItemMouseEnterBase, onItemMouseLeave: this._onMouseItemLeave, onItemMouseMove: this._onItemMouseMoveBase, onItemMouseDown: this._onItemMouseDown, executeItemClick: this._executeItemClick, onItemClick: this._onAnchorClick, onItemKeyDown: this._onItemKeyDown, getSubMenuId: this._getSubMenuId, expandedMenuItemKey: expandedMenuItemKey, openSubMenu: this._onItemSubMenuExpand, dismissSubMenu: this._onSubMenuDismiss, dismissMenu: this.dismiss }));
    };
    ContextualMenuBase.prototype._renderButtonItem = function (item, 
    // eslint-disable-next-line deprecation/deprecation
    classNames, index, focusableElementIndex, totalItemCount, hasCheckmarks, hasIcons) {
        var contextualMenuItemAs = this.props.contextualMenuItemAs;
        var expandedMenuItemKey = this.state.expandedMenuItemKey;
        return (createElement(ContextualMenuButton, { item: item, classNames: classNames, index: index, focusableElementIndex: focusableElementIndex, totalItemCount: totalItemCount, hasCheckmarks: hasCheckmarks, hasIcons: hasIcons, contextualMenuItemAs: contextualMenuItemAs, onItemMouseEnter: this._onItemMouseEnterBase, onItemMouseLeave: this._onMouseItemLeave, onItemMouseMove: this._onItemMouseMoveBase, onItemMouseDown: this._onItemMouseDown, executeItemClick: this._executeItemClick, onItemClick: this._onItemClick, onItemClickBase: this._onItemClickBase, onItemKeyDown: this._onItemKeyDown, getSubMenuId: this._getSubMenuId, expandedMenuItemKey: expandedMenuItemKey, openSubMenu: this._onItemSubMenuExpand, dismissSubMenu: this._onSubMenuDismiss, dismissMenu: this.dismiss }));
    };
    ContextualMenuBase.prototype._renderSplitButton = function (item, 
    // eslint-disable-next-line deprecation/deprecation
    classNames, index, focusableElementIndex, totalItemCount, hasCheckmarks, hasIcons) {
        var contextualMenuItemAs = this.props.contextualMenuItemAs;
        var expandedMenuItemKey = this.state.expandedMenuItemKey;
        return (createElement(ContextualMenuSplitButton, { item: item, classNames: classNames, index: index, focusableElementIndex: focusableElementIndex, totalItemCount: totalItemCount, hasCheckmarks: hasCheckmarks, hasIcons: hasIcons, contextualMenuItemAs: contextualMenuItemAs, onItemMouseEnter: this._onItemMouseEnterBase, onItemMouseLeave: this._onMouseItemLeave, onItemMouseMove: this._onItemMouseMoveBase, onItemMouseDown: this._onItemMouseDown, executeItemClick: this._executeItemClick, onItemClick: this._onItemClick, onItemClickBase: this._onItemClickBase, onItemKeyDown: this._onItemKeyDown, openSubMenu: this._onItemSubMenuExpand, dismissSubMenu: this._onSubMenuDismiss, dismissMenu: this.dismiss, expandedMenuItemKey: expandedMenuItemKey, onTap: this._onPointerAndTouchEvent }));
    };
    /**
     * Returns true if the key for the event is alt (Mac option) or meta (Mac command).
     */
    ContextualMenuBase.prototype._isAltOrMeta = function (ev) {
        return ev.which === KeyCodes.alt || ev.key === 'Meta';
    };
    ContextualMenuBase.prototype._shouldIgnoreMouseEvent = function () {
        return !this._isScrollIdle || !this._gotMouseMove;
    };
    /**
     * Handles updating focus when mouseEnter or mouseMove fire.
     * As part of updating focus, This function will also update
     * the expand/collapse state accordingly.
     */
    ContextualMenuBase.prototype._updateFocusOnMouseEvent = function (item, ev, target) {
        var _this = this;
        var targetElement = target ? target : ev.currentTarget;
        var _a = this.props.subMenuHoverDelay, timeoutDuration = _a === void 0 ? NavigationIdleDelay : _a;
        if (item.key === this.state.expandedMenuItemKey) {
            return;
        }
        if (this._enterTimerId !== undefined) {
            this._async.clearTimeout(this._enterTimerId);
            this._enterTimerId = undefined;
        }
        // If the menu is not expanded we can update focus without any delay
        if (this.state.expandedMenuItemKey === undefined) {
            targetElement.focus();
        }
        // Delay updating expanding/dismissing the submenu
        // and only set focus if we have not already done so
        if (hasSubmenu(item)) {
            ev.stopPropagation();
            this._enterTimerId = this._async.setTimeout(function () {
                targetElement.focus();
                _this.setState({
                    expandedByMouseClick: true,
                });
                _this._onItemSubMenuExpand(item, targetElement);
                _this._enterTimerId = undefined;
            }, timeoutDuration);
        }
        else {
            this._enterTimerId = this._async.setTimeout(function () {
                _this._onSubMenuDismiss(ev);
                targetElement.focus();
                _this._enterTimerId = undefined;
            }, timeoutDuration);
        }
    };
    ContextualMenuBase.prototype._getSubmenuProps = function () {
        var _a = this.state, submenuTarget = _a.submenuTarget, expandedMenuItemKey = _a.expandedMenuItemKey;
        var item = this._findItemByKey(expandedMenuItemKey);
        var submenuProps = null;
        if (item) {
            submenuProps = {
                items: getSubmenuItems(item),
                target: submenuTarget,
                onDismiss: this._onSubMenuDismiss,
                isSubMenu: true,
                id: this.state.subMenuId,
                shouldFocusOnMount: true,
                shouldFocusOnContainer: this.state.expandedByMouseClick,
                directionalHint: getRTL$1(this.props.theme) ? DirectionalHint.leftTopEdge : DirectionalHint.rightTopEdge,
                className: this.props.className,
                gapSpace: 0,
                isBeakVisible: false,
            };
            if (item.subMenuProps) {
                assign(submenuProps, item.subMenuProps);
            }
        }
        return submenuProps;
    };
    ContextualMenuBase.prototype._findItemByKey = function (key) {
        var items = this.props.items;
        return this._findItemByKeyFromItems(key, items);
    };
    /**
     * Returns the item that mathes a given key if any.
     * @param key - The key of the item to match
     * @param items - The items to look for the key
     */
    ContextualMenuBase.prototype._findItemByKeyFromItems = function (key, items) {
        for (var _i = 0, items_2 = items; _i < items_2.length; _i++) {
            var item = items_2[_i];
            if (item.itemType === ContextualMenuItemType.Section && item.sectionProps) {
                var match = this._findItemByKeyFromItems(key, item.sectionProps.items);
                if (match) {
                    return match;
                }
            }
            else if (item.key && item.key === key) {
                return item;
            }
        }
    };
    ContextualMenuBase.prototype._setTargetWindowAndElement = function (target) {
        var currentElement = this._host;
        if (target) {
            if (typeof target === 'string') {
                var currentDoc = getDocument(currentElement);
                this._target = currentDoc ? currentDoc.querySelector(target) : null;
                this._targetWindow = getWindow(currentElement);
                // Cast to any prevents error about stopPropagation always existing
            }
            else if (target.stopPropagation) {
                this._targetWindow = getWindow(target.target);
                this._target = target;
            }
            else if (
            // eslint-disable-next-line deprecation/deprecation
            (target.left !== undefined || target.x !== undefined) &&
                // eslint-disable-next-line deprecation/deprecation
                (target.top !== undefined || target.y !== undefined)) {
                this._targetWindow = getWindow(currentElement);
                this._target = target;
            }
            else if (target.current !== undefined) {
                this._target = target.current;
                this._targetWindow = getWindow(this._target);
            }
            else {
                var targetElement = target;
                this._targetWindow = getWindow(targetElement);
                this._target = target;
            }
        }
        else {
            this._targetWindow = getWindow(currentElement);
        }
    };
    // The default ContextualMenu properties have no items and beak, the default submenu direction is right and top.
    ContextualMenuBase.defaultProps = {
        items: [],
        shouldFocusOnMount: true,
        gapSpace: 0,
        directionalHint: DirectionalHint.bottomAutoEdge,
        beakWidth: 16,
    };
    ContextualMenuBase = __decorate([
        withResponsiveMode
    ], ContextualMenuBase);
    return ContextualMenuBase;
}(Component));

var GlobalClassNames$5 = {
    root: 'ms-ContextualMenu',
    container: 'ms-ContextualMenu-container',
    list: 'ms-ContextualMenu-list',
    header: 'ms-ContextualMenu-header',
    title: 'ms-ContextualMenu-title',
    isopen: 'is-open',
};
var getStyles$6 = function (props) {
    var className = props.className, theme = props.theme;
    var classNames = getGlobalClassNames(GlobalClassNames$5, theme);
    var fonts = theme.fonts, semanticColors = theme.semanticColors, effects = theme.effects;
    return {
        root: [
            theme.fonts.medium,
            classNames.root,
            classNames.isopen,
            {
                backgroundColor: semanticColors.menuBackground,
                minWidth: '180px',
            },
            className,
        ],
        container: [
            classNames.container,
            {
                selectors: {
                    ':focus': { outline: 0 },
                },
            },
        ],
        list: [
            classNames.list,
            classNames.isopen,
            {
                listStyleType: 'none',
                margin: '0',
                padding: '0',
            },
        ],
        header: [
            classNames.header,
            fonts.small,
            {
                fontWeight: FontWeights.semibold,
                color: semanticColors.menuHeader,
                background: 'none',
                backgroundColor: 'transparent',
                border: 'none',
                height: CONTEXTUAL_MENU_ITEM_HEIGHT,
                lineHeight: CONTEXTUAL_MENU_ITEM_HEIGHT,
                cursor: 'default',
                padding: '0px 6px',
                userSelect: 'none',
                textAlign: 'left',
            },
        ],
        title: [
            classNames.title,
            {
                fontSize: fonts.mediumPlus.fontSize,
                paddingRight: '14px',
                paddingLeft: '14px',
                paddingBottom: '5px',
                paddingTop: '5px',
                backgroundColor: semanticColors.menuItemBackgroundPressed,
            },
        ],
        subComponentStyles: {
            callout: {
                root: {
                    boxShadow: effects.elevation8,
                },
            },
            menuItem: {},
        },
    };
};

function onRenderSubMenu(subMenuProps) {
    return createElement(LocalContextualMenu, __assign({}, subMenuProps));
}
// This is to prevent cyclic import with ContextualMenu.base.tsx.
var LocalContextualMenu = styled(ContextualMenuBase, getStyles$6, function () { return ({ onRenderSubMenu: onRenderSubMenu }); }, { scope: 'ContextualMenu' });
/**
 * ContextualMenu description
 */
var ContextualMenu = LocalContextualMenu;

var ButtonGlobalClassNames = {
    msButton: 'ms-Button',
    msButtonHasMenu: 'ms-Button--hasMenu',
    msButtonIcon: 'ms-Button-icon',
    msButtonMenuIcon: 'ms-Button-menuIcon',
    msButtonLabel: 'ms-Button-label',
    msButtonDescription: 'ms-Button-description',
    msButtonScreenReaderText: 'ms-Button-screenReaderText',
    msButtonFlexContainer: 'ms-Button-flexContainer',
    msButtonTextContainer: 'ms-Button-textContainer',
};
var getBaseButtonClassNames = memoizeFunction(function (theme, styles, className, variantClassName, iconClassName, menuIconClassName, disabled, hasMenu, checked, expanded, isSplit) {
    var _a, _b;
    var classNames = getGlobalClassNames(ButtonGlobalClassNames, theme || {});
    var isExpanded = expanded && !isSplit;
    return mergeStyleSets({
        root: [
            classNames.msButton,
            styles.root,
            variantClassName,
            checked && ['is-checked', styles.rootChecked],
            isExpanded && [
                'is-expanded',
                styles.rootExpanded,
                {
                    selectors: (_a = {},
                        _a[":hover ." + classNames.msButtonIcon] = styles.iconExpandedHovered,
                        // menuIcon falls back to rootExpandedHovered to support original behavior
                        _a[":hover ." + classNames.msButtonMenuIcon] = styles.menuIconExpandedHovered || styles.rootExpandedHovered,
                        _a[':hover'] = styles.rootExpandedHovered,
                        _a),
                },
            ],
            hasMenu && [ButtonGlobalClassNames.msButtonHasMenu, styles.rootHasMenu],
            disabled && ['is-disabled', styles.rootDisabled],
            !disabled &&
                !isExpanded &&
                !checked && {
                selectors: (_b = {
                        ':hover': styles.rootHovered
                    },
                    _b[":hover ." + classNames.msButtonLabel] = styles.labelHovered,
                    _b[":hover ." + classNames.msButtonIcon] = styles.iconHovered,
                    _b[":hover ." + classNames.msButtonDescription] = styles.descriptionHovered,
                    _b[":hover ." + classNames.msButtonMenuIcon] = styles.menuIconHovered,
                    _b[':focus'] = styles.rootFocused,
                    _b[':active'] = styles.rootPressed,
                    _b[":active ." + classNames.msButtonIcon] = styles.iconPressed,
                    _b[":active ." + classNames.msButtonDescription] = styles.descriptionPressed,
                    _b[":active ." + classNames.msButtonMenuIcon] = styles.menuIconPressed,
                    _b),
            },
            disabled && checked && [styles.rootCheckedDisabled],
            !disabled &&
                checked && {
                selectors: {
                    ':hover': styles.rootCheckedHovered,
                    ':active': styles.rootCheckedPressed,
                },
            },
            className,
        ],
        flexContainer: [classNames.msButtonFlexContainer, styles.flexContainer],
        textContainer: [classNames.msButtonTextContainer, styles.textContainer],
        icon: [
            classNames.msButtonIcon,
            iconClassName,
            styles.icon,
            isExpanded && styles.iconExpanded,
            checked && styles.iconChecked,
            disabled && styles.iconDisabled,
        ],
        label: [classNames.msButtonLabel, styles.label, checked && styles.labelChecked, disabled && styles.labelDisabled],
        menuIcon: [
            classNames.msButtonMenuIcon,
            menuIconClassName,
            styles.menuIcon,
            checked && styles.menuIconChecked,
            disabled && !isSplit && styles.menuIconDisabled,
            !disabled &&
                !isExpanded &&
                !checked && {
                selectors: {
                    ':hover': styles.menuIconHovered,
                    ':active': styles.menuIconPressed,
                },
            },
            isExpanded && ['is-expanded', styles.menuIconExpanded],
        ],
        description: [
            classNames.msButtonDescription,
            styles.description,
            checked && styles.descriptionChecked,
            disabled && styles.descriptionDisabled,
        ],
        screenReaderText: [classNames.msButtonScreenReaderText, styles.screenReaderText],
    });
});

var getClassNames$7 = memoizeFunction(function (styles, disabled, expanded, checked, primaryDisabled) {
    return {
        root: mergeStyles(styles.splitButtonMenuButton, expanded && [styles.splitButtonMenuButtonExpanded], disabled && [styles.splitButtonMenuButtonDisabled], checked && !disabled && [styles.splitButtonMenuButtonChecked]),
        splitButtonContainer: mergeStyles(styles.splitButtonContainer, !disabled &&
            checked && [
            styles.splitButtonContainerChecked,
            {
                selectors: {
                    ':hover': styles.splitButtonContainerCheckedHovered,
                },
            },
        ], !disabled &&
            !checked && [
            {
                selectors: {
                    ':hover': styles.splitButtonContainerHovered,
                    ':focus': styles.splitButtonContainerFocused,
                },
            },
        ], disabled && styles.splitButtonContainerDisabled),
        icon: mergeStyles(styles.splitButtonMenuIcon, disabled && styles.splitButtonMenuIconDisabled, !disabled && primaryDisabled && styles.splitButtonMenuIcon),
        flexContainer: mergeStyles(styles.splitButtonFlexContainer),
        divider: mergeStyles(styles.splitButtonDivider, (primaryDisabled || disabled) && styles.splitButtonDividerDisabled),
    };
});

var TouchIdleDelay$1 = 500; /* ms */
var COMPONENT_NAME$1 = 'BaseButton';
/**
 * {@docCategory Button}
 */
var BaseButton = /** @class */ (function (_super) {
    __extends(BaseButton, _super);
    function BaseButton(props) {
        var _this = _super.call(this, props) || this;
        _this._buttonElement = createRef();
        _this._splitButtonContainer = createRef();
        _this._renderedVisibleMenu = false;
        _this._getMemoizedMenuButtonKeytipProps = memoizeFunction(function (keytipProps) {
            return __assign(__assign({}, keytipProps), { hasMenu: true });
        });
        _this._onRenderIcon = function (buttonProps, defaultRender) {
            var iconProps = _this.props.iconProps;
            if (iconProps && (iconProps.iconName !== undefined || iconProps.imageProps)) {
                var className = iconProps.className, imageProps = iconProps.imageProps, rest = __rest(iconProps, ["className", "imageProps"]);
                // If the styles prop is specified as part of iconProps, fall back to regular Icon as FontIcon and ImageIcon
                // do not have this prop.
                if (iconProps.styles) {
                    return createElement(Icon, __assign({ className: css(_this._classNames.icon, className), imageProps: imageProps }, rest));
                }
                if (iconProps.iconName) {
                    return createElement(FontIcon, __assign({ className: css(_this._classNames.icon, className) }, rest));
                }
                if (imageProps) {
                    return createElement(ImageIcon, __assign({ className: css(_this._classNames.icon, className), imageProps: imageProps }, rest));
                }
            }
            return null;
        };
        _this._onRenderTextContents = function () {
            var _a = _this.props, text = _a.text, children = _a.children, 
            // eslint-disable-next-line deprecation/deprecation
            _b = _a.secondaryText, 
            // eslint-disable-next-line deprecation/deprecation
            secondaryText = _b === void 0 ? _this.props.description : _b, _c = _a.onRenderText, onRenderText = _c === void 0 ? _this._onRenderText : _c, _d = _a.onRenderDescription, onRenderDescription = _d === void 0 ? _this._onRenderDescription : _d;
            if (text || typeof children === 'string' || secondaryText) {
                return (createElement("span", { className: _this._classNames.textContainer },
                    onRenderText(_this.props, _this._onRenderText),
                    onRenderDescription(_this.props, _this._onRenderDescription)));
            }
            return [onRenderText(_this.props, _this._onRenderText), onRenderDescription(_this.props, _this._onRenderDescription)];
        };
        _this._onRenderText = function () {
            var text = _this.props.text;
            var children = _this.props.children;
            // For backwards compat, we should continue to take in the text content from children.
            if (text === undefined && typeof children === 'string') {
                text = children;
            }
            if (_this._hasText()) {
                return (createElement("span", { key: _this._labelId, className: _this._classNames.label, id: _this._labelId }, text));
            }
            return null;
        };
        _this._onRenderChildren = function () {
            var children = _this.props.children;
            // If children is just a string, either it or the text will be rendered via onRenderLabel
            // If children is another component, it will be rendered after text
            if (typeof children === 'string') {
                return null;
            }
            return children;
        };
        _this._onRenderDescription = function (props) {
            // eslint-disable-next-line deprecation/deprecation
            var _a = props.secondaryText, secondaryText = _a === void 0 ? _this.props.description : _a;
            // ms-Button-description is only shown when the button type is compound.
            // In other cases it will not be displayed.
            return secondaryText ? (createElement("span", { key: _this._descriptionId, className: _this._classNames.description, id: _this._descriptionId }, secondaryText)) : null;
        };
        _this._onRenderAriaDescription = function () {
            var ariaDescription = _this.props.ariaDescription;
            // If ariaDescription is given, descriptionId will be assigned to ariaDescriptionSpan,
            // otherwise it will be assigned to descriptionSpan.
            return ariaDescription ? (createElement("span", { className: _this._classNames.screenReaderText, id: _this._ariaDescriptionId }, ariaDescription)) : null;
        };
        _this._onRenderMenuIcon = function (props) {
            var menuIconProps = _this.props.menuIconProps;
            return createElement(FontIcon, __assign({ iconName: "ChevronDown" }, menuIconProps, { className: _this._classNames.menuIcon }));
        };
        _this._onRenderMenu = function (menuProps) {
            var persistMenu = _this.props.persistMenu;
            var menuHidden = _this.state.menuHidden;
            var MenuType = _this.props.menuAs || ContextualMenu;
            // the accessible menu label (accessible name) has a relationship to the button.
            // If the menu props do not specify an explicit value for aria-label or aria-labelledBy,
            // AND the button has text, we'll set the menu aria-labelledBy to the text element id.
            if (!menuProps.ariaLabel && !menuProps.labelElementId && _this._hasText()) {
                menuProps = __assign(__assign({}, menuProps), { labelElementId: _this._labelId });
            }
            return (createElement(MenuType, __assign({ id: _this._labelId + '-menu', directionalHint: DirectionalHint.bottomLeftEdge }, menuProps, { shouldFocusOnContainer: _this._menuShouldFocusOnContainer, shouldFocusOnMount: _this._menuShouldFocusOnMount, hidden: persistMenu ? menuHidden : undefined, className: css('ms-BaseButton-menuhost', menuProps.className), target: _this._isSplitButton ? _this._splitButtonContainer.current : _this._buttonElement.current, onDismiss: _this._onDismissMenu })));
        };
        _this._onDismissMenu = function (ev) {
            var menuProps = _this.props.menuProps;
            if (menuProps && menuProps.onDismiss) {
                menuProps.onDismiss(ev);
            }
            if (!ev || !ev.defaultPrevented) {
                _this._dismissMenu();
            }
        };
        _this._dismissMenu = function () {
            _this._menuShouldFocusOnMount = undefined;
            _this._menuShouldFocusOnContainer = undefined;
            _this.setState({ menuHidden: true });
        };
        _this._openMenu = function (shouldFocusOnContainer, shouldFocusOnMount) {
            if (shouldFocusOnMount === void 0) { shouldFocusOnMount = true; }
            if (_this.props.menuProps) {
                _this._menuShouldFocusOnContainer = shouldFocusOnContainer;
                _this._menuShouldFocusOnMount = shouldFocusOnMount;
                _this._renderedVisibleMenu = true;
                _this.setState({ menuHidden: false });
            }
        };
        _this._onToggleMenu = function (shouldFocusOnContainer) {
            var shouldFocusOnMount = true;
            if (_this.props.menuProps && _this.props.menuProps.shouldFocusOnMount === false) {
                shouldFocusOnMount = false;
            }
            _this.state.menuHidden ? _this._openMenu(shouldFocusOnContainer, shouldFocusOnMount) : _this._dismissMenu();
        };
        _this._onSplitContainerFocusCapture = function (ev) {
            var container = _this._splitButtonContainer.current;
            // If the target is coming from the portal we do not need to set focus on the container.
            if (!container || (ev.target && portalContainsElement(ev.target, container))) {
                return;
            }
            // We should never be able to focus the individual buttons in a split button. Focus
            // should always remain on the container.
            container.focus();
        };
        _this._onSplitButtonPrimaryClick = function (ev) {
            if (!_this.state.menuHidden) {
                _this._dismissMenu();
            }
            if (!_this._processingTouch && _this.props.onClick) {
                _this.props.onClick(ev);
            }
            else if (_this._processingTouch) {
                _this._onMenuClick(ev);
            }
        };
        _this._onKeyDown = function (ev) {
            // explicity cancelling event so click won't fire after this
            if (_this.props.disabled && (ev.which === KeyCodes.enter || ev.which === KeyCodes.space)) {
                ev.preventDefault();
                ev.stopPropagation();
            }
            else if (!_this.props.disabled) {
                if (_this.props.menuProps) {
                    _this._onMenuKeyDown(ev);
                }
                else if (_this.props.onKeyDown !== undefined) {
                    _this.props.onKeyDown(ev); // not cancelling event because it's not disabled
                }
            }
        };
        _this._onKeyUp = function (ev) {
            if (!_this.props.disabled && _this.props.onKeyUp !== undefined) {
                _this.props.onKeyUp(ev); // not cancelling event because it's not disabled
            }
        };
        _this._onKeyPress = function (ev) {
            if (!_this.props.disabled && _this.props.onKeyPress !== undefined) {
                _this.props.onKeyPress(ev); // not cancelling event because it's not disabled
            }
        };
        _this._onMouseUp = function (ev) {
            if (!_this.props.disabled && _this.props.onMouseUp !== undefined) {
                _this.props.onMouseUp(ev); // not cancelling event because it's not disabled
            }
        };
        _this._onMouseDown = function (ev) {
            if (!_this.props.disabled && _this.props.onMouseDown !== undefined) {
                _this.props.onMouseDown(ev); // not cancelling event because it's not disabled
            }
        };
        _this._onClick = function (ev) {
            if (!_this.props.disabled) {
                if (_this.props.menuProps) {
                    _this._onMenuClick(ev);
                }
                else if (_this.props.onClick !== undefined) {
                    _this.props.onClick(ev); // not cancelling event because it's not disabled
                }
            }
        };
        _this._onSplitButtonContainerKeyDown = function (ev) {
            if (ev.which === KeyCodes.enter || ev.which === KeyCodes.space) {
                if (_this._buttonElement.current) {
                    _this._buttonElement.current.click();
                    ev.preventDefault();
                    ev.stopPropagation();
                }
            }
            else {
                _this._onMenuKeyDown(ev);
            }
        };
        _this._onMenuKeyDown = function (ev) {
            if (_this.props.disabled) {
                return;
            }
            if (_this.props.onKeyDown) {
                _this.props.onKeyDown(ev);
            }
            var isUp = ev.which === KeyCodes.up;
            var isDown = ev.which === KeyCodes.down;
            if (!ev.defaultPrevented && _this._isValidMenuOpenKey(ev)) {
                var onMenuClick = _this.props.onMenuClick;
                if (onMenuClick) {
                    onMenuClick(ev, _this.props);
                }
                _this._onToggleMenu(false);
                ev.preventDefault();
                ev.stopPropagation();
            }
            if (!(ev.altKey || ev.metaKey) && (isUp || isDown)) {
                // Suppose a menu, with shouldFocusOnMount: false, is open, and user wants to keyboard to the menu items
                // We need to re-render the menu with shouldFocusOnMount as true.
                if (!_this.state.menuHidden && _this.props.menuProps) {
                    var currentShouldFocusOnMount = _this._menuShouldFocusOnMount !== undefined
                        ? _this._menuShouldFocusOnMount
                        : _this.props.menuProps.shouldFocusOnMount;
                    if (!currentShouldFocusOnMount) {
                        ev.preventDefault();
                        ev.stopPropagation();
                        _this._menuShouldFocusOnMount = true;
                        _this.forceUpdate();
                    }
                }
            }
        };
        _this._onTouchStart = function () {
            if (_this._isSplitButton &&
                _this._splitButtonContainer.current &&
                !('onpointerdown' in _this._splitButtonContainer.current)) {
                _this._handleTouchAndPointerEvent();
            }
        };
        _this._onMenuClick = function (ev) {
            var onMenuClick = _this.props.onMenuClick;
            if (onMenuClick) {
                onMenuClick(ev, _this.props);
            }
            if (!ev.defaultPrevented) {
                // When Edge + Narrator are used together (regardless of if the button is in a form or not), pressing
                // "Enter" fires this method and not _onMenuKeyDown. Checking ev.nativeEvent.detail differentiates
                // between a real click event and a keypress event (detail should be the number of mouse clicks).
                // ...Plot twist! For a real click event in IE 11, detail is always 0 (Edge sets it properly to 1).
                // So we also check the pointerType property, which both Edge and IE set to "mouse" for real clicks
                // and "" for pressing "Enter" with Narrator on.
                var shouldFocusOnContainer = ev.nativeEvent.detail !== 0 || ev.nativeEvent.pointerType === 'mouse';
                _this._onToggleMenu(shouldFocusOnContainer);
                ev.preventDefault();
                ev.stopPropagation();
            }
        };
        initializeComponentRef(_this);
        _this._async = new Async(_this);
        _this._events = new EventGroup(_this);
        warnConditionallyRequiredProps(COMPONENT_NAME$1, props, ['menuProps', 'onClick'], 'split', _this.props.split);
        warnDeprecations(COMPONENT_NAME$1, props, {
            rootProps: undefined,
            description: 'secondaryText',
            toggled: 'checked',
        });
        _this._labelId = getId();
        _this._descriptionId = getId();
        _this._ariaDescriptionId = getId();
        _this.state = {
            menuHidden: true,
        };
        return _this;
    }
    Object.defineProperty(BaseButton.prototype, "_isSplitButton", {
        get: function () {
            return !!this.props.menuProps && !!this.props.onClick && this.props.split === true;
        },
        enumerable: true,
        configurable: true
    });
    BaseButton.prototype.render = function () {
        var _a;
        var _b = this.props, ariaDescription = _b.ariaDescription, ariaLabel = _b.ariaLabel, ariaHidden = _b.ariaHidden, className = _b.className, disabled = _b.disabled, allowDisabledFocus = _b.allowDisabledFocus, primaryDisabled = _b.primaryDisabled, 
        // eslint-disable-next-line deprecation/deprecation
        _c = _b.secondaryText, 
        // eslint-disable-next-line deprecation/deprecation
        secondaryText = _c === void 0 ? this.props.description : _c, href = _b.href, iconProps = _b.iconProps, menuIconProps = _b.menuIconProps, styles = _b.styles, checked = _b.checked, variantClassName = _b.variantClassName, theme = _b.theme, toggle = _b.toggle, getClassNames = _b.getClassNames, role = _b.role;
        var menuHidden = this.state.menuHidden;
        // Button is disabled if the whole button (in case of splitbutton is disabled) or if the primary action is disabled
        var isPrimaryButtonDisabled = disabled || primaryDisabled;
        this._classNames = getClassNames
            ? getClassNames(theme, className, variantClassName, iconProps && iconProps.className, menuIconProps && menuIconProps.className, isPrimaryButtonDisabled, checked, !menuHidden, !!this.props.menuProps, this.props.split, !!allowDisabledFocus)
            : getBaseButtonClassNames(theme, styles, className, variantClassName, iconProps && iconProps.className, menuIconProps && menuIconProps.className, isPrimaryButtonDisabled, !!this.props.menuProps, checked, !menuHidden, this.props.split);
        var _d = this, _ariaDescriptionId = _d._ariaDescriptionId, _labelId = _d._labelId, _descriptionId = _d._descriptionId;
        // Anchor tag cannot be disabled hence in disabled state rendering
        // anchor button as normal button
        var renderAsAnchor = !isPrimaryButtonDisabled && !!href;
        var tag = renderAsAnchor ? 'a' : 'button';
        var nativeProps = getNativeProps(
        // eslint-disable-next-line deprecation/deprecation
        assign(renderAsAnchor ? {} : { type: 'button' }, this.props.rootProps, this.props), renderAsAnchor ? anchorProperties : buttonProperties, [
            'disabled',
        ]);
        // Check for ariaLabel passed in via Button props, and fall back to aria-label passed in via native props
        var resolvedAriaLabel = ariaLabel || nativeProps['aria-label'];
        // Check for ariaDescription, secondaryText or aria-describedby in the native props to determine source of
        // aria-describedby. Otherwise default to undefined so property does not appear in output.
        var ariaDescribedBy = undefined;
        if (ariaDescription) {
            ariaDescribedBy = _ariaDescriptionId;
        }
        else if (secondaryText && this.props.onRenderDescription !== nullRender) {
            // for buttons like CompoundButton with a valid onRenderDescription, we need to set an ariaDescribedBy
            // for buttons that do not render anything (via nullRender), we should not set an ariaDescribedBy
            ariaDescribedBy = _descriptionId;
        }
        else if (nativeProps['aria-describedby']) {
            ariaDescribedBy = nativeProps['aria-describedby'];
        }
        // If an explicit ariaLabel is given, use that as the label and we're done.
        // If an explicit aria-labelledby is given, use that and we're done.
        // If any kind of description is given (which will end up as an aria-describedby attribute),
        // set the labelledby element. Otherwise, the button is labeled implicitly by the descendent
        // text on the button (if it exists). Never set both aria-label and aria-labelledby.
        var ariaLabelledBy = undefined;
        if (!resolvedAriaLabel) {
            if (nativeProps['aria-labelledby']) {
                ariaLabelledBy = nativeProps['aria-labelledby'];
            }
            else if (ariaDescribedBy) {
                ariaLabelledBy = this._hasText() ? _labelId : undefined;
            }
        }
        var dataIsFocusable = this.props['data-is-focusable'] === false || (disabled && !allowDisabledFocus) || this._isSplitButton
            ? false
            : true;
        var isCheckboxTypeRole = role === 'menuitemcheckbox' || role === 'checkbox';
        // if isCheckboxTypeRole, always return a checked value.
        // Otherwise only return checked value if toggle is set to true.
        // This is because role="checkbox" always needs to have an aria-checked value
        // but our checked prop only sets aria-pressed if we mark the button as a toggle="true"
        var checkedOrPressedValue = isCheckboxTypeRole ? !!checked : toggle === true ? !!checked : undefined;
        var buttonProps = assign(nativeProps, (_a = {
                className: this._classNames.root,
                ref: this._buttonElement,
                disabled: isPrimaryButtonDisabled && !allowDisabledFocus,
                onKeyDown: this._onKeyDown,
                onKeyPress: this._onKeyPress,
                onKeyUp: this._onKeyUp,
                onMouseDown: this._onMouseDown,
                onMouseUp: this._onMouseUp,
                onClick: this._onClick,
                'aria-label': resolvedAriaLabel,
                'aria-labelledby': ariaLabelledBy,
                'aria-describedby': ariaDescribedBy,
                'aria-disabled': isPrimaryButtonDisabled,
                'data-is-focusable': dataIsFocusable
            },
            // aria-pressed attribute should only be present for toggle buttons
            // aria-checked attribute should only be present for toggle buttons with checkbox type role
            _a[isCheckboxTypeRole ? 'aria-checked' : 'aria-pressed'] = checkedOrPressedValue,
            _a));
        if (ariaHidden) {
            buttonProps['aria-hidden'] = true;
        }
        if (this._isSplitButton) {
            return this._onRenderSplitButtonContent(tag, buttonProps);
        }
        else if (this.props.menuProps) {
            assign(buttonProps, {
                'aria-expanded': !menuHidden,
                'aria-owns': !menuHidden ? this._labelId + '-menu' : null,
                'aria-haspopup': true,
            });
        }
        return this._onRenderContent(tag, buttonProps);
    };
    BaseButton.prototype.componentDidMount = function () {
        // For split buttons, touching anywhere in the button should drop the dropdown, which should contain the
        // primary action. This gives more hit target space for touch environments. We're setting the onpointerdown here,
        // because React does not support Pointer events yet.
        if (this._isSplitButton && this._splitButtonContainer.current) {
            if ('onpointerdown' in this._splitButtonContainer.current) {
                this._events.on(this._splitButtonContainer.current, 'pointerdown', this._onPointerDown, true);
            }
            if ('onpointerup' in this._splitButtonContainer.current && this.props.onPointerUp) {
                this._events.on(this._splitButtonContainer.current, 'pointerup', this.props.onPointerUp, true);
            }
        }
    };
    BaseButton.prototype.componentDidUpdate = function (prevProps, prevState) {
        // If Button's menu was closed, run onAfterMenuDismiss.
        if (this.props.onAfterMenuDismiss && !prevState.menuHidden && this.state.menuHidden) {
            this.props.onAfterMenuDismiss();
        }
    };
    BaseButton.prototype.componentWillUnmount = function () {
        this._async.dispose();
        this._events.dispose();
    };
    BaseButton.prototype.focus = function () {
        if (this._isSplitButton && this._splitButtonContainer.current) {
            this._splitButtonContainer.current.focus();
        }
        else if (this._buttonElement.current) {
            this._buttonElement.current.focus();
        }
    };
    BaseButton.prototype.dismissMenu = function () {
        this._dismissMenu();
    };
    BaseButton.prototype.openMenu = function (shouldFocusOnContainer, shouldFocusOnMount) {
        this._openMenu(shouldFocusOnContainer, shouldFocusOnMount);
    };
    BaseButton.prototype._onRenderContent = function (tag, buttonProps) {
        var _this = this;
        var props = this.props;
        var Tag = tag;
        var menuIconProps = props.menuIconProps, menuProps = props.menuProps, _a = props.onRenderIcon, onRenderIcon = _a === void 0 ? this._onRenderIcon : _a, _b = props.onRenderAriaDescription, onRenderAriaDescription = _b === void 0 ? this._onRenderAriaDescription : _b, _c = props.onRenderChildren, onRenderChildren = _c === void 0 ? this._onRenderChildren : _c, 
        // eslint-disable-next-line deprecation/deprecation
        _d = props.onRenderMenu, 
        // eslint-disable-next-line deprecation/deprecation
        onRenderMenu = _d === void 0 ? this._onRenderMenu : _d, _e = props.onRenderMenuIcon, onRenderMenuIcon = _e === void 0 ? this._onRenderMenuIcon : _e, disabled = props.disabled;
        var keytipProps = props.keytipProps;
        if (keytipProps && menuProps) {
            keytipProps = this._getMemoizedMenuButtonKeytipProps(keytipProps);
        }
        var Button = function (keytipAttributes) { return (createElement(Tag, __assign({}, buttonProps, keytipAttributes),
            createElement("span", { className: _this._classNames.flexContainer, "data-automationid": "splitbuttonprimary" },
                onRenderIcon(props, _this._onRenderIcon),
                _this._onRenderTextContents(),
                onRenderAriaDescription(props, _this._onRenderAriaDescription),
                onRenderChildren(props, _this._onRenderChildren),
                !_this._isSplitButton &&
                    (menuProps || menuIconProps || _this.props.onRenderMenuIcon) &&
                    onRenderMenuIcon(_this.props, _this._onRenderMenuIcon),
                menuProps &&
                    !menuProps.doNotLayer &&
                    _this._shouldRenderMenu() &&
                    onRenderMenu(menuProps, _this._onRenderMenu)))); };
        var Content = keytipProps ? (
        // If we're making a split button, we won't put the keytip here
        createElement(KeytipData, { keytipProps: !this._isSplitButton ? keytipProps : undefined, ariaDescribedBy: buttonProps['aria-describedby'], disabled: disabled }, function (keytipAttributes) { return Button(keytipAttributes); })) : (Button());
        if (menuProps && menuProps.doNotLayer) {
            return (createElement("span", { style: { display: 'inline-block' } },
                Content,
                this._shouldRenderMenu() && onRenderMenu(menuProps, this._onRenderMenu)));
        }
        return (createElement(Fragment, null,
            Content,
            createElement(FocusRects, null)));
    };
    /**
     * Method to help determine if the menu's component tree should
     * be rendered. It takes into account whether the menu is expanded,
     * whether it is a persisted menu and whether it has been shown to the user.
     */
    BaseButton.prototype._shouldRenderMenu = function () {
        var menuHidden = this.state.menuHidden;
        // eslint-disable-next-line deprecation/deprecation
        var _a = this.props, persistMenu = _a.persistMenu, renderPersistedMenuHiddenOnMount = _a.renderPersistedMenuHiddenOnMount;
        if (!menuHidden) {
            // Always should render a menu when it is expanded
            return true;
        }
        else if (persistMenu && (this._renderedVisibleMenu || renderPersistedMenuHiddenOnMount)) {
            // _renderedVisibleMenu ensures that the first rendering of
            // the menu happens on-screen, as edge's scrollbar calculations are off if done while hidden.
            return true;
        }
        return false;
    };
    BaseButton.prototype._hasText = function () {
        // _onRenderTextContents and _onRenderText do not perform the same checks. Below is parity with what _onRenderText
        // used to have before the refactor that introduced this function. _onRenderTextContents does not require props.
        // text to be undefined in order for props.children to be used as a fallback.
        // Purely a code maintainability/reuse issue, but logged as Issue #4979.
        return this.props.text !== null && (this.props.text !== undefined || typeof this.props.children === 'string');
    };
    BaseButton.prototype._onRenderSplitButtonContent = function (tag, buttonProps) {
        var _this = this;
        var _a = this.props, _b = _a.styles, styles = _b === void 0 ? {} : _b, disabled = _a.disabled, allowDisabledFocus = _a.allowDisabledFocus, checked = _a.checked, getSplitButtonClassNames = _a.getSplitButtonClassNames, primaryDisabled = _a.primaryDisabled, menuProps = _a.menuProps, toggle = _a.toggle, role = _a.role, primaryActionButtonProps = _a.primaryActionButtonProps;
        var keytipProps = this.props.keytipProps;
        var menuHidden = this.state.menuHidden;
        var classNames = getSplitButtonClassNames
            ? getSplitButtonClassNames(!!disabled, !menuHidden, !!checked, !!allowDisabledFocus)
            : styles && getClassNames$7(styles, !!disabled, !menuHidden, !!checked, !!primaryDisabled);
        assign(buttonProps, {
            onClick: undefined,
            onPointerDown: undefined,
            onPointerUp: undefined,
            tabIndex: -1,
            'data-is-focusable': false,
        });
        var ariaDescribedBy = buttonProps.ariaDescription;
        if (keytipProps && menuProps) {
            keytipProps = this._getMemoizedMenuButtonKeytipProps(keytipProps);
        }
        var containerProps = getNativeProps(buttonProps, [], ['disabled']);
        // Add additional props to apply on primary action button
        if (primaryActionButtonProps) {
            assign(buttonProps, primaryActionButtonProps);
        }
        var SplitButton = function (keytipAttributes) { return (createElement("div", __assign({}, containerProps, { "data-ktp-target": keytipAttributes ? keytipAttributes['data-ktp-target'] : undefined, role: role ? role : 'button', "aria-disabled": disabled, "aria-haspopup": true, "aria-expanded": !menuHidden, "aria-pressed": toggle ? !!checked : undefined, "aria-describedby": mergeAriaAttributeValues(ariaDescribedBy, keytipAttributes ? keytipAttributes['aria-describedby'] : undefined), className: classNames && classNames.splitButtonContainer, onKeyDown: _this._onSplitButtonContainerKeyDown, onTouchStart: _this._onTouchStart, ref: _this._splitButtonContainer, "data-is-focusable": true, onClick: !disabled && !primaryDisabled ? _this._onSplitButtonPrimaryClick : undefined, tabIndex: !disabled || allowDisabledFocus ? 0 : undefined, "aria-roledescription": buttonProps['aria-roledescription'], onFocusCapture: _this._onSplitContainerFocusCapture }),
            createElement("span", { style: { display: 'flex' } },
                _this._onRenderContent(tag, buttonProps),
                _this._onRenderSplitButtonMenuButton(classNames, keytipAttributes),
                _this._onRenderSplitButtonDivider(classNames)))); };
        return keytipProps ? (createElement(KeytipData, { keytipProps: keytipProps, disabled: disabled }, function (keytipAttributes) { return SplitButton(keytipAttributes); })) : (SplitButton());
    };
    BaseButton.prototype._onRenderSplitButtonDivider = function (classNames) {
        if (classNames && classNames.divider) {
            var onClick = function (ev) {
                ev.stopPropagation();
            };
            return createElement("span", { className: classNames.divider, "aria-hidden": true, onClick: onClick });
        }
        return null;
    };
    BaseButton.prototype._onRenderSplitButtonMenuButton = function (classNames, keytipAttributes) {
        var _a = this.props, allowDisabledFocus = _a.allowDisabledFocus, checked = _a.checked, disabled = _a.disabled, splitButtonMenuProps = _a.splitButtonMenuProps, splitButtonAriaLabel = _a.splitButtonAriaLabel;
        var menuHidden = this.state.menuHidden;
        var menuIconProps = this.props.menuIconProps;
        if (menuIconProps === undefined) {
            menuIconProps = {
                iconName: 'ChevronDown',
            };
        }
        var splitButtonProps = __assign(__assign({}, splitButtonMenuProps), { styles: classNames, checked: checked, disabled: disabled, allowDisabledFocus: allowDisabledFocus, onClick: this._onMenuClick, menuProps: undefined, iconProps: __assign(__assign({}, menuIconProps), { className: this._classNames.menuIcon }), ariaLabel: splitButtonAriaLabel, 'aria-haspopup': true, 'aria-expanded': !menuHidden, 'data-is-focusable': false });
        // Add data-ktp-execute-target to the split button if the keytip is defined
        return (createElement(BaseButton, __assign({}, splitButtonProps, { "data-ktp-execute-target": keytipAttributes ? keytipAttributes['data-ktp-execute-target'] : keytipAttributes, onMouseDown: this._onMouseDown, tabIndex: -1 })));
    };
    BaseButton.prototype._onPointerDown = function (ev) {
        var onPointerDown = this.props.onPointerDown;
        if (onPointerDown) {
            onPointerDown(ev);
        }
        if (ev.pointerType === 'touch') {
            this._handleTouchAndPointerEvent();
            ev.preventDefault();
            ev.stopImmediatePropagation();
        }
    };
    BaseButton.prototype._handleTouchAndPointerEvent = function () {
        var _this = this;
        // If we already have an existing timeeout from a previous touch and pointer event
        // cancel that timeout so we can set a new one.
        if (this._lastTouchTimeoutId !== undefined) {
            this._async.clearTimeout(this._lastTouchTimeoutId);
            this._lastTouchTimeoutId = undefined;
        }
        this._processingTouch = true;
        this._lastTouchTimeoutId = this._async.setTimeout(function () {
            _this._processingTouch = false;
            _this._lastTouchTimeoutId = undefined;
            // Touch and pointer events don't focus the button naturally,
            // so adding an imperative focus call to guarantee this behavior.
            _this.focus();
        }, TouchIdleDelay$1);
    };
    /**
     * Returns if the user hits a valid keyboard key to open the menu
     * @param ev - the keyboard event
     * @returns True if user clicks on custom trigger key if enabled or alt + down arrow if not. False otherwise.
     */
    BaseButton.prototype._isValidMenuOpenKey = function (ev) {
        if (this.props.menuTriggerKeyCode) {
            return ev.which === this.props.menuTriggerKeyCode;
        }
        else if (this.props.menuProps) {
            return ev.which === KeyCodes.down && (ev.altKey || ev.metaKey);
        }
        // Note: When enter is pressed, we will let the event continue to propagate
        // to trigger the onClick event on the button
        return false;
    };
    BaseButton.defaultProps = {
        baseClassName: 'ms-Button',
        styles: {},
        split: false,
    };
    return BaseButton;
}(Component));

var noOutline = {
    outline: 0,
};
var iconStyle = function (fontSize) {
    return {
        fontSize: fontSize,
        margin: '0 4px',
        height: '16px',
        lineHeight: '16px',
        textAlign: 'center',
        flexShrink: 0,
    };
};
/**
 * Gets the base button styles. Note: because it is a base class to be used with the `mergeRules`
 * helper, it should have values for all class names in the interface. This let `mergeRules` optimize
 * mixing class names together.
 */
var getStyles$7 = memoizeFunction(function (theme) {
    var _a, _b;
    var semanticColors = theme.semanticColors, effects = theme.effects, fonts = theme.fonts;
    var border = semanticColors.buttonBorder;
    var disabledBackground = semanticColors.disabledBackground;
    var disabledText = semanticColors.disabledText;
    var buttonHighContrastFocus = {
        left: -2,
        top: -2,
        bottom: -2,
        right: -2,
        outlineColor: 'ButtonText',
    };
    return {
        root: [
            getFocusStyle(theme, { inset: 1, highContrastStyle: buttonHighContrastFocus, borderColor: 'transparent' }),
            theme.fonts.medium,
            {
                boxSizing: 'border-box',
                border: '1px solid ' + border,
                userSelect: 'none',
                display: 'inline-block',
                textDecoration: 'none',
                textAlign: 'center',
                cursor: 'pointer',
                padding: '0 16px',
                borderRadius: effects.roundedCorner2,
                selectors: {
                    // IE11 workaround for preventing shift of child elements of a button when active.
                    ':active > *': {
                        position: 'relative',
                        left: 0,
                        top: 0,
                    },
                },
            },
        ],
        rootDisabled: [
            getFocusStyle(theme, { inset: 1, highContrastStyle: buttonHighContrastFocus, borderColor: 'transparent' }),
            {
                backgroundColor: disabledBackground,
                borderColor: disabledBackground,
                color: disabledText,
                cursor: 'default',
                pointerEvents: 'none',
                selectors: {
                    ':hover': noOutline,
                    ':focus': noOutline,
                },
            },
        ],
        iconDisabled: {
            color: disabledText,
            selectors: (_a = {},
                _a[HighContrastSelector] = {
                    color: 'GrayText',
                },
                _a),
        },
        menuIconDisabled: {
            color: disabledText,
            selectors: (_b = {},
                _b[HighContrastSelector] = {
                    color: 'GrayText',
                },
                _b),
        },
        flexContainer: {
            display: 'flex',
            height: '100%',
            flexWrap: 'nowrap',
            justifyContent: 'center',
            alignItems: 'center',
        },
        description: {
            display: 'block',
        },
        textContainer: {
            flexGrow: 1,
            display: 'block',
        },
        icon: iconStyle(fonts.mediumPlus.fontSize),
        menuIcon: iconStyle(fonts.small.fontSize),
        label: {
            margin: '0 4px',
            lineHeight: '100%',
            display: 'block',
        },
        screenReaderText: hiddenContentStyle,
    };
});

var getStyles$8 = memoizeFunction(function (theme, customStyles) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
    var effects = theme.effects, palette = theme.palette, semanticColors = theme.semanticColors;
    var buttonHighContrastFocus = {
        left: -2,
        top: -2,
        bottom: -2,
        right: -2,
        border: 'none',
    };
    var splitButtonDividerBaseStyles = {
        position: 'absolute',
        width: 1,
        right: 31,
        top: 8,
        bottom: 8,
    };
    var splitButtonStyles = {
        splitButtonContainer: [
            getFocusStyle(theme, { highContrastStyle: buttonHighContrastFocus, inset: 2 }),
            {
                display: 'inline-flex',
                selectors: {
                    '.ms-Button--default': {
                        borderTopRightRadius: '0',
                        borderBottomRightRadius: '0',
                        borderRight: 'none',
                    },
                    '.ms-Button--primary': {
                        borderTopRightRadius: '0',
                        borderBottomRightRadius: '0',
                        border: 'none',
                        selectors: (_a = {},
                            _a[HighContrastSelector] = {
                                color: 'WindowText',
                                backgroundColor: 'Window',
                                border: '1px solid WindowText',
                                borderRightWidth: '0',
                                MsHighContrastAdjust: 'none',
                            },
                            _a),
                    },
                    '.ms-Button--primary + .ms-Button': {
                        border: 'none',
                        selectors: (_b = {},
                            _b[HighContrastSelector] = {
                                border: '1px solid WindowText',
                                borderLeftWidth: '0',
                            },
                            _b),
                    },
                },
            },
        ],
        splitButtonContainerHovered: {
            selectors: {
                '.ms-Button--primary': {
                    selectors: (_c = {},
                        _c[HighContrastSelector] = {
                            color: 'Window',
                            backgroundColor: 'Highlight',
                        },
                        _c),
                },
                '.ms-Button.is-disabled': {
                    color: semanticColors.buttonTextDisabled,
                    selectors: (_d = {},
                        _d[HighContrastSelector] = {
                            color: 'GrayText',
                            borderColor: 'GrayText',
                            backgroundColor: 'Window',
                        },
                        _d),
                },
            },
        },
        splitButtonContainerChecked: {
            selectors: {
                '.ms-Button--primary': {
                    selectors: (_e = {},
                        _e[HighContrastSelector] = {
                            color: 'Window',
                            backgroundColor: 'WindowText',
                            MsHighContrastAdjust: 'none',
                        },
                        _e),
                },
            },
        },
        splitButtonContainerCheckedHovered: {
            selectors: {
                '.ms-Button--primary': {
                    selectors: (_f = {},
                        _f[HighContrastSelector] = {
                            color: 'Window',
                            backgroundColor: 'WindowText',
                            MsHighContrastAdjust: 'none',
                        },
                        _f),
                },
            },
        },
        splitButtonContainerFocused: {
            outline: 'none!important',
        },
        splitButtonMenuButton: {
            padding: 6,
            height: 'auto',
            boxSizing: 'border-box',
            borderRadius: 0,
            borderTopRightRadius: effects.roundedCorner2,
            borderBottomRightRadius: effects.roundedCorner2,
            border: "1px solid " + palette.neutralSecondaryAlt,
            borderLeft: 'none',
            outline: 'transparent',
            userSelect: 'none',
            display: 'inline-block',
            textDecoration: 'none',
            textAlign: 'center',
            cursor: 'pointer',
            verticalAlign: 'top',
            width: 32,
            marginLeft: -1,
            marginTop: 0,
            marginRight: 0,
            marginBottom: 0,
        },
        splitButtonDivider: __assign(__assign({}, splitButtonDividerBaseStyles), { selectors: (_g = {},
                _g[HighContrastSelector] = {
                    backgroundColor: 'WindowText',
                },
                _g) }),
        splitButtonDividerDisabled: __assign(__assign({}, splitButtonDividerBaseStyles), { selectors: (_h = {},
                _h[HighContrastSelector] = {
                    backgroundColor: 'GrayText',
                },
                _h) }),
        splitButtonMenuButtonDisabled: {
            pointerEvents: 'none',
            border: 'none',
            selectors: (_j = {
                    ':hover': {
                        cursor: 'default',
                    },
                    '.ms-Button--primary': {
                        selectors: (_k = {},
                            _k[HighContrastSelector] = {
                                color: 'GrayText',
                                borderColor: 'GrayText',
                                backgroundColor: 'Window',
                            },
                            _k),
                    },
                    '.ms-Button-menuIcon': {
                        selectors: (_l = {},
                            _l[HighContrastSelector] = {
                                color: 'GrayText',
                            },
                            _l),
                    }
                },
                _j[HighContrastSelector] = {
                    color: 'GrayText',
                    border: '1px solid GrayText',
                    backgroundColor: 'Window',
                },
                _j),
        },
        splitButtonFlexContainer: {
            display: 'flex',
            height: '100%',
            flexWrap: 'nowrap',
            justifyContent: 'center',
            alignItems: 'center',
        },
        splitButtonContainerDisabled: {
            outline: 'none',
            border: 'none',
            selectors: __assign((_m = {}, _m[HighContrastSelector] = {
                color: 'GrayText',
                borderColor: 'GrayText',
                backgroundColor: 'Window',
            }, _m), getEdgeChromiumNoHighContrastAdjustSelector()),
        },
    };
    return concatStyleSets(splitButtonStyles, customStyles);
});

var splitButtonDividerBaseStyles = function () {
    return {
        position: 'absolute',
        width: 1,
        right: 31,
        top: 8,
        bottom: 8,
    };
};
function standardStyles(theme) {
    var _a, _b, _c, _d, _e;
    var s = theme.semanticColors, p = theme.palette;
    var buttonBackground = s.buttonBackground;
    var buttonBackgroundPressed = s.buttonBackgroundPressed;
    var buttonBackgroundHovered = s.buttonBackgroundHovered;
    var buttonText = s.buttonText;
    var buttonTextHovered = s.buttonTextHovered;
    var buttonTextChecked = s.buttonTextChecked;
    var buttonTextCheckedHovered = s.buttonTextCheckedHovered;
    return {
        root: {
            backgroundColor: buttonBackground,
            color: buttonText,
        },
        rootHovered: {
            backgroundColor: buttonBackgroundHovered,
            color: buttonTextHovered,
            selectors: (_a = {},
                _a[HighContrastSelector] = {
                    borderColor: 'Highlight',
                    color: 'Highlight',
                },
                _a),
        },
        rootPressed: {
            backgroundColor: buttonBackgroundPressed,
            color: buttonTextChecked,
        },
        rootExpanded: {
            backgroundColor: buttonBackgroundPressed,
            color: buttonTextChecked,
        },
        rootChecked: {
            backgroundColor: buttonBackgroundPressed,
            color: buttonTextChecked,
        },
        rootCheckedHovered: {
            backgroundColor: buttonBackgroundPressed,
            color: buttonTextCheckedHovered,
        },
        rootDisabled: {
            selectors: (_b = {},
                _b[HighContrastSelector] = {
                    color: 'GrayText',
                    borderColor: 'GrayText',
                    backgroundColor: 'Window',
                },
                _b),
        },
        // Split button styles
        splitButtonContainer: {
            selectors: (_c = {},
                _c[HighContrastSelector] = {
                    border: 'none',
                },
                _c),
        },
        splitButtonMenuButton: {
            color: p.white,
            backgroundColor: 'transparent',
            selectors: {
                ':hover': {
                    backgroundColor: p.neutralLight,
                    selectors: (_d = {},
                        _d[HighContrastSelector] = {
                            color: 'Highlight',
                        },
                        _d),
                },
            },
        },
        splitButtonMenuButtonDisabled: {
            backgroundColor: s.buttonBackgroundDisabled,
            selectors: {
                ':hover': {
                    backgroundColor: s.buttonBackgroundDisabled,
                },
            },
        },
        splitButtonDivider: __assign(__assign({}, splitButtonDividerBaseStyles()), { backgroundColor: p.neutralTertiaryAlt, selectors: (_e = {},
                _e[HighContrastSelector] = {
                    backgroundColor: 'WindowText',
                },
                _e) }),
        splitButtonDividerDisabled: {
            backgroundColor: theme.palette.neutralTertiaryAlt,
        },
        splitButtonMenuButtonChecked: {
            backgroundColor: p.neutralQuaternaryAlt,
            selectors: {
                ':hover': {
                    backgroundColor: p.neutralQuaternaryAlt,
                },
            },
        },
        splitButtonMenuButtonExpanded: {
            backgroundColor: p.neutralQuaternaryAlt,
            selectors: {
                ':hover': {
                    backgroundColor: p.neutralQuaternaryAlt,
                },
            },
        },
        splitButtonMenuIcon: {
            color: s.buttonText,
        },
        splitButtonMenuIconDisabled: {
            color: s.buttonTextDisabled,
        },
    };
}
function primaryStyles(theme) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j;
    var p = theme.palette, s = theme.semanticColors;
    return {
        root: {
            backgroundColor: s.primaryButtonBackground,
            border: "1px solid " + s.primaryButtonBackground,
            color: s.primaryButtonText,
            selectors: (_a = {},
                _a[HighContrastSelector] = {
                    color: 'Window',
                    backgroundColor: 'WindowText',
                    borderColor: 'WindowText',
                    MsHighContrastAdjust: 'none',
                },
                _a["." + IsFocusVisibleClassName + " &:focus"] = {
                    selectors: {
                        ':after': {
                            border: "none",
                            outlineColor: p.white,
                        },
                    },
                },
                _a),
        },
        rootHovered: {
            backgroundColor: s.primaryButtonBackgroundHovered,
            border: "1px solid " + s.primaryButtonBackgroundHovered,
            color: s.primaryButtonTextHovered,
            selectors: (_b = {},
                _b[HighContrastSelector] = {
                    color: 'Window',
                    backgroundColor: 'Highlight',
                    borderColor: 'Highlight',
                },
                _b),
        },
        rootPressed: {
            backgroundColor: s.primaryButtonBackgroundPressed,
            border: "1px solid " + s.primaryButtonBackgroundPressed,
            color: s.primaryButtonTextPressed,
            selectors: (_c = {},
                _c[HighContrastSelector] = {
                    color: 'Window',
                    backgroundColor: 'WindowText',
                    borderColor: 'WindowText',
                    MsHighContrastAdjust: 'none',
                },
                _c),
        },
        rootExpanded: {
            backgroundColor: s.primaryButtonBackgroundPressed,
            color: s.primaryButtonTextPressed,
        },
        rootChecked: {
            backgroundColor: s.primaryButtonBackgroundPressed,
            color: s.primaryButtonTextPressed,
        },
        rootCheckedHovered: {
            backgroundColor: s.primaryButtonBackgroundPressed,
            color: s.primaryButtonTextPressed,
        },
        rootDisabled: {
            selectors: (_d = {},
                _d[HighContrastSelector] = {
                    color: 'GrayText',
                    borderColor: 'GrayText',
                    backgroundColor: 'Window',
                },
                _d),
        },
        // Split button styles
        splitButtonContainer: {
            selectors: (_e = {},
                _e[HighContrastSelector] = {
                    border: 'none',
                },
                _e),
        },
        splitButtonDivider: __assign(__assign({}, splitButtonDividerBaseStyles()), { backgroundColor: p.white, selectors: (_f = {},
                _f[HighContrastSelector] = {
                    backgroundColor: 'Window',
                },
                _f) }),
        splitButtonMenuButton: {
            backgroundColor: s.primaryButtonBackground,
            color: s.primaryButtonText,
            selectors: (_g = {},
                _g[HighContrastSelector] = {
                    backgroundColor: 'WindowText',
                },
                _g[':hover'] = {
                    backgroundColor: s.primaryButtonBackgroundHovered,
                    selectors: (_h = {},
                        _h[HighContrastSelector] = {
                            color: 'Highlight',
                        },
                        _h),
                },
                _g),
        },
        splitButtonMenuButtonDisabled: {
            backgroundColor: s.primaryButtonBackgroundDisabled,
            selectors: {
                ':hover': {
                    backgroundColor: s.primaryButtonBackgroundDisabled,
                },
            },
        },
        splitButtonMenuButtonChecked: {
            backgroundColor: s.primaryButtonBackgroundPressed,
            selectors: {
                ':hover': {
                    backgroundColor: s.primaryButtonBackgroundPressed,
                },
            },
        },
        splitButtonMenuButtonExpanded: {
            backgroundColor: s.primaryButtonBackgroundPressed,
            selectors: {
                ':hover': {
                    backgroundColor: s.primaryButtonBackgroundPressed,
                },
            },
        },
        splitButtonMenuIcon: {
            color: s.primaryButtonText,
        },
        splitButtonMenuIconDisabled: {
            color: p.neutralTertiary,
            selectors: (_j = {},
                _j[HighContrastSelector] = {
                    color: 'GrayText',
                },
                _j),
        },
    };
}

var DEFAULT_BUTTON_HEIGHT = '32px';
var DEFAULT_BUTTON_MIN_WIDTH = '80px';
var getStyles$9 = memoizeFunction(function (theme, customStyles, primary) {
    var baseButtonStyles = getStyles$7(theme);
    var splitButtonStyles = getStyles$8(theme);
    var defaultButtonStyles = {
        root: {
            minWidth: DEFAULT_BUTTON_MIN_WIDTH,
            height: DEFAULT_BUTTON_HEIGHT,
        },
        label: {
            fontWeight: FontWeights.semibold,
        },
    };
    return concatStyleSets(baseButtonStyles, defaultButtonStyles, primary ? primaryStyles(theme) : standardStyles(theme), splitButtonStyles, customStyles);
});

/**
 * {@docCategory Button}
 */
var DefaultButton = /** @class */ (function (_super) {
    __extends(DefaultButton, _super);
    function DefaultButton() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DefaultButton.prototype.render = function () {
        var _a = this.props, _b = _a.primary, primary = _b === void 0 ? false : _b, styles = _a.styles, theme = _a.theme;
        return (createElement(BaseButton, __assign({}, this.props, { variantClassName: primary ? 'ms-Button--primary' : 'ms-Button--default', styles: getStyles$9(theme, styles, primary), onRenderDescription: nullRender })));
    };
    DefaultButton = __decorate([
        customizable('DefaultButton', ['theme', 'styles'], true)
    ], DefaultButton);
    return DefaultButton;
}(Component));

var DEFAULT_BUTTON_HEIGHT$1 = '40px';
var DEFAULT_PADDING = '0 4px';
var getStyles$a = memoizeFunction(function (theme, customStyles) {
    var _a;
    var baseButtonStyles = getStyles$7(theme);
    var actionButtonStyles = {
        root: {
            padding: DEFAULT_PADDING,
            height: DEFAULT_BUTTON_HEIGHT$1,
            color: theme.palette.neutralPrimary,
            backgroundColor: 'transparent',
            border: '1px solid transparent',
        },
        rootHovered: {
            color: theme.palette.themePrimary,
            selectors: (_a = {},
                _a[HighContrastSelector] = {
                    borderColor: 'Highlight',
                    color: 'Highlight',
                },
                _a),
        },
        iconHovered: {
            color: theme.palette.themePrimary,
        },
        rootPressed: {
            color: theme.palette.black,
        },
        rootExpanded: {
            color: theme.palette.themePrimary,
        },
        iconPressed: {
            color: theme.palette.themeDarker,
        },
        rootDisabled: {
            color: theme.palette.neutralTertiary,
            backgroundColor: 'transparent',
            borderColor: 'transparent',
        },
        rootChecked: {
            color: theme.palette.black,
        },
        iconChecked: {
            color: theme.palette.themeDarker,
        },
        flexContainer: {
            justifyContent: 'flex-start',
        },
        icon: {
            color: theme.palette.themeDarkAlt,
        },
        iconDisabled: {
            color: 'inherit',
        },
        menuIcon: {
            color: theme.palette.neutralSecondary,
        },
        textContainer: {
            flexGrow: 0,
        },
    };
    return concatStyleSets(baseButtonStyles, actionButtonStyles, customStyles);
});

/**
 * {@docCategory Button}
 */
var ActionButton = /** @class */ (function (_super) {
    __extends(ActionButton, _super);
    function ActionButton() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ActionButton.prototype.render = function () {
        var _a = this.props, styles = _a.styles, theme = _a.theme;
        return (createElement(BaseButton, __assign({}, this.props, { variantClassName: "ms-Button--action ms-Button--command", styles: getStyles$a(theme, styles), onRenderDescription: nullRender })));
    };
    ActionButton = __decorate([
        customizable('ActionButton', ['theme', 'styles'], true)
    ], ActionButton);
    return ActionButton;
}(Component));

var getStyles$b = memoizeFunction(function (theme, customStyles) {
    var _a;
    var baseButtonStyles = getStyles$7(theme);
    var splitButtonStyles = getStyles$8(theme);
    var palette = theme.palette, semanticColors = theme.semanticColors;
    var iconButtonStyles = {
        root: {
            padding: '0 4px',
            width: '32px',
            height: '32px',
            backgroundColor: 'transparent',
            border: 'none',
            color: semanticColors.link,
        },
        rootHovered: {
            color: palette.themeDarkAlt,
            backgroundColor: palette.neutralLighter,
            selectors: (_a = {},
                _a[HighContrastSelector] = {
                    borderColor: 'Highlight',
                    color: 'Highlight',
                },
                _a),
        },
        rootHasMenu: {
            width: 'auto',
        },
        rootPressed: {
            color: palette.themeDark,
            backgroundColor: palette.neutralLight,
        },
        rootExpanded: {
            color: palette.themeDark,
            backgroundColor: palette.neutralLight,
        },
        rootChecked: {
            color: palette.themeDark,
            backgroundColor: palette.neutralLight,
        },
        rootCheckedHovered: {
            color: palette.themeDark,
            backgroundColor: palette.neutralQuaternaryAlt,
        },
        rootDisabled: {
            color: palette.neutralTertiaryAlt,
        },
    };
    return concatStyleSets(baseButtonStyles, iconButtonStyles, splitButtonStyles, customStyles);
});

/**
 * {@docCategory Button}
 */
var IconButton = /** @class */ (function (_super) {
    __extends(IconButton, _super);
    function IconButton() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    IconButton.prototype.render = function () {
        var _a = this.props, styles = _a.styles, theme = _a.theme;
        return (createElement(BaseButton, __assign({}, this.props, { variantClassName: "ms-Button--icon", styles: getStyles$b(theme, styles), onRenderText: nullRender, onRenderDescription: nullRender })));
    };
    IconButton = __decorate([
        customizable('IconButton', ['theme', 'styles'], true)
    ], IconButton);
    return IconButton;
}(Component));

/**
 * {@docCategory Button}
 */
var PrimaryButton = /** @class */ (function (_super) {
    __extends(PrimaryButton, _super);
    function PrimaryButton() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PrimaryButton.prototype.render = function () {
        return createElement(DefaultButton, __assign({}, this.props, { primary: true, onRenderDescription: nullRender }));
    };
    PrimaryButton = __decorate([
        customizable('PrimaryButton', ['theme', 'styles'], true)
    ], PrimaryButton);
    return PrimaryButton;
}(Component));

var WizardFooterStyles = function WizardFooterStyles() {
  return mergeStyleSets$1({
    frame: {
      display: "inline-flex",
      flexDirection: "row-reverse",
      paddingTop: "10px",
      paddingBottom: "10px"
    },
    next: {
      height: "44px",
      padding: "12px",
      fontSize: "18px",
      lineHeight: "24px",
      fontWeight: "400",
      marginLeft: "10px"
    },
    back: {
      height: "44px",
      padding: "12px",
      fontSize: "18px",
      lineHeight: "24px",
      fontWeight: "400"
    }
  });
};

var WizardFooter = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(WizardFooter, _React$PureComponent);

  var _super = _createSuper(WizardFooter);

  function WizardFooter() {
    _classCallCheck(this, WizardFooter);

    return _super.apply(this, arguments);
  }

  _createClass(WizardFooter, [{
    key: "render",
    value: function render() {
      var styles = WizardFooterStyles();
      return React__default.createElement("div", {
        className: styles.frame
      }, React__default.createElement(PrimaryButton, {
        className: styles.next,
        text: localization.Footer.next,
        onClick: this.props.onNext
      }), !!this.props.onPrevious && React__default.createElement(DefaultButton, {
        className: styles.back,
        text: localization.Footer.back,
        onClick: this.props.onPrevious
      }));
    }
  }]);

  return WizardFooter;
}(React__default.PureComponent);

var FeatureTabStyles = function FeatureTabStyles() {
  var theme = getTheme$1();
  return mergeStyleSets$1({
    itemCell: {
      display: "flex",
      flexDirection: "row",
      padding: "20px 0",
      width: "100%",
      cursor: "pointer",
      boxSizing: "border-box",
      borderBottom: "1px solid",
      borderBottomColor: theme.semanticColors.bodyDivider,
      selectors: {
        "&:hover": {
          background: theme.semanticColors.listItemBackgroundHovered
        }
      }
    },
    iconClass: {
      fontSize: FontSizes$1.large,
      color: theme.semanticColors.accentButtonBackground
    },
    itemsList: {
      overflowY: "auto"
    },
    frame: {
      height: "100%"
    },
    main: {
      height: "100%",
      maxWidth: "700px",
      flex: 1
    },
    header: {
      color: theme.semanticColors.bodyText,
      fontWeight: FontWeights$1.semibold,
      margin: "26px 0"
    },
    textBody: {
      paddingTop: "12px",
      fontWeight: FontWeights$1.semilight,
      color: theme.semanticColors.bodyText
    },
    tableHeader: {
      display: "flex",
      flexDirection: "row",
      justifyContent: "space-between",
      paddingBottom: "15px",
      color: theme.semanticColors.bodyText,
      borderBottom: "1px solid",
      borderColor: theme.semanticColors.bodyDivider
    },
    itemTitle: {
      margin: 0,
      color: theme.semanticColors.listText
    },
    valueCount: {
      paddingTop: "15px",
      color: theme.semanticColors.bodyText
    },
    iconWrapper: {
      paddingTop: "4px",
      paddingLeft: "5px",
      width: "30px"
    },
    featureDescriptionSection: {
      flex: 1,
      paddingRight: "20px",
      minHeight: "75px"
    },
    binSection: {
      width: "130px"
    },
    expandButton: {
      paddingLeft: 0,
      selectors: {
        "& i": {
          marginLeft: 0
        }
      }
    },
    category: {
      textOverflow: "ellipsis",
      whiteSpace: "nowrap",
      overflow: "hidden",
      color: theme.semanticColors.bodyText
    },
    subgroupHeader: {
      width: "130px"
    }
  });
};

var FeatureTabSubGroup = /*#__PURE__*/function (_React$Component) {
  _inherits(FeatureTabSubGroup, _React$Component);

  var _super = _createSuper(FeatureTabSubGroup);

  function FeatureTabSubGroup(props) {
    var _this;

    _classCallCheck(this, FeatureTabSubGroup);

    _this = _super.call(this, props);

    _this.toggle = function () {
      _this.setState(function (prev) {
        return {
          expanded: !prev.expanded
        };
      });
    };

    _this.state = {
      expanded: false
    };
    return _this;
  }

  _createClass(FeatureTabSubGroup, [{
    key: "render",
    value: function render() {
      var styles = FeatureTabStyles();
      var item = this.props.item;
      var labelArray = this.state.expanded ? item.labelArray : item.labelArray.slice(0, 7);
      return !!item.labelArray && React__default.createElement("div", null, labelArray.map(function (category, index) {
        return React__default.createElement(Text$1, {
          key: index,
          className: styles.category,
          block: true
        }, category);
      }), item.labelArray.length > 7 && React__default.createElement(ActionButton$1, {
        className: styles.expandButton,
        iconProps: {
          iconName: this.state.expanded ? "ChevronUpMed" : "ChevronDownMed"
        },
        onClick: this.toggle
      }, this.state.expanded ? localization.Feature.hideCategories : localization.Feature.showCategories));
    }
  }]);

  return FeatureTabSubGroup;
}(React__default.Component);

var FeatureTab = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(FeatureTab, _React$PureComponent);

  var _super = _createSuper(FeatureTab);

  function FeatureTab(props) {
    var _this;

    _classCallCheck(this, FeatureTab);

    _this = _super.call(this, props);

    _this.getKey = function (item) {
      return _this.props.featureBins.indexOf(item).toString();
    };

    _this.hideModal = function () {
      _this.setState({
        editingFeatureIndex: undefined
      });
    };

    _this.onBinSave = function (bin) {
      _this.setState({
        editingFeatureIndex: undefined
      });

      _this.props.saveBin(bin);
    };

    _this.editBins = function (index) {
      _this.setState({
        editingFeatureIndex: index
      });
    };

    _this.renderFeatureNameCell = function (item, index) {
      var _this$props$dashboard;

      if (index === undefined || !item) {
        return undefined;
      }

      var styles = FeatureTabStyles();
      return React__default.createElement(React__default.Fragment, null, React__default.createElement(Text$1, {
        className: styles.itemTitle,
        block: true
      }, _this.props.dashboardContext.modelMetadata.featureNames[index]), item.rangeType === RangeTypes.categorical && React__default.createElement(Text$1, {
        variant: "mediumPlus",
        className: styles.valueCount,
        block: true
      }, localization.formatString(localization.Feature.summaryCategoricalCount, item.array.length)), item.rangeType !== RangeTypes.categorical && React__default.createElement(Text$1, {
        variant: "mediumPlus",
        className: styles.valueCount,
        block: true
      }, localization.formatString(localization.Feature.summaryNumericCount, _this.props.dashboardContext.modelMetadata.featureRanges[index].min, _this.props.dashboardContext.modelMetadata.featureRanges[index].max, item.labelArray.length)), !((_this$props$dashboard = _this.props.dashboardContext.modelMetadata.featureIsCategorical) === null || _this$props$dashboard === void 0 ? void 0 : _this$props$dashboard[index]) && React__default.createElement(ActionButton$1, {
        className: styles.expandButton,
        iconProps: {
          iconName: "Edit"
        },
        onClick: _this.editBins.bind(_assertThisInitialized(_this), index)
      }, localization.Feature.editBinning));
    };

    _this.renderSubGroupCell = function (item) {
      if (!item) {
        return undefined;
      }

      return React__default.createElement(FeatureTabSubGroup, {
        item: item
      });
    };

    _this.selection = new Selection({
      onSelectionChanged: function onSelectionChanged() {
        var select = _this.selection.getSelectedIndices()[0];

        if (select !== undefined && select !== _this.props.selectedFeatureIndex) {
          _this.props.selectedFeatureChange(select);
        }
      }
    });
    _this.state = {
      expandedBins: new Set(),
      editingFeatureIndex: undefined
    };
    _this.columns = [{
      key: "feature",
      name: localization.Intro.features,
      minWidth: 75,
      onRender: _this.renderFeatureNameCell
    }, {
      key: "subgroup",
      name: localization.Feature.subgroups,
      minWidth: 130,
      onRender: _this.renderSubGroupCell
    }];
    return _this;
  }

  _createClass(FeatureTab, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this2 = this;

      setImmediate(function () {
        _this2.selection.setIndexSelected(_this2.props.selectedFeatureIndex, true, false);
      });
    }
  }, {
    key: "render",
    value: function render() {
      var styles = FeatureTabStyles();
      return React__default.createElement(Stack$1, {
        horizontal: true,
        horizontalAlign: "space-between",
        className: styles.frame
      }, React__default.createElement(Modal, {
        isOpen: this.state.editingFeatureIndex !== undefined,
        isBlocking: false,
        onDismiss: this.hideModal
      }, this.state.editingFeatureIndex !== undefined && React__default.createElement(BinDialog$i, {
        range: this.props.dashboardContext.modelMetadata.featureRanges[this.state.editingFeatureIndex],
        bins: this.props.featureBins[this.state.editingFeatureIndex],
        dataset: this.props.dashboardContext.dataset || [],
        index: this.state.editingFeatureIndex,
        onSave: this.onBinSave,
        onCancel: this.hideModal
      })), React__default.createElement(Stack$1, {
        className: styles.main
      }, React__default.createElement(Text$1, {
        variant: "mediumPlus",
        className: styles.header,
        block: true
      }, localization.Feature.header), React__default.createElement(Text$1, {
        className: styles.textBody,
        block: true
      }, localization.Feature.body), React__default.createElement(DetailsList, {
        items: this.props.featureBins,
        columns: this.columns,
        selectionMode: SelectionMode.single,
        selection: this.selection,
        selectionPreservedOnEmptyClick: true,
        getKey: this.getKey,
        setKey: "set"
      }), React__default.createElement(WizardFooter, {
        onNext: this.props.onNext
      })), React__default.createElement(DataSpecificationBlade, {
        numberRows: this.props.dashboardContext.trueY.length,
        featureNames: this.props.dashboardContext.modelMetadata.featureNames
      }));
    }
  }]);

  return FeatureTab;
}(React__default.PureComponent);

var assign$1 = __assign;

/**
 * This function is required for any module that uses slots.
 *
 * This function is a slot resolver that automatically evaluates slot functions to generate React elements.
 * A byproduct of this resolver is that it removes slots from the React hierarchy by bypassing React.createElement.
 *
 * To use this function on a per-file basis, use the jsx directive targeting withSlots.
 * This directive must be the FIRST LINE in the file to work correctly.
 * Usage of this pragma also requires withSlots import statement.
 *
 * See React.createElement
 */
// Can't use typeof on React.createElement since it's overloaded. Approximate createElement's signature for now
// and widen as needed.
function withSlots(type, props) {
    var children = [];
    for (var _i = 2; _i < arguments.length; _i++) {
        children[_i - 2] = arguments[_i];
    }
    var slotType = type;
    if (slotType.isSlot) {
        // TODO: There is something weird going on here with children embedded in props vs. rest args.
        // Comment out these lines to see. Make sure this function is doing the right things.
        var numChildren = Children.count(children);
        if (numChildren === 0) {
            return slotType(props);
        }
        // Since we are bypassing createElement, use React.Children.toArray to make sure children are
        // properly assigned keys.
        // TODO: should this be mutating? does React mutate children subprop with createElement?
        // TODO: will toArray clobber existing keys?
        // TODO: React generates warnings because it doesn't detect hidden member _store that is set in createElement.
        //        Even children passed to createElement without keys don't generate this warning.
        //        Is there a better way to prevent slots from appearing in hierarchy? toArray doesn't address root issue.
        children = Children.toArray(children);
        return slotType(__assign(__assign({}, props), { children: children }));
    }
    else {
        // TODO: Are there some cases where children should NOT be spread? Also, spreading reraises perf question.
        //        Children had to be spread to avoid breaking KeytipData in Toggle.view:
        //        react-dom.development.js:18931 Uncaught TypeError: children is not a function
        //        Without spread, function child is a child array of one element
        // TODO: is there a reason this can't be:
        // return React.createElement.apply(this, arguments);
        return createElement.apply(React, __spreadArrays([type, props], children));
    }
}
/**
 * This function creates factories that render ouput depending on the user ISlotProp props passed in.
 * @param DefaultComponent - Base component to render when not overridden by user props.
 * @param options - Factory options, including defaultProp value for shorthand prop mapping.
 * @returns ISlotFactory function used for rendering slots.
 */
function createFactory(DefaultComponent, options) {
    if (options === void 0) { options = {}; }
    var _a = options.defaultProp, defaultProp = _a === void 0 ? 'children' : _a;
    var result = function (componentProps, userProps, userSlotOptions, defaultStyles, theme) {
        // If they passed in raw JSX, just return that.
        if (isValidElement(userProps)) {
            return userProps;
        }
        var flattenedUserProps = _translateShorthand(defaultProp, userProps);
        var finalProps = _constructFinalProps(defaultStyles, theme, componentProps, flattenedUserProps);
        if (userSlotOptions) {
            if (userSlotOptions.component) {
                // TODO: Remove cast if possible. This cast is needed because TS errors on the intrinsic portion of ReactType.
                // return <userSlotOptions.component {...finalProps} />;
                var UserComponent = userSlotOptions.component;
                return createElement(UserComponent, __assign({}, finalProps));
            }
            if (userSlotOptions.render) {
                return userSlotOptions.render(finalProps, DefaultComponent);
            }
        }
        return createElement(DefaultComponent, __assign({}, finalProps));
    };
    return result;
}
/**
 * Default factory for components without explicit factories.
 */
var defaultFactory = memoizeFunction(function (type) { return createFactory(type); });
/**
 * This function generates slots that can be used in JSX given a definition of slots and their corresponding types.
 * @param userProps - Props as pass to component.
 * @param slots - Slot definition object defining the default slot component for each slot.
 * @returns A set of created slots that components can render in JSX.
 */
function getSlots(userProps, slots) {
    var result = {};
    // userProps already has default props mixed in by createComponent. Recast here to gain typing for this function.
    var mixedProps = userProps;
    var _loop_1 = function (name_1) {
        if (slots.hasOwnProperty(name_1)) {
            // This closure method requires the use of withSlots to prevent unnecessary rerenders. This is because React
            // detects each closure as a different component (since it is a new instance) from the previous one and then
            // forces a rerender of the entire slot subtree. For now, the only way to avoid this is to use withSlots, which
            // bypasses the call to React.createElement.
            var slot = function (componentProps) {
                var args = [];
                for (var _i = 1; _i < arguments.length; _i++) {
                    args[_i - 1] = arguments[_i];
                }
                if (args.length > 0) {
                    // If React.createElement is being incorrectly used with slots, there will be additional arguments.
                    // We can detect these additional arguments and error on their presence.
                    throw new Error('Any module using getSlots must use withSlots. Please see withSlots javadoc for more info.');
                }
                // TODO: having TS infer types here seems to cause infinite loop.
                //   use explicit types or casting to preserve typing if possible.
                // TODO: this should be a lookup on TProps property instead of being TProps directly, which is probably
                //   causing the infinite loop
                return _renderSlot(slots[name_1], 
                // TODO: this cast to any is hiding a relationship issue between the first two args
                componentProps, mixedProps[name_1], mixedProps.slots && mixedProps.slots[name_1], 
                // _defaultStyles should always be present, but a check for existence is added to make view tests
                // easier to use.
                mixedProps._defaultStyles && mixedProps._defaultStyles[name_1], mixedProps.theme);
            };
            slot.isSlot = true;
            result[name_1] = slot;
        }
    };
    for (var name_1 in slots) {
        _loop_1(name_1);
    }
    return result;
}
/**
 * Helper function that translates shorthand as needed.
 * @param defaultProp
 * @param slotProps
 */
function _translateShorthand(defaultProp, slotProps) {
    var _a;
    var transformedProps;
    if (typeof slotProps === 'string' || typeof slotProps === 'number' || typeof slotProps === 'boolean') {
        transformedProps = (_a = {},
            _a[defaultProp] = slotProps,
            _a);
    }
    else {
        transformedProps = slotProps;
    }
    return transformedProps;
}
/**
 * Helper function that constructs final styles and props given a series of props ordered by increasing priority.
 */
function _constructFinalProps(defaultStyles, theme) {
    var allProps = [];
    for (var _i = 2; _i < arguments.length; _i++) {
        allProps[_i - 2] = arguments[_i];
    }
    var finalProps = {};
    var classNames = [];
    for (var _a = 0, allProps_1 = allProps; _a < allProps_1.length; _a++) {
        var props = allProps_1[_a];
        classNames.push(props && props.className);
        assign$1(finalProps, props);
    }
    finalProps.className = mergeCss([defaultStyles, classNames], { rtl: getRTL$1(theme) });
    return finalProps;
}
/**
 * Render a slot given component and user props. Uses component factory if available, otherwise falls back
 * to default factory.
 * @param ComponentType Factory component type.
 * @param componentProps The properties passed into slot from within the component.
 * @param userProps The user properties passed in from outside of the component.
 */
function _renderSlot(ComponentType, componentProps, userProps, slotOptions, defaultStyles, theme) {
    if (ComponentType.create !== undefined) {
        return ComponentType.create(componentProps, userProps, slotOptions, defaultStyles);
    }
    else {
        // TODO: need to resolve typing / generic issues passing through memoizeFunction. for now, cast to 'unknown'
        return defaultFactory(ComponentType)(componentProps, userProps, slotOptions, defaultStyles, theme);
    }
}

/**
 * Assembles a higher order component based on the following: styles, theme, view, and state.
 * Imposes a separation of concern and centralizes styling processing to increase ease of use and robustness
 * in how components use and apply styling and theming.
 *
 * Automatically merges and applies themes and styles with theme / styleprops having the highest priority.
 * State component, if provided, is passed in props for processing. Props from state / user are automatically processed
 * and styled before finally being passed to view.
 *
 * State components should contain all stateful behavior and should not generate any JSX, but rather simply call
 * the view prop.
 *
 * Views should simply be stateless pure functions that receive all props needed for rendering their output.
 *
 * State component is optional. If state is not provided, created component is essentially a functional
 * stateless component.
 *
 * @param options - component Component options. See IComponentOptions for more detail.
 */
function createComponent(view, options) {
    if (options === void 0) { options = {}; }
    var _a = options.factoryOptions, factoryOptions = _a === void 0 ? {} : _a;
    var defaultProp = factoryOptions.defaultProp;
    var ResultComponent = function (componentProps) {
        var settings = _getCustomizations(options.displayName, useContext(CustomizerContext), options.fields);
        var stateReducer = options.state;
        if (stateReducer) {
            // Don't assume state will return all props, so spread useState result over component props.
            componentProps = __assign(__assign({}, componentProps), stateReducer(componentProps));
        }
        var theme = componentProps.theme || settings.theme;
        var tokens = _resolveTokens(componentProps, theme, options.tokens, settings.tokens, componentProps.tokens);
        var styles = _resolveStyles(componentProps, theme, tokens, options.styles, settings.styles, componentProps.styles);
        var viewProps = __assign(__assign({}, componentProps), { styles: styles,
            tokens: tokens, _defaultStyles: styles, theme: theme });
        return view(viewProps);
    };
    ResultComponent.displayName = options.displayName || view.name;
    // If a shorthand prop is defined, create a factory for the component.
    // TODO: This shouldn't be a concern of createComponent.. factoryOptions should just be forwarded.
    //       Need to weigh creating default factories on component creation vs. memoizing them on use in slots.tsx.
    if (defaultProp) {
        ResultComponent.create = createFactory(ResultComponent, { defaultProp: defaultProp });
    }
    assign$1(ResultComponent, options.statics);
    // Later versions of TypeSript should allow us to merge objects in a type safe way and avoid this cast.
    return ResultComponent;
}
/**
 * Resolve all styles functions with both props and tokens and flatten results along with all styles objects.
 */
function _resolveStyles(props, theme, tokens) {
    var allStyles = [];
    for (var _i = 3; _i < arguments.length; _i++) {
        allStyles[_i - 3] = arguments[_i];
    }
    return concatStyleSets.apply(void 0, allStyles.map(function (styles) {
        return typeof styles === 'function' ? styles(props, theme, tokens) : styles;
    }));
}
/**
 * Resolve all tokens functions with props flatten results along with all tokens objects.
 */
function _resolveTokens(props, theme) {
    var allTokens = [];
    for (var _i = 2; _i < arguments.length; _i++) {
        allTokens[_i - 2] = arguments[_i];
    }
    var tokens = {};
    for (var _a = 0, allTokens_1 = allTokens; _a < allTokens_1.length; _a++) {
        var currentTokens = allTokens_1[_a];
        if (currentTokens) {
            // TODO: why is this cast needed? TS seems to think there is a (TToken | Function) union from somewhere.
            currentTokens =
                typeof currentTokens === 'function'
                    ? currentTokens(props, theme)
                    : currentTokens;
            if (Array.isArray(currentTokens)) {
                currentTokens = _resolveTokens.apply(void 0, __spreadArrays([props, theme], currentTokens));
            }
            assign$1(tokens, currentTokens);
        }
    }
    return tokens;
}
/**
 * Helper function for calling Customizations.getSettings falling back to default fields.
 *
 * @param displayName Displayable name for component.
 * @param context React context passed to component containing contextual settings.
 * @param fields Optional list of properties to grab from global store and context.
 */
function _getCustomizations(displayName, context, fields) {
    // TODO: do we want field props? should fields be part of IComponent and used here?
    // TODO: should we centrally define DefaultFields? (not exported from styling)
    // TODO: tie this array to ICustomizationProps, such that each array element is keyof ICustomizationProps
    var DefaultFields = ['theme', 'styles', 'tokens'];
    return Customizations.getSettings(fields || DefaultFields, displayName, context.customizations);
}

var GlobalClassNames$6 = {
    root: 'ms-StackItem',
};
var alignMap = {
    start: 'flex-start',
    end: 'flex-end',
};
var StackItemStyles = function (props, theme, tokens) {
    var grow = props.grow, shrink = props.shrink, disableShrink = props.disableShrink, align = props.align, verticalFill = props.verticalFill, order = props.order, className = props.className;
    var classNames = getGlobalClassNames(GlobalClassNames$6, theme);
    return {
        root: [
            theme.fonts.medium,
            classNames.root,
            {
                margin: tokens.margin,
                height: verticalFill ? '100%' : 'auto',
                width: 'auto',
            },
            grow && { flexGrow: grow === true ? 1 : grow },
            (disableShrink || (!grow && !shrink)) && {
                flexShrink: 0,
            },
            shrink &&
                !disableShrink && {
                flexShrink: 1,
            },
            align && {
                alignSelf: alignMap[align] || align,
            },
            order && {
                order: order,
            },
            className,
        ],
    };
};

/** @jsx withSlots */
var StackItemView = function (props) {
    var children = props.children;
    if (Children.count(children) < 1) {
        return null;
    }
    var Slots = getSlots(props, {
        root: 'div',
    });
    return withSlots(Slots.root, null, children);
};
var StackItem = createComponent(StackItemView, {
    displayName: 'StackItem',
    styles: StackItemStyles,
});

/**
 * Functions used by Stack components to simplify style-related computations
 */
// Helper function that converts a themed spacing key (if given) to the corresponding themed spacing value.
var _getThemedSpacing = function (space, theme) {
    if (theme.spacing.hasOwnProperty(space)) {
        return theme.spacing[space];
    }
    return space;
};
// Helper function that takes a gap as a string and converts it into a { value, unit } representation.
var _getValueUnitGap = function (gap) {
    var numericalPart = parseFloat(gap);
    var numericalValue = isNaN(numericalPart) ? 0 : numericalPart;
    var numericalString = isNaN(numericalPart) ? '' : numericalPart.toString();
    var unitPart = gap.substring(numericalString.toString().length);
    return {
        value: numericalValue,
        unit: unitPart || 'px',
    };
};
/**
 * Takes in a gap size in either a CSS-style format (e.g. 10 or "10px")
 *  or a key of a themed spacing value (e.g. "s1").
 * Returns the separate numerical value of the padding (e.g. 10)
 *  and the CSS unit (e.g. "px").
 */
var parseGap = function (gap, theme) {
    if (gap === undefined || gap === '') {
        return {
            rowGap: {
                value: 0,
                unit: 'px',
            },
            columnGap: {
                value: 0,
                unit: 'px',
            },
        };
    }
    if (typeof gap === 'number') {
        return {
            rowGap: {
                value: gap,
                unit: 'px',
            },
            columnGap: {
                value: gap,
                unit: 'px',
            },
        };
    }
    var splitGap = gap.split(' ');
    // If the array has more than two values, then return 0px.
    if (splitGap.length > 2) {
        return {
            rowGap: {
                value: 0,
                unit: 'px',
            },
            columnGap: {
                value: 0,
                unit: 'px',
            },
        };
    }
    // If the array has two values, then parse each one.
    if (splitGap.length === 2) {
        return {
            rowGap: _getValueUnitGap(_getThemedSpacing(splitGap[0], theme)),
            columnGap: _getValueUnitGap(_getThemedSpacing(splitGap[1], theme)),
        };
    }
    // Else, parse the numerical value and pass it as both the vertical and horizontal gap.
    var calculatedGap = _getValueUnitGap(_getThemedSpacing(gap, theme));
    return {
        rowGap: calculatedGap,
        columnGap: calculatedGap,
    };
};
/**
 * Takes in a padding in a CSS-style format (e.g. 10, "10px", "10px 10px", etc.)
 *  where the separate padding values can also be the key of a themed spacing value
 *  (e.g. "s1 m", "10px l1 20px l2", etc.).
 * Returns a CSS-style padding.
 */
var parsePadding = function (padding, theme) {
    if (padding === undefined || typeof padding === 'number' || padding === '') {
        return padding;
    }
    var paddingValues = padding.split(' ');
    if (paddingValues.length < 2) {
        return _getThemedSpacing(padding, theme);
    }
    return paddingValues.reduce(function (padding1, padding2) {
        return _getThemedSpacing(padding1, theme) + ' ' + _getThemedSpacing(padding2, theme);
    });
};

var nameMap = {
    start: 'flex-start',
    end: 'flex-end',
};
var GlobalClassNames$7 = {
    root: 'ms-Stack',
    inner: 'ms-Stack-inner',
};
var styles = function (props, theme, tokens) {
    var _a, _b, _c, _d, _e, _f, _g;
    var verticalFill = props.verticalFill, horizontal = props.horizontal, reversed = props.reversed, grow = props.grow, wrap = props.wrap, horizontalAlign = props.horizontalAlign, verticalAlign = props.verticalAlign, disableShrink = props.disableShrink, className = props.className;
    var classNames = getGlobalClassNames(GlobalClassNames$7, theme);
    /* eslint-disable deprecation/deprecation */
    var childrenGap = tokens && tokens.childrenGap ? tokens.childrenGap : props.gap;
    var maxHeight = tokens && tokens.maxHeight ? tokens.maxHeight : props.maxHeight;
    var maxWidth = tokens && tokens.maxWidth ? tokens.maxWidth : props.maxWidth;
    var padding = tokens && tokens.padding ? tokens.padding : props.padding;
    /* eslint-enable deprecation/deprecation */
    var _h = parseGap(childrenGap, theme), rowGap = _h.rowGap, columnGap = _h.columnGap;
    var horizontalMargin = "" + -0.5 * columnGap.value + columnGap.unit;
    var verticalMargin = "" + -0.5 * rowGap.value + rowGap.unit;
    // styles to be applied to all direct children regardless of wrap or direction
    var childStyles = {
        textOverflow: 'ellipsis',
    };
    // selectors to be applied regardless of wrap or direction
    var commonSelectors = {
        // flexShrink styles are applied by the StackItem
        '> *:not(.ms-StackItem)': {
            flexShrink: disableShrink ? 0 : 1,
        },
    };
    if (wrap) {
        return {
            root: [
                classNames.root,
                {
                    flexWrap: 'wrap',
                    maxWidth: maxWidth,
                    maxHeight: maxHeight,
                    width: 'auto',
                    overflow: 'visible',
                    height: '100%',
                },
                horizontalAlign && (_a = {},
                    _a[horizontal ? 'justifyContent' : 'alignItems'] = nameMap[horizontalAlign] || horizontalAlign,
                    _a),
                verticalAlign && (_b = {},
                    _b[horizontal ? 'alignItems' : 'justifyContent'] = nameMap[verticalAlign] || verticalAlign,
                    _b),
                className,
                {
                    // not allowed to be overridden by className
                    // since this is necessary in order to prevent collapsing margins
                    display: 'flex',
                },
                horizontal && {
                    height: verticalFill ? '100%' : 'auto',
                },
            ],
            inner: [
                classNames.inner,
                {
                    display: 'flex',
                    flexWrap: 'wrap',
                    marginLeft: horizontalMargin,
                    marginRight: horizontalMargin,
                    marginTop: verticalMargin,
                    marginBottom: verticalMargin,
                    overflow: 'visible',
                    boxSizing: 'border-box',
                    padding: parsePadding(padding, theme),
                    // avoid unnecessary calc() calls if horizontal gap is 0
                    width: columnGap.value === 0 ? '100%' : "calc(100% + " + columnGap.value + columnGap.unit + ")",
                    maxWidth: '100vw',
                    selectors: __assign({ '> *': __assign({ margin: "" + 0.5 * rowGap.value + rowGap.unit + " " + 0.5 * columnGap.value + columnGap.unit }, childStyles) }, commonSelectors),
                },
                horizontalAlign && (_c = {},
                    _c[horizontal ? 'justifyContent' : 'alignItems'] = nameMap[horizontalAlign] || horizontalAlign,
                    _c),
                verticalAlign && (_d = {},
                    _d[horizontal ? 'alignItems' : 'justifyContent'] = nameMap[verticalAlign] || verticalAlign,
                    _d),
                horizontal && {
                    flexDirection: reversed ? 'row-reverse' : 'row',
                    // avoid unnecessary calc() calls if vertical gap is 0
                    height: rowGap.value === 0 ? '100%' : "calc(100% + " + rowGap.value + rowGap.unit + ")",
                    selectors: {
                        '> *': {
                            maxWidth: columnGap.value === 0 ? '100%' : "calc(100% - " + columnGap.value + columnGap.unit + ")",
                        },
                    },
                },
                !horizontal && {
                    flexDirection: reversed ? 'column-reverse' : 'column',
                    height: "calc(100% + " + rowGap.value + rowGap.unit + ")",
                    selectors: {
                        '> *': {
                            maxHeight: rowGap.value === 0 ? '100%' : "calc(100% - " + rowGap.value + rowGap.unit + ")",
                        },
                    },
                },
            ],
        };
    }
    return {
        root: [
            classNames.root,
            {
                display: 'flex',
                flexDirection: horizontal ? (reversed ? 'row-reverse' : 'row') : reversed ? 'column-reverse' : 'column',
                flexWrap: 'nowrap',
                width: 'auto',
                height: verticalFill ? '100%' : 'auto',
                maxWidth: maxWidth,
                maxHeight: maxHeight,
                padding: parsePadding(padding, theme),
                boxSizing: 'border-box',
                selectors: __assign((_e = { '> *': childStyles }, _e[reversed ? '> *:not(:last-child)' : '> *:not(:first-child)'] = [
                    horizontal && {
                        marginLeft: "" + columnGap.value + columnGap.unit,
                    },
                    !horizontal && {
                        marginTop: "" + rowGap.value + rowGap.unit,
                    },
                ], _e), commonSelectors),
            },
            grow && {
                flexGrow: grow === true ? 1 : grow,
            },
            horizontalAlign && (_f = {},
                _f[horizontal ? 'justifyContent' : 'alignItems'] = nameMap[horizontalAlign] || horizontalAlign,
                _f),
            verticalAlign && (_g = {},
                _g[horizontal ? 'alignItems' : 'justifyContent'] = nameMap[verticalAlign] || verticalAlign,
                _g),
            className,
        ],
    };
};

var StackView = function (props) {
    var _a = props.as, RootType = _a === void 0 ? 'div' : _a, disableShrink = props.disableShrink, wrap = props.wrap, rest = __rest(props, ["as", "disableShrink", "wrap"]);
    warnDeprecations('Stack', props, {
        gap: 'tokens.childrenGap',
        maxHeight: 'tokens.maxHeight',
        maxWidth: 'tokens.maxWidth',
        padding: 'tokens.padding',
    });
    var stackChildren = Children.map(props.children, function (child, index) {
        if (!child) {
            return null;
        }
        if (_isStackItem(child)) {
            var defaultItemProps = {
                shrink: !disableShrink,
            };
            return cloneElement(child, __assign(__assign({}, defaultItemProps), child.props));
        }
        return child;
    });
    var nativeProps = getNativeProps(rest, htmlElementProperties);
    var Slots = getSlots(props, {
        root: RootType,
        inner: 'div',
    });
    if (wrap) {
        return (withSlots(Slots.root, __assign({}, nativeProps),
            withSlots(Slots.inner, null, stackChildren)));
    }
    return withSlots(Slots.root, __assign({}, nativeProps), stackChildren);
};
function _isStackItem(item) {
    // In theory, we should be able to just check item.type === StackItem.
    // However, under certain unclear circumstances (see https://github.com/microsoft/fluentui/issues/10785),
    // the object identity is different despite the function implementation being the same.
    return (!!item &&
        typeof item === 'object' &&
        !!item.type &&
        // StackItem is generated by createComponent, so we need to check its displayName instead of name
        item.type.displayName === StackItem.displayName);
}
var StackStatics = {
    Item: StackItem,
};
var Stack = createComponent(StackView, {
    displayName: 'Stack',
    styles: styles,
    statics: StackStatics,
});

var AccuracyTabStyles = function AccuracyTabStyles() {
  var theme = getTheme$1();
  return mergeStyleSets$1({
    iconClass: {
      fontSize: "20px",
      position: "absolute",
      right: "10px",
      top: "10px"
    },
    itemsList: {
      overflowY: "auto"
    },
    frame: {
      height: "100%"
    },
    main: {
      height: "100%",
      maxWidth: "750px",
      flex: 1
    },
    header: {
      color: theme.semanticColors.bodyText,
      fontWeight: FontWeights$1.semibold,
      margin: "26px 0"
    },
    textBody: {
      paddingTop: "12px",
      fontWeight: FontWeights$1.semilight,
      color: theme.semanticColors.bodyText,
      paddingBottom: "12px"
    }
  });
};

var TileListStyles = function TileListStyles() {
  var theme = getTheme$1();
  return mergeStyleSets$1({
    container: {
      display: "inline-flex",
      flexDirection: "row",
      flexWrap: "wrap",
      justifyContent: "space-between",
      borderBottom: "1px solid",
      borderBottomColor: theme.semanticColors.bodyDivider
    },
    itemCell: {
      padding: "15px",
      width: "235px",
      position: "relative",
      "float": "left",
      cursor: "pointer",
      boxSizing: "border-box",
      backgroundColor: theme.semanticColors.bodyDivider,
      marginBottom: "10px",
      marginRight: "10px",
      selectors: {
        "&:hover": {
          background: theme.semanticColors.bodyBackgroundHovered
        }
      }
    },
    iconClass: {
      color: theme.semanticColors.accentButtonBackground,
      position: "absolute",
      right: "10px",
      top: "10px"
    },
    title: {
      color: theme.semanticColors.bodyText,
      paddingRight: "16px",
      margin: 0
    },
    description: {
      paddingTop: "10px",
      color: theme.semanticColors.bodySubtext
    }
  });
};

var TileList = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(TileList, _React$PureComponent);

  var _super = _createSuper(TileList);

  function TileList() {
    var _this;

    _classCallCheck(this, TileList);

    _this = _super.apply(this, arguments);

    _this._onRenderCell = function (item, index, styles) {
      return React__default.createElement("div", {
        className: styles.itemCell,
        onClick: item.onSelect.bind(_assertThisInitialized(_this)),
        key: index,
        "data-is-focusable": true,
        role: "radio",
        "aria-checked": item.selected
      }, React__default.createElement(Icon$1, {
        iconName: item.selected ? "RadioBtnOn" : "RadioBtnOff",
        className: styles.iconClass
      }), React__default.createElement(Text$1, {
        className: styles.title,
        block: true
      }, item.title), React__default.createElement(Text$1, {
        className: styles.description
      }, item.description));
    };

    return _this;
  }

  _createClass(TileList, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var styles = TileListStyles();
      return React__default.createElement("div", {
        className: styles.container
      }, this.props.items.map(function (item, index) {
        return _this2._onRenderCell(item, index, styles);
      }));
    }
  }]);

  return TileList;
}(React__default.PureComponent);

var AccuracyTab = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(AccuracyTab, _React$PureComponent);

  var _super = _createSuper(AccuracyTab);

  function AccuracyTab() {
    _classCallCheck(this, AccuracyTab);

    return _super.apply(this, arguments);
  }

  _createClass(AccuracyTab, [{
    key: "render",
    value: function render() {
      var _this = this;

      var styles = AccuracyTabStyles();
      return React__default.createElement(Stack, {
        horizontal: true,
        horizontalAlign: "space-between",
        className: styles.frame
      }, React__default.createElement(Stack, {
        className: styles.main
      }, React__default.createElement(Text$1, {
        className: styles.header,
        block: true
      }, localization.Accuracy.header), React__default.createElement(Text$1, {
        className: styles.textBody,
        block: true
      }, localization.formatString(localization.Accuracy.body, this.props.dashboardContext.modelMetadata.PredictionType !== PredictionTypes.regression ? localization.Accuracy.binary : localization.Accuracy.continuous, this.props.dashboardContext.modelMetadata.PredictionType === PredictionTypes.binaryClassification ? localization.Accuracy.binary : localization.Accuracy.continuous, this.props.dashboardContext.predictions.length === 1 ? localization.Accuracy.modelMakes : localization.Accuracy.modelsMake)), React__default.createElement(StackItem, {
        grow: 2,
        className: styles.itemsList
      }, React__default.createElement(FocusZone$1, {
        shouldFocusOnMount: true
      }, React__default.createElement(TileList, {
        items: this.props.accuracyPickerProps.accuracyOptions.map(function (accuracy) {
          return {
            title: accuracy.title,
            description: accuracy.description,
            onSelect: _this.props.accuracyPickerProps.onAccuracyChange.bind(_this, accuracy.key),
            selected: _this.props.accuracyPickerProps.selectedAccuracyKey === accuracy.key
          };
        })
      }))), React__default.createElement(WizardFooter, {
        onNext: this.props.onNext,
        onPrevious: this.props.onPrevious
      })), React__default.createElement(DataSpecificationBlade, {
        numberRows: this.props.dashboardContext.trueY.length,
        featureNames: this.props.dashboardContext.modelMetadata.featureNames
      }));
    }
  }]);

  return AccuracyTab;
}(React__default.PureComponent);

var IntroTabStyles = function IntroTabStyles() {
  var theme = getTheme$1();
  return mergeStyleSets$1({
    firstSection: {
      padding: "43px 94px",
      backgroundColor: theme.semanticColors.bodyBackground,
      color: theme.semanticColors.bodyText
    },
    firstSectionTitle: {
      fontSize: "60px",
      fontWeight: FontWeights$1.light,
      lineHeight: "82px"
    },
    firstSectionSubtitle: {
      fontSize: "60px",
      fontWeight: FontWeights$1.semibold,
      lineHeight: "82px"
    },
    firstSectionBody: {
      paddingTop: "30px",
      paddingBottom: "70px",
      maxWidth: "500px",
      fontWeight: FontWeights$1.semilight,
      lineHeight: "24px"
    },
    lowerSection: {
      padding: "50px 70px 90px 90px",
      backgroundColor: theme.semanticColors.bodyBackground,
      color: theme.semanticColors.bodyText,
      flexGrow: 1
    },
    stepsContainer: {
      display: "flex",
      flexDirection: "row",
      justifyContent: "space-between",
      borderBottom: "1px solid",
      borderBottomColor: theme.semanticColors.bodyDivider,
      paddingBottom: "38px"
    },
    boldStep: {
      maxWidth: "300px",
      paddingRight: "25px",
      flex: 1
    },
    numericLabel: {
      fontWeight: FontWeights$1.bold,
      width: "30px",
      lineHeight: "24px"
    },
    explanatoryStep: {
      maxWidth: "300px",
      paddingRight: "20px",
      flex: 1
    },
    explanatoryText: {
      paddingTop: "15px"
    },
    getStarted: {
      paddingTop: "30px",
      fontSize: FontSizes$1.large,
      fontWeight: FontWeights$1.regular
    }
  });
};

var IntroTab = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(IntroTab, _React$PureComponent);

  var _super = _createSuper(IntroTab);

  function IntroTab() {
    _classCallCheck(this, IntroTab);

    return _super.apply(this, arguments);
  }

  _createClass(IntroTab, [{
    key: "render",
    value: function render() {
      var styles = IntroTabStyles();
      return React__default.createElement(Stack$1, {
        style: {
          height: "100%"
        }
      }, React__default.createElement("div", {
        className: styles.firstSection
      }, React__default.createElement(Text$1, {
        className: styles.firstSectionTitle,
        block: true
      }, localization.Intro.welcome), React__default.createElement(Text$1, {
        className: styles.firstSectionSubtitle,
        block: true
      }, localization.Intro.fairlearnDashboard), React__default.createElement(Text$1, {
        variant: "large",
        block: true
      }, localization.Intro.introBody)), React__default.createElement("div", {
        className: styles.lowerSection
      }, React__default.createElement("div", {
        className: styles.stepsContainer
      }, React__default.createElement(Text$1, {
        variant: "large",
        className: styles.boldStep
      }, localization.Intro.explanatoryStep), React__default.createElement("div", {
        className: styles.explanatoryStep
      }, React__default.createElement("div", null, React__default.createElement(Text$1, {
        variant: "large",
        className: styles.numericLabel
      }, "01"), React__default.createElement(Text$1, {
        variant: "large"
      }, localization.Intro.features)), React__default.createElement(Text$1, {
        className: styles.explanatoryText,
        block: true
      }, localization.Intro.featuresInfo)), React__default.createElement("div", {
        className: styles.explanatoryStep
      }, React__default.createElement("div", null, React__default.createElement(Text$1, {
        variant: "large",
        className: styles.numericLabel
      }, "02"), React__default.createElement(Text$1, {
        variant: "large"
      }, localization.Intro.accuracy)), React__default.createElement(Text$1, {
        className: styles.explanatoryText,
        block: true
      }, localization.Intro.accuracyInfo))), React__default.createElement(Stack$1, {
        horizontalAlign: "center"
      }, React__default.createElement(ActionButton$1, {
        iconProps: {
          iconName: "Forward"
        },
        className: styles.getStarted,
        onClick: this.props.onNext
      }, localization.Intro.getStarted))));
    }
  }]);

  return IntroTab;
}(React__default.PureComponent);

var FormatMetrics = function FormatMetrics() {
  _classCallCheck(this, FormatMetrics);
};

FormatMetrics.formatNumbers = function (value, key) {
  var isRatio = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  var sigDigits = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 3;

  if (value === null || value === undefined) {
    return Number.NaN.toString();
  }

  var styleObject = {
    maximumSignificantDigits: sigDigits
  };

  if (AccuracyOptions[key] && AccuracyOptions[key].isPercentage && !isRatio) {
    styleObject.style = "percent";
  }

  return value.toLocaleString(undefined, styleObject);
};

var ModelComparisonChartStyles = function ModelComparisonChartStyles() {
  var theme = getTheme$1();
  return mergeStyleSets$1({
    frame: {
      flex: 1,
      display: "flex",
      flexDirection: "column"
    },
    spinner: {
      margin: "auto",
      padding: "40px"
    },
    header: {
      backgroundColor: theme.semanticColors.bodyFrameBackground,
      padding: "0 90px",
      height: "90px",
      display: "inline-flex",
      flexDirection: "row",
      justifyContent: "space-between",
      alignItems: "center"
    },
    headerTitle: {
      color: theme.semanticColors.bodyText,
      fontWeight: FontWeights$1.semibold
    },
    editButton: {
      color: theme.semanticColors.buttonText
    },
    main: {
      height: "100%",
      flex: 1,
      display: "inline-flex",
      flexDirection: "row",
      backgroundColor: theme.semanticColors.bodyBackground
    },
    mainRight: {
      padding: "30px 0 0 35px",
      width: "300px"
    },
    rightTitle: {
      color: theme.semanticColors.bodyText,
      paddingBottom: "18px",
      borderBottom: "1px solid",
      borderColor: theme.semanticColors.bodyDivider
    },
    rightText: {
      padding: "16px 15px 30px 0",
      color: theme.semanticColors.bodyText,
      borderBottom: "0.5px dashed",
      borderColor: theme.semanticColors.bodyDivider
    },
    insights: {
      textTransform: "uppercase",
      color: theme.semanticColors.bodyText,
      padding: "18px 0"
    },
    insightsText: {
      paddingBottom: "18px",
      paddingRight: "15px",
      borderBottom: "1px solid",
      borderColor: theme.semanticColors.bodyDivider
    },
    chart: {
      padding: "60px 0 0 0",
      flex: 1
    },
    textSection: {
      color: theme.semanticColors.bodyText,
      paddingBottom: "5px"
    },
    radio: {
      paddingBottom: "30px",
      paddingLeft: "75px",
      backgroundColor: theme.semanticColors.bodyBackground
    },
    radioOptions: {
      color: theme.semanticColors.bodyText
    }
  });
};

var theme = getTheme$1();
var ModelComparisonChart = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(ModelComparisonChart, _React$PureComponent);

  var _super = _createSuper(ModelComparisonChart);

  function ModelComparisonChart(props) {
    var _this;

    _classCallCheck(this, ModelComparisonChart);

    _this = _super.call(this, props);
    _this.plotlyProps = {
      config: {
        displaylogo: false,
        responsive: true,
        modeBarButtonsToRemove: ["toggleSpikelines", "hoverClosestCartesian", "hoverCompareCartesian", "zoom2d", "pan2d", "select2d", "lasso2d", "zoomIn2d", "zoomOut2d", "autoScale2d", "resetScale2d"]
      },
      data: [{
        datapointLevelAccessors: {
          customdata: {
            path: ["index"],
            plotlyPath: "customdata"
          }
        },
        mode: PlotlyMode.markers,
        marker: {
          size: 14
        },
        type: "scatter",
        xAccessor: "Accuracy",
        yAccessor: "Parity",
        hoverinfo: "text"
      }],
      layout: {
        autosize: true,
        font: {
          size: 10
        },
        margin: {
          t: 4,
          r: 0
        },
        hovermode: "closest",
        xaxis: {
          automargin: true,
          fixedrange: true,
          mirror: true,
          linecolor: theme.semanticColors.disabledBorder,
          linewidth: 1,
          title: {
            text: "Error"
          }
        },
        yaxis: {
          automargin: true,
          fixedrange: true,
          title: {
            text: "Disparity"
          }
        }
      }
    };

    _this.disparityChanged = function (_ev, option) {
      var disparityInOutcomes = (option === null || option === void 0 ? void 0 : option.key) !== "accuracy";

      if (_this.state.disparityInOutcomes !== disparityInOutcomes) {
        _this.setState({
          disparityInOutcomes: disparityInOutcomes,
          disparityArray: undefined
        });
      }
    };

    _this.state = {
      disparityInOutcomes: true
    };
    return _this;
  }

  _createClass(ModelComparisonChart, [{
    key: "render",
    value: function render() {
      var _this2 = this,
          _props$layout,
          _props$layout2;

      var styles = ModelComparisonChartStyles();

      if (!this.state || this.state.accuracyArray === undefined || this.state.disparityArray === undefined) {
        this.loadData();
        return React__default.createElement(Spinner$1, {
          className: styles.spinner,
          size: SpinnerSize$1.large,
          label: localization.calculating
        });
      }

      var disparityArray = this.state.disparityArray;
      var data = this.state.accuracyArray.map(function (accuracy, index) {
        return {
          Parity: disparityArray[index],
          Accuracy: accuracy,
          index: index
        };
      });
      var minAccuracy = Number.MAX_SAFE_INTEGER;
      var maxAccuracy = Number.MIN_SAFE_INTEGER;
      var maxDisparity = Number.MIN_SAFE_INTEGER;
      var minDisparity = Number.MAX_SAFE_INTEGER;
      var minAccuracyIndex = 0;
      var maxAccuracyIndex = this.state.accuracyArray[0];
      var minDisparityIndex = 0;
      this.state.accuracyArray.forEach(function (value, index) {
        if (value === undefined) {
          return;
        }

        if (value >= maxAccuracy) {
          maxAccuracyIndex = index;
          maxAccuracy = value;
        }

        if (value <= minAccuracy) {
          minAccuracyIndex = index;
          minAccuracy = value;
        }
      });
      this.state.disparityArray.forEach(function (value, index) {
        if (value >= maxDisparity) {
          maxDisparity = value;
        }

        if (value <= minDisparity) {
          minDisparityIndex = index;
          minDisparity = value;
        }
      });
      var formattedMinAccuracy = FormatMetrics.formatNumbers(minAccuracy, this.props.accuracyPickerProps.selectedAccuracyKey);
      var formattedMaxAccuracy = FormatMetrics.formatNumbers(maxAccuracy, this.props.accuracyPickerProps.selectedAccuracyKey);
      var formattedMinDisparity = FormatMetrics.formatNumbers(minDisparity, this.props.accuracyPickerProps.selectedAccuracyKey);
      var formattedMaxDisparity = FormatMetrics.formatNumbers(maxDisparity, this.props.accuracyPickerProps.selectedAccuracyKey);
      var selectedMetric = AccuracyOptions[this.props.accuracyPickerProps.selectedAccuracyKey] || this.props.accuracyPickerProps.accuracyOptions.find(function (metric) {
        return metric.key === _this2.props.accuracyPickerProps.selectedAccuracyKey;
      }) || this.props.accuracyPickerProps.accuracyOptions[0];
      var insights2 = localization.formatString(localization.ModelComparison.insightsText2, selectedMetric.title, formattedMinAccuracy, formattedMaxAccuracy, formattedMinDisparity, formattedMaxDisparity);
      var metricTitleAppropriateCase = selectedMetric.alwaysUpperCase ? selectedMetric.title : selectedMetric.title.toLowerCase();
      var insights3 = localization.formatString(localization.ModelComparison.insightsText3, metricTitleAppropriateCase, selectedMetric.isMinimization ? formattedMinAccuracy : formattedMaxAccuracy, FormatMetrics.formatNumbers(minAccuracyIndex === undefined || maxAccuracyIndex === undefined ? undefined : this.state.disparityArray[selectedMetric.isMinimization ? minAccuracyIndex : maxAccuracyIndex], this.props.accuracyPickerProps.selectedAccuracyKey));
      var insights4 = localization.formatString(localization.ModelComparison.insightsText4, metricTitleAppropriateCase, FormatMetrics.formatNumbers(this.state.accuracyArray[minDisparityIndex], this.props.accuracyPickerProps.selectedAccuracyKey), formattedMinDisparity);
      var howToReadText = localization.formatString(localization.ModelComparison.howToReadText, this.props.modelCount.toString(), metricTitleAppropriateCase, selectedMetric.isMinimization ? localization.ModelComparison.lower : localization.ModelComparison.higher);

      var props = _.cloneDeep(this.plotlyProps);

      props.data = ChartBuilder.buildPlotlySeries(props.data[0], data).map(function (series) {
        series.name = _this2.props.dashboardContext.modelNames[series.name || ""];
        series.text = _this2.props.dashboardContext.modelNames;
        return series;
      });
      var accuracyMetricTitle = selectedMetric.title;

      if ((_props$layout = props.layout) === null || _props$layout === void 0 ? void 0 : _props$layout.xaxis) {
        props.layout.xaxis.title = accuracyMetricTitle;
      }

      if ((_props$layout2 = props.layout) === null || _props$layout2 === void 0 ? void 0 : _props$layout2.yaxis) {
        props.layout.yaxis.title = this.state.disparityInOutcomes ? localization.ModelComparison.disparityInOutcomes : localization.formatString(localization.ModelComparison.disparityInAccuracy, metricTitleAppropriateCase);
      }

      return React__default.createElement(Stack$1, {
        className: styles.frame
      }, React__default.createElement("div", {
        className: styles.header
      }, React__default.createElement(Text$1, {
        variant: "large",
        className: styles.headerTitle,
        block: true
      }, localization.ModelComparison.title), React__default.createElement(ActionButton$1, {
        iconProps: {
          iconName: "Edit"
        },
        onClick: this.props.onEditConfigs,
        className: styles.editButton,
        autoFocus: true
      }, localization.Report.editConfiguration)), React__default.createElement("div", {
        className: styles.main
      }, React__default.createElement("div", {
        className: styles.chart
      }, React__default.createElement(AccessibleChart, {
        plotlyProps: props,
        onClickHandler: this.props.onChartClick,
        theme: undefined
      })), React__default.createElement("div", {
        className: styles.mainRight
      }, React__default.createElement(Text$1, {
        className: styles.rightTitle,
        block: true
      }, localization.ModelComparison.howToRead), React__default.createElement(Text$1, {
        className: styles.rightText,
        block: true
      }, howToReadText), React__default.createElement(Text$1, {
        className: styles.insights,
        block: true
      }, localization.ModelComparison.insightsLegacy), React__default.createElement("div", {
        className: styles.insightsText
      }, React__default.createElement(Text$1, {
        className: styles.textSection,
        block: true
      }, insights2), React__default.createElement(Text$1, {
        className: styles.textSection,
        block: true
      }, insights3), React__default.createElement(Text$1, {
        className: styles.textSection,
        block: true
      }, insights4)))), React__default.createElement("div", null, React__default.createElement(ChoiceGroup, {
        className: styles.radio,
        selectedKey: this.state.disparityInOutcomes ? "outcomes" : "accuracy",
        options: [{
          key: "accuracy",
          text: localization.formatString(localization.ModelComparison.disparityInAccuracy, metricTitleAppropriateCase),
          styles: {
            choiceFieldWrapper: styles.radioOptions
          }
        }, {
          key: "outcomes",
          text: localization.ModelComparison.disparityInOutcomes,
          styles: {
            choiceFieldWrapper: styles.radioOptions
          }
        }],
        onChange: this.disparityChanged,
        label: localization.ModelComparison.howToMeasureDisparity,
        required: false
      })));
    }
  }, {
    key: "loadData",
    value: function () {
      var _loadData = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
        var _this3 = this;

        var accuracyPromises, disparityMetric, disparityPromises, accuracyArray, disparityArray;
        return regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.prev = 0;
                accuracyPromises = new Array(this.props.modelCount).fill(0).map(function (_, modelIndex) {
                  return _this3.props.metricsCache.getMetric(_this3.props.dashboardContext.binVector, _this3.props.featureBinPickerProps.selectedBinIndex, modelIndex, _this3.props.accuracyPickerProps.selectedAccuracyKey);
                });
                disparityMetric = this.getDisparityMetric();
                disparityPromises = new Array(this.props.modelCount).fill(0).map(function (_, modelIndex) {
                  return _this3.props.metricsCache.getDisparityMetric(_this3.props.dashboardContext.binVector, _this3.props.featureBinPickerProps.selectedBinIndex, modelIndex, disparityMetric, ParityModes.difference);
                });
                _context.next = 6;
                return Promise.all(accuracyPromises);

              case 6:
                accuracyArray = _context.sent.map(function (metric) {
                  return metric.global;
                });
                _context.next = 9;
                return Promise.all(disparityPromises);

              case 9:
                disparityArray = _context.sent;
                this.setState({
                  accuracyArray: accuracyArray,
                  disparityArray: disparityArray
                });
                _context.next = 15;
                break;

              case 13:
                _context.prev = 13;
                _context.t0 = _context["catch"](0);

              case 15:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, this, [[0, 13]]);
      }));

      function loadData() {
        return _loadData.apply(this, arguments);
      }

      return loadData;
    }()
  }, {
    key: "getDisparityMetric",
    value: function getDisparityMetric() {
      if (this.state.disparityInOutcomes) {
        if (this.props.dashboardContext.modelMetadata.PredictionType === PredictionTypes.binaryClassification) {
          return "selection_rate";
        }

        return "average";
      }

      return this.props.accuracyPickerProps.selectedAccuracyKey;
    }
  }]);

  return ModelComparisonChart;
}(React__default.PureComponent);

var ParityTab = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(ParityTab, _React$PureComponent);

  var _super = _createSuper(ParityTab);

  function ParityTab() {
    _classCallCheck(this, ParityTab);

    return _super.apply(this, arguments);
  }

  _createClass(ParityTab, [{
    key: "render",
    value: function render() {
      var _this = this,
          _this$props$dashboard;

      return React__default.createElement(Stack$1, {
        horizontal: true
      }, React__default.createElement(StackItem$1, {
        grow: 2
      }, React__default.createElement(Stack$1, null, React__default.createElement("h2", {
        style: {
          fontWeight: "bold"
        }
      }, localization.Parity.header), React__default.createElement("p", null, localization.Parity.bodyLegacy), React__default.createElement(StackItem$1, {
        grow: 2
      }, React__default.createElement(TileList, {
        items: this.props.parityPickerProps.parityOptions.map(function (parity) {
          var selected = _this.props.parityPickerProps.selectedParityKey === parity.key;
          return {
            title: parity.title,
            description: parity.description,
            onSelect: _this.props.parityPickerProps.onParityChange.bind(_this, parity.key),
            selected: selected
          };
        })
      })), React__default.createElement(Separator, null), React__default.createElement(WizardFooter, {
        onNext: this.props.onNext,
        onPrevious: this.props.onPrevious
      }))), React__default.createElement(DataSpecificationBlade, {
        numberRows: ((_this$props$dashboard = this.props.dashboardContext.dataset) === null || _this$props$dashboard === void 0 ? void 0 : _this$props$dashboard.length) || 0,
        featureNames: this.props.dashboardContext.modelMetadata.featureNames
      }));
    }
  }]);

  return ParityTab;
}(React__default.PureComponent);

var theme$1 = getTheme$1();
var ChartColors = [theme$1.palette.blue, theme$1.palette.orangeLighter //"#ff7f0e"
];

var SummaryTableStyles = function SummaryTableStyles() {
  var theme = getTheme$1();
  return mergeStyleSets$1({
    minMaxLabel: {
      padding: "1px 9px",
      marginTop: "4px",
      color: theme.semanticColors.bodySubtext,
      backgroundColor: theme.semanticColors.bodyStandoutBackground
    },
    groupCol: {
      display: "inline-flex",
      flexDirection: "column",
      height: "100%",
      width: "max-content"
    },
    groupLabel: {
      color: theme.semanticColors.bodyText,
      height: "26px"
    },
    flexCol: {
      display: "flex",
      flex: 1,
      flexDirection: "column",
      borderTop: "1px solid",
      borderBottom: "1px solid",
      borderColor: theme.semanticColors.bodyDivider
    },
    binBox: {
      flex: 1,
      width: "130px",
      display: "flex",
      flexDirection: "column",
      justifyContent: "center",
      borderBottom: "0.5px dashed",
      borderColor: theme.semanticColors.bodyDivider
    },
    binTitle: {
      color: theme.semanticColors.bodyText
    },
    metricCol: {
      display: "inline-flex",
      flexDirection: "column",
      height: "100%",
      width: "120px"
    },
    metricLabel: {
      color: theme.semanticColors.bodyText,
      height: "26px",
      paddingLeft: "10px"
    },
    metricBox: {
      flex: 1,
      paddingLeft: "10px",
      color: theme.semanticColors.bodyText,
      fontWeight: FontWeights$1.light,
      display: "flex",
      flexDirection: "column",
      justifyContent: "center",
      borderLeft: "0.5px dashed",
      borderBottom: "0.5px dashed",
      borderColor: theme.semanticColors.bodyDivider
    },
    frame: {
      paddingBottom: "19px",
      display: "flex"
    }
  });
};

var SummaryTable = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(SummaryTable, _React$PureComponent);

  var _super = _createSuper(SummaryTable);

  function SummaryTable() {
    _classCallCheck(this, SummaryTable);

    return _super.apply(this, arguments);
  }

  _createClass(SummaryTable, [{
    key: "render",
    value: function render() {
      var _this$props$binValues;

      var styles = SummaryTableStyles();
      var minIndexes = [];
      var maxIndexes = [];
      var minValue = Number.MAX_SAFE_INTEGER;
      var maxValue = Number.MIN_SAFE_INTEGER;
      (_this$props$binValues = this.props.binValues) === null || _this$props$binValues === void 0 ? void 0 : _this$props$binValues.forEach(function (value, index) {
        if (value >= maxValue) {
          if (value === maxValue) {
            maxIndexes.push(index);
          } else {
            maxIndexes = [index];
            maxValue = value;
          }
        }

        if (value <= minValue) {
          if (value === minValue) {
            minIndexes.push(index);
          } else {
            minIndexes = [index];
            minValue = value;
          }
        }
      });
      return React__default.createElement("div", {
        className: styles.frame
      }, React__default.createElement("div", {
        className: styles.groupCol
      }, React__default.createElement(Text$1, {
        variant: "small",
        className: styles.groupLabel
      }, this.props.binGroup), React__default.createElement("div", {
        className: styles.flexCol
      }, this.props.binLabels.map(function (label, index) {
        return React__default.createElement("div", {
          className: styles.binBox,
          key: index
        }, React__default.createElement(Text$1, {
          className: styles.binTitle
        }, label), React__default.createElement(Stack$1, {
          horizontal: true
        }, minIndexes.includes(index) && React__default.createElement(Text$1, {
          variant: "xSmall",
          className: styles.minMaxLabel
        }, localization.Report.minTag), maxIndexes.includes(index) && React__default.createElement(Text$1, {
          variant: "xSmall",
          className: styles.minMaxLabel
        }, localization.Report.maxTag)));
      }))), React__default.createElement("div", {
        className: styles.metricCol
      }, React__default.createElement(Text$1, {
        variant: "small",
        className: styles.metricLabel
      }, this.props.metricLabel), React__default.createElement("div", {
        className: styles.flexCol
      }, this.props.formattedBinValues.map(function (value, index) {
        return React__default.createElement(Text$1, {
          variant: "xLargePlus",
          className: styles.metricBox,
          key: index
        }, value !== undefined ? value : "empty");
      }))));
    }
  }]);

  return SummaryTable;
}(React__default.PureComponent);

var WizardReportStyles = function WizardReportStyles() {
  var theme = getTheme$1();
  return mergeStyleSets$1({
    spinner: {
      margin: "auto",
      padding: "40px"
    },
    header: {
      padding: "0 90px",
      backgroundColor: theme.semanticColors.bodyStandoutBackground
    },
    multimodelButton: {
      marginTop: "20px",
      padding: 0
    },
    headerTitle: {
      paddingTop: "10px",
      color: theme.semanticColors.bodyText
    },
    headerBanner: {
      display: "flex"
    },
    bannerWrapper: {
      width: "100%",
      paddingTop: "18px",
      paddingBottom: "15px",
      display: "inline-flex",
      flexDirection: "row",
      justifyContent: "space-between"
    },
    metricText: {
      color: theme.semanticColors.bodyText,
      paddingRight: "12px",
      fontWeight: FontWeights$1.light,
      lineHeight: "44px",
      fontSize: "36px"
    },
    firstMetricLabel: {
      color: theme.semanticColors.bodyText,
      padding: "8px 12px 0 12px",
      maxWidth: "120px",
      borderRight: "1px solid",
      borderRightColor: theme.semanticColors.bodyDivider,
      marginRight: "20px",
      lineHeight: "16px"
    },
    metricLabel: {
      color: theme.semanticColors.bodyText,
      paddingTop: "8px",
      maxWidth: "130px"
    },
    presentationArea: {
      display: "flex",
      flexDirection: "row",
      padding: "20px 0 30px 90px",
      backgroundColor: theme.semanticColors.bodyBackground
    },
    chartWrapper: {
      flex: "1 0 40%",
      display: "flex",
      flexDirection: "column"
    },
    chartBody: {
      flex: 1
    },
    chartHeader: {
      height: "23px",
      paddingLeft: "10px",
      color: theme.semanticColors.bodyText
    },
    mainRight: {
      minWidth: "200px",
      paddingLeft: "35px",
      flexBasis: "300px",
      flexShrink: 1
    },
    rightTitle: {
      color: theme.semanticColors.bodyText,
      paddingBottom: "11px",
      borderBottom: "1px solid",
      borderBottomColor: theme.semanticColors.bodyDivider
    },
    rightText: {
      padding: "16px 15px 30px 0",
      color: theme.semanticColors.bodyText,
      borderBottom: "0.5px dashed",
      borderBottomColor: theme.semanticColors.bodyDivider
    },
    insights: {
      textTransform: "uppercase",
      color: theme.semanticColors.bodyText,
      padding: "18px 0"
    },
    insightsText: {
      color: theme.semanticColors.bodyText,
      paddingBottom: "18px",
      paddingRight: "15px",
      borderBottom: "1px solid",
      borderBottomColor: theme.semanticColors.bodyDivider
    },
    tableWrapper: {
      paddingBottom: "20px"
    },
    textRow: {
      display: "flex",
      flexDirection: "row",
      alignItems: "center",
      paddingBottom: "7px",
      color: theme.semanticColors.bodyText
    },
    colorBlock: {
      width: "15px",
      height: "15px",
      marginRight: "9px"
    },
    multimodelSection: {
      display: "flex",
      flexDirection: "row"
    },
    modelLabel: {
      alignSelf: "center",
      paddingLeft: "35px",
      paddingTop: "16px",
      color: theme.semanticColors.bodyText
    },
    groupLabel: {
      color: theme.semanticColors.bodyText
    }
  });
};

var theme$2 = getTheme$1();
var WizardReport = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(WizardReport, _React$PureComponent);

  var _super = _createSuper(WizardReport);

  function WizardReport() {
    var _this;

    _classCallCheck(this, WizardReport);

    _this = _super.apply(this, arguments);

    _this.clearModelSelection = function () {
      if (_this.props.onChartClick) {
        _this.props.onChartClick(undefined);
      }
    };

    _this.onEditConfigs = function () {
      if (_this.props.modelCount > 1) {
        if (_this.props.onChartClick) {
          _this.props.onChartClick(undefined);
        }
      }

      _this.props.onEditConfigs();
    };

    return _this;
  }

  _createClass(WizardReport, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var styles = WizardReportStyles();

      if (!this.state || !this.state.metrics) {
        this.loadData();
        return React__default.createElement(Spinner$1, {
          className: styles.spinner,
          size: SpinnerSize$1.large,
          label: localization.calculating
        });
      }

      var alternateHeight = this.props.featureBinPickerProps.featureBins[this.props.featureBinPickerProps.selectedBinIndex].labelArray.length * 60 + 106;
      var areaHeights = Math.max(460, alternateHeight);
      var accuracyKey = this.props.accuracyPickerProps.selectedAccuracyKey;
      var outcomeKey = this.props.dashboardContext.modelMetadata.PredictionType === PredictionTypes.binaryClassification ? "selection_rate" : "average";
      var outcomeMetric = AccuracyOptions[outcomeKey];

      var accuracyPlot = _.cloneDeep(WizardReport.barPlotlyProps);

      var opportunityPlot = _.cloneDeep(WizardReport.barPlotlyProps);

      var nameIndex = this.props.dashboardContext.groupNames.map(function (_, i) {
        return i;
      });
      var howToReadAccuracySection;
      var howToReadOutcomesSection;
      var accuracyChartHeader = "";
      var opportunityChartHeader = "";

      if (this.props.dashboardContext.modelMetadata.PredictionType === PredictionTypes.binaryClassification) {
        var _this$state$metrics$b, _this$state$metrics$b2, _this$state$metrics$b3, _accuracyPlot$layout, _opportunityPlot$layo;

        accuracyPlot.data = [{
          x: this.state.metrics.binnedOverprediction,
          y: nameIndex,
          text: (_this$state$metrics$b = this.state.metrics.binnedOverprediction) === null || _this$state$metrics$b === void 0 ? void 0 : _this$state$metrics$b.map(function (num) {
            return FormatMetrics.formatNumbers(num, "accuracy_score", false, 2);
          }),
          name: localization.Metrics.overprediction,
          width: 0.5,
          fillcolor: ChartColors[0],
          orientation: "h",
          type: "bar",
          hoverinfo: "skip",
          textposition: "inside"
        }, {
          x: (_this$state$metrics$b2 = this.state.metrics.binnedUnderprediction) === null || _this$state$metrics$b2 === void 0 ? void 0 : _this$state$metrics$b2.map(function (x) {
            return -1 * x;
          }),
          y: nameIndex,
          text: (_this$state$metrics$b3 = this.state.metrics.binnedUnderprediction) === null || _this$state$metrics$b3 === void 0 ? void 0 : _this$state$metrics$b3.map(function (num) {
            return FormatMetrics.formatNumbers(num, "accuracy_score", false, 2);
          }),
          name: localization.Metrics.underprediction,
          width: 0.5,
          fillcolor: ChartColors[1],
          orientation: "h",
          type: "bar",
          hoverinfo: "skip",
          textposition: "inside",
          textfont: {
            color: theme$2.palette.black
          }
        }];

        if (accuracyPlot.layout) {
          accuracyPlot.layout.annotations = [{
            text: localization.Report.underestimationError,
            x: 0.02,
            y: 1,
            yref: "paper",
            xref: "paper",
            showarrow: false,
            font: {
              color: theme$2.semanticColors.bodySubtext,
              size: 10
            }
          }, {
            text: localization.Report.overestimationError,
            x: 0.98,
            y: 1,
            yref: "paper",
            xref: "paper",
            showarrow: false,
            font: {
              color: theme$2.semanticColors.bodySubtext,
              size: 10
            }
          }];
        }

        if ((_accuracyPlot$layout = accuracyPlot.layout) === null || _accuracyPlot$layout === void 0 ? void 0 : _accuracyPlot$layout.xaxis) {
          accuracyPlot.layout.xaxis.tickformat = ",.0%";
        }

        opportunityPlot.data = [{
          x: this.state.metrics.binnedOutcome,
          y: nameIndex,
          text: this.state.metrics.binnedOutcome.map(function (num) {
            return FormatMetrics.formatNumbers(num, "selection_rate", false, 2);
          }),
          name: outcomeMetric.title,
          fillcolor: ChartColors[0],
          orientation: "h",
          type: "bar",
          textposition: "inside",
          hoverinfo: "skip"
        }];

        if ((_opportunityPlot$layo = opportunityPlot.layout) === null || _opportunityPlot$layo === void 0 ? void 0 : _opportunityPlot$layo.xaxis) {
          opportunityPlot.layout.xaxis.tickformat = ",.0%";
        }

        howToReadAccuracySection = React__default.createElement("div", {
          className: styles.rightText
        }, React__default.createElement("div", {
          className: styles.textRow
        }, React__default.createElement("div", {
          className: styles.colorBlock,
          style: {
            backgroundColor: ChartColors[1]
          }
        }), React__default.createElement("div", null, React__default.createElement(Text$1, {
          block: true
        }, localization.Report.underestimationError), React__default.createElement(Text$1, {
          block: true
        }, localization.Report.underpredictionExplanation))), React__default.createElement("div", {
          className: styles.textRow
        }, React__default.createElement("div", {
          className: styles.colorBlock,
          style: {
            backgroundColor: ChartColors[0]
          }
        }), React__default.createElement("div", null, React__default.createElement(Text$1, {
          block: true
        }, localization.Report.overestimationError), React__default.createElement(Text$1, {
          block: true
        }, localization.Report.overpredictionExplanation))), React__default.createElement(Text$1, {
          block: true
        }, localization.Report.classificationAccuracyHowToRead1), React__default.createElement(Text$1, {
          block: true
        }, localization.Report.classificationAccuracyHowToRead2), React__default.createElement(Text$1, {
          block: true
        }, localization.Report.classificationAccuracyHowToRead3));
        howToReadOutcomesSection = React__default.createElement(Text$1, {
          className: styles.textRow,
          block: true
        }, localization.Report.classificationOutcomesHowToRead);
      }

      if (this.props.dashboardContext.modelMetadata.PredictionType === PredictionTypes.probability) {
        var _this$state$metrics$b4, _this$state$metrics$b5, _this$state$metrics$b6, _this$state$metrics$p;

        accuracyPlot.data = [{
          x: this.state.metrics.binnedOverprediction,
          y: nameIndex,
          text: (_this$state$metrics$b4 = this.state.metrics.binnedOverprediction) === null || _this$state$metrics$b4 === void 0 ? void 0 : _this$state$metrics$b4.map(function (num) {
            return FormatMetrics.formatNumbers(num, "overprediction", false, 2);
          }),
          name: localization.Metrics.overprediction,
          width: 0.5,
          fillcolor: ChartColors[0],
          orientation: "h",
          type: "bar",
          textposition: "inside",
          hoverinfo: "skip"
        }, {
          x: (_this$state$metrics$b5 = this.state.metrics.binnedUnderprediction) === null || _this$state$metrics$b5 === void 0 ? void 0 : _this$state$metrics$b5.map(function (x) {
            return -1 * x;
          }),
          y: nameIndex,
          text: (_this$state$metrics$b6 = this.state.metrics.binnedUnderprediction) === null || _this$state$metrics$b6 === void 0 ? void 0 : _this$state$metrics$b6.map(function (num) {
            return FormatMetrics.formatNumbers(num, "underprediction", false, 2);
          }),
          name: localization.Metrics.underprediction,
          width: 0.5,
          fillcolor: ChartColors[1],
          orientation: "h",
          type: "bar",
          textposition: "inside",
          hoverinfo: "skip",
          textfont: {
            color: theme$2.palette.black
          }
        }];

        if (accuracyPlot.layout) {
          accuracyPlot.layout.annotations = [{
            text: localization.Report.underestimationError,
            x: 0.1,
            y: 1,
            yref: "paper",
            xref: "paper",
            showarrow: false,
            font: {
              color: theme$2.semanticColors.bodyText,
              size: 10
            }
          }, {
            text: localization.Report.overestimationError,
            x: 0.9,
            y: 1,
            yref: "paper",
            xref: "paper",
            showarrow: false,
            font: {
              color: theme$2.semanticColors.bodyText,
              size: 10
            }
          }];
        }

        var opportunityText = (_this$state$metrics$p = this.state.metrics.predictions) === null || _this$state$metrics$p === void 0 ? void 0 : _this$state$metrics$p.map(function (val) {
          return localization.formatString(localization.Report.tooltipPrediction, FormatMetrics.formatNumbers(val, "average", false, 3));
        });
        opportunityPlot.data = [{
          x: this.state.metrics.predictions,
          y: this.props.dashboardContext.binVector,
          text: opportunityText,
          type: "box",
          color: ChartColors[0],
          boxmean: true,
          orientation: "h",
          boxpoints: "all",
          hoverinfo: "text",
          hoveron: "points",
          jitter: 0.4,
          pointpos: 0
        }];
        howToReadAccuracySection = React__default.createElement("div", null, React__default.createElement("div", {
          className: styles.textRow
        }, React__default.createElement("div", {
          className: styles.colorBlock,
          style: {
            backgroundColor: ChartColors[0]
          }
        }), React__default.createElement(Text$1, {
          block: true
        }, localization.Report.overestimationError)), React__default.createElement("div", {
          className: styles.textRow
        }, React__default.createElement("div", {
          className: styles.colorBlock,
          style: {
            backgroundColor: ChartColors[1]
          }
        }), React__default.createElement(Text$1, {
          block: true
        }, localization.Report.underestimationError)), React__default.createElement(Text$1, {
          className: styles.textRow,
          block: true
        }, localization.Report.probabilityAccuracyHowToRead1), React__default.createElement(Text$1, {
          className: styles.textRow,
          block: true
        }, localization.Report.probabilityAccuracyHowToRead2), React__default.createElement(Text$1, {
          className: styles.textRow,
          block: true
        }, localization.Report.probabilityAccuracyHowToRead3));
        howToReadOutcomesSection = React__default.createElement("div", null, React__default.createElement(Text$1, {
          className: styles.textRow,
          block: true
        }, localization.Report.regressionOutcomesHowToRead));
        opportunityChartHeader = localization.Report.distributionOfPredictions;
      }

      if (this.props.dashboardContext.modelMetadata.PredictionType === PredictionTypes.regression) {
        var _this$state$metrics$p2, _this$state$metrics$p3;

        var _opportunityText = (_this$state$metrics$p2 = this.state.metrics.predictions) === null || _this$state$metrics$p2 === void 0 ? void 0 : _this$state$metrics$p2.map(function (val) {
          return localization.formatString(localization.Report.tooltipPrediction, val);
        });

        var accuracyText = (_this$state$metrics$p3 = this.state.metrics.predictions) === null || _this$state$metrics$p3 === void 0 ? void 0 : _this$state$metrics$p3.map(function (val, index) {
          var _this2$state$metrics;

          return "".concat(localization.formatString(localization.Report.tooltipError, FormatMetrics.formatNumbers(((_this2$state$metrics = _this2.state.metrics) === null || _this2$state$metrics === void 0 ? void 0 : _this2$state$metrics.errors) ? _this2.state.metrics.errors[index] : undefined, "average", false, 3)), "<br>").concat(localization.formatString(localization.Report.tooltipPrediction, FormatMetrics.formatNumbers(val, "average", false, 3)));
        });
        accuracyPlot.data = [{
          x: this.state.metrics.errors,
          y: this.props.dashboardContext.binVector,
          text: accuracyText,
          type: "box",
          color: ChartColors[0],
          orientation: "h",
          boxmean: true,
          hoveron: "points",
          hoverinfo: "text",
          boxpoints: "all",
          jitter: 0.4,
          pointpos: 0
        }];
        opportunityPlot.data = [{
          x: this.state.metrics.predictions,
          y: this.props.dashboardContext.binVector,
          text: _opportunityText,
          type: "box",
          color: ChartColors[0],
          boxmean: true,
          orientation: "h",
          hoveron: "points",
          boxpoints: "all",
          hoverinfo: "text",
          jitter: 0.4,
          pointpos: 0
        }];
        howToReadAccuracySection = React__default.createElement("div", null, React__default.createElement(Text$1, {
          className: styles.textRow,
          block: true
        }, localization.Report.regressionAccuracyHowToRead));
        howToReadOutcomesSection = React__default.createElement("div", null, React__default.createElement(Text$1, {
          className: styles.textRow,
          block: true
        }, localization.Report.regressionOutcomesHowToRead));
        opportunityChartHeader = localization.Report.distributionOfPredictions;
        accuracyChartHeader = localization.Report.distributionOfErrors;
      }

      var globalAccuracyString = FormatMetrics.formatNumbers(this.state.metrics.globalAccuracy, accuracyKey);
      var disparityAccuracyString = FormatMetrics.formatNumbers(this.state.metrics.accuracyDisparity, accuracyKey);
      var selectedMetric = AccuracyOptions[this.props.accuracyPickerProps.selectedAccuracyKey] || this.props.accuracyPickerProps.accuracyOptions.find(function (metric) {
        return metric.key === _this2.props.accuracyPickerProps.selectedAccuracyKey;
      });
      var globalOutcomeString = FormatMetrics.formatNumbers(this.state.metrics.globalOutcome, outcomeKey);
      var disparityOutcomeString = FormatMetrics.formatNumbers(this.state.metrics.outcomeDisparity, outcomeKey);
      var formattedBinAccuracyValues = this.state.metrics.binnedAccuracy.map(function (value) {
        return FormatMetrics.formatNumbers(value, accuracyKey);
      });
      var formattedBinOutcomeValues = this.state.metrics.binnedOutcome.map(function (value) {
        return FormatMetrics.formatNumbers(value, outcomeKey);
      });
      return React__default.createElement("div", {
        style: {
          height: "100%",
          overflowY: "auto"
        }
      }, React__default.createElement("div", {
        className: styles.header
      }, this.props.modelCount > 1 && React__default.createElement("div", {
        className: styles.multimodelSection
      }, React__default.createElement(ActionButton$1, {
        className: styles.multimodelButton,
        iconProps: {
          iconName: "ChevronLeft"
        },
        onClick: this.clearModelSelection
      }, localization.Report.backToComparisonsLegacy), React__default.createElement(Text$1, {
        variant: "large",
        className: styles.modelLabel
      }, this.props.dashboardContext.modelNames[this.props.selectedModelIndex])), React__default.createElement(Text$1, {
        variant: "mediumPlus",
        className: styles.headerTitle
      }, localization.Report.title), React__default.createElement("div", {
        className: styles.bannerWrapper
      }, React__default.createElement("div", {
        className: styles.headerBanner
      }, React__default.createElement(Text$1, {
        className: styles.metricText,
        block: true
      }, globalAccuracyString), React__default.createElement(Text$1, {
        className: styles.firstMetricLabel,
        block: true
      }, localization.formatString(localization.Report.globalAccuracyText, selectedMetric.alwaysUpperCase ? selectedMetric.title : selectedMetric.title.toLowerCase())), React__default.createElement(Text$1, {
        className: styles.metricText,
        block: true
      }, disparityAccuracyString), React__default.createElement(Text$1, {
        className: styles.metricLabel,
        block: true
      }, localization.formatString(localization.Report.accuracyDisparityText, selectedMetric.alwaysUpperCase ? selectedMetric.title : selectedMetric.title.toLowerCase()))), React__default.createElement(ActionButton$1, {
        iconProps: {
          iconName: "Edit"
        },
        onClick: this.onEditConfigs,
        autoFocus: true
      }, localization.Report.editConfiguration))), React__default.createElement("div", {
        className: styles.presentationArea,
        style: {
          height: "".concat(areaHeights, "px")
        }
      }, React__default.createElement(SummaryTable, {
        binGroup: this.props.dashboardContext.modelMetadata.featureNames[this.props.featureBinPickerProps.selectedBinIndex],
        binLabels: this.props.dashboardContext.groupNames,
        formattedBinValues: formattedBinAccuracyValues,
        metricLabel: selectedMetric.title,
        binValues: this.state.metrics.binnedAccuracy
      }), React__default.createElement("div", {
        className: styles.chartWrapper
      }, React__default.createElement(Text$1, {
        variant: "small",
        className: styles.chartHeader
      }, accuracyChartHeader), React__default.createElement("div", {
        className: styles.chartBody
      }, React__default.createElement(AccessibleChart, {
        plotlyProps: accuracyPlot,
        theme: undefined
      }))), React__default.createElement("div", {
        className: styles.mainRight
      }, React__default.createElement(Text$1, {
        className: styles.rightTitle,
        block: true
      }, localization.ModelComparison.howToRead), howToReadAccuracySection)), React__default.createElement("div", {
        className: styles.header
      }, React__default.createElement(Text$1, {
        variant: "mediumPlus",
        className: styles.headerTitle
      }, localization.Report.outcomesTitle), React__default.createElement("div", {
        className: styles.bannerWrapper
      }, React__default.createElement("div", {
        className: styles.headerBanner
      }, React__default.createElement(Text$1, {
        variant: "xxLargePlus",
        className: styles.metricText,
        block: true
      }, globalOutcomeString), React__default.createElement(Text$1, {
        className: styles.firstMetricLabel,
        block: true
      }, localization.formatString(localization.Report.globalAccuracyText, outcomeMetric.title.toLowerCase())), React__default.createElement(Text$1, {
        variant: "xxLargePlus",
        className: styles.metricText,
        block: true
      }, disparityOutcomeString), React__default.createElement(Text$1, {
        className: styles.metricLabel,
        block: true
      }, localization.formatString(localization.Report.accuracyDisparityText, outcomeMetric.title.toLowerCase()))))), React__default.createElement("div", {
        className: styles.presentationArea,
        style: {
          height: "".concat(areaHeights, "px")
        }
      }, React__default.createElement(SummaryTable, {
        binGroup: this.props.dashboardContext.modelMetadata.featureNames[this.props.featureBinPickerProps.selectedBinIndex],
        binLabels: this.props.dashboardContext.groupNames,
        formattedBinValues: formattedBinOutcomeValues,
        metricLabel: outcomeMetric.title,
        binValues: this.state.metrics.binnedOutcome
      }), React__default.createElement("div", {
        className: styles.chartWrapper
      }, React__default.createElement(Text$1, {
        variant: "small",
        className: styles.chartHeader,
        block: true
      }, opportunityChartHeader), React__default.createElement("div", {
        className: styles.chartBody
      }, React__default.createElement(AccessibleChart, {
        plotlyProps: opportunityPlot,
        theme: undefined
      }))), React__default.createElement("div", {
        className: styles.mainRight
      }, React__default.createElement(Text$1, {
        className: styles.rightTitle,
        block: true
      }, localization.ModelComparison.howToRead), React__default.createElement(Text$1, {
        className: styles.rightText,
        block: true
      }, howToReadOutcomesSection))));
    }
  }, {
    key: "loadData",
    value: function () {
      var _loadData = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
        var _this3 = this;

        var binnedOverprediction, binnedUnderprediction, predictions, errors, outcomes, outcomeDisparity, accuracy, accuracyDisparity;
        return regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.prev = 0;
                _context.next = 3;
                return this.props.metricsCache.getMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, this.props.accuracyPickerProps.selectedAccuracyKey);

              case 3:
                accuracy = _context.sent;
                _context.next = 6;
                return this.props.metricsCache.getDisparityMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, this.props.accuracyPickerProps.selectedAccuracyKey, ParityModes.difference);

              case 6:
                accuracyDisparity = _context.sent;
                _context.t0 = this.props.dashboardContext.modelMetadata.PredictionType;
                _context.next = _context.t0 === PredictionTypes.binaryClassification ? 10 : _context.t0 === PredictionTypes.probability ? 23 : _context.t0 === PredictionTypes.regression ? 37 : 37;
                break;

              case 10:
                _context.next = 12;
                return this.props.metricsCache.getMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "underprediction");

              case 12:
                binnedUnderprediction = _context.sent.bins;
                _context.next = 15;
                return this.props.metricsCache.getMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "overprediction");

              case 15:
                binnedOverprediction = _context.sent.bins;
                _context.next = 18;
                return this.props.metricsCache.getMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "selection_rate");

              case 18:
                outcomes = _context.sent;
                _context.next = 21;
                return this.props.metricsCache.getDisparityMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "selection_rate", ParityModes.difference);

              case 21:
                outcomeDisparity = _context.sent;
                return _context.abrupt("break", 46);

              case 23:
                predictions = this.props.dashboardContext.predictions[this.props.selectedModelIndex];
                _context.next = 26;
                return this.props.metricsCache.getMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "overprediction");

              case 26:
                binnedOverprediction = _context.sent.bins;
                _context.next = 29;
                return this.props.metricsCache.getMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "underprediction");

              case 29:
                binnedUnderprediction = _context.sent.bins;
                _context.next = 32;
                return this.props.metricsCache.getMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "average");

              case 32:
                outcomes = _context.sent;
                _context.next = 35;
                return this.props.metricsCache.getDisparityMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "average", ParityModes.difference);

              case 35:
                outcomeDisparity = _context.sent;
                return _context.abrupt("break", 46);

              case 37:
                predictions = this.props.dashboardContext.predictions[this.props.selectedModelIndex];
                errors = predictions.map(function (predicted, index) {
                  return predicted - _this3.props.dashboardContext.trueY[index];
                });
                _context.next = 41;
                return this.props.metricsCache.getMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "average");

              case 41:
                outcomes = _context.sent;
                _context.next = 44;
                return this.props.metricsCache.getDisparityMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "average", ParityModes.difference);

              case 44:
                outcomeDisparity = _context.sent;
                return _context.abrupt("break", 46);

              case 46:
                this.setState({
                  metrics: {
                    globalAccuracy: accuracy.global,
                    binnedAccuracy: accuracy.bins,
                    accuracyDisparity: accuracyDisparity,
                    globalOutcome: outcomes.global,
                    binnedOutcome: outcomes.bins,
                    outcomeDisparity: outcomeDisparity,
                    predictions: predictions,
                    errors: errors,
                    binnedOverprediction: binnedOverprediction,
                    binnedUnderprediction: binnedUnderprediction
                  }
                });
                _context.next = 51;
                break;

              case 49:
                _context.prev = 49;
                _context.t1 = _context["catch"](0);

              case 51:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, this, [[0, 49]]);
      }));

      function loadData() {
        return _loadData.apply(this, arguments);
      }

      return loadData;
    }()
  }]);

  return WizardReport;
}(React__default.PureComponent);
WizardReport.barPlotlyProps = {
  config: {
    displaylogo: false,
    responsive: true,
    modeBarButtonsToRemove: ["toggleSpikelines", "hoverClosestCartesian", "hoverCompareCartesian", "zoom2d", "pan2d", "select2d", "lasso2d", "zoomIn2d", "zoomOut2d", "autoScale2d", "resetScale2d"]
  },
  data: [{
    orientation: "h",
    type: "bar"
  }],
  layout: {
    autosize: true,
    barmode: "relative",
    font: {
      size: 10
    },
    margin: {
      t: 4,
      l: 0,
      r: 0,
      b: 20
    },
    showlegend: false,
    hovermode: "closest",
    plot_bgcolor: theme$2.semanticColors.bodyFrameBackground,
    xaxis: {
      fixedrange: true,
      autorange: true,
      mirror: true,
      linecolor: theme$2.semanticColors.disabledBorder,
      linewidth: 1
    },
    yaxis: {
      fixedrange: true,
      showticklabels: false,
      showgrid: true,
      dtick: 1,
      tick0: 0.5,
      gridcolor: theme$2.semanticColors.disabledBorder,
      gridwidth: 1,
      autorange: "reversed"
    }
  }
};

var FairnessWizardStyles = function FairnessWizardStyles() {
  var theme = getTheme$1();
  return mergeStyleSets$1({
    frame: {
      minHeight: "800px",
      minWidth: "800px"
    },
    thinHeader: {
      height: "36px",
      backgroundColor: theme.semanticColors.bodyBackground,
      color: theme.semanticColors.bodyText
    },
    headerLeft: {
      padding: "20px"
    },
    pivot: {
      flex: 1,
      display: "flex",
      flexDirection: "column",
      padding: "30px 90px 0 82px"
    },
    body: {
      flex: 1,
      display: "flex",
      flexDirection: "column",
      backgroundColor: theme.semanticColors.bodyBackground
    },
    errorMessage: {
      padding: "50px",
      fontSize: "18px"
    }
  });
};

var defaultTheme = createTheme$1({
  palette: {
    themePrimary: "#0078d4",
    themeLighterAlt: "#eff6fc",
    themeLighter: "#deecf9",
    themeLight: "#c7e0f4",
    themeTertiary: "#71afe5",
    themeSecondary: "#2b88d8",
    themeDarkAlt: "#106ebe",
    themeDark: "#005a9e",
    themeDarker: "#004578",
    neutralLighterAlt: "#faf9f8",
    neutralLighter: "#f3f2f1",
    neutralLight: "#edebe9",
    neutralQuaternaryAlt: "#e1dfdd",
    neutralQuaternary: "#d0d0d0",
    neutralTertiaryAlt: "#c8c6c4",
    neutralTertiary: "#a19f9d",
    neutralSecondary: "#605e5c",
    neutralPrimaryAlt: "#3b3a39",
    neutralPrimary: "#323130",
    neutralDark: "#201f1e",
    black: "#000000",
    white: "#ffffff"
  }
});

var introTabKey = "introTab";
var featureBinTabKey = "featureBinTab";
var accuracyTabKey = "accuracyTab";
var disparityTabKey = "disparityTab";
var reportTabKey = "reportTab";
var flights = {
  skipDisparity: true
};
var FairnessWizardV1 = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(FairnessWizardV1, _React$PureComponent);

  var _super = _createSuper(FairnessWizardV1);

  function FairnessWizardV1(props) {
    var _this;

    _classCallCheck(this, FairnessWizardV1);

    _this = _super.call(this, props);

    _this.setTab = function (key) {
      _this.setState({
        activeTabKey: key
      });
    };

    _this.onSelectModel = function (data) {
      if (!data) {
        _this.setState({
          selectedModelId: undefined
        });

        return;
      }

      if (data.points && data.points[0]) {
        _this.setState({
          selectedModelId: data.points[0].customdata
        });
      }
    };

    _this.setAccuracyKey = function (key) {
      var value = {
        selectedAccuracyKey: key
      };

      {
        value.selectedParityKey = key;
      }

      _this.setState(value);
    };

    _this.setParityKey = function (key) {
      _this.setState({
        selectedParityKey: key
      });
    };

    _this.setBinIndex = function (index) {
      if (_this.props.precomputedMetrics) {
        var newContext = _.cloneDeep(_this.state.dashboardContext);

        newContext.binVector = _this.props.precomputedFeatureBins[index].binVector;
        newContext.groupNames = _this.props.precomputedFeatureBins[index].binLabels;

        _this.setState({
          dashboardContext: newContext,
          selectedBinIndex: index
        });
      } else {
        _this.binningSet(_this.state.featureBins[index]);
      }
    };

    _this.handleTabClick = function (item) {
      if (item && item.props.itemKey) {
        _this.setState({
          activeTabKey: item.props.itemKey
        });
      }
    };

    _this.binningSet = function (value) {
      if (!value || value.hasError || value.array.length === 0) {
        return;
      }

      var newContext = _.cloneDeep(_this.state.dashboardContext);

      newContext.binVector = WizardBuilder.generateBinVectorForBin(value, _this.state.dashboardContext.dataset);
      newContext.groupNames = value.labelArray;

      _this.setState({
        dashboardContext: newContext,
        selectedBinIndex: value.featureIndex
      });
    };

    _this.saveBin = function (bin) {
      var newBin = _toConsumableArray(_this.state.featureBins);

      newBin[bin.featureIndex] = bin;

      _this.setState({
        featureBins: newBin
      });

      _this.state.metricCache.clearCache(bin.featureIndex);

      _this.binningSet(bin);
    };

    WizardBuilder.initializeIcons(props);

    if (_this.props.locale) {
      localization.setLanguage(_this.props.locale);
    }

    var accuracyMetrics;
    loadTheme(props.theme || defaultTheme); // handle the case of precomputed metrics separately. As it becomes more defined, can integrate with existing code path.

    if (_this.props.precomputedMetrics && _this.props.precomputedFeatureBins) {
      // we must assume that the same accuracy metrics are provided across models and bins
      accuracyMetrics = WizardBuilder.buildAccuracyListForPrecomputedMetrics(_this.props);

      var readonlyFeatureBins = _this.props.precomputedFeatureBins.map(function (initialBin, index) {
        return {
          hasError: false,
          array: initialBin.binLabels,
          labelArray: initialBin.binLabels,
          featureIndex: index,
          rangeType: RangeTypes.categorical
        };
      });

      _this.state = {
        accuracyMetrics: accuracyMetrics,
        selectedAccuracyKey: accuracyMetrics[0].key,
        parityMetrics: accuracyMetrics,
        selectedParityKey: accuracyMetrics[0].key,
        dashboardContext: WizardBuilder.buildPrecomputedFairnessContext(_this.props),
        activeTabKey: featureBinTabKey,
        featureBins: readonlyFeatureBins,
        selectedBinIndex: 0,
        selectedModelId: _this.props.predictedY.length === 1 ? 0 : undefined,
        metricCache: new MetricsCache(0, 0, undefined, props.precomputedMetrics)
      };
      return _possibleConstructorReturn(_this);
    }

    var fairnessContext = WizardBuilder.buildInitialFairnessContext(_this.props);
    var featureBins = WizardBuilder.buildFeatureBins(fairnessContext);

    if (featureBins.length > 0) {
      fairnessContext.binVector = WizardBuilder.generateBinVectorForBin(featureBins[0], fairnessContext.dataset);
      fairnessContext.groupNames = featureBins[0].labelArray;
    }

    accuracyMetrics = _this.getAccuracyMetrics(fairnessContext);
    accuracyMetrics = accuracyMetrics.filter(function (metric) {
      return !!metric;
    });
    _this.state = {
      accuracyMetrics: accuracyMetrics,
      selectedAccuracyKey: accuracyMetrics[0].key,
      parityMetrics: accuracyMetrics,
      selectedParityKey: accuracyMetrics[0].key,
      dashboardContext: fairnessContext,
      activeTabKey: introTabKey,
      featureBins: featureBins,
      selectedBinIndex: 0,
      selectedModelId: _this.props.predictedY.length === 1 ? 0 : undefined,
      metricCache: new MetricsCache(featureBins.length, _this.props.predictedY.length, _this.props.requestMetrics)
    };
    return _this;
  }

  _createClass(FairnessWizardV1, [{
    key: "componentDidUpdate",
    value: function componentDidUpdate(prev) {
      if (prev.theme !== this.props.theme) {
        loadTheme(this.props.theme || defaultTheme);
      }

      if (this.props.locale && prev.locale !== this.props.locale) {
        localization.setLanguage(this.props.locale);
      }
    }
  }, {
    key: "render",
    value: function render() {
      var styles = FairnessWizardStyles();
      var accuracyPickerProps = {
        accuracyOptions: this.state.accuracyMetrics,
        selectedAccuracyKey: this.state.selectedAccuracyKey,
        onAccuracyChange: this.setAccuracyKey
      };
      var parityPickerProps = {
        parityOptions: this.state.parityMetrics,
        selectedParityKey: this.state.selectedParityKey,
        onParityChange: this.setParityKey
      };
      var featureBinPickerProps = {
        featureBins: this.state.featureBins,
        selectedBinIndex: this.state.selectedBinIndex,
        onBinChange: this.setBinIndex
      };

      if (this.state.featureBins.length === 0) {
        return React__default.createElement(Stack$1, {
          className: styles.frame
        }, React__default.createElement(Stack$1, {
          horizontal: true,
          horizontalAlign: "space-between",
          verticalAlign: "center",
          className: styles.thinHeader
        }), React__default.createElement(Stack$1.Item, {
          grow: 2,
          className: styles.body
        }, React__default.createElement(Text$1, {
          variant: "mediumPlus"
        }, localization.errorOnInputs)));
      }

      return React__default.createElement(Stack$1, {
        className: styles.frame
      }, React__default.createElement(Stack$1, {
        horizontal: true,
        horizontalAlign: "space-between",
        verticalAlign: "center",
        className: styles.thinHeader
      }), this.state.activeTabKey === introTabKey && React__default.createElement(StackItem$1, {
        grow: 2,
        className: styles.body
      }, React__default.createElement(IntroTab, {
        onNext: this.setTab.bind(this, featureBinTabKey)
      })), (this.state.activeTabKey === featureBinTabKey || this.state.activeTabKey === accuracyTabKey || this.state.activeTabKey === disparityTabKey) && React__default.createElement(Stack$1.Item, {
        grow: 2,
        className: styles.body
      }, React__default.createElement(Pivot, {
        className: styles.pivot,
        styles: {
          itemContainer: {
            height: "100%"
          }
        },
        selectedKey: this.state.activeTabKey,
        onLinkClick: this.handleTabClick
      }, React__default.createElement(PivotItem, {
        headerText: localization.Intro.features,
        itemKey: featureBinTabKey,
        style: {
          height: "100%",
          paddingLeft: "8px"
        }
      }, React__default.createElement(FeatureTab, {
        dashboardContext: this.state.dashboardContext,
        selectedFeatureChange: this.setBinIndex,
        selectedFeatureIndex: this.state.selectedBinIndex,
        featureBins: this.state.featureBins.filter(function (x) {
          return !!x;
        }),
        onNext: this.setTab.bind(this, accuracyTabKey),
        saveBin: this.saveBin
      })), React__default.createElement(PivotItem, {
        headerText: localization.accuracyMetricLegacy,
        itemKey: accuracyTabKey,
        style: {
          height: "100%",
          paddingLeft: "8px"
        }
      }, React__default.createElement(AccuracyTab, {
        dashboardContext: this.state.dashboardContext,
        accuracyPickerProps: accuracyPickerProps,
        onNext: this.setTab.bind(this,  reportTabKey ),
        onPrevious: this.setTab.bind(this, featureBinTabKey)
      })), flights.skipDisparity === false )), this.state.activeTabKey === reportTabKey && this.state.selectedModelId !== undefined && React__default.createElement(WizardReport, {
        dashboardContext: this.state.dashboardContext,
        metricsCache: this.state.metricCache,
        modelCount: this.props.predictedY.length,
        accuracyPickerProps: accuracyPickerProps,
        onChartClick: this.onSelectModel,
        parityPickerProps: parityPickerProps,
        featureBinPickerProps: featureBinPickerProps,
        selectedModelIndex: this.state.selectedModelId,
        onEditConfigs: this.setTab.bind(this, featureBinTabKey)
      }), this.state.activeTabKey === reportTabKey && this.state.selectedModelId === undefined && React__default.createElement(ModelComparisonChart, {
        dashboardContext: this.state.dashboardContext,
        metricsCache: this.state.metricCache,
        onChartClick: this.onSelectModel,
        modelCount: this.props.predictedY.length,
        accuracyPickerProps: accuracyPickerProps,
        parityPickerProps: parityPickerProps,
        featureBinPickerProps: featureBinPickerProps,
        onEditConfigs: this.setTab.bind(this, featureBinTabKey)
      }));
    }
  }, {
    key: "getAccuracyMetrics",
    value: function getAccuracyMetrics(fairnessContext) {
      if (fairnessContext.modelMetadata.PredictionType === PredictionTypes.binaryClassification) {
        return this.props.supportedBinaryClassificationAccuracyKeys.map(function (key) {
          return AccuracyOptions[key];
        });
      }

      if (fairnessContext.modelMetadata.PredictionType === PredictionTypes.regression) {
        return this.props.supportedRegressionAccuracyKeys.map(function (key) {
          return AccuracyOptions[key];
        });
      }

      return this.props.supportedProbabilityAccuracyKeys.map(function (key) {
        return AccuracyOptions[key];
      });
    }
  }]);

  return FairnessWizardV1;
}(React__default.PureComponent);

var AccuracyTabStyles$1 = function AccuracyTabStyles() {
  var theme = getTheme$1();
  return mergeStyleSets$1({
    iconClass: {
      fontSize: "20px",
      position: "absolute",
      right: "10px",
      top: "10px"
    },
    itemsList: {
      overflowY: "auto"
    },
    frame: {
      height: "100%"
    },
    main: {
      height: "100%",
      maxWidth: "750px",
      flex: 1
    },
    header: {
      color: theme.semanticColors.bodyText,
      fontWeight: FontWeights$1.semibold,
      margin: "26px 0"
    },
    textBody: {
      paddingTop: "12px",
      fontWeight: FontWeights$1.semilight,
      color: theme.semanticColors.bodyText,
      paddingBottom: "50px"
    }
  });
};

var TileListStyles$1 = function TileListStyles() {
  var theme = getTheme$1();
  return mergeStyleSets$1({
    container: {
      display: "inline-flex",
      flexDirection: "row",
      flexWrap: "wrap",
      justifyContent: "space-between",
      borderBottom: "1px solid",
      borderBottomColor: theme.semanticColors.bodyDivider
    },
    itemCell: {
      padding: "15px",
      width: "235px",
      position: "relative",
      "float": "left",
      cursor: "pointer",
      boxSizing: "border-box",
      backgroundColor: theme.semanticColors.bodyDivider,
      marginBottom: "10px",
      marginRight: "10px",
      selectors: {
        "&:hover": {
          background: theme.semanticColors.bodyBackgroundHovered
        }
      }
    },
    iconClass: {
      color: theme.semanticColors.accentButtonBackground,
      position: "absolute",
      right: "10px",
      top: "10px"
    },
    title: {
      color: theme.semanticColors.bodyText,
      paddingRight: "16px",
      margin: 0
    },
    description: {
      paddingTop: "10px",
      color: theme.semanticColors.bodySubtext
    }
  });
};

var TileList$1 = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(TileList, _React$PureComponent);

  var _super = _createSuper(TileList);

  function TileList() {
    var _this;

    _classCallCheck(this, TileList);

    _this = _super.apply(this, arguments);

    _this._onRenderCell = function (item, index, styles) {
      return React__default.createElement("div", {
        className: styles.itemCell,
        onClick: item.onSelect.bind(_assertThisInitialized(_this)),
        key: index,
        "data-is-focusable": true,
        role: "radio",
        "aria-checked": item.selected
      }, React__default.createElement(Icon$1, {
        iconName: item.selected ? "RadioBtnOn" : "RadioBtnOff",
        className: styles.iconClass
      }), React__default.createElement(Text$1, {
        className: styles.title,
        block: true
      }, item.title), React__default.createElement(Text$1, {
        className: styles.description
      }, item.description));
    };

    return _this;
  }

  _createClass(TileList, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var styles = TileListStyles$1();
      return React__default.createElement("div", {
        className: styles.container
      }, this.props.items.map(function (item, index) {
        return _this2._onRenderCell(item, index, styles);
      }));
    }
  }]);

  return TileList;
}(React__default.PureComponent);

var AccuracyTab$1 = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(AccuracyTab, _React$PureComponent);

  var _super = _createSuper(AccuracyTab);

  function AccuracyTab() {
    _classCallCheck(this, AccuracyTab);

    return _super.apply(this, arguments);
  }

  _createClass(AccuracyTab, [{
    key: "render",
    value: function render() {
      var _this = this;

      var styles = AccuracyTabStyles$1();
      return React__default.createElement(Stack, {
        horizontal: true,
        horizontalAlign: "space-between",
        className: styles.frame
      }, React__default.createElement(Stack, {
        className: styles.main
      }, React__default.createElement(Text$1, {
        className: styles.header,
        block: true
      }, localization.Accuracy.header), React__default.createElement(Text$1, {
        className: styles.textBody,
        block: true
      }, localization.formatString(localization.Accuracy.body, this.props.dashboardContext.modelMetadata.PredictionType !== PredictionTypes.regression ? localization.Accuracy.binary : localization.Accuracy.continuous, this.props.dashboardContext.modelMetadata.PredictionType === PredictionTypes.binaryClassification ? localization.Accuracy.binary : localization.Accuracy.continuous, this.props.dashboardContext.predictions.length === 1 ? localization.Accuracy.modelMakes : localization.Accuracy.modelsMake)), React__default.createElement(StackItem, {
        grow: 2,
        className: styles.itemsList
      }, React__default.createElement(FocusZone$1, {
        shouldFocusOnMount: true
      }, React__default.createElement(TileList$1, {
        items: this.props.accuracyPickerProps.accuracyOptions.map(function (accuracy) {
          return {
            title: accuracy.title,
            description: accuracy.description,
            onSelect: _this.props.accuracyPickerProps.onAccuracyChange.bind(_this, accuracy.key),
            selected: _this.props.accuracyPickerProps.selectedAccuracyKey === accuracy.key
          };
        })
      }))), React__default.createElement(WizardFooter, {
        onNext: this.props.onNext,
        onPrevious: this.props.onPrevious
      })), React__default.createElement(DataSpecificationBlade, {
        numberRows: this.props.dashboardContext.trueY.length,
        featureNames: this.props.dashboardContext.modelMetadata.featureNames
      }));
    }
  }]);

  return AccuracyTab;
}(React__default.PureComponent);

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var _ref = /*#__PURE__*/createElement("path", {
  d: "M9.5 121a8.5 8.5 0 100-17 8.5 8.5 0 000 17zM87.5 82a8.5 8.5 0 100-17 8.5 8.5 0 000 17zM169.5 155a8.5 8.5 0 10-.001-17.001A8.5 8.5 0 00169.5 155zM248.5 65a8.5 8.5 0 100-17 8.5 8.5 0 000 17zM348.5 18a8.5 8.5 0 100-17 8.5 8.5 0 000 17z",
  stroke: "#fff"
});

var _ref2 = /*#__PURE__*/createElement("path", {
  d: "M22 108l54-27M98.419 80.418L160 136M178.419 135.583l61.162-69.166M336.379 15.208l-76.172 34.167"
});

function SvgIntroTabIcon(props) {
  return /*#__PURE__*/createElement("svg", _extends({
    width: 358,
    height: 156
  }, props), _ref, _ref2);
}

var IntroTabStyles$1 = function IntroTabStyles() {
  var theme = getTheme$1();
  return mergeStyleSets$1({
    firstSection: {
      padding: "43px 94px",
      backgroundColor: theme.semanticColors.bodyBackground,
      color: theme.semanticColors.bodyText
    },
    firstSectionContainer: {
      width: "100%",
      height: "250px"
    },
    firstSectionTitle: {
      fontSize: "42px",
      lineHeight: "50px",
      fontWeight: FontWeights$1.light
    },
    firstSectionSubtitle: {
      fontSize: "42px",
      lineHeight: "50px",
      fontWeight: FontWeights$1.semibold
    },
    firstSectionBody: {
      paddingTop: "30px",
      paddingBottom: "70px",
      maxWidth: "500px",
      fontWeight: FontWeights$1.semilight,
      lineHeight: "24px"
    },
    firstSectionGraphics: {
      width: "346px",
      height: "154px",
      background: theme.semanticColors.bodyBackground,
      fill: theme.semanticColors.bodyText,
      stroke: theme.semanticColors.bodyText
    },
    lowerSection: {
      padding: "50px 70px 90px 90px",
      backgroundColor: theme.semanticColors.bodyBackground,
      color: theme.semanticColors.bodyText,
      flexGrow: 1
    },
    stepsContainer: {
      display: "flex",
      flexDirection: "row",
      justifyContent: "space-between",
      borderBottom: "1px solid",
      borderBottomColor: theme.semanticColors.bodyDivider,
      paddingBottom: "38px"
    },
    boldStep: {
      maxWidth: "300px",
      paddingRight: "25px",
      flex: 1
    },
    numericLabel: {
      fontWeight: FontWeights$1.bold,
      width: "20px",
      marginRight: "5px"
    },
    explanatoryStep: {
      maxWidth: "300px",
      paddingRight: "20px",
      flex: 1
    },
    explanatoryText: {
      paddingTop: "15px"
    },
    getStarted: {
      height: "44px",
      padding: "12px",
      lineHeight: "24px",
      fontSize: FontSizes$1.large,
      fontWeight: FontWeights$1.regular
    }
  });
};

var IntroTab$1 = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(IntroTab, _React$PureComponent);

  var _super = _createSuper(IntroTab);

  function IntroTab() {
    _classCallCheck(this, IntroTab);

    return _super.apply(this, arguments);
  }

  _createClass(IntroTab, [{
    key: "render",
    value: function render() {
      var styles = IntroTabStyles$1();
      return React__default.createElement(Stack$1, {
        style: {
          height: "100%"
        }
      }, React__default.createElement("div", {
        className: styles.firstSection
      }, React__default.createElement(Stack$1, {
        wrap: true,
        horizontalAlign: "start",
        className: styles.firstSectionContainer
      }, React__default.createElement(Text$1, {
        className: styles.firstSectionTitle,
        block: true
      }, localization.Intro.welcome), React__default.createElement(Text$1, {
        className: styles.firstSectionSubtitle,
        block: true
      }, localization.Intro.fairlearnDashboard), React__default.createElement(Text$1, {
        className: styles.firstSectionBody,
        variant: "large",
        block: true
      }, localization.Intro.introBody), React__default.createElement("div", {
        className: styles.firstSectionGraphics
      }, React__default.createElement(SvgIntroTabIcon, null)))), React__default.createElement("div", {
        className: styles.lowerSection
      }, React__default.createElement("div", {
        className: styles.stepsContainer
      }, React__default.createElement(Text$1, {
        variant: "large",
        className: styles.boldStep
      }, localization.Intro.explanatoryStep), React__default.createElement("div", {
        className: styles.explanatoryStep
      }, React__default.createElement("div", null, React__default.createElement(Text$1, {
        variant: "large",
        className: styles.numericLabel
      }, "01"), React__default.createElement(Text$1, {
        variant: "large"
      }, localization.Intro.features)), React__default.createElement(Text$1, {
        className: styles.explanatoryText,
        block: true
      }, localization.Intro.featuresInfo)), React__default.createElement("div", {
        className: styles.explanatoryStep
      }, React__default.createElement("div", null, React__default.createElement(Text$1, {
        variant: "large",
        className: styles.numericLabel
      }, "02"), React__default.createElement(Text$1, {
        variant: "large"
      }, localization.Intro.accuracy)), React__default.createElement(Text$1, {
        className: styles.explanatoryText,
        block: true
      }, localization.Intro.accuracyInfo)), React__default.createElement("div", {
        className: styles.explanatoryStep
      }, React__default.createElement("div", null, React__default.createElement(Text$1, {
        variant: "large",
        className: styles.numericLabel
      }, "03"), React__default.createElement(Text$1, {
        variant: "large"
      }, localization.Intro.parity)), React__default.createElement(Text$1, {
        className: styles.explanatoryText,
        block: true
      }, localization.Intro.parityInfo))), React__default.createElement(Stack$1, {
        horizontalAlign: "end",
        style: {
          marginTop: "20px"
        }
      }, React__default.createElement(PrimaryButton$1, {
        id: "nextButton",
        className: styles.getStarted,
        onClick: this.props.onNext
      }, localization.Intro.getStarted))));
    }
  }]);

  return IntroTab;
}(React__default.PureComponent);

var ModelComparisonChartStyles$1 = function ModelComparisonChartStyles() {
  var theme = getTheme$1();
  return mergeStyleSets$1({
    frame: {
      flex: 1,
      display: "flex",
      flexDirection: "column"
    },
    spinner: {
      margin: "auto",
      padding: "40px"
    },
    header: {
      backgroundColor: theme.semanticColors.bodyBackground,
      padding: "0 90px",
      height: "90px",
      display: "inline-flex",
      flexDirection: "row",
      justifyContent: "space-between",
      alignItems: "center"
    },
    headerTitle: {
      fontSize: "24px",
      color: theme.semanticColors.bodyText,
      fontWeight: FontWeights$1.semibold
    },
    headerOptions: {
      backgroundColor: theme.semanticColors.bodyBackground,
      padding: "0 100px"
    },
    dropDown: {
      margin: "10px 10px 10px 0px",
      display: "inline-block"
    },
    infoButton: {
      color: theme.semanticColors.bodyText,
      "float": "left",
      width: "15px",
      height: "15px",
      textAlign: "center",
      fontSize: "12px",
      lineHeight: "14px",
      fontWeight: "600",
      borderRadius: "50%",
      border: "1px solid",
      marginTop: "3px",
      marginRight: "3px"
    },
    doneButton: {
      margin: "auto",
      height: "44px",
      padding: "12px",
      lineHeight: "24px",
      color: theme.semanticColors.bodyText,
      fontSize: FontSizes$1.large,
      fontWeight: FontWeights$1.regular
    },
    modalContentIntro: {
      "float": "left",
      width: "250px"
    },
    modalContentIntroText: {
      padding: "0px 20px",
      textAlign: "center",
      wordWrap: "break-word"
    },
    modalContentHelp: {
      "float": "left",
      width: "250px"
    },
    modalContentHelpText: {
      padding: "0px 20px",
      textAlign: "center",
      wordWrap: "break-word"
    },
    editButton: {
      color: theme.semanticColors.buttonText
    },
    howTo: {
      paddingTop: "20px",
      paddingLeft: "100px"
    },
    main: {
      height: "100%",
      flex: 1,
      display: "inline-flex",
      flexDirection: "row",
      backgroundColor: theme.semanticColors.bodyBackground
    },
    mainLeft: {
      width: "75%",
      backgroundColor: theme.semanticColors.bodyBackground
    },
    mainRight: {
      padding: "30px 0 0 35px",
      width: "300px"
    },
    rightTitle: {
      color: theme.semanticColors.bodyText,
      paddingBottom: "18px",
      borderBottom: "1px solid",
      borderColor: theme.semanticColors.bodyDivider
    },
    rightText: {
      padding: "16px 15px 30px 0",
      color: theme.semanticColors.bodyText,
      borderBottom: "0.5px dashed",
      borderColor: theme.semanticColors.bodyDivider
    },
    insights: {
      textTransform: "uppercase",
      color: theme.semanticColors.bodyText,
      padding: "18px 10px",
      display: "inline"
    },
    insightsIcon: {
      verticalAlign: "middle",
      marginRight: "10px",
      width: "24",
      height: "28"
    },
    insightsText: {
      marginTop: "20px",
      paddingBottom: "18px",
      paddingRight: "15px",
      borderBottom: "1px solid",
      borderColor: theme.semanticColors.bodyDivider
    },
    downloadIcon: {
      verticalAlign: "middle",
      marginRight: "10px",
      width: "17",
      height: "18"
    },
    downloadReport: {
      color: theme.semanticColors.bodyText,
      fontSize: "12px",
      lineHeight: "16px",
      fontWeight: "normal",
      paddingTop: "20px",
      paddingBottom: "20px",
      paddingLeft: "0px"
    },
    chart: {
      padding: "0px 0 0 0",
      flex: 1
    },
    textSection: {
      color: theme.semanticColors.bodyText,
      paddingBottom: "5px"
    },
    radio: {
      paddingBottom: "30px",
      paddingLeft: "75px",
      backgroundColor: theme.semanticColors.bodyBackground
    },
    radioOptions: {
      color: theme.semanticColors.bodyText
    }
  });
};

var theme$3 = getTheme$1();
var ModelComparisonChart$1 = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(ModelComparisonChart, _React$PureComponent);

  var _super = _createSuper(ModelComparisonChart);

  function ModelComparisonChart(props) {
    var _this;

    _classCallCheck(this, ModelComparisonChart);

    _this = _super.call(this, props);
    _this.plotlyProps = {
      config: {
        displaylogo: false,
        responsive: true,
        modeBarButtonsToRemove: ["toggleSpikelines", "hoverClosestCartesian", "hoverCompareCartesian", "zoom2d", "pan2d", "select2d", "lasso2d", "zoomIn2d", "zoomOut2d", "autoScale2d", "resetScale2d"]
      },
      data: [{
        datapointLevelAccessors: {
          customdata: {
            path: ["index"],
            plotlyPath: "customdata"
          }
        },
        mode: PlotlyMode.textMarkers,
        marker: {
          size: 14
        },
        textposition: "top",
        type: "scatter",
        xAccessor: "Accuracy",
        yAccessor: "Parity",
        hoverinfo: "text"
      }],
      layout: {
        autosize: true,
        plot_bgcolor: theme$3.semanticColors.bodyFrameBackground,
        font: {
          size: 10
        },
        margin: {
          t: 4,
          r: 0
        },
        hovermode: "closest",
        xaxis: {
          automargin: true,
          fixedrange: true,
          mirror: true,
          linecolor: theme$3.semanticColors.disabledBorder,
          linewidth: 1,
          showgrid: false,
          title: {
            text: "Error"
          }
        },
        yaxis: {
          automargin: true,
          fixedrange: true,
          showgrid: false,
          title: {
            text: "Disparity"
          }
        }
      }
    };

    _this.featureChanged = function (_ev, option) {
      if (!option) {
        return;
      }

      var featureKey = option.key.toString();

      if (_this.state.featureKey !== featureKey) {
        _this.props.featureBinPickerProps.selectedBinIndex = _this.props.dashboardContext.modelMetadata.featureNames.indexOf(featureKey);

        _this.setState({
          featureKey: featureKey,
          accuracyArray: undefined,
          disparityArray: undefined
        });
      }
    };

    _this.accuracyChanged = function (_ev, option) {
      if (!option) {
        return;
      }

      var accuracyKey = option.key.toString();

      if (_this.state.accuracyKey !== accuracyKey) {
        _this.props.accuracyPickerProps.onAccuracyChange(accuracyKey);

        _this.setState({
          accuracyKey: accuracyKey,
          accuracyArray: undefined
        });
      }
    };

    _this.parityChanged = function (_ev, option) {
      if (!option) {
        return;
      }

      var parityKey = option.key.toString();

      if (_this.state.parityKey !== parityKey) {
        _this.props.parityPickerProps.onParityChange(parityKey);

        _this.setState({
          parityKey: parityKey,
          disparityArray: undefined
        });
      }
    };

    _this.handleCloseModalIntro = function () {
      _this.setState({
        showModalIntro: false
      });

      _this.props.onHideIntro();
    };

    _this.handleOpenModalHelp = function () {
      _this.setState({
        showModalHelp: true
      });
    };

    _this.handleCloseModalHelp = function () {
      _this.setState({
        showModalHelp: false
      });
    };

    _this.state = {
      showModalIntro: _this.props.showIntro,
      accuracyKey: _this.props.accuracyPickerProps.selectedAccuracyKey,
      parityKey: _this.props.parityPickerProps.selectedParityKey
    };
    return _this;
  }

  _createClass(ModelComparisonChart, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var featureOptions = this.props.dashboardContext.modelMetadata.featureNames.map(function (x) {
        return {
          key: x,
          text: x
        };
      });
      var accuracyOptions = this.props.accuracyPickerProps.accuracyOptions.map(function (x) {
        return {
          key: x.key,
          text: x.title
        };
      });
      var parityOptions = this.props.parityPickerProps.parityOptions.map(function (x) {
        return {
          key: x.key,
          text: x.title
        };
      });
      var dropdownStyles = {
        dropdown: {
          width: 180
        },
        title: {
          borderRadius: "5px"
        }
      };
      var iconButtonStyles = {
        root: {
          color: theme$3.semanticColors.bodyText,
          marginLeft: "auto",
          marginTop: "4px",
          marginRight: "2px"
        },
        rootHovered: {
          color: theme$3.semanticColors.bodyBackgroundHovered
        }
      };
      var styles = ModelComparisonChartStyles$1();
      var mainChart;

      if (!this.state || this.state.accuracyArray === undefined || this.state.disparityArray === undefined) {
        this.loadData();
        mainChart = React__default.createElement(Spinner$1, {
          className: styles.spinner,
          size: SpinnerSize$1.large,
          label: localization.calculating
        });
      } else {
        var _props$layout, _props$layout2;

        var disparityArray = this.state.disparityArray;
        var data = this.state.accuracyArray.map(function (accuracy, index) {
          return {
            Parity: disparityArray[index],
            Accuracy: accuracy,
            index: index
          };
        });
        var minAccuracy = Number.MAX_SAFE_INTEGER;
        var maxAccuracy = Number.MIN_SAFE_INTEGER;
        var maxDisparity = Number.MIN_SAFE_INTEGER;
        var minDisparity = Number.MAX_SAFE_INTEGER;
        var minAccuracyIndex = 0;
        var maxAccuracyIndex = 0;
        var minDisparityIndex = 0;
        this.state.accuracyArray.forEach(function (value, index) {
          if (value >= maxAccuracy) {
            maxAccuracyIndex = index;
            maxAccuracy = value;
          }

          if (value <= minAccuracy) {
            minAccuracyIndex = index;
            minAccuracy = value;
          }
        });
        this.state.disparityArray.forEach(function (value, index) {
          if (value >= maxDisparity) {
            maxDisparity = value;
          }

          if (value <= minDisparity) {
            minDisparityIndex = index;
            minDisparity = value;
          }
        });
        var formattedMinAccuracy = FormatMetrics.formatNumbers(minAccuracy, this.props.accuracyPickerProps.selectedAccuracyKey);
        var formattedMaxAccuracy = FormatMetrics.formatNumbers(maxAccuracy, this.props.accuracyPickerProps.selectedAccuracyKey);
        var formattedMinDisparity = FormatMetrics.formatNumbers(minDisparity, this.props.accuracyPickerProps.selectedAccuracyKey);
        var formattedMaxDisparity = FormatMetrics.formatNumbers(maxDisparity, this.props.accuracyPickerProps.selectedAccuracyKey);
        var selectedMetric = AccuracyOptions[this.props.accuracyPickerProps.selectedAccuracyKey] || this.props.accuracyPickerProps.accuracyOptions.find(function (metric) {
          return metric.key === _this2.props.accuracyPickerProps.selectedAccuracyKey;
        });
        var insights2 = localization.formatString(localization.ModelComparison.insightsText2, selectedMetric.title, formattedMinAccuracy, formattedMaxAccuracy, formattedMinDisparity, formattedMaxDisparity);
        var insights3 = localization.formatString(localization.ModelComparison.insightsText3, selectedMetric.title.toLowerCase(), selectedMetric.isMinimization ? formattedMinAccuracy : formattedMaxAccuracy, FormatMetrics.formatNumbers(this.state.disparityArray[selectedMetric.isMinimization ? minAccuracyIndex : maxAccuracyIndex], this.props.accuracyPickerProps.selectedAccuracyKey));
        var insights4 = localization.formatString(localization.ModelComparison.insightsText4, selectedMetric.title.toLowerCase(), FormatMetrics.formatNumbers(this.state.accuracyArray[minDisparityIndex], this.props.accuracyPickerProps.selectedAccuracyKey), formattedMinDisparity);

        var props = _.cloneDeep(this.plotlyProps);

        props.data = ChartBuilder.buildPlotlySeries(props.data[0], data).map(function (series) {
          if (series.name) {
            series.name = _this2.props.dashboardContext.modelNames[series.name];
          }

          series.text = _this2.props.dashboardContext.modelNames;
          return series;
        });
        var accuracyMetricTitle = selectedMetric.title;
        var parityMetricTitle = ParityOptions[this.props.parityPickerProps.selectedParityKey].title;

        if ((_props$layout = props.layout) === null || _props$layout === void 0 ? void 0 : _props$layout.xaxis) {
          props.layout.xaxis.title = accuracyMetricTitle;
        }

        if ((_props$layout2 = props.layout) === null || _props$layout2 === void 0 ? void 0 : _props$layout2.yaxis) {
          props.layout.yaxis.title = parityMetricTitle;
        }

        var InsightsIcon = function InsightsIcon() {
          return React__default.createElement(Icon$1, {
            iconName: "CRMCustomerInsightsApp",
            className: styles.insightsIcon
          });
        };

        var DownloadIcon = function DownloadIcon() {
          return React__default.createElement(Icon$1, {
            iconName: "Download",
            className: styles.downloadIcon
          });
        };

        var cancelIcon = {
          iconName: "Cancel"
        };
        mainChart = React__default.createElement("div", {
          className: styles.main
        }, React__default.createElement("div", {
          className: styles.mainLeft
        }, React__default.createElement("div", {
          className: styles.howTo
        }, React__default.createElement(Modal, {
          titleAriaId: "intro modal",
          isOpen: this.state.showModalIntro,
          onDismiss: this.handleCloseModalIntro,
          isModeless: true,
          containerClassName: styles.modalContentIntro
        }, React__default.createElement("div", {
          style: {
            display: "flex"
          }
        }, React__default.createElement(IconButton$1, {
          styles: iconButtonStyles,
          iconProps: cancelIcon,
          ariaLabel: "Close intro modal",
          onClick: this.handleCloseModalIntro
        })), React__default.createElement("p", {
          className: styles.modalContentIntroText
        }, localization.ModelComparison.introModalText), React__default.createElement("div", {
          style: {
            display: "flex",
            paddingBottom: "20px"
          }
        }, React__default.createElement(PrimaryButton$1, {
          className: styles.doneButton,
          onClick: this.handleCloseModalIntro
        }, localization.done))), React__default.createElement(ActionButton$1, {
          onClick: this.handleOpenModalHelp
        }, React__default.createElement("div", {
          className: styles.infoButton
        }, "i"), localization.ModelComparison.howToRead), React__default.createElement(Modal, {
          titleAriaId: "help modal",
          isOpen: this.state.showModalHelp,
          onDismiss: this.handleCloseModalHelp,
          isModeless: true,
          containerClassName: styles.modalContentHelp
        }, React__default.createElement("div", {
          style: {
            display: "flex"
          }
        }, React__default.createElement(IconButton$1, {
          styles: iconButtonStyles,
          iconProps: cancelIcon,
          ariaLabel: "Close popup modal",
          onClick: this.handleCloseModalHelp
        })), React__default.createElement("p", {
          className: styles.modalContentHelpText
        }, localization.ModelComparison.helpModalText1, React__default.createElement("br", null), React__default.createElement("br", null), localization.ModelComparison.helpModalText2), React__default.createElement("div", {
          style: {
            display: "flex",
            paddingBottom: "20px"
          }
        }, React__default.createElement(PrimaryButton$1, {
          className: styles.doneButton,
          onClick: this.handleCloseModalHelp
        }, localization.done)))), React__default.createElement("div", {
          className: styles.chart
        }, React__default.createElement(AccessibleChart, {
          plotlyProps: props,
          onClickHandler: this.props.onChartClick,
          theme: undefined
        }))), React__default.createElement("div", {
          className: styles.mainRight
        }, React__default.createElement("div", {
          className: styles.insights
        }, React__default.createElement(InsightsIcon, null), React__default.createElement(Text$1, {
          className: styles.insights,
          block: true
        }, localization.ModelComparison.insights)), React__default.createElement("div", {
          className: styles.insightsText
        }, React__default.createElement(Text$1, {
          className: styles.textSection,
          block: true
        }, insights2), React__default.createElement(Text$1, {
          className: styles.textSection,
          block: true
        }, insights3), React__default.createElement(Text$1, {
          className: styles.textSection,
          block: true
        }, insights4)), React__default.createElement("div", {
          className: styles.downloadReport
        }, React__default.createElement(DownloadIcon, null), React__default.createElement(Text$1, {
          style: {
            verticalAlign: "middle"
          }
        }, localization.ModelComparison.downloadReport))));
      }

      return React__default.createElement(Stack$1, {
        className: styles.frame
      }, React__default.createElement("div", {
        className: styles.header
      }, React__default.createElement(Text$1, {
        variant: "large",
        className: styles.headerTitle,
        block: true
      }, localization.ModelComparison.title, " ", React__default.createElement("b", null, "assessment"))), React__default.createElement("div", {
        className: styles.headerOptions
      }, React__default.createElement(Dropdown, {
        className: styles.dropDown,
        defaultSelectedKey: this.props.dashboardContext.modelMetadata.featureNames[this.props.featureBinPickerProps.selectedBinIndex],
        options: featureOptions,
        disabled: false,
        onChange: this.featureChanged,
        styles: dropdownStyles
      }), React__default.createElement(Dropdown, {
        className: styles.dropDown,
        defaultSelectedKey: this.props.accuracyPickerProps.selectedAccuracyKey,
        options: accuracyOptions,
        disabled: false,
        onChange: this.accuracyChanged,
        styles: dropdownStyles
      }), React__default.createElement(Dropdown, {
        className: styles.dropDown,
        defaultSelectedKey: this.props.parityPickerProps.selectedParityKey,
        options: parityOptions,
        disabled: false,
        onChange: this.parityChanged,
        styles: dropdownStyles
      })), mainChart);
    }
  }, {
    key: "loadData",
    value: function () {
      var _loadData = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
        var _this3 = this;

        var accuracyPromises, parityOption, disparityMetric, parityMode, disparityPromises, accuracyArray, disparityArray;
        return regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.prev = 0;
                accuracyPromises = new Array(this.props.modelCount).fill(0).map(function (_, modelIndex) {
                  return _this3.props.metricsCache.getMetric(_this3.props.dashboardContext.binVector, _this3.props.featureBinPickerProps.selectedBinIndex, modelIndex, _this3.props.accuracyPickerProps.selectedAccuracyKey);
                });
                parityOption = ParityOptions[this.props.parityPickerProps.selectedParityKey];
                disparityMetric = this.props.dashboardContext.modelMetadata.PredictionType === PredictionTypes.binaryClassification ? parityOption.parityMetric : "average";
                parityMode = parityOption.parityMode;
                disparityPromises = new Array(this.props.modelCount).fill(0).map(function (_, modelIndex) {
                  return _this3.props.metricsCache.getDisparityMetric(_this3.props.dashboardContext.binVector, _this3.props.featureBinPickerProps.selectedBinIndex, modelIndex, disparityMetric, parityMode);
                });
                _context.next = 8;
                return Promise.all(accuracyPromises);

              case 8:
                accuracyArray = _context.sent.map(function (metric) {
                  return metric.global;
                });
                _context.next = 11;
                return Promise.all(disparityPromises);

              case 11:
                disparityArray = _context.sent;
                this.setState({
                  accuracyArray: accuracyArray,
                  disparityArray: disparityArray
                });
                _context.next = 17;
                break;

              case 15:
                _context.prev = 15;
                _context.t0 = _context["catch"](0);

              case 17:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, this, [[0, 15]]);
      }));

      function loadData() {
        return _loadData.apply(this, arguments);
      }

      return loadData;
    }()
  }]);

  return ModelComparisonChart;
}(React__default.PureComponent);

var ParityTabStyles = function ParityTabStyles() {
  var theme = getTheme$1();
  return mergeStyleSets$1({
    iconClass: {
      fontSize: "20px",
      position: "absolute",
      right: "10px",
      top: "10px"
    },
    itemsList: {
      overflowY: "auto"
    },
    frame: {
      width: "750px",
      height: "100%"
    },
    main: {
      height: "100%",
      minWidth: "550px",
      flex: 1
    },
    header: {
      color: theme.semanticColors.bodyText,
      fontWeight: FontWeights$1.semibold,
      margin: "26px 0"
    },
    textBody: {
      fontWeight: FontWeights$1.semilight,
      color: theme.semanticColors.bodyText,
      paddingTop: "12px",
      paddingBottom: "50px"
    }
  });
};

var ParityTab$1 = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(ParityTab, _React$PureComponent);

  var _super = _createSuper(ParityTab);

  function ParityTab() {
    _classCallCheck(this, ParityTab);

    return _super.apply(this, arguments);
  }

  _createClass(ParityTab, [{
    key: "render",
    value: function render() {
      var _this = this;

      var styles = ParityTabStyles();
      return React__default.createElement(Stack$1, {
        horizontal: true,
        horizontalAlign: "space-between",
        className: styles.frame
      }, React__default.createElement(StackItem$1, {
        grow: 2
      }, React__default.createElement(Stack$1, {
        className: styles.main
      }, React__default.createElement(Text$1, {
        className: styles.header,
        block: true
      }, localization.Accuracy.header), React__default.createElement(Text$1, {
        className: styles.textBody,
        block: true
      }, localization.Parity.body), React__default.createElement(StackItem$1, {
        grow: 2,
        className: styles.itemsList
      }, React__default.createElement(TileList$1, {
        items: this.props.parityPickerProps.parityOptions.map(function (parity) {
          var selected = _this.props.parityPickerProps.selectedParityKey === parity.key;
          return {
            title: parity.title,
            description: parity.description,
            onSelect: _this.props.parityPickerProps.onParityChange.bind(_this, parity.key),
            selected: selected
          };
        })
      })), React__default.createElement(WizardFooter, {
        onNext: this.props.onNext,
        onPrevious: this.props.onPrevious
      }))), React__default.createElement(DataSpecificationBlade, {
        numberRows: this.props.dashboardContext.trueY.length,
        featureNames: this.props.dashboardContext.modelMetadata.featureNames
      }));
    }
  }]);

  return ParityTab;
}(React__default.PureComponent);

/**
 * Possible variations of the spinner circle size.
 * {@docCategory Spinner}
 */
var SpinnerSize;
(function (SpinnerSize) {
    /**
     * 12px Spinner diameter
     */
    SpinnerSize[SpinnerSize["xSmall"] = 0] = "xSmall";
    /**
     * 16px Spinner diameter
     */
    SpinnerSize[SpinnerSize["small"] = 1] = "small";
    /**
     * 20px Spinner diameter
     */
    SpinnerSize[SpinnerSize["medium"] = 2] = "medium";
    /**
     * 28px Spinner diameter
     */
    SpinnerSize[SpinnerSize["large"] = 3] = "large";
})(SpinnerSize || (SpinnerSize = {}));
/**
 * Deprecated at v2.0.0, use `SpinnerSize` instead.
 * @deprecated Use `SpinnerSize` instead.
 * {@docCategory Spinner}
 */
var SpinnerType;
(function (SpinnerType) {
    /**
     * Deprecated and will be removed at \>= 2.0.0. Use `SpinnerSize.medium` instead.
     * @deprecated Use `SpinnerSize.medium` instead.
     */
    SpinnerType[SpinnerType["normal"] = 0] = "normal";
    /**
     * Deprecated and will be removed at \>= 2.0.0. Use `SpinnerSize.large` instead.
     * @deprecated Use `SpinnerSize.large` instead.
     */
    SpinnerType[SpinnerType["large"] = 1] = "large";
})(SpinnerType || (SpinnerType = {}));

var getClassNames$8 = classNamesFunction();
var SpinnerBase = /** @class */ (function (_super) {
    __extends(SpinnerBase, _super);
    function SpinnerBase() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SpinnerBase.prototype.render = function () {
        // eslint-disable-next-line deprecation/deprecation
        var _a = this.props, type = _a.type, size = _a.size, ariaLabel = _a.ariaLabel, ariaLive = _a.ariaLive, styles = _a.styles, label = _a.label, theme = _a.theme, className = _a.className, labelPosition = _a.labelPosition;
        var statusMessage = ariaLabel;
        var nativeProps = getNativeProps(this.props, divProperties, ['size']);
        // SpinnerType is deprecated. If someone is still using this property, rather than putting the SpinnerType into the
        // ISpinnerStyleProps, we'll map SpinnerType to its equivalent SpinnerSize and pass that in. Once SpinnerType
        // finally goes away we should delete this.
        var styleSize = size;
        if (styleSize === undefined && type !== undefined) {
            // eslint-disable-next-line deprecation/deprecation
            styleSize = type === SpinnerType.large ? SpinnerSize.large : SpinnerSize.medium;
        }
        var classNames = getClassNames$8(styles, {
            theme: theme,
            size: styleSize,
            className: className,
            labelPosition: labelPosition,
        });
        return (createElement("div", __assign({}, nativeProps, { className: classNames.root }),
            createElement("div", { className: classNames.circle }),
            label && createElement("div", { className: classNames.label }, label),
            statusMessage && (createElement("div", { role: "status", "aria-live": ariaLive },
                createElement(DelayedRender, null,
                    createElement("div", { className: classNames.screenReaderText }, statusMessage))))));
    };
    SpinnerBase.defaultProps = {
        size: SpinnerSize.medium,
        ariaLive: 'polite',
        labelPosition: 'bottom',
    };
    return SpinnerBase;
}(Component));

var GlobalClassNames$8 = {
    root: 'ms-Spinner',
    circle: 'ms-Spinner-circle',
    label: 'ms-Spinner-label',
};
var spinAnimation = memoizeFunction(function () {
    return keyframes({
        '0%': {
            transform: 'rotate(0deg)',
        },
        '100%': {
            transform: 'rotate(360deg)',
        },
    });
});
var getStyles$c = function (props) {
    var _a;
    var theme = props.theme, size = props.size, className = props.className, labelPosition = props.labelPosition;
    var palette = theme.palette;
    var classNames = getGlobalClassNames(GlobalClassNames$8, theme);
    return {
        root: [
            classNames.root,
            {
                display: 'flex',
                flexDirection: 'column',
                alignItems: 'center',
                justifyContent: 'center',
            },
            labelPosition === 'top' && {
                flexDirection: 'column-reverse',
            },
            labelPosition === 'right' && {
                flexDirection: 'row',
            },
            labelPosition === 'left' && {
                flexDirection: 'row-reverse',
            },
            className,
        ],
        circle: [
            classNames.circle,
            {
                boxSizing: 'border-box',
                borderRadius: '50%',
                border: '1.5px solid ' + palette.themeLight,
                borderTopColor: palette.themePrimary,
                animationName: spinAnimation(),
                animationDuration: '1.3s',
                animationIterationCount: 'infinite',
                animationTimingFunction: 'cubic-bezier(.53,.21,.29,.67)',
                selectors: __assign((_a = {}, _a[HighContrastSelector] = {
                    borderTopColor: 'Highlight',
                }, _a), getEdgeChromiumNoHighContrastAdjustSelector()),
            },
            size === SpinnerSize.xSmall && [
                'ms-Spinner--xSmall',
                {
                    width: 12,
                    height: 12,
                },
            ],
            size === SpinnerSize.small && [
                'ms-Spinner--small',
                {
                    width: 16,
                    height: 16,
                },
            ],
            size === SpinnerSize.medium && [
                'ms-Spinner--medium',
                {
                    width: 20,
                    height: 20,
                },
            ],
            size === SpinnerSize.large && [
                'ms-Spinner--large',
                {
                    width: 28,
                    height: 28,
                },
            ],
        ],
        label: [
            classNames.label,
            theme.fonts.small,
            {
                color: palette.themePrimary,
                margin: '8px 0 0',
                textAlign: 'center',
            },
            labelPosition === 'top' && {
                margin: '0 0 8px',
            },
            labelPosition === 'right' && {
                margin: '0 0 0 8px',
            },
            labelPosition === 'left' && {
                margin: '0 8px 0 0',
            },
        ],
        screenReaderText: hiddenContentStyle,
    };
};

var Spinner = styled(SpinnerBase, getStyles$c, undefined, { scope: 'Spinner' });

var TextView = function (props) {
    if (Children.count(props.children) === 0) {
        return null;
    }
    var block = props.block, className = props.className, _a = props.as, RootType = _a === void 0 ? 'span' : _a, variant = props.variant, nowrap = props.nowrap, rest = __rest(props, ["block", "className", "as", "variant", "nowrap"]);
    var Slots = getSlots(props, {
        root: RootType,
    });
    return withSlots(Slots.root, __assign({}, getNativeProps(rest, htmlElementProperties)));
};

var TextStyles = function (props, theme) {
    var as = props.as, className = props.className, block = props.block, nowrap = props.nowrap, variant = props.variant;
    var fonts = theme.fonts;
    var variantObject = fonts[variant || 'medium'];
    return {
        root: [
            theme.fonts.medium,
            {
                display: block ? (as === 'td' ? 'table-cell' : 'block') : 'inline',
                fontFamily: variantObject.fontFamily,
                fontSize: variantObject.fontSize,
                fontWeight: variantObject.fontWeight,
                color: variantObject.color,
                mozOsxFontSmoothing: variantObject.MozOsxFontSmoothing,
                webkitFontSmoothing: variantObject.WebkitFontSmoothing,
            },
            nowrap && {
                whiteSpace: 'nowrap',
                overflow: 'hidden',
                textOverflow: 'ellipsis',
            },
            className,
        ],
    };
};

var Text = createComponent(TextView, {
    displayName: 'Text',
    styles: TextStyles,
});

var theme$4 = getTheme$1();
var ChartColors$1 = [theme$4.palette.blue, theme$4.palette.orangeLighter //"#ff7f0e"
];

var SummaryTableStyles$1 = function SummaryTableStyles() {
  var theme = getTheme$1();
  return mergeStyleSets$1({
    minMaxLabel: {
      padding: "1px 9px",
      marginTop: "4px",
      color: theme.semanticColors.bodySubtext,
      backgroundColor: theme.semanticColors.bodyStandoutBackground
    },
    groupCol: {
      display: "inline-flex",
      flexDirection: "column",
      height: "100%",
      width: "max-content"
    },
    groupLabel: {
      color: theme.semanticColors.bodyText,
      height: "26px"
    },
    flexCol: {
      display: "flex",
      flex: 1,
      flexDirection: "column",
      borderTop: "1px solid",
      borderBottom: "1px solid",
      borderColor: theme.semanticColors.bodyDivider
    },
    binBox: {
      flex: 1,
      width: "130px",
      display: "flex",
      flexDirection: "column",
      justifyContent: "center",
      borderBottom: "0.5px dashed",
      borderColor: theme.semanticColors.bodyDivider
    },
    binTitle: {
      color: theme.semanticColors.bodyText
    },
    metricCol: {
      display: "inline-flex",
      flexDirection: "column",
      height: "100%",
      width: "120px"
    },
    metricLabel: {
      color: theme.semanticColors.bodyText,
      height: "26px",
      paddingLeft: "10px"
    },
    metricBox: {
      flex: 1,
      paddingLeft: "10px",
      color: theme.semanticColors.bodyText,
      fontWeight: FontWeights$1.light,
      display: "flex",
      flexDirection: "column",
      justifyContent: "center",
      borderLeft: "0.5px dashed",
      borderBottom: "0.5px dashed",
      borderColor: theme.semanticColors.bodyDivider
    },
    frame: {
      paddingBottom: "19px",
      display: "flex"
    }
  });
};

var SummaryTable$1 = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(SummaryTable, _React$PureComponent);

  var _super = _createSuper(SummaryTable);

  function SummaryTable() {
    _classCallCheck(this, SummaryTable);

    return _super.apply(this, arguments);
  }

  _createClass(SummaryTable, [{
    key: "render",
    value: function render() {
      var styles = SummaryTableStyles$1();
      var minIndexes = [];
      var maxIndexes = [];
      var minValue = Number.MAX_SAFE_INTEGER;
      var maxValue = Number.MIN_SAFE_INTEGER;
      this.props.binValues.forEach(function (value, index) {
        if (value >= maxValue) {
          if (value === maxValue) {
            maxIndexes.push(index);
          } else {
            maxIndexes = [index];
            maxValue = value;
          }
        }

        if (value <= minValue) {
          if (value === minValue) {
            minIndexes.push(index);
          } else {
            minIndexes = [index];
            minValue = value;
          }
        }
      });
      return React__default.createElement("div", {
        className: styles.frame
      }, React__default.createElement("div", {
        className: styles.groupCol
      }, React__default.createElement(Text$1, {
        variant: "small",
        className: styles.groupLabel
      }, this.props.binGroup), React__default.createElement("div", {
        className: styles.flexCol
      }, this.props.binLabels.map(function (label, index) {
        return React__default.createElement("div", {
          className: styles.binBox,
          key: index
        }, React__default.createElement(Text$1, {
          className: styles.binTitle
        }, label));
      }))));
    }
  }]);

  return SummaryTable;
}(React__default.PureComponent);

var WizardReportStyles$1 = function WizardReportStyles() {
  var theme = getTheme$1();
  return mergeStyleSets$1({
    spinner: {
      margin: "auto",
      padding: "40px"
    },
    header: {
      padding: "0 100px 20px 100px",
      backgroundColor: theme.semanticColors.bodyBackground
    },
    multimodelButton: {
      marginTop: "20px",
      padding: 0
    },
    headerTitle: {
      paddingTop: "10px",
      color: theme.semanticColors.bodyText
    },
    headerBanner: {
      display: "flex"
    },
    headerOptions: {
      backgroundColor: theme.semanticColors.bodyBackground
    },
    bannerWrapper: {
      width: "100%",
      paddingTop: "18px",
      paddingBottom: "15px",
      display: "inline-flex",
      flexDirection: "row",
      justifyContent: "space-between"
    },
    metricText: {
      color: theme.semanticColors.bodyText,
      paddingRight: "12px",
      fontWeight: FontWeights$1.light,
      lineHeight: "44px",
      fontSize: "36px"
    },
    firstMetricLabel: {
      color: theme.semanticColors.bodyText,
      padding: "8px 12px 0 12px",
      maxWidth: "120px",
      borderRight: "1px solid",
      borderRightColor: theme.semanticColors.bodyDivider,
      marginRight: "20px",
      lineHeight: "16px"
    },
    metricLabel: {
      color: theme.semanticColors.bodyText,
      paddingTop: "8px",
      maxWidth: "130px"
    },
    expandAttributes: {
      color: theme.semanticColors.bodyText,
      fontSize: "12px",
      lineHeight: "16px",
      fontWeight: "normal",
      height: "26px",
      marginLeft: "100px",
      marginBottom: "20px"
    },
    overallArea: {
      display: "flex",
      flexDirection: "row",
      padding: "20px 0 0 100px",
      color: theme.semanticColors.bodyText,
      backgroundColor: theme.semanticColors.bodyBackground
    },
    presentationArea: {
      display: "flex",
      flexDirection: "row",
      padding: "20px 0 30px 100px",
      backgroundColor: theme.semanticColors.bodyBackground
    },
    chartWrapper: {
      flex: "1 0 40%",
      display: "flex",
      flexDirection: "column"
    },
    chartBody: {
      flex: 1
    },
    chartHeader: {
      height: "23px",
      paddingLeft: "10px",
      color: theme.semanticColors.bodyText
    },
    main: {
      display: "flex",
      flexDirection: "row"
    },
    mainLeft: {
      width: "75%",
      backgroundColor: theme.semanticColors.bodyBackground
    },
    dropDown: {
      margin: "10px 0px",
      display: "inline-block"
    },
    mainRight: {
      minWidth: "200px",
      paddingLeft: "35px",
      flexBasis: "300px",
      flexShrink: 1,
      backgroundColor: theme.semanticColors.bodyBackground
    },
    rightTitle: {
      color: theme.semanticColors.bodyText,
      paddingBottom: "11px",
      borderBottom: "1px solid",
      borderBottomColor: theme.semanticColors.bodyDivider
    },
    rightText: {
      padding: "16px 15px 30px 0",
      color: theme.semanticColors.bodyText,
      borderBottom: "0.5px dashed",
      borderBottomColor: theme.semanticColors.bodyDivider
    },
    insights: {
      textTransform: "uppercase",
      color: theme.semanticColors.bodyText,
      padding: "18px 0",
      display: "inline"
    },
    insightsIcon: {
      verticalAlign: "middle",
      marginRight: "10px",
      width: "24",
      height: "28"
    },
    insightsText: {
      marginTop: "20px",
      color: theme.semanticColors.bodyText,
      paddingBottom: "18px",
      paddingRight: "15px",
      borderBottom: "1px solid",
      borderBottomColor: theme.semanticColors.bodyDivider
    },
    downloadIcon: {
      verticalAlign: "middle",
      marginRight: "10px",
      width: "17",
      height: "18"
    },
    chevronIcon: {
      verticalAlign: "middle",
      marginRight: "10px",
      width: "9",
      height: "6"
    },
    downloadReport: {
      color: theme.semanticColors.bodyText,
      fontSize: "12px",
      lineHeight: "16px",
      fontWeight: "normal",
      paddingTop: "20px",
      paddingBottom: "20px",
      paddingLeft: "0px"
    },
    tableWrapper: {
      paddingBottom: "20px"
    },
    textRow: {
      display: "flex",
      flexDirection: "row",
      alignItems: "center",
      paddingBottom: "7px",
      color: theme.semanticColors.bodyText
    },
    infoButton: {
      color: theme.semanticColors.bodyText,
      "float": "left",
      width: "15px",
      height: "15px",
      textAlign: "center",
      fontSize: "12px",
      lineHeight: "14px",
      fontWeight: "600",
      borderRadius: "50%",
      border: "1px solid",
      marginTop: "3px",
      marginRight: "3px",
      marginLeft: "250px"
    },
    closeButton: {
      color: theme.semanticColors.bodyText,
      "float": "right",
      fontFamily: "Arial",
      fontSize: "20px",
      lineHeight: "20px",
      fontWeight: "400",
      paddingLeft: "20px"
    },
    doneButton: {
      margin: "auto",
      height: "44px",
      padding: "12px",
      lineHeight: "24px",
      color: theme.semanticColors.bodyText,
      fontSize: FontSizes$1.large,
      fontWeight: FontWeights$1.regular
    },
    equalizedOdds: {
      color: theme.semanticColors.bodyText,
      "float": "left",
      fontSize: "18px",
      lineHeight: "22px",
      fontWeight: "normal",
      paddingTop: "30px",
      paddingLeft: "100px"
    },
    howTo: {
      paddingTop: "20px",
      paddingLeft: "100px"
    },
    colorBlock: {
      width: "15px",
      height: "15px",
      marginRight: "9px"
    },
    multimodelSection: {
      display: "flex",
      flexDirection: "row"
    },
    modalContentHelp: {
      "float": "left",
      width: "350px"
    },
    modalContentHelpText: {
      padding: "0px 20px",
      textAlign: "center",
      wordWrap: "break-word"
    },
    modelLabel: {
      fontSize: "24px",
      alignSelf: "center",
      paddingTop: "16px",
      color: theme.semanticColors.bodyText
    },
    groupLabel: {
      color: theme.semanticColors.bodyText
    },
    legendPanel: {
      marginLeft: "100px"
    },
    legendTitle: {
      color: theme.semanticColors.bodyText,
      fontSize: "12px",
      lineHeight: "16px"
    },
    legendSubtitle: {
      color: theme.semanticColors.bodySubtext,
      fontSize: "9px",
      lineHeight: "12x",
      fontStyle: "italic"
    }
  });
};

var OverallTableStyles = function OverallTableStyles() {
  var theme = getTheme$1();
  return mergeStyleSets$1({
    minMaxLabel: {
      padding: "1px 9px",
      marginTop: "4px",
      fontSize: "10px",
      lineHeight: "20px",
      fontWeight: "400",
      backgroundColor: theme.semanticColors.bodyBackground
    },
    groupCol: {
      display: "inline-flex",
      flexDirection: "column",
      height: "100%",
      width: "max-content"
    },
    groupLabel: {
      fontSize: "12px",
      lineHeight: "12px",
      fontWeight: "500",
      height: "26px"
    },
    flexCol: {
      display: "flex",
      flex: 1,
      flexDirection: "column",
      borderTop: "0.5px solid",
      borderTopColor: theme.semanticColors.inputBorder
    },
    binBox: {
      flex: 1,
      width: "130px",
      display: "flex",
      flexDirection: "column",
      justifyContent: "center",
      borderBottom: "0.5px solid",
      borderBottomColor: theme.semanticColors.inputBorder
    },
    binTitle: {
      fontSize: "12px",
      lineHeight: "16px",
      fontWeight: "600"
    },
    binLabel: {
      fontSize: "12px",
      lineHeight: "16px",
      fontWeight: "normal"
    },
    sensitiveAttributes: {
      fontSize: "12px",
      lineHeight: "16px",
      fontWeight: "normal",
      height: "26px",
      paddingLeft: "10px"
    },
    metricCol: {
      display: "inline-flex",
      flexDirection: "column",
      height: "100%",
      width: "120px"
    },
    metricLabel: {
      fontSize: "11px",
      lineHeight: "16px",
      fontWeight: "600",
      height: "26px",
      paddingLeft: "10px"
    },
    metricBox: {
      flex: 1,
      paddingLeft: "10px",
      fontSize: "12px",
      lineHeight: "16px",
      fontWeight: "normal",
      display: "flex",
      flexDirection: "column",
      justifyContent: "center",
      borderBottom: "0.5px solid",
      borderBottomColor: theme.semanticColors.inputBorder
    },
    frame: {
      paddingBottom: "19px",
      display: "flex"
    }
  });
};

//     title: string;
//     score: string;
//     isMin: boolean;
//     isMax: boolean;
// }

var OverallTable = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(OverallTable, _React$PureComponent);

  var _super = _createSuper(OverallTable);

  function OverallTable() {
    _classCallCheck(this, OverallTable);

    return _super.apply(this, arguments);
  }

  _createClass(OverallTable, [{
    key: "render",
    value: function render() {
      var _this = this;

      var styles = OverallTableStyles();
      var minIndexes = [];
      var maxIndexes = [];
      var minValue = Number.MAX_SAFE_INTEGER;
      var maxValue = Number.MIN_SAFE_INTEGER;
      this.props.binValues.forEach(function (value, index) {
        if (value >= maxValue) {
          if (value === maxValue) {
            maxIndexes.push(index);
          } else {
            maxIndexes = [index];
            maxValue = value;
          }
        }

        if (value <= minValue) {
          if (value === minValue) {
            minIndexes.push(index);
          } else {
            minIndexes = [index];
            minValue = value;
          }
        }
      });
      return React__default.createElement("div", {
        className: styles.frame
      }, React__default.createElement("div", {
        className: styles.groupCol
      }, React__default.createElement("div", {
        className: styles.groupLabel
      }), React__default.createElement("div", {
        className: styles.flexCol
      }, React__default.createElement("div", {
        className: styles.binBox
      }, React__default.createElement("div", {
        className: styles.binTitle
      }, localization.Report.overallLabel)), this.props.binLabels.map(function (label, index) {
        if (_this.props.expandAttributes) {
          return React__default.createElement("div", {
            className: styles.binBox,
            key: index
          }, React__default.createElement("div", {
            className: styles.binLabel
          }, label));
        }

        return React__default.createElement("div", {
          style: {
            display: "none"
          }
        });
      }))), this.props.metricLabels.map(function (metric, index) {
        var _this$props$formatted;

        return React__default.createElement("div", {
          className: styles.metricCol
        }, React__default.createElement("div", {
          className: styles.metricLabel
        }, metric), React__default.createElement("div", {
          className: styles.flexCol
        }, React__default.createElement("div", {
          className: styles.metricBox
        }, _this.props.overallMetrics[index]), (_this$props$formatted = _this.props.formattedBinValues[index]) === null || _this$props$formatted === void 0 ? void 0 : _this$props$formatted.map(function (value, index) {
          if (_this.props.expandAttributes) {
            return React__default.createElement("div", {
              className: styles.metricBox,
              key: index
            }, value !== undefined ? value : "empty");
          }

          return React__default.createElement("div", {
            style: {
              display: "none"
            }
          });
        })));
      }));
    }
  }]);

  return OverallTable;
}(React__default.PureComponent);

var theme$5 = getTheme();
var WizardReport$1 = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(WizardReport, _React$PureComponent);

  var _super = _createSuper(WizardReport);

  function WizardReport() {
    var _this;

    _classCallCheck(this, WizardReport);

    _this = _super.apply(this, arguments);

    _this.clearModelSelection = function () {
      if (_this.props.onChartClick) {
        _this.props.onChartClick();
      }
    };

    _this.expandAttributes = function () {
      _this.setState({
        expandAttributes: !_this.state.expandAttributes
      });
    }; // private readonly onEditConfigs = (): void => {
    //   if (this.props.modelCount > 1) {
    //     this.props.onChartClick(undefined);
    //   }
    //   this.props.onEditConfigs();
    // };


    _this.handleOpenModalHelp = function () {
      _this.setState({
        showModalHelp: true
      });
    };

    _this.handleCloseModalHelp = function () {
      _this.setState({
        showModalHelp: false
      });
    };

    _this.featureChanged = function (_, option) {
      if (!option) {
        return;
      }

      var featureKey = option.key.toString();

      if (_this.state.featureKey !== featureKey) {
        _this.props.featureBinPickerProps.selectedBinIndex = _this.props.dashboardContext.modelMetadata.featureNames.indexOf(featureKey);

        _this.setState({
          featureKey: featureKey,
          metrics: undefined
        });
      }
    };

    return _this;
  }

  _createClass(WizardReport, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var styles = WizardReportStyles$1();
      var dropdownStyles = {
        dropdown: {
          width: 180
        },
        title: {
          borderWidth: "1px",
          borderRadius: "5px"
        }
      };
      var iconButtonStyles = {
        root: {
          color: theme$5.semanticColors.bodyText,
          marginLeft: "auto",
          marginTop: "4px",
          marginRight: "2px"
        },
        rootHovered: {
          color: theme$5.semanticColors.bodyBackgroundHovered
        }
      };
      var featureOptions = this.props.dashboardContext.modelMetadata.featureNames.map(function (x) {
        return {
          key: x,
          text: x
        };
      });
      var alternateHeight = this.props.featureBinPickerProps.featureBins[this.props.featureBinPickerProps.selectedBinIndex].labelArray.length * 60 + 106;
      var areaHeights = Math.max(300, alternateHeight);
      var accuracyKey = this.props.accuracyPickerProps.selectedAccuracyKey;
      var outcomeKey = this.props.dashboardContext.modelMetadata.PredictionType === PredictionTypes.binaryClassification ? "selection_rate" : "average";
      var outcomeMetric = AccuracyOptions[outcomeKey];
      var overpredicitonKey = "overprediction";
      var underpredictionKey = "underprediction";

      var accuracyPlot = _.cloneDeep(WizardReport.barPlotlyProps);

      var opportunityPlot = _.cloneDeep(WizardReport.barPlotlyProps);

      var nameIndex = this.props.dashboardContext.groupNames.map(function (_, i) {
        return i;
      }); // let howToReadAccuracySection: React.ReactNode;
      // let howToReadOutcomesSection: React.ReactNode;

      var accuracyChartHeader = ""; // let opportunityChartHeader = "";

      var mainChart;

      if (!this.state || !this.state.metrics) {
        this.loadData();
        mainChart = React__default.createElement(Spinner, {
          className: styles.spinner,
          size: SpinnerSize.large,
          label: localization.calculating
        });
      } else {
        var _this$state$metrics$b7, _this$state$metrics$b8;

        if (this.props.dashboardContext.modelMetadata.PredictionType === PredictionTypes.binaryClassification) {
          var _this$state$metrics$b, _this$state$metrics$b2, _this$state$metrics$b3, _accuracyPlot$layout, _opportunityPlot$layo;

          accuracyPlot.data = [{
            x: this.state.metrics.binnedOverprediction,
            y: nameIndex,
            text: (_this$state$metrics$b = this.state.metrics.binnedOverprediction) === null || _this$state$metrics$b === void 0 ? void 0 : _this$state$metrics$b.map(function (num) {
              return FormatMetrics.formatNumbers(num, "accuracy_score", false, 2);
            }),
            name: localization.Metrics.overprediction,
            width: 0.5,
            color: ChartColors$1[0],
            orientation: "h",
            type: "bar",
            textposition: "auto",
            hoverinfo: "skip"
          }, {
            x: (_this$state$metrics$b2 = this.state.metrics.binnedUnderprediction) === null || _this$state$metrics$b2 === void 0 ? void 0 : _this$state$metrics$b2.map(function (x) {
              return -1 * x;
            }),
            y: nameIndex,
            text: (_this$state$metrics$b3 = this.state.metrics.binnedUnderprediction) === null || _this$state$metrics$b3 === void 0 ? void 0 : _this$state$metrics$b3.map(function (num) {
              return FormatMetrics.formatNumbers(num, "accuracy_score", false, 2);
            }),
            name: localization.Metrics.underprediction,
            width: 0.5,
            color: ChartColors$1[1],
            orientation: "h",
            type: "bar",
            textposition: "auto",
            hoverinfo: "skip"
          }];

          if (accuracyPlot.layout) {
            accuracyPlot.layout.annotations = [{
              text: localization.Report.underestimationError,
              x: 0.02,
              y: 1,
              yref: "paper",
              xref: "paper",
              showarrow: false,
              font: {
                color: theme$5.semanticColors.bodySubtext,
                size: 10
              }
            }, {
              text: localization.Report.overestimationError,
              x: 0.98,
              y: 1,
              yref: "paper",
              xref: "paper",
              showarrow: false,
              font: {
                color: theme$5.semanticColors.bodySubtext,
                size: 10
              }
            }];
          }

          if ((_accuracyPlot$layout = accuracyPlot.layout) === null || _accuracyPlot$layout === void 0 ? void 0 : _accuracyPlot$layout.xaxis) {
            accuracyPlot.layout.xaxis.tickformat = ",.0%";
          }

          opportunityPlot.data = [{
            x: this.state.metrics.binnedOutcome,
            y: nameIndex,
            text: this.state.metrics.binnedOutcome.map(function (num) {
              return FormatMetrics.formatNumbers(num, "selection_rate", false, 2);
            }),
            name: outcomeMetric.title,
            color: ChartColors$1[0],
            orientation: "h",
            type: "bar",
            textposition: "auto",
            hoverinfo: "skip"
          }];

          if ((_opportunityPlot$layo = opportunityPlot.layout) === null || _opportunityPlot$layo === void 0 ? void 0 : _opportunityPlot$layo.xaxis) {
            opportunityPlot.layout.xaxis.tickformat = ",.0%";
          } // howToReadAccuracySection = (
          //   <div className={styles.rightText}>
          //     <div className={styles.textRow}>
          //       <div
          //         className={styles.colorBlock}
          //         style={{ backgroundColor: ChartColors[1] }}
          //       />
          //       <div>
          //         <Text block>{localization.Report.underestimationError}</Text>
          //         <Text block>
          //           {localization.Report.underpredictionExplanation}
          //         </Text>
          //       </div>
          //     </div>
          //     <div className={styles.textRow}>
          //       <div
          //         className={styles.colorBlock}
          //         style={{ backgroundColor: ChartColors[0] }}
          //       />
          //       <div>
          //         <Text block>{localization.Report.overestimationError}</Text>
          //         <Text block>
          //           {localization.Report.overpredictionExplanation}
          //         </Text>
          //       </div>
          //     </div>
          //     <Text block>
          //       {localization.Report.classificationAccuracyHowToRead1}
          //     </Text>
          //     <Text block>
          //       {localization.Report.classificationAccuracyHowToRead2}
          //     </Text>
          //     <Text block>
          //       {localization.Report.classificationAccuracyHowToRead3}
          //     </Text>
          //   </div>
          // );
          // howToReadOutcomesSection = (
          //   <Text className={styles.textRow} block>
          //     {localization.Report.classificationOutcomesHowToRead}
          //   </Text>
          // );

        }

        if (this.props.dashboardContext.modelMetadata.PredictionType === PredictionTypes.probability) {
          var _this$state$metrics$b4, _this$state$metrics$b5, _this$state$metrics$b6, _this$state$metrics$p;

          accuracyPlot.data = [{
            x: this.state.metrics.binnedOverprediction,
            y: nameIndex,
            text: (_this$state$metrics$b4 = this.state.metrics.binnedOverprediction) === null || _this$state$metrics$b4 === void 0 ? void 0 : _this$state$metrics$b4.map(function (num) {
              return FormatMetrics.formatNumbers(num, "overprediction", false, 2);
            }),
            name: localization.Metrics.overprediction,
            width: 0.5,
            color: ChartColors$1[0],
            orientation: "h",
            type: "bar",
            textposition: "auto",
            hoverinfo: "skip"
          }, {
            x: (_this$state$metrics$b5 = this.state.metrics.binnedUnderprediction) === null || _this$state$metrics$b5 === void 0 ? void 0 : _this$state$metrics$b5.map(function (x) {
              return -1 * x;
            }),
            y: nameIndex,
            text: (_this$state$metrics$b6 = this.state.metrics.binnedUnderprediction) === null || _this$state$metrics$b6 === void 0 ? void 0 : _this$state$metrics$b6.map(function (num) {
              return FormatMetrics.formatNumbers(num, "underprediction", false, 2);
            }),
            name: localization.Metrics.underprediction,
            width: 0.5,
            color: ChartColors$1[1],
            orientation: "h",
            type: "bar",
            textposition: "auto",
            hoverinfo: "skip"
          }];

          if (accuracyPlot.layout) {
            accuracyPlot.layout.annotations = [{
              text: localization.Report.underestimationError,
              x: 0.1,
              y: 1,
              yref: "paper",
              xref: "paper",
              showarrow: false,
              font: {
                color: theme$5.semanticColors.bodySubtext,
                size: 10
              }
            }, {
              text: localization.Report.overestimationError,
              x: 0.9,
              y: 1,
              yref: "paper",
              xref: "paper",
              showarrow: false,
              font: {
                color: theme$5.semanticColors.bodySubtext,
                size: 10
              }
            }];
          }

          var opportunityText = (_this$state$metrics$p = this.state.metrics.predictions) === null || _this$state$metrics$p === void 0 ? void 0 : _this$state$metrics$p.map(function (val) {
            return localization.formatString(localization.Report.tooltipPrediction, FormatMetrics.formatNumbers(val, "average", false, 3));
          });
          opportunityPlot.data = [{
            x: this.state.metrics.predictions,
            y: this.props.dashboardContext.binVector,
            text: opportunityText,
            type: "box",
            color: ChartColors$1[0],
            boxmean: true,
            orientation: "h",
            boxpoints: "all",
            hoverinfo: "text",
            hoveron: "points",
            jitter: 0.4,
            pointpos: 0
          }];
        }

        if (this.props.dashboardContext.modelMetadata.PredictionType === PredictionTypes.regression) {
          var _this$state$metrics$p2, _this$state$metrics$p3;

          var _opportunityText = (_this$state$metrics$p2 = this.state.metrics.predictions) === null || _this$state$metrics$p2 === void 0 ? void 0 : _this$state$metrics$p2.map(function (val) {
            return localization.formatString(localization.Report.tooltipPrediction, val);
          });

          var accuracyText = (_this$state$metrics$p3 = this.state.metrics.predictions) === null || _this$state$metrics$p3 === void 0 ? void 0 : _this$state$metrics$p3.map(function (val, index) {
            var _this2$state$metrics, _this2$state$metrics$;

            return "".concat(localization.formatString(localization.Report.tooltipError, FormatMetrics.formatNumbers((_this2$state$metrics = _this2.state.metrics) === null || _this2$state$metrics === void 0 ? void 0 : (_this2$state$metrics$ = _this2$state$metrics.errors) === null || _this2$state$metrics$ === void 0 ? void 0 : _this2$state$metrics$[index], "average", false, 3)), "<br>").concat(localization.formatString(localization.Report.tooltipPrediction, FormatMetrics.formatNumbers(val, "average", false, 3)));
          });
          accuracyPlot.data = [{
            x: this.state.metrics.errors,
            y: this.props.dashboardContext.binVector,
            text: accuracyText,
            type: "box",
            color: ChartColors$1[0],
            orientation: "h",
            boxmean: true,
            hoveron: "points",
            hoverinfo: "text",
            boxpoints: "all",
            jitter: 0.4,
            pointpos: 0
          }];
          opportunityPlot.data = [{
            x: this.state.metrics.predictions,
            y: this.props.dashboardContext.binVector,
            text: _opportunityText,
            type: "box",
            color: ChartColors$1[0],
            boxmean: true,
            orientation: "h",
            hoveron: "points",
            boxpoints: "all",
            hoverinfo: "text",
            jitter: 0.4,
            pointpos: 0
          }];
          accuracyChartHeader = localization.Report.distributionOfErrors;
        }

        var globalAccuracyString = FormatMetrics.formatNumbers(this.state.metrics.globalAccuracy, accuracyKey); // const disparityAccuracyString = FormatMetrics.formatNumbers(
        //   this.state.metrics.accuracyDisparity,
        //   accuracyKey
        // );

        var selectedMetric = AccuracyOptions[this.props.accuracyPickerProps.selectedAccuracyKey] || this.props.accuracyPickerProps.accuracyOptions.find(function (metric) {
          return metric.key === _this2.props.accuracyPickerProps.selectedAccuracyKey;
        });
        var globalOutcomeString = FormatMetrics.formatNumbers(this.state.metrics.globalOutcome, outcomeKey); // const disparityOutcomeString = FormatMetrics.formatNumbers(
        //   this.state.metrics.outcomeDisparity,
        //   outcomeKey
        // );

        var formattedBinAccuracyValues = this.state.metrics.binnedAccuracy.map(function (value) {
          return FormatMetrics.formatNumbers(value, accuracyKey);
        });
        var formattedBinOutcomeValues = this.state.metrics.binnedOutcome.map(function (value) {
          return FormatMetrics.formatNumbers(value, outcomeKey);
        });
        var formattedBinOverPredictionValues = (_this$state$metrics$b7 = this.state.metrics.binnedOverprediction) === null || _this$state$metrics$b7 === void 0 ? void 0 : _this$state$metrics$b7.map(function (value) {
          return FormatMetrics.formatNumbers(value, overpredicitonKey);
        });
        var formattedBinUnderPredictionValues = (_this$state$metrics$b8 = this.state.metrics.binnedUnderprediction) === null || _this$state$metrics$b8 === void 0 ? void 0 : _this$state$metrics$b8.map(function (value) {
          return FormatMetrics.formatNumbers(value, underpredictionKey);
        });
        var globalOverpredictionString = FormatMetrics.formatNumbers(this.state.metrics.globalOverprediction, outcomeKey);
        var globalUnderpredictionString = FormatMetrics.formatNumbers(this.state.metrics.globalUnderprediction, outcomeKey);
        var overallMetrics = [globalAccuracyString, globalOutcomeString, globalOverpredictionString, globalUnderpredictionString];
        var formattedBinValues = [formattedBinAccuracyValues, formattedBinOutcomeValues, formattedBinOverPredictionValues, formattedBinUnderPredictionValues];
        var metricLabels = [(this.props.accuracyPickerProps.accuracyOptions.find(function (a) {
          return a.key === accuracyKey;
        }) || AccuracyOptions[accuracyKey]).title, AccuracyOptions[outcomeKey].title, AccuracyOptions[overpredicitonKey].title, AccuracyOptions[underpredictionKey].title];

        var InsightsIcon = function InsightsIcon() {
          return React__default.createElement(Icon$1, {
            iconName: "CRMCustomerInsightsApp",
            className: styles.insightsIcon
          });
        };

        var DownloadIcon = function DownloadIcon() {
          return React__default.createElement(Icon$1, {
            iconName: "Download",
            className: styles.downloadIcon
          });
        };

        var ChevronUp = function ChevronUp() {
          return React__default.createElement(Icon$1, {
            iconName: "ChevronUp",
            className: styles.chevronIcon
          });
        };

        var ChevronDown = function ChevronDown() {
          return React__default.createElement(Icon$1, {
            iconName: "ChevronDown",
            className: styles.chevronIcon
          });
        };

        var cancelIcon = {
          iconName: "Cancel"
        };
        mainChart = React__default.createElement("div", {
          className: styles.main
        }, React__default.createElement("div", {
          className: styles.mainLeft
        }, React__default.createElement("div", {
          className: styles.overallArea,
          style: {
            height: this.state.expandAttributes ? "".concat(150 + 50 * (areaHeights / 150), "px") : "150px"
          }
        }, React__default.createElement(OverallTable, {
          binGroup: this.props.dashboardContext.modelMetadata.featureNames[this.props.featureBinPickerProps.selectedBinIndex],
          binLabels: this.props.dashboardContext.groupNames,
          formattedBinValues: formattedBinValues,
          metricLabels: metricLabels,
          overallMetrics: overallMetrics,
          expandAttributes: this.state.expandAttributes,
          binValues: this.state.metrics.binnedAccuracy
        })), React__default.createElement("div", {
          className: styles.expandAttributes,
          onClick: this.expandAttributes
        }, this.state.expandAttributes && React__default.createElement(ChevronUp, null) || !this.state.expandAttributes && React__default.createElement(ChevronDown, null), React__default.createElement(Text, null, this.state.expandAttributes && localization.Report.collapseSensitiveAttributes || !this.state.expandAttributes && localization.Report.expandSensitiveAttributes)), React__default.createElement("div", {
          className: styles.equalizedOdds
        }, React__default.createElement(Text, null, localization.Report.equalizedOddsDisparity)), React__default.createElement("div", {
          className: styles.howTo
        }, React__default.createElement(ActionButton, {
          onClick: this.handleOpenModalHelp
        }, React__default.createElement("div", {
          className: styles.infoButton
        }, "i"), localization.ModelComparison.howToRead), React__default.createElement(Modal, {
          titleAriaId: "intro modal",
          isOpen: this.state.showModalHelp,
          onDismiss: this.handleCloseModalHelp,
          isModeless: true,
          containerClassName: styles.modalContentHelp
        }, React__default.createElement("div", {
          style: {
            display: "flex"
          }
        }, React__default.createElement(IconButton, {
          styles: iconButtonStyles,
          iconProps: cancelIcon,
          ariaLabel: "Close popup modal",
          onClick: this.handleCloseModalHelp
        })), React__default.createElement("p", {
          className: styles.modalContentHelpText
        }, localization.Report.classificationAccuracyHowToRead1, React__default.createElement("br", null), React__default.createElement("br", null), localization.Report.classificationAccuracyHowToRead2, React__default.createElement("br", null), React__default.createElement("br", null), localization.Report.classificationAccuracyHowToRead3, React__default.createElement("br", null), React__default.createElement("br", null)), React__default.createElement("div", {
          style: {
            display: "flex",
            paddingBottom: "20px"
          }
        }, React__default.createElement(PrimaryButton, {
          className: styles.doneButton,
          onClick: this.handleCloseModalHelp
        }, localization.done)))), React__default.createElement("div", {
          className: styles.presentationArea,
          style: {
            height: "".concat(areaHeights, "px")
          }
        }, React__default.createElement(SummaryTable$1, {
          binGroup: this.props.dashboardContext.modelMetadata.featureNames[this.props.featureBinPickerProps.selectedBinIndex],
          binLabels: this.props.dashboardContext.groupNames,
          formattedBinValues: formattedBinAccuracyValues,
          metricLabel: selectedMetric.title,
          binValues: this.state.metrics.binnedAccuracy
        }), React__default.createElement("div", {
          className: styles.chartWrapper
        }, React__default.createElement("div", {
          className: styles.chartHeader
        }, accuracyChartHeader), React__default.createElement("div", {
          className: styles.chartBody
        }, React__default.createElement(AccessibleChart, {
          plotlyProps: accuracyPlot,
          theme: undefined
        })))), React__default.createElement("div", {
          className: styles.legendPanel
        }, React__default.createElement("div", {
          className: styles.textRow
        }, React__default.createElement("div", {
          className: styles.colorBlock,
          style: {
            backgroundColor: ChartColors$1[1]
          }
        }), React__default.createElement("div", null, React__default.createElement("div", {
          className: styles.legendTitle
        }, localization.Report.underestimationError), React__default.createElement("div", {
          className: styles.legendSubtitle
        }, localization.Report.underpredictionExplanation))), React__default.createElement("div", {
          className: styles.textRow
        }, React__default.createElement("div", {
          className: styles.colorBlock,
          style: {
            backgroundColor: ChartColors$1[0]
          }
        }), React__default.createElement("div", null, React__default.createElement("div", {
          className: styles.legendTitle
        }, localization.Report.overestimationError), React__default.createElement("div", {
          className: styles.legendSubtitle
        }, localization.Report.overpredictionExplanation))))), React__default.createElement("div", {
          className: styles.mainRight
        }, React__default.createElement("div", {
          className: styles.insights
        }, React__default.createElement(InsightsIcon, null), React__default.createElement(Text, {
          style: {
            verticalAlign: "middle"
          }
        }, localization.ModelComparison.insights)), React__default.createElement("div", {
          className: styles.insightsText
        }, localization.loremIpsum), React__default.createElement("div", {
          className: styles.downloadReport
        }, React__default.createElement(DownloadIcon, null), React__default.createElement(Text, {
          style: {
            verticalAlign: "middle"
          }
        }, localization.ModelComparison.downloadReport))));
      }

      return React__default.createElement("div", {
        style: {
          height: "100%",
          overflowY: "auto"
        }
      }, React__default.createElement("div", {
        className: styles.header
      }, this.props.modelCount > 1 && React__default.createElement("div", {
        className: styles.multimodelSection
      }, React__default.createElement(ActionButton, {
        className: styles.multimodelButton,
        iconProps: {
          iconName: "ChevronLeft"
        },
        onClick: this.clearModelSelection
      }, localization.Report.backToComparisons)), React__default.createElement("div", {
        className: styles.modelLabel
      }, localization.Report.assessmentResults, " ", React__default.createElement("b", null, this.props.dashboardContext.modelNames[this.props.selectedModelIndex])), React__default.createElement("div", {
        className: styles.headerOptions
      }, React__default.createElement(Dropdown, {
        className: styles.dropDown,
        // label="Feature"
        defaultSelectedKey: this.props.dashboardContext.modelMetadata.featureNames[this.props.featureBinPickerProps.selectedBinIndex],
        options: featureOptions,
        disabled: false,
        onChange: this.featureChanged,
        styles: dropdownStyles
      }))), mainChart);
    }
  }, {
    key: "loadData",
    value: function () {
      var _loadData = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
        var _this3 = this;

        var overallOverprediction, overallUnderprediction, binnedOverprediction, binnedUnderprediction, predictions, errors, outcomes, outcomeDisparity, accuracy, accuracyDisparity;
        return regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.prev = 0;
                _context.next = 3;
                return this.props.metricsCache.getMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, this.props.accuracyPickerProps.selectedAccuracyKey);

              case 3:
                accuracy = _context.sent;
                _context.next = 6;
                return this.props.metricsCache.getDisparityMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, this.props.accuracyPickerProps.selectedAccuracyKey, ParityModes.difference);

              case 6:
                accuracyDisparity = _context.sent;
                _context.t0 = this.props.dashboardContext.modelMetadata.PredictionType;
                _context.next = _context.t0 === PredictionTypes.binaryClassification ? 10 : _context.t0 === PredictionTypes.probability ? 29 : _context.t0 === PredictionTypes.regression ? 43 : 43;
                break;

              case 10:
                _context.next = 12;
                return this.props.metricsCache.getMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "underprediction");

              case 12:
                binnedUnderprediction = _context.sent.bins;
                _context.next = 15;
                return this.props.metricsCache.getMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "underprediction");

              case 15:
                overallUnderprediction = _context.sent.global;
                _context.next = 18;
                return this.props.metricsCache.getMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "overprediction");

              case 18:
                binnedOverprediction = _context.sent.bins;
                _context.next = 21;
                return this.props.metricsCache.getMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "overprediction");

              case 21:
                overallOverprediction = _context.sent.global;
                _context.next = 24;
                return this.props.metricsCache.getMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "selection_rate");

              case 24:
                outcomes = _context.sent;
                _context.next = 27;
                return this.props.metricsCache.getDisparityMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "selection_rate", ParityModes.difference);

              case 27:
                outcomeDisparity = _context.sent;
                return _context.abrupt("break", 52);

              case 29:
                predictions = this.props.dashboardContext.predictions[this.props.selectedModelIndex];
                _context.next = 32;
                return this.props.metricsCache.getMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "overprediction");

              case 32:
                binnedOverprediction = _context.sent.bins;
                _context.next = 35;
                return this.props.metricsCache.getMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "underprediction");

              case 35:
                binnedUnderprediction = _context.sent.bins;
                _context.next = 38;
                return this.props.metricsCache.getMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "average");

              case 38:
                outcomes = _context.sent;
                _context.next = 41;
                return this.props.metricsCache.getDisparityMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "average", ParityModes.difference);

              case 41:
                outcomeDisparity = _context.sent;
                return _context.abrupt("break", 52);

              case 43:
                predictions = this.props.dashboardContext.predictions[this.props.selectedModelIndex];
                errors = predictions.map(function (predicted, index) {
                  return predicted - _this3.props.dashboardContext.trueY[index];
                });
                _context.next = 47;
                return this.props.metricsCache.getMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "average");

              case 47:
                outcomes = _context.sent;
                _context.next = 50;
                return this.props.metricsCache.getDisparityMetric(this.props.dashboardContext.binVector, this.props.featureBinPickerProps.selectedBinIndex, this.props.selectedModelIndex, "average", ParityModes.difference);

              case 50:
                outcomeDisparity = _context.sent;
                return _context.abrupt("break", 52);

              case 52:
                this.setState({
                  metrics: {
                    globalAccuracy: accuracy.global,
                    binnedAccuracy: accuracy.bins,
                    accuracyDisparity: accuracyDisparity,
                    globalOutcome: outcomes.global,
                    binnedOutcome: outcomes.bins,
                    outcomeDisparity: outcomeDisparity,
                    predictions: predictions,
                    errors: errors,
                    globalOverprediction: overallOverprediction,
                    globalUnderprediction: overallUnderprediction,
                    binnedOverprediction: binnedOverprediction,
                    binnedUnderprediction: binnedUnderprediction
                  }
                });
                _context.next = 57;
                break;

              case 55:
                _context.prev = 55;
                _context.t1 = _context["catch"](0);

              case 57:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, this, [[0, 55]]);
      }));

      function loadData() {
        return _loadData.apply(this, arguments);
      }

      return loadData;
    }()
  }]);

  return WizardReport;
}(React__default.PureComponent);
WizardReport$1.barPlotlyProps = {
  config: {
    displaylogo: false,
    responsive: true,
    modeBarButtonsToRemove: ["toggleSpikelines", "hoverClosestCartesian", "hoverCompareCartesian", "zoom2d", "pan2d", "select2d", "lasso2d", "zoomIn2d", "zoomOut2d", "autoScale2d", "resetScale2d"]
  },
  data: [{
    orientation: "h",
    type: "bar"
  }],
  layout: {
    autosize: true,
    barmode: "relative",
    colorway: ChartColors$1,
    font: {
      size: 10
    },
    margin: {
      t: 4,
      l: 0,
      r: 0,
      b: 20
    },
    showlegend: false,
    hovermode: "closest",
    plot_bgcolor: theme$5.semanticColors.bodyFrameBackground,
    xaxis: {
      fixedrange: true,
      autorange: true,
      mirror: true,
      linecolor: theme$5.semanticColors.disabledBorder,
      linewidth: 1
    },
    yaxis: {
      fixedrange: true,
      showticklabels: false,
      showgrid: true,
      dtick: 1,
      tick0: 0.5,
      gridcolor: theme$5.semanticColors.disabledBorder,
      gridwidth: 1,
      autorange: "reversed"
    }
  }
};

var FairnessWizardStyles$1 = function FairnessWizardStyles() {
  var theme = getTheme$1();
  return mergeStyleSets$1({
    frame: {
      minHeight: "800px",
      minWidth: "800px"
    },
    thinHeader: {
      height: "36px",
      backgroundColor: theme.semanticColors.bodyBackground,
      color: theme.semanticColors.bodyText
    },
    headerLeft: {
      padding: "20px"
    },
    pivot: {
      flex: 1,
      display: "flex",
      flexDirection: "column",
      padding: "30px 90px 0 82px"
    },
    body: {
      flex: 1,
      display: "flex",
      flexDirection: "column",
      backgroundColor: theme.semanticColors.bodyBackground
    },
    errorMessage: {
      padding: "50px",
      fontSize: "18px"
    }
  });
};

var defaultTheme$1 = createTheme$1({
  palette: {
    themePrimary: "#0078d4",
    themeLighterAlt: "#eff6fc",
    themeLighter: "#deecf9",
    themeLight: "#c7e0f4",
    themeTertiary: "#71afe5",
    themeSecondary: "#2b88d8",
    themeDarkAlt: "#106ebe",
    themeDark: "#005a9e",
    themeDarker: "#004578",
    neutralLighterAlt: "#faf9f8",
    neutralLighter: "#f3f2f1",
    neutralLight: "#edebe9",
    neutralQuaternaryAlt: "#e1dfdd",
    neutralQuaternary: "#d0d0d0",
    neutralTertiaryAlt: "#c8c6c4",
    neutralTertiary: "#a19f9d",
    neutralSecondary: "#605e5c",
    neutralPrimaryAlt: "#3b3a39",
    neutralPrimary: "#323130",
    neutralDark: "#201f1e",
    black: "#000000",
    white: "#ffffff"
  }
});

var introTabKey$1 = "introTab";
var featureBinTabKey$1 = "featureBinTab";
var accuracyTabKey$1 = "accuracyTab";
var disparityTabKey$1 = "disparityTab";
var reportTabKey$1 = "reportTab";
var FairnessWizardV2 = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(FairnessWizardV2, _React$PureComponent);

  var _super = _createSuper(FairnessWizardV2);

  function FairnessWizardV2(props) {
    var _this;

    _classCallCheck(this, FairnessWizardV2);

    _this = _super.call(this, props);

    _this.hideIntro = function () {
      _this.setState({
        showIntro: false
      });
    };

    _this.setTab = function (key) {
      _this.setState({
        activeTabKey: key
      });
    };

    _this.onSelectModel = function (data) {
      if (!data) {
        _this.setState({
          selectedModelId: undefined
        });

        return;
      }

      if (data.points && data.points[0]) {
        _this.setState({
          selectedModelId: data.points[0].customdata
        });
      }
    };

    _this.setAccuracyKey = function (key) {
      var value = {
        selectedAccuracyKey: key
      };

      _this.setState(value);
    };

    _this.setParityKey = function (key) {
      _this.setState({
        selectedParityKey: key
      });
    };

    _this.setBinIndex = function (index) {
      if (_this.props.precomputedMetrics) {
        var newContext = _.cloneDeep(_this.state.dashboardContext);

        newContext.binVector = _this.props.precomputedFeatureBins[index].binVector;
        newContext.groupNames = _this.props.precomputedFeatureBins[index].binLabels;

        _this.setState({
          dashboardContext: newContext,
          selectedBinIndex: index
        });
      } else {
        _this.binningSet(_this.state.featureBins[index]);
      }
    };

    _this.handleTabClick = function (item) {
      var _item$props;

      if (item === null || item === void 0 ? void 0 : (_item$props = item.props) === null || _item$props === void 0 ? void 0 : _item$props.itemKey) {
        _this.setState({
          activeTabKey: item.props.itemKey
        });
      }
    };

    _this.binningSet = function (value) {
      if (!value || value.hasError || value.array.length === 0) {
        return;
      }

      var newContext = _.cloneDeep(_this.state.dashboardContext);

      newContext.binVector = WizardBuilder.generateBinVectorForBin(value, _this.state.dashboardContext.dataset);
      newContext.groupNames = value.labelArray;

      _this.setState({
        dashboardContext: newContext,
        selectedBinIndex: value.featureIndex
      });
    };

    _this.saveBin = function (bin) {
      var newBin = _toConsumableArray(_this.state.featureBins);

      newBin[bin.featureIndex] = bin;

      _this.setState({
        featureBins: newBin
      });

      _this.state.metricCache.clearCache(bin.featureIndex);

      _this.binningSet(bin);
    };

    WizardBuilder.initializeIcons(props);

    if (_this.props.locale) {
      localization.setLanguage(_this.props.locale);
    }

    var accuracyMetrics;
    var parityMetrics;
    loadTheme(props.theme || defaultTheme$1); // handle the case of precomputed metrics separately. As it becomes more defined, can integrate with existing code path.

    if (_this.props.precomputedMetrics && _this.props.precomputedFeatureBins) {
      // we must assume that the same accuracy metrics are provided across models and bins
      accuracyMetrics = WizardBuilder.buildAccuracyListForPrecomputedMetrics(_this.props);
      parityMetrics = WizardBuilder.buildParityListForPrecomputedMetrics(_this.props);

      var readonlyFeatureBins = _this.props.precomputedFeatureBins.map(function (initialBin, index) {
        return {
          hasError: false,
          array: initialBin.binLabels,
          labelArray: initialBin.binLabels,
          featureIndex: index,
          rangeType: RangeTypes.categorical
        };
      });

      _this.state = {
        showIntro: true,
        accuracyMetrics: accuracyMetrics,
        selectedAccuracyKey: accuracyMetrics[0].key,
        parityMetrics: parityMetrics,
        selectedParityKey: parityMetrics[0].key,
        dashboardContext: WizardBuilder.buildPrecomputedFairnessContext(_this.props),
        activeTabKey: featureBinTabKey$1,
        featureBins: readonlyFeatureBins,
        selectedBinIndex: 0,
        selectedModelId: _this.props.predictedY.length === 1 ? 0 : undefined,
        metricCache: new MetricsCache(0, 0, undefined, props.precomputedMetrics)
      };
      return _possibleConstructorReturn(_this);
    }

    var fairnessContext = WizardBuilder.buildInitialFairnessContext(_this.props);
    var featureBins = WizardBuilder.buildFeatureBins(fairnessContext);

    if (featureBins.length > 0) {
      fairnessContext.binVector = WizardBuilder.generateBinVectorForBin(featureBins[0], fairnessContext.dataset);
      fairnessContext.groupNames = featureBins[0].labelArray;
    }

    accuracyMetrics = _this.getAccuracyMetrics(fairnessContext);
    accuracyMetrics = accuracyMetrics.filter(function (metric) {
      return !!metric;
    }); // TODO

    parityMetrics = Object.values(ParityOptions);
    _this.state = {
      showIntro: true,
      accuracyMetrics: accuracyMetrics,
      selectedAccuracyKey: accuracyMetrics[0].key,
      parityMetrics: parityMetrics,
      selectedParityKey: parityMetrics[0].key,
      dashboardContext: fairnessContext,
      activeTabKey: introTabKey$1,
      featureBins: featureBins,
      selectedBinIndex: 0,
      selectedModelId: _this.props.predictedY.length === 1 ? 0 : undefined,
      metricCache: new MetricsCache(featureBins.length, _this.props.predictedY.length, _this.props.requestMetrics)
    };
    return _this;
  }

  _createClass(FairnessWizardV2, [{
    key: "componentDidUpdate",
    value: function componentDidUpdate(prev) {
      if (prev.theme !== this.props.theme) {
        loadTheme(this.props.theme || defaultTheme$1);
      }

      if (this.props.locale && prev.locale !== this.props.locale) {
        localization.setLanguage(this.props.locale);
      }
    }
  }, {
    key: "render",
    value: function render() {
      var styles = FairnessWizardStyles$1();
      var accuracyPickerProps = {
        accuracyOptions: this.state.accuracyMetrics,
        selectedAccuracyKey: this.state.selectedAccuracyKey,
        onAccuracyChange: this.setAccuracyKey
      };
      var parityPickerProps = {
        parityOptions: this.state.parityMetrics,
        selectedParityKey: this.state.selectedParityKey,
        onParityChange: this.setParityKey
      };
      var featureBinPickerProps = {
        featureBins: this.state.featureBins,
        selectedBinIndex: this.state.selectedBinIndex,
        onBinChange: this.setBinIndex
      };

      if (this.state.featureBins.length === 0) {
        return React__default.createElement(Stack$1, {
          className: styles.frame
        }, React__default.createElement(Stack$1, {
          horizontal: true,
          horizontalAlign: "space-between",
          verticalAlign: "center",
          className: styles.thinHeader
        }));
      }

      return React__default.createElement(Stack$1, {
        className: styles.frame
      }, React__default.createElement(Stack$1, {
        horizontal: true,
        horizontalAlign: "space-between",
        verticalAlign: "center",
        className: styles.thinHeader
      }), this.state.activeTabKey === introTabKey$1 && React__default.createElement(StackItem$1, {
        grow: 2,
        className: styles.body
      }, React__default.createElement(IntroTab$1, {
        onNext: this.setTab.bind(this, featureBinTabKey$1)
      })), (this.state.activeTabKey === featureBinTabKey$1 || this.state.activeTabKey === accuracyTabKey$1 || this.state.activeTabKey === disparityTabKey$1) && React__default.createElement(Stack$1.Item, {
        grow: 2,
        className: styles.body
      }, React__default.createElement(Pivot, {
        className: styles.pivot,
        styles: {
          itemContainer: {
            height: "100%"
          }
        },
        selectedKey: this.state.activeTabKey,
        onLinkClick: this.handleTabClick
      }, React__default.createElement(PivotItem, {
        headerText: localization.sensitiveFeatures,
        itemKey: featureBinTabKey$1,
        style: {
          height: "100%",
          paddingLeft: "8px"
        }
      }, React__default.createElement(FeatureTab, {
        dashboardContext: this.state.dashboardContext,
        selectedFeatureChange: this.setBinIndex,
        selectedFeatureIndex: this.state.selectedBinIndex,
        featureBins: this.state.featureBins.filter(function (x) {
          return !!x;
        }),
        onNext: this.setTab.bind(this, accuracyTabKey$1),
        saveBin: this.saveBin
      })), React__default.createElement(PivotItem, {
        headerText: localization.accuracyMetric,
        itemKey: accuracyTabKey$1,
        style: {
          height: "100%",
          paddingLeft: "8px"
        }
      }, React__default.createElement(AccuracyTab$1, {
        dashboardContext: this.state.dashboardContext,
        accuracyPickerProps: accuracyPickerProps,
        onNext: this.setTab.bind(this,  disparityTabKey$1),
        onPrevious: this.setTab.bind(this, featureBinTabKey$1)
      })),  React__default.createElement(PivotItem, {
        headerText: localization.disparityMetric,
        itemKey: disparityTabKey$1,
        style: {
          height: "100%",
          paddingLeft: "8px"
        }
      }, React__default.createElement(ParityTab$1, {
        dashboardContext: this.state.dashboardContext,
        parityPickerProps: parityPickerProps,
        onNext: this.setTab.bind(this, reportTabKey$1),
        onPrevious: this.setTab.bind(this, accuracyTabKey$1)
      })))), this.state.activeTabKey === reportTabKey$1 && this.state.selectedModelId !== undefined && React__default.createElement(WizardReport$1, {
        showIntro: this.state.showIntro,
        dashboardContext: this.state.dashboardContext,
        metricsCache: this.state.metricCache,
        modelCount: this.props.predictedY.length,
        accuracyPickerProps: accuracyPickerProps,
        onChartClick: this.onSelectModel,
        parityPickerProps: parityPickerProps,
        featureBinPickerProps: featureBinPickerProps,
        selectedModelIndex: this.state.selectedModelId,
        onHideIntro: this.hideIntro.bind(this),
        onEditConfigs: this.setTab.bind(this, featureBinTabKey$1)
      }), this.state.activeTabKey === reportTabKey$1 && this.state.selectedModelId === undefined && React__default.createElement(ModelComparisonChart$1, {
        showIntro: this.state.showIntro,
        dashboardContext: this.state.dashboardContext,
        metricsCache: this.state.metricCache,
        onChartClick: this.onSelectModel,
        modelCount: this.props.predictedY.length,
        accuracyPickerProps: accuracyPickerProps,
        parityPickerProps: parityPickerProps,
        featureBinPickerProps: featureBinPickerProps,
        onHideIntro: this.hideIntro.bind(this),
        onEditConfigs: this.setTab.bind(this, featureBinTabKey$1)
      }));
    }
  }, {
    key: "getAccuracyMetrics",
    value: function getAccuracyMetrics(fairnessContext) {
      if (fairnessContext.modelMetadata.PredictionType === PredictionTypes.binaryClassification) {
        return this.props.supportedBinaryClassificationAccuracyKeys.map(function (key) {
          return AccuracyOptions[key];
        });
      }

      if (fairnessContext.modelMetadata.PredictionType === PredictionTypes.regression) {
        return this.props.supportedRegressionAccuracyKeys.map(function (key) {
          return AccuracyOptions[key];
        });
      }

      return this.props.supportedProbabilityAccuracyKeys.map(function (key) {
        return AccuracyOptions[key];
      });
    }
  }]);

  return FairnessWizardV2;
}(React__default.PureComponent);

export { FairnessWizardV1, FairnessWizardV2, PredictionTypes };
